@@ -1,5 +1,5 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* vim:expandtab:shiftwidth=2:tabstop=2: */
+/* vim: set ts=2 et sw=2 tw=80: */
 /* ***** BEGIN LICENSE BLOCK *****
  * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
@@ -73,13 +73,8 @@ doActionCB(AtkAction *aAction, gint aActionIndex)
 gint
 getActionCountCB(AtkAction *aAction)
 {
-    nsAccessibleWrap *accWrap = GetAccessibleWrap(ATK_OBJECT(aAction));
-    if (!accWrap)
-        return 0;
-
-    PRUint8 num = 0;
-    nsresult rv = accWrap->GetNumActions(&num);
-    return (NS_FAILED(rv)) ? 0 : static_cast<gint>(num);
+  nsAccessibleWrap* accWrap = GetAccessibleWrap(ATK_OBJECT(aAction));
+  return accWrap ? accWrap->ActionCount() : 0;
 }
 
 const gchar *
@@ -111,97 +106,53 @@ getActionNameCB(AtkAction *aAction, gint aActionIndex)
 const gchar *
 getKeyBindingCB(AtkAction *aAction, gint aActionIndex)
 {
-    nsAccessibleWrap *accWrap = GetAccessibleWrap(ATK_OBJECT(aAction));
-    if (!accWrap)
-        return nsnull;
+  nsAccessibleWrap* acc = GetAccessibleWrap(ATK_OBJECT(aAction));
+  if (!acc)
+    return nsnull;
 
-    //return all KeyBindings including accesskey and shortcut
-    nsAutoString allKeyBinding;
+  // Return all key bindings including access key and keyboard shortcut.
+  nsAutoString keyBindingsStr;
 
-    //get accesskey
-    nsAutoString accessKey;
-    nsresult rv = accWrap->GetKeyboardShortcut(accessKey);
+  // Get access key.
+  KeyBinding keyBinding = acc->AccessKey();
+  if (!keyBinding.IsEmpty()) {
+    keyBinding.AppendToString(keyBindingsStr, KeyBinding::eAtkFormat);
 
-    if (NS_SUCCEEDED(rv) && !accessKey.IsEmpty()) {
-        nsAccessible* parent = accWrap->GetParent();
-        if (parent) {
-          PRUint32 atkRole = atkRoleMap[parent->NativeRole()];
+    nsAccessible* parent = acc->Parent();
+    PRUint32 role = parent ? parent->Role() : 0;
+    if (role == nsIAccessibleRole::ROLE_PARENT_MENUITEM ||
+        role == nsIAccessibleRole::ROLE_MENUITEM ||
+        role == nsIAccessibleRole::ROLE_RADIO_MENU_ITEM ||
+        role == nsIAccessibleRole::ROLE_CHECK_MENU_ITEM) {
+      // It is submenu, expose keyboard shortcuts from menu hierarchy like
+      // "s;<Alt>f:s"
+      nsAutoString keysInHierarchyStr = keyBindingsStr;
+      do {
+        KeyBinding parentKeyBinding = parent->AccessKey();
+        if (!parentKeyBinding.IsEmpty()) {
+          nsAutoString str;
+          parentKeyBinding.ToString(str, KeyBinding::eAtkFormat);
+          str.Append(':');
 
-            if (atkRole == ATK_ROLE_MENU_BAR) {
-                //it is topmenu, change from "Alt+f" to "f;<Alt>f"
-                nsAutoString rightChar;
-                accessKey.Right(rightChar, 1);
-                allKeyBinding = rightChar + NS_LITERAL_STRING(";<Alt>") +
-                                rightChar;
-            }
-            else if ((atkRole == ATK_ROLE_MENU) || (atkRole == ATK_ROLE_MENU_ITEM)) {
-                //it is submenu, change from "s" to "s;<Alt>f:s"
-                nsAutoString allKey = accessKey;
-                nsAccessible* grandParent = parent;
-
-                do {
-                    nsAutoString grandParentKey;
-                    grandParent->GetKeyboardShortcut(grandParentKey);
-
-                    if (!grandParentKey.IsEmpty()) {
-                        nsAutoString rightChar;
-                        grandParentKey.Right(rightChar, 1);
-                        allKey = rightChar + NS_LITERAL_STRING(":") + allKey;
-                    }
-
-                } while ((grandParent = grandParent->GetParent()) &&
-                         atkRoleMap[grandParent->NativeRole()] != ATK_ROLE_MENU_BAR);
-
-                allKeyBinding = accessKey + NS_LITERAL_STRING(";<Alt>") +
-                                allKey;
-            }
-        }
-        else {
-            //default process, rarely happens.
-            nsAutoString rightChar;
-            accessKey.Right(rightChar, 1);
-            allKeyBinding = rightChar + NS_LITERAL_STRING(";<Alt>") + rightChar;
+          keysInHierarchyStr.Insert(str, 0);
         }
+      } while ((parent = parent->Parent()) &&
+               parent->Role() != nsIAccessibleRole::ROLE_MENUBAR);
+
+      keyBindingsStr.Append(';');
+      keyBindingsStr.Append(keysInHierarchyStr);
     }
-    else  //don't have accesskey
-        allKeyBinding.AssignLiteral(";");
+  } else {
+    // No access key, add ';' to point this.
+    keyBindingsStr.Append(';');
+  }
 
-    //get shortcut
-    nsAutoString subShortcut;
-    nsCOMPtr<nsIDOMDOMStringList> keyBindings;
-    rv = accWrap->GetKeyBindings(aActionIndex, getter_AddRefs(keyBindings));
+  // Get keyboard shortcut.
+  keyBindingsStr.Append(';');
+  keyBinding = acc->KeyboardShortcut();
+  if (!keyBinding.IsEmpty()) {
+    keyBinding.AppendToString(keyBindingsStr, KeyBinding::eAtkFormat);
+  }
 
-    if (NS_SUCCEEDED(rv) && keyBindings) {
-        PRUint32 length = 0;
-        keyBindings->GetLength(&length);
-        for (PRUint32 i = 0; i < length; i++) {
-            nsAutoString keyBinding;
-            keyBindings->Item(i, keyBinding);
-
-            //change the shortcut from "Ctrl+Shift+L" to "<Control><Shift>L"
-            PRInt32 oldPos, curPos=0;
-            while ((curPos != -1) && (curPos < (PRInt32)keyBinding.Length())) {
-                oldPos = curPos;
-                nsAutoString subString;
-                curPos = keyBinding.FindChar('+', oldPos);
-                if (curPos == -1) {
-                    keyBinding.Mid(subString, oldPos, keyBinding.Length() - oldPos);
-                    subShortcut += subString;
-                } else {
-                    keyBinding.Mid(subString, oldPos, curPos - oldPos);
-
-                    //change "Ctrl" to "Control"
-                    if (subString.LowerCaseEqualsLiteral("ctrl"))
-                        subString.AssignLiteral("Control");
-
-                    subShortcut += NS_LITERAL_STRING("<") + subString +
-                                   NS_LITERAL_STRING(">");
-                    curPos++;
-                }
-            }
-        }
-    }
-
-    allKeyBinding += NS_LITERAL_STRING(";") + subShortcut;
-    return nsAccessibleWrap::ReturnString(allKeyBinding);
+  return nsAccessibleWrap::ReturnString(keyBindingsStr);
 }
