@@ -61,6 +61,7 @@
 #include "nsIFrame.h"
 #include "nsINameSpaceManager.h"
 #include "nsITextControlFrame.h"
+#include "nsMenuPopupFrame.h"
 
 using namespace mozilla::a11y;
 
@@ -72,6 +73,8 @@ nsXULButtonAccessible::
   nsXULButtonAccessible(nsIContent *aContent, nsIWeakReference *aShell) :
   nsAccessibleWrap(aContent, aShell)
 {
+  if (ContainsMenu())
+    mFlags |= eMenuButtonAccessible;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -125,7 +128,7 @@ nsXULButtonAccessible::NativeState()
   // get focus and disable status from base class
   PRUint64 state = nsAccessible::NativeState();
 
-  PRBool disabled = PR_FALSE;
+  bool disabled = false;
   nsCOMPtr<nsIDOMXULControlElement> xulFormElement(do_QueryInterface(mContent));
   if (xulFormElement) {
     xulFormElement->GetDisabled(&disabled);
@@ -142,7 +145,7 @@ nsXULButtonAccessible::NativeState()
     xulButtonElement->GetType(type);
     if (type.EqualsLiteral("checkbox") || type.EqualsLiteral("radio")) {
       state |= states::CHECKABLE;
-      PRBool checked = PR_FALSE;
+      bool checked = false;
       PRInt32 checkState = 0;
       xulButtonElement->GetChecked(&checked);
       if (checked) {
@@ -164,6 +167,42 @@ nsXULButtonAccessible::NativeState()
   return state;
 }
 
+////////////////////////////////////////////////////////////////////////////////
+// nsXULButtonAccessible: Widgets
+
+bool
+nsXULButtonAccessible::IsWidget() const
+{
+  return true;
+}
+
+bool
+nsXULButtonAccessible::IsActiveWidget() const
+{
+  return FocusMgr()->HasDOMFocus(mContent);
+}
+
+bool
+nsXULButtonAccessible::AreItemsOperable() const
+{
+  if (IsMenuButton()) {
+    nsAccessible* menuPopup = mChildren.SafeElementAt(0, nsnull);
+    if (menuPopup) {
+      nsMenuPopupFrame* menuPopupFrame = do_QueryFrame(menuPopup->GetFrame());
+      return menuPopupFrame->IsOpen();
+    }
+  }
+  return false; // no items
+}
+
+nsAccessible*
+nsXULButtonAccessible::ContainerWidget() const
+{
+  if (IsMenuButton() && mParent && mParent->IsAutoComplete())
+    return mParent;
+  return nsnull;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // nsXULButtonAccessible: nsAccessible protected
 
@@ -176,13 +215,13 @@ nsXULButtonAccessible::CacheChildren()
 
   // XXX: no children until the button is menu button. Probably it's not
   // totally correct but in general AT wants to have leaf buttons.
-  PRBool isMenu = mContent->AttrValueIs(kNameSpaceID_None,
+  bool isMenu = mContent->AttrValueIs(kNameSpaceID_None,
                                        nsGkAtoms::type,
                                        nsGkAtoms::menu,
                                        eCaseMatters);
 
-  PRBool isMenuButton = isMenu ?
-    PR_FALSE :
+  bool isMenuButton = isMenu ?
+    false :
     mContent->AttrValueIs(kNameSpaceID_None, nsGkAtoms::type,
                           nsGkAtoms::menuButton, eCaseMatters);
 
@@ -192,7 +231,7 @@ nsXULButtonAccessible::CacheChildren()
   nsAccessible* menupopup = nsnull;
   nsAccessible* button = nsnull;
 
-  nsAccTreeWalker walker(mWeakShell, mContent, PR_TRUE);
+  nsAccTreeWalker walker(mWeakShell, mContent, true);
 
   nsAccessible* child = nsnull;
   while ((child = walker.NextChild())) {
@@ -225,7 +264,7 @@ nsXULButtonAccessible::CacheChildren()
 ////////////////////////////////////////////////////////////////////////////////
 // nsXULButtonAccessible protected
 
-PRBool
+bool
 nsXULButtonAccessible::ContainsMenu()
 {
   static nsIContent::AttrValuesArray strings[] =
@@ -252,9 +291,9 @@ nsXULDropmarkerAccessible::ActionCount()
   return 1;
 }
 
-PRBool nsXULDropmarkerAccessible::DropmarkerOpen(PRBool aToggleOpen)
+bool nsXULDropmarkerAccessible::DropmarkerOpen(bool aToggleOpen)
 {
-  PRBool isOpen = PR_FALSE;
+  bool isOpen = false;
 
   nsCOMPtr<nsIDOMXULButtonElement> parentButtonElement =
     do_QueryInterface(mContent->GetParent());
@@ -283,7 +322,7 @@ PRBool nsXULDropmarkerAccessible::DropmarkerOpen(PRBool aToggleOpen)
 NS_IMETHODIMP nsXULDropmarkerAccessible::GetActionName(PRUint8 aIndex, nsAString& aName)
 {
   if (aIndex == eAction_Click) {
-    if (DropmarkerOpen(PR_FALSE))
+    if (DropmarkerOpen(false))
       aName.AssignLiteral("close");
     else
       aName.AssignLiteral("open");
@@ -299,7 +338,7 @@ NS_IMETHODIMP nsXULDropmarkerAccessible::GetActionName(PRUint8 aIndex, nsAString
 NS_IMETHODIMP nsXULDropmarkerAccessible::DoAction(PRUint8 index)
 {
   if (index == eAction_Click) {
-    DropmarkerOpen(PR_TRUE); // Reverse the open attribute
+    DropmarkerOpen(true); // Reverse the open attribute
     return NS_OK;
   }
   return NS_ERROR_INVALID_ARG;
@@ -314,7 +353,7 @@ nsXULDropmarkerAccessible::NativeRole()
 PRUint64
 nsXULDropmarkerAccessible::NativeState()
 {
-  return DropmarkerOpen(PR_FALSE) ? states::PRESSED : 0;
+  return DropmarkerOpen(false) ? states::PRESSED : 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -383,7 +422,7 @@ nsXULCheckboxAccessible::NativeState()
   nsCOMPtr<nsIDOMXULCheckboxElement> xulCheckboxElement =
     do_QueryInterface(mContent);
   if (xulCheckboxElement) {
-    PRBool checked = PR_FALSE;
+    bool checked = false;
     xulCheckboxElement->GetChecked(&checked);
     if (checked) {
       state |= states::CHECKED;
@@ -464,19 +503,19 @@ nsXULRadioButtonAccessible::
 {
 }
 
-/** We are Focusable and can be Checked and focused */
 PRUint64
 nsXULRadioButtonAccessible::NativeState()
 {
   PRUint64 state = nsFormControlAccessible::NativeState();
-
   state |= states::CHECKABLE;
-  
-  PRBool selected = PR_FALSE;   // Radio buttons can be selected
+
+  if (!(state & states::UNAVAILABLE))
+    state |= states::FOCUSABLE;
 
   nsCOMPtr<nsIDOMXULSelectControlItemElement> radioButton =
     do_QueryInterface(mContent);
   if (radioButton) {
+    bool selected = false;   // Radio buttons can be selected
     radioButton->GetSelected(&selected);
     if (selected) {
       state |= states::CHECKED;
@@ -494,6 +533,15 @@ nsXULRadioButtonAccessible::GetPositionAndSizeInternal(PRInt32 *aPosInSet,
                                                         aSetSize);
 }
 
+////////////////////////////////////////////////////////////////////////////////
+// nsXULRadioButtonAccessible: Widgets
+
+nsAccessible*
+nsXULRadioButtonAccessible::ContainerWidget() const
+{
+  return mParent;
+}
+
 
 ////////////////////////////////////////////////////////////////////////////////
 // nsXULRadioGroupAccessible
@@ -529,7 +577,28 @@ nsXULRadioGroupAccessible::NativeState()
   return nsAccessible::NativeState() & ~(states::FOCUSABLE | states::FOCUSED);
 }
 
-                      
+////////////////////////////////////////////////////////////////////////////////
+// nsXULRadioGroupAccessible: Widgets
+
+bool
+nsXULRadioGroupAccessible::IsWidget() const
+{
+  return true;
+}
+
+bool
+nsXULRadioGroupAccessible::IsActiveWidget() const
+{
+  return FocusMgr()->HasDOMFocus(mContent);
+}
+
+bool
+nsXULRadioGroupAccessible::AreItemsOperable() const
+{
+  return true;
+}
+
+
 ////////////////////////////////////////////////////////////////////////////////
 // nsXULStatusBarAccessible
 ////////////////////////////////////////////////////////////////////////////////
@@ -589,7 +658,7 @@ nsXULToolbarButtonAccessible::GetPositionAndSizeInternal(PRInt32 *aPosInSet,
   *aSetSize = setSize;
 }
 
-PRBool
+bool
 nsXULToolbarButtonAccessible::IsSeparator(nsAccessible *aAccessible)
 {
   nsCOMPtr<nsIDOMNode> domNode;
@@ -597,7 +666,7 @@ nsXULToolbarButtonAccessible::IsSeparator(nsAccessible *aAccessible)
   nsCOMPtr<nsIContent> contentDomNode(do_QueryInterface(domNode));
 
   if (!contentDomNode)
-    return PR_FALSE;
+    return false;
 
   return (contentDomNode->Tag() == nsGkAtoms::toolbarseparator) ||
          (contentDomNode->Tag() == nsGkAtoms::toolbarspacer) ||
@@ -719,9 +788,6 @@ nsXULTextFieldAccessible::NativeState()
 
   state |= tempAccessible->NativeState();
 
-  if (gLastFocusedNode == mContent)
-    state |= states::FOCUSED;
-
   nsCOMPtr<nsIDOMXULMenuListElement> menuList(do_QueryInterface(mContent));
   if (menuList) {
     // <xul:menulist droppable="false">
@@ -782,10 +848,10 @@ NS_IMETHODIMP nsXULTextFieldAccessible::DoAction(PRUint8 index)
   return NS_ERROR_INVALID_ARG;
 }
 
-PRBool
+bool
 nsXULTextFieldAccessible::GetAllowsAnonChildAccessibles()
 {
-  return PR_FALSE;
+  return false;
 }
 
 NS_IMETHODIMP nsXULTextFieldAccessible::GetAssociatedEditor(nsIEditor **aEditor)
@@ -810,12 +876,23 @@ nsXULTextFieldAccessible::CacheChildren()
   if (!inputContent)
     return;
 
-  nsAccTreeWalker walker(mWeakShell, inputContent, PR_FALSE);
+  nsAccTreeWalker walker(mWeakShell, inputContent, false);
 
   nsAccessible* child = nsnull;
   while ((child = walker.NextChild()) && AppendChild(child));
 }
 
+////////////////////////////////////////////////////////////////////////////////
+// nsXULTextFieldAccessible: nsHyperTextAccessible protected
+
+already_AddRefed<nsFrameSelection>
+nsXULTextFieldAccessible::FrameSelection()
+{
+  nsCOMPtr<nsIContent> inputContent(GetInputField());
+  nsIFrame* frame = inputContent->GetPrimaryFrame();
+  return frame ? frame->GetFrameSelection() : nsnull;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // nsXULTextFieldAccessible protected
 
