@@ -39,6 +39,8 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
+#include "mozilla/Util.h"
+
 #include <stdio.h>
 #include <string.h>
 #include <windows.h>
@@ -109,6 +111,8 @@
 #define REGISTRY_IE_SEARCHURL_KEY \
   NS_LITERAL_STRING("Software\\Microsoft\\Internet Explorer\\SearchUrl")
 
+using namespace mozilla;
+
 const int sInitialCookieBufferSize = 1024; // but it can grow
 const int sUsernameLengthLimit     = 80;
 const int sHostnameLengthLimit     = 255;
@@ -240,14 +244,14 @@ TranslateLanglist(nsIWindowsRegKey *aRegKey, const nsString& aRegValueName,
                *sourceEnd = source + langCstr.Length();
   char   *dest = prefStringValue,
          *destEnd = dest + (MAX_PATH-2); // room for " \0"
-  PRBool  skip = PR_FALSE,
-          comma = PR_FALSE;
+  bool    skip = false,
+          comma = false;
 
   while (source < sourceEnd && *source && dest < destEnd) {
     if (*source == ',')
-      skip = PR_FALSE;
+      skip = false;
     else if (*source == ';')
-      skip = PR_TRUE;
+      skip = true;
     if (!skip) {
       if (comma && *source != ' ')
         *dest++ = ' ';
@@ -418,10 +422,10 @@ nsIEProfileMigrator::Migrate(PRUint16 aItems, nsIProfileStartup* aStartup, const
 {
   nsresult rv = NS_OK;
 
-  PRBool aReplace = PR_FALSE;
+  bool aReplace = false;
 
   if (aStartup) {
-    aReplace = PR_TRUE;
+    aReplace = true;
     rv = aStartup->DoStartup();
     NS_ENSURE_SUCCESS(rv, rv);
   }
@@ -442,7 +446,7 @@ nsIEProfileMigrator::Migrate(PRUint16 aItems, nsIProfileStartup* aStartup, const
 
 NS_IMETHODIMP
 nsIEProfileMigrator::GetMigrateData(const PRUnichar* aProfile, 
-                                    PRBool aReplace,
+                                    bool aReplace,
                                     PRUint16* aResult)
 {
   if (TestForIE7()) {
@@ -466,18 +470,18 @@ nsIEProfileMigrator::GetMigrateData(const PRUnichar* aProfile,
 }
 
 NS_IMETHODIMP
-nsIEProfileMigrator::GetSourceExists(PRBool* aResult)
+nsIEProfileMigrator::GetSourceExists(bool* aResult)
 {
   // IE always exists. 
-  *aResult = PR_TRUE;
+  *aResult = true;
 
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsIEProfileMigrator::GetSourceHasMultipleProfiles(PRBool* aResult)
+nsIEProfileMigrator::GetSourceHasMultipleProfiles(bool* aResult)
 {
-  *aResult = PR_FALSE;
+  *aResult = false;
   return NS_OK;
 }
 
@@ -563,39 +567,39 @@ nsIEProfileMigrator::~nsIEProfileMigrator()
 
 // Test used in detecting Internet Explorer 7 prior to presenting
 // import options.
-PRBool 
+bool 
 nsIEProfileMigrator::TestForIE7()
 {
   nsCOMPtr<nsIWindowsRegKey> regKey =  
     do_CreateInstance("@mozilla.org/windows-registry-key;1"); 
   if (!regKey)  
-    return PR_FALSE;  
+    return false;  
 
   NS_NAMED_LITERAL_STRING(key,
       "Applications\\iexplore.exe\\shell\\open\\command");
   if (NS_FAILED(regKey->Open(nsIWindowsRegKey::ROOT_KEY_CLASSES_ROOT,
                              key, nsIWindowsRegKey::ACCESS_QUERY_VALUE)))
-    return PR_FALSE;
+    return false;
 
   nsAutoString iePath;
   if (NS_FAILED(regKey->ReadStringValue(EmptyString(), iePath)))
-    return PR_FALSE; 
+    return false; 
 
   // Replace embedded environment variables. 
   PRUint32 bufLength =  
     ::ExpandEnvironmentStringsW(iePath.get(), 
                                L"", 0); 
   if (bufLength == 0) // Error 
-    return PR_FALSE; 
+    return false; 
 
   nsAutoArrayPtr<PRUnichar> destination(new PRUnichar[bufLength]); 
   if (!destination) 
-    return PR_FALSE; 
+    return false; 
 
   if (!::ExpandEnvironmentStringsW(iePath.get(), 
                                    destination, 
                                    bufLength)) 
-    return PR_FALSE; 
+    return false; 
 
   iePath = destination; 
 
@@ -607,27 +611,27 @@ nsIEProfileMigrator::TestForIE7()
   }
 
   nsCOMPtr<nsILocalFile> lf; 
-  NS_NewLocalFile(iePath, PR_TRUE, getter_AddRefs(lf)); 
+  NS_NewLocalFile(iePath, true, getter_AddRefs(lf)); 
 
   nsCOMPtr<nsILocalFileWin> lfw = do_QueryInterface(lf); 
   if (!lfw)
-   return PR_FALSE;
+   return false;
    
   nsAutoString ieVersion;
   if (NS_FAILED(lfw->GetVersionInfoField("FileVersion", ieVersion)))
-   return PR_FALSE;
+   return false;
 
   if (ieVersion.Length() > 2) {
     PRUint32 index = ieVersion.FindChar('.', 0);
     if (index < 0)
-      return PR_FALSE;
+      return false;
     ieVersion.Cut(index, ieVersion.Length());
     PRInt32 ver = wcstol(ieVersion.get(), nsnull, 0);
     if (ver >= 7) // Found 7 or greater major version
-      return PR_TRUE;
+      return true;
   }
 
-  return PR_FALSE;
+  return false;
 }
 
 NS_IMETHODIMP
@@ -641,16 +645,16 @@ nsIEProfileMigrator::RunBatched(nsISupports* aUserData)
 
   switch (batchAction) {
     case BATCH_ACTION_HISTORY:
-      rv = CopyHistoryBatched(PR_FALSE);
+      rv = CopyHistoryBatched(false);
       break;
     case BATCH_ACTION_HISTORY_REPLACE:
-      rv = CopyHistoryBatched(PR_TRUE);
+      rv = CopyHistoryBatched(true);
       break;
     case BATCH_ACTION_BOOKMARKS:
-      rv = CopyFavoritesBatched(PR_FALSE);
+      rv = CopyFavoritesBatched(false);
       break;
     case BATCH_ACTION_BOOKMARKS_REPLACE:
-      rv = CopyFavoritesBatched(PR_TRUE);
+      rv = CopyFavoritesBatched(true);
       break;
   }
   NS_ENSURE_SUCCESS(rv, rv);
@@ -659,7 +663,7 @@ nsIEProfileMigrator::RunBatched(nsISupports* aUserData)
 }
 
 nsresult
-nsIEProfileMigrator::CopyHistory(PRBool aReplace)
+nsIEProfileMigrator::CopyHistory(bool aReplace)
 {
   nsresult rv;
   nsCOMPtr<nsINavHistoryService> history =
@@ -681,7 +685,7 @@ nsIEProfileMigrator::CopyHistory(PRBool aReplace)
 }
 
 nsresult
-nsIEProfileMigrator::CopyHistoryBatched(PRBool aReplace)
+nsIEProfileMigrator::CopyHistoryBatched(bool aReplace)
 {
   nsCOMPtr<nsIBrowserHistory> hist(do_GetService(NS_GLOBALHISTORY2_CONTRACTID));
   nsCOMPtr<nsIIOService> ios(do_GetService(NS_IOSERVICE_CONTRACTID));
@@ -704,7 +708,7 @@ nsIEProfileMigrator::CopyHistoryBatched(PRBool aReplace)
       _bstr_t url;
       nsCAutoString scheme;
       SYSTEMTIME st;
-      PRBool validScheme = PR_FALSE;
+      bool validScheme = false;
       PRUnichar* tempTitle = nsnull;
 
       for (int count = 0; (hr = enumURLs->Next(1, &statURL, &fetched)) == S_OK; ++count) {
@@ -927,7 +931,7 @@ static GUID IEPStoreSiteAuthGUID = { 0x5e7e8100, 0x9138, 0x11d1, { 0x94, 0x5a, 0
 //
 
 nsresult
-nsIEProfileMigrator::CopyPasswords(PRBool aReplace)
+nsIEProfileMigrator::CopyPasswords(bool aReplace)
 {
   HRESULT hr;
   nsresult rv;
@@ -1089,7 +1093,7 @@ nsIEProfileMigrator::GetSignonsListFromPStore(IPStore* aPStore, nsTArray<SignonD
   return NS_OK;
 }
 
-PRBool
+bool
 nsIEProfileMigrator::KeyIsURI(const nsAString& aKey, char** aRealm)
 {
   *aRealm = nsnull;
@@ -1097,9 +1101,9 @@ nsIEProfileMigrator::KeyIsURI(const nsAString& aKey, char** aRealm)
   nsCOMPtr<nsIURI> uri;
 
   if (NS_FAILED(NS_NewURI(getter_AddRefs(uri), aKey))) 
-    return PR_FALSE;
+    return false;
 
-  PRBool validScheme = PR_FALSE;
+  bool validScheme = false;
   const char* schemes[] = { "http", "https" };
   for (int i = 0; i < 2; ++i) {
     uri->SchemeIs(schemes[i], &validScheme);
@@ -1116,7 +1120,7 @@ nsIEProfileMigrator::KeyIsURI(const nsAString& aKey, char** aRealm)
       return validScheme;
     }
   }
-  return PR_FALSE;
+  return false;
 }
 
 nsresult
@@ -1252,7 +1256,7 @@ nsIEProfileMigrator::GetUserNameAndPass(unsigned char* data, unsigned long len,
 // "Quite Easily Done". ;-)
 // 
 nsresult
-nsIEProfileMigrator::CopyFormData(PRBool aReplace)
+nsIEProfileMigrator::CopyFormData(bool aReplace)
 {
   HRESULT hr;
 
@@ -1328,15 +1332,15 @@ nsIEProfileMigrator::AddDataToFormHistory(const nsAString& aKey, PRUnichar* aDat
 // search keywords
 //
 nsresult
-nsIEProfileMigrator::CopyFavorites(PRBool aReplace)
+nsIEProfileMigrator::CopyFavorites(bool aReplace)
 {
   nsresult rv;
   nsCOMPtr<nsINavBookmarksService> bookmarks =
     do_GetService(NS_NAVBOOKMARKSSERVICE_CONTRACTID, &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  PRBool batchAction = aReplace ? BATCH_ACTION_BOOKMARKS_REPLACE
-                                : BATCH_ACTION_BOOKMARKS;
+  PRUint8 batchAction = aReplace ? BATCH_ACTION_BOOKMARKS_REPLACE
+                                 : BATCH_ACTION_BOOKMARKS;
   nsCOMPtr<nsISupportsPRUint8> supports =
     do_CreateInstance(NS_SUPPORTS_PRUINT8_CONTRACTID);
   NS_ENSURE_TRUE(supports, NS_ERROR_OUT_OF_MEMORY);
@@ -1350,7 +1354,7 @@ nsIEProfileMigrator::CopyFavorites(PRBool aReplace)
 }
 
 nsresult
-nsIEProfileMigrator::CopyFavoritesBatched(PRBool aReplace)
+nsIEProfileMigrator::CopyFavoritesBatched(bool aReplace)
 {
   // If "aReplace" is true, merge into the root level of bookmarks. Otherwise,
   // create a folder called "Imported IE Favorites" and place all the Bookmarks
@@ -1431,7 +1435,7 @@ nsIEProfileMigrator::CopyFavoritesBatched(PRBool aReplace)
   // Only try to read Favorites folder if it exists on the machine.
   if (favoritesDirectory) {
     rv = ParseFavoritesFolder(favoritesDirectory, folder, bms,
-                              personalToolbarFolderName, PR_TRUE);
+                              personalToolbarFolderName, true);
     NS_ENSURE_SUCCESS(rv, rv);
   }
 
@@ -1548,7 +1552,7 @@ nsIEProfileMigrator::ParseFavoritesFolder(nsIFile* aDirectory,
                                           PRInt64 aParentFolder,
                                           nsINavBookmarksService* aBMS,
                                           const nsAString& aPersonalToolbarFolderName,
-                                          PRBool aIsAtRootLevel)
+                                          bool aIsAtRootLevel)
 {
   nsresult rv;
 
@@ -1557,7 +1561,7 @@ nsIEProfileMigrator::ParseFavoritesFolder(nsIFile* aDirectory,
   NS_ENSURE_SUCCESS(rv, rv);
 
   do {
-    PRBool hasMore = PR_FALSE;
+    bool hasMore = false;
     rv = entries->HasMoreElements(&hasMore);
     if (NS_FAILED(rv) || !hasMore) break;
 
@@ -1574,8 +1578,8 @@ nsIEProfileMigrator::ParseFavoritesFolder(nsIFile* aDirectory,
     nsAutoString bookmarkName;
     currFile->GetLeafName(bookmarkName);
 
-    PRBool isSymlink = PR_FALSE;
-    PRBool isDir = PR_FALSE;
+    bool isSymlink = false;
+    bool isDir = false;
 
     currFile->IsSymlink(&isSymlink);
     currFile->IsDirectory(&isDir);
@@ -1591,7 +1595,7 @@ nsIEProfileMigrator::ParseFavoritesFolder(nsIFile* aDirectory,
       if (NS_FAILED(rv)) continue;
 
       nsCOMPtr<nsILocalFile> localFile;
-      rv = NS_NewLocalFile(path, PR_TRUE, getter_AddRefs(localFile));
+      rv = NS_NewLocalFile(path, true, getter_AddRefs(localFile));
       if (NS_FAILED(rv)) continue;
 
       // Check for dir here.  If path is not a dir, just continue with
@@ -1633,7 +1637,7 @@ nsIEProfileMigrator::ParseFavoritesFolder(nsIFile* aDirectory,
 
       rv = ParseFavoritesFolder(currFile, folderId,
                                 aBMS, aPersonalToolbarFolderName,
-                                PR_FALSE);
+                                false);
       if (NS_FAILED(rv)) continue;
     }
     else {
@@ -1669,11 +1673,11 @@ nsIEProfileMigrator::ParseFavoritesFolder(nsIFile* aDirectory,
 }
 
 nsresult
-nsIEProfileMigrator::CopyPreferences(PRBool aReplace) 
+nsIEProfileMigrator::CopyPreferences(bool aReplace) 
 {
-  PRBool          regKeyOpen = PR_FALSE;
+  bool            regKeyOpen = false;
   const regEntry  *entry,
-                  *endEntry = gRegEntries + NS_ARRAY_LENGTH(gRegEntries);
+                  *endEntry = ArrayEnd(gRegEntries);
                               
 
   nsCOMPtr<nsIPrefBranch> prefs;
@@ -1698,7 +1702,7 @@ nsIEProfileMigrator::CopyPreferences(PRBool aReplace)
     if (entry->regKeyName) {
       if (regKeyOpen) {
         regKey->Close();
-        regKeyOpen = PR_FALSE;
+        regKeyOpen = false;
       }
       regKeyOpen = NS_SUCCEEDED(regKey->
                                 Open(nsIWindowsRegKey::ROOT_KEY_CURRENT_USER,
@@ -1727,7 +1731,7 @@ nsIEProfileMigrator::CopyPreferences(PRBool aReplace)
 /* Fetch and translate the current user's cookies.
    Return true if successful. */
 nsresult
-nsIEProfileMigrator::CopyCookies(PRBool aReplace) 
+nsIEProfileMigrator::CopyCookies(bool aReplace) 
 {
   // IE cookies are stored in files named <username>@domain[n].txt
   // (in <username>'s Cookies folder. isn't the naming redundant?)
@@ -1788,7 +1792,7 @@ nsIEProfileMigrator::CopyCookies(PRBool aReplace)
 
   do { // for each file in the cookies directory
     // get the next file
-    PRBool moreFiles = PR_FALSE;
+    bool moreFiles = false;
     if (NS_FAILED(cookieFiles->HasMoreElements(&moreFiles)) || !moreFiles)
       break;
 
@@ -1923,13 +1927,13 @@ nsIEProfileMigrator::CopyCookiesFromBuffer(char *aBuffer,
 
     // delete any possible extant matching host cookie and
     // check if we're dealing with an IPv4/IPv6 hostname.
-    PRBool isIPAddress = PR_FALSE;
+    bool isIPAddress = false;
     if (hostCopy[0] == '.') {
       aCookieManager->Remove(nsDependentCString(hostCopy+1),
-                             stringName, stringPath, PR_FALSE);
+                             stringName, stringPath, false);
       PRNetAddr addr;
       if (PR_StringToNetAddr(hostCopy+1, &addr) == PR_SUCCESS)
-        isIPAddress = PR_TRUE;
+        isIPAddress = true;
     }
 
     nsresult onerv;
@@ -1939,8 +1943,8 @@ nsIEProfileMigrator::CopyCookiesFromBuffer(char *aBuffer,
                                 stringName,
                                 nsDependentCString(value),
                                 flagsValue & 0x1, // isSecure
-                                PR_FALSE, // isHttpOnly
-                                PR_FALSE, // isSession
+                                false, // isHttpOnly
+                                false, // isSession
                                 PRInt64(expirationDate));
     if (NS_FAILED(onerv)) {
       rv = onerv;
@@ -2011,7 +2015,7 @@ nsIEProfileMigrator::FileTimeToTimeT(const char *aLowDateIntString,
 /* Find the accessibility stylesheet if it exists and replace Mozilla's
    with it. Return true if we found and copied a stylesheet. */
 nsresult
-nsIEProfileMigrator::CopyStyleSheet(PRBool aReplace) 
+nsIEProfileMigrator::CopyStyleSheet(bool aReplace) 
 {
   nsresult rv = NS_OK; // return failure only if filecopy fails
 
@@ -2042,7 +2046,7 @@ nsIEProfileMigrator::CopyStyleSheet(PRBool aReplace)
       // point an nsIFile at it
       nsCOMPtr<nsILocalFile> tridentFile(do_CreateInstance(NS_LOCAL_FILE_CONTRACTID));
       if (tridentFile) {
-        PRBool exists;
+        bool exists;
 
         tridentFile->InitWithPath(tridentFilename);
         tridentFile->Exists(&exists);
@@ -2072,7 +2076,7 @@ nsIEProfileMigrator::GetUserStyleSheetFile(nsIFile **aUserFile)
   NS_GetSpecialDirectory(NS_APP_USER_CHROME_DIR, getter_AddRefs(userChrome));
 
   if (userChrome) {
-    PRBool exists;
+    bool exists;
     userChrome->Exists(&exists);
     if (!exists &&
         NS_FAILED(userChrome->Create(nsIFile::DIRECTORY_TYPE, 0755)))
@@ -2099,8 +2103,8 @@ nsIEProfileMigrator::CopySecurityPrefs(nsIPrefBranch* aPrefs)
     PRUint32 value;
     if (NS_SUCCEEDED(regKey->ReadIntValue(NS_LITERAL_STRING("SecureProtocols"),
                                           &value))) { 
-      aPrefs->SetBoolPref("security.enable_ssl3", (value >> 5) & PR_TRUE);
-      aPrefs->SetBoolPref("security.enable_tls",  (value >> 7) & PR_TRUE);
+      aPrefs->SetBoolPref("security.enable_ssl3", (value >> 5) & true);
+      aPrefs->SetBoolPref("security.enable_tls",  (value >> 7) & true);
     }
   }
 
@@ -2110,7 +2114,7 @@ nsIEProfileMigrator::CopySecurityPrefs(nsIPrefBranch* aPrefs)
 struct ProxyData {
   char*   prefix;
   PRInt32 prefixLength;
-  PRBool  proxyConfigured;
+  bool    proxyConfigured;
   char*   hostPref;
   char*   portPref;
 };
@@ -2156,24 +2160,24 @@ nsIEProfileMigrator::CopyProxyPreferences(nsIPrefBranch* aPrefs)
                      ReadStringValue(NS_LITERAL_STRING("ProxyServer"), buf))) {
 
       ProxyData data[] = {
-        { "ftp=",     4, PR_FALSE, "network.proxy.ftp",
+        { "ftp=",     4, false, "network.proxy.ftp",
           "network.proxy.ftp_port"    },
-        { "http=",    5, PR_FALSE, "network.proxy.http",
+        { "http=",    5, false, "network.proxy.http",
           "network.proxy.http_port"   },
-        { "https=",   6, PR_FALSE, "network.proxy.ssl",
+        { "https=",   6, false, "network.proxy.ssl",
           "network.proxy.ssl_port"    },
-        { "socks=",   6, PR_FALSE, "network.proxy.socks",
+        { "socks=",   6, false, "network.proxy.socks",
           "network.proxy.socks_port"  },
       };
 
       PRInt32 startIndex = 0, count = 0;
-      PRBool foundSpecificProxy = PR_FALSE;
-      for (PRUint32 i = 0; i < NS_ARRAY_LENGTH(data); ++i) {
+      bool foundSpecificProxy = false;
+      for (PRUint32 i = 0; i < ArrayLength(data); ++i) {
         PRInt32 offset = buf.Find(NS_ConvertASCIItoUTF16(data[i].prefix));
         if (offset >= 0) {
-          foundSpecificProxy = PR_TRUE;
+          foundSpecificProxy = true;
 
-          data[i].proxyConfigured = PR_TRUE;
+          data[i].proxyConfigured = true;
 
           startIndex = offset + data[i].prefixLength;
 
@@ -2191,9 +2195,9 @@ nsIEProfileMigrator::CopyProxyPreferences(nsIPrefBranch* aPrefs)
         // No proxy config for any specific type was found, assume 
         // the ProxyServer value is of the form host:port and that 
         // it applies to all protocols.
-        for (PRUint32 i = 0; i < NS_ARRAY_LENGTH(data); ++i)
+        for (PRUint32 i = 0; i < ArrayLength(data); ++i)
           SetProxyPref(buf, data[i].hostPref, data[i].portPref, aPrefs);
-        aPrefs->SetBoolPref("network.proxy.share_proxy_settings", PR_TRUE);
+        aPrefs->SetBoolPref("network.proxy.share_proxy_settings", true);
       }
     }
 
