@@ -62,7 +62,6 @@ const nsIURIFixup            = Components.interfaces.nsIURIFixup;
 const nsIWebNavigation       = Components.interfaces.nsIWebNavigation;
 const nsIWindowMediator      = Components.interfaces.nsIWindowMediator;
 const nsIWindowWatcher       = Components.interfaces.nsIWindowWatcher;
-const nsICategoryManager     = Components.interfaces.nsICategoryManager;
 const nsIWebNavigationInfo   = Components.interfaces.nsIWebNavigationInfo;
 const nsIBrowserSearchService = Components.interfaces.nsIBrowserSearchService;
 const nsICommandLineValidator = Components.interfaces.nsICommandLineValidator;
@@ -630,10 +629,6 @@ nsBrowserContentHandler.prototype = {
       var choice = prefb.getIntPref("browser.startup.page");
       if (choice == 1 || choice == 3)
         startPage = this.startPage;
-
-      if (choice == 2)
-        startPage = Components.classes["@mozilla.org/browser/global-history;2"]
-                              .getService(nsIBrowserHistory).lastPageVisited;
     } catch (e) {
       Components.utils.reportError(e);
     }
@@ -649,36 +644,13 @@ nsBrowserContentHandler.prototype = {
   },
 
   get startPage() {
-    var prefb = Components.classes["@mozilla.org/preferences-service;1"]
-                          .getService(nsIPrefBranch);
-
-    var uri = prefb.getComplexValue("browser.startup.homepage",
-                                    nsIPrefLocalizedString).data;
-
+    var uri = Services.prefs.getComplexValue("browser.startup.homepage",
+                                             nsIPrefLocalizedString).data;
     if (!uri) {
-      prefb.clearUserPref("browser.startup.homepage");
-      uri = prefb.getComplexValue("browser.startup.homepage",
-                                  nsIPrefLocalizedString).data;
+      Services.prefs.clearUserPref("browser.startup.homepage");
+      uri = Services.prefs.getComplexValue("browser.startup.homepage",
+                                           nsIPrefLocalizedString).data;
     }
-                                
-    var count;
-    try {
-      count = prefb.getIntPref("browser.startup.homepage.count");
-    }
-    catch (e) {
-      return uri;
-    }
-
-    for (var i = 1; i < count; ++i) {
-      try {
-        var page = prefb.getComplexValue("browser.startup.homepage." + i,
-                                         nsIPrefLocalizedString).data;
-        uri += "\n" + page;
-      }
-      catch (e) {
-      }
-    }
-
     return uri;
   },
 
@@ -740,8 +712,6 @@ nsBrowserContentHandler.prototype = {
 };
 var gBrowserContentHandler = new nsBrowserContentHandler();
 
-const CONTRACTID_PREFIX = "@mozilla.org/uriloader/content-handler;1?type=";
-
 function handURIToExistingBrowser(uri, location, cmdLine)
 {
   if (!shouldLoadURI(uri))
