@@ -42,8 +42,6 @@ MOZ_UPDATER=1
 MOZ_PHOENIX=1
 
 MOZ_CHROME_FILE_FORMAT=omni
-# always enabled for form history
-MOZ_MORKREADER=1
 MOZ_SAFE_BROWSING=1
 MOZ_SERVICES_SYNC=1
 MOZ_APP_VERSION=$FIREFOX_VERSION
@@ -51,5 +49,5 @@ MOZ_EXTENSIONS_DEFAULT=" gnomevfs"
 # MOZ_APP_DISPLAYNAME will be set by branding/configure.sh
 # Changing either of these values requires a clobber to ensure correct results,
 # because branding dependencies are broken.
-MOZ_BRANDING_DIRECTORY=browser/branding/aurora
+MOZ_BRANDING_DIRECTORY=browser/branding/official
 MOZ_OFFICIAL_BRANDING_DIRECTORY=browser/branding/official
