@@ -59,12 +59,12 @@ Cu.import("resource://gre/modules/Services.jsm");
 Cu.import("resource://gre/modules/NetUtil.jsm");
 Cu.import("resource:///modules/PropertyPanel.jsm");
 Cu.import("resource:///modules/source-editor.jsm");
+Cu.import("resource:///modules/devtools/scratchpad-manager.jsm");
+
 
 const SCRATCHPAD_CONTEXT_CONTENT = 1;
 const SCRATCHPAD_CONTEXT_BROWSER = 2;
-const SCRATCHPAD_WINDOW_URL = "chrome://browser/content/scratchpad.xul";
-const SCRATCHPAD_L10N = "chrome://browser/locale/scratchpad.properties";
-const SCRATCHPAD_WINDOW_FEATURES = "chrome,titlebar,toolbar,centerscreen,resizable,dialog=no";
+const SCRATCHPAD_L10N = "chrome://browser/locale/devtools/scratchpad.properties";
 const DEVTOOLS_CHROME_ENABLED = "devtools.chrome.enabled";
 
 /**
@@ -84,10 +84,10 @@ var Scratchpad = {
   executionContext: SCRATCHPAD_CONTEXT_CONTENT,
 
   /**
-   * Retrieve the xul:statusbarpanel DOM element. The status bar tells the
-   * current code execution context.
+   * Retrieve the xul:notificationbox DOM element. It notifies the user when
+   * the current code execution context is SCRATCHPAD_CONTEXT_BROWSER.
    */
-  get statusbarStatus() document.getElementById("scratchpad-status"),
+  get notificationBox() document.getElementById("scratchpad-notificationbox"),
 
   /**
    * Get the selected text from the editor.
@@ -132,6 +132,55 @@ var Scratchpad = {
     this.editor.setText(aText, aStart, aEnd);
   },
 
+  /**
+   * Set the filename in the scratchpad UI and object
+   *
+   * @param string aFilename
+   *        The new filename
+   */
+  setFilename: function SP_setFilename(aFilename)
+  {
+    document.title = this.filename = aFilename;
+  },
+
+  /**
+   * Get the current state of the scratchpad. Called by the
+   * Scratchpad Manager for session storing.
+   *
+   * @return object
+   *        An object with 3 properties: filename, text, and
+   *        executionContext.
+   */
+  getState: function SP_getState()
+  {
+    return {
+      filename: this.filename,
+      text: this.getText(),
+      executionContext: this.executionContext
+    };
+  },
+
+  /**
+   * Set the filename and execution context using the given state. Called
+   * when scratchpad is being restored from a previous session.
+   *
+   * @param object aState
+   *        An object with filename and executionContext properties.
+   */
+  setState: function SP_getState(aState)
+  {
+    if (aState.filename) {
+      this.setFilename(aState.filename);
+    }
+
+    if (aState.executionContext == SCRATCHPAD_CONTEXT_BROWSER) {
+      this.setBrowserContext();
+    }
+    else {
+      this.setContentContext();
+    }
+  },
+
   /**
    * Get the most recent chrome window of type navigator:browser.
    */
@@ -264,7 +313,7 @@ var Scratchpad = {
    */
   evalInContentSandbox: function SP_evalInContentSandbox(aString)
   {
-    let result;
+    let error, result;
     try {
       result = Cu.evalInSandbox(aString, this.contentSandbox, "1.8",
                                 "Scratchpad", 1);
@@ -283,9 +332,11 @@ var Scratchpad = {
                                    this.getInnerWindowId(contentWindow));
 
       Services.console.logMessage(scriptError);
+
+      error = true;
     }
 
-    return result;
+    return [error, result];
   },
 
   /**
@@ -298,7 +349,7 @@ var Scratchpad = {
    */
   evalInChromeSandbox: function SP_evalInChromeSandbox(aString)
   {
-    let result;
+    let error, result;
     try {
       result = Cu.evalInSandbox(aString, this.chromeSandbox, "1.8",
                                 "Scratchpad", 1);
@@ -307,9 +358,11 @@ var Scratchpad = {
       Cu.reportError(ex);
       Cu.reportError(ex.stack);
       this.openErrorConsole();
+
+      error = true;
     }
 
-    return result;
+    return [error, result];
   },
 
   /**
@@ -335,9 +388,9 @@ var Scratchpad = {
   run: function SP_run()
   {
     let selection = this.selectedText || this.getText();
-    let result = this.evalForContext(selection);
+    let [error, result] = this.evalForContext(selection);
     this.deselect();
-    return [selection, result];
+    return [selection, error, result];
   },
 
   /**
@@ -347,9 +400,9 @@ var Scratchpad = {
    */
   inspect: function SP_inspect()
   {
-    let [selection, result] = this.run();
+    let [selection, error, result] = this.run();
 
-    if (result) {
+    if (!error) {
       this.openPropertyPanel(selection, result);
     }
   },
@@ -367,12 +420,12 @@ var Scratchpad = {
                          selection.end : // after selected text
                          this.editor.getCharCount(); // after text end
 
-    let [selectedText, result] = this.run();
-    if (!result) {
+    let [selectedText, error, result] = this.run();
+    if (error) {
       return;
     }
 
-    let newComment = "/*\n" + result.toString() + "\n*/";
+    let newComment = "/*\n" + result + "\n*/";
 
     this.setText(newComment, insertionPoint, insertionPoint);
 
@@ -410,14 +463,11 @@ var Scratchpad = {
         accesskey: this.strings.
                    GetStringFromName("propertyPanel.updateButton.accesskey"),
         oncommand: function () {
-          try {
-            let result = self.evalForContext(aEvalString);
+          let [error, result] = self.evalForContext(aEvalString);
 
-            if (result !== undefined) {
-              propPanel.treeView.data = result;
-            }
+          if (!error) {
+            propPanel.treeView.data = result;
           }
-          catch (ex) { }
         }
       });
     }
@@ -442,8 +492,7 @@ var Scratchpad = {
    */
   openScratchpad: function SP_openScratchpad()
   {
-    Services.ww.openWindow(null, SCRATCHPAD_WINDOW_URL, "_blank",
-                           SCRATCHPAD_WINDOW_FEATURES, null);
+    ScratchpadManager.openScratchpad();
   },
 
   /**
@@ -541,7 +590,7 @@ var Scratchpad = {
             Ci.nsIFilePicker.modeOpen);
     fp.defaultString = "";
     if (fp.show() != Ci.nsIFilePicker.returnCancel) {
-      document.title = this.filename = fp.file.path;
+      this.setFilename(fp.file.path);
       this.importFromFile(fp.file);
     }
   },
@@ -599,11 +648,15 @@ var Scratchpad = {
    */
   setContentContext: function SP_setContentContext()
   {
+    if (this.executionContext == SCRATCHPAD_CONTEXT_CONTENT) {
+      return;
+    }
+
     let content = document.getElementById("sp-menu-content");
     document.getElementById("sp-menu-browser").removeAttribute("checked");
     content.setAttribute("checked", true);
     this.executionContext = SCRATCHPAD_CONTEXT_CONTENT;
-    this.statusbarStatus.label = content.getAttribute("label");
+    this.notificationBox.removeAllNotifications(false);
     this.resetContext();
   },
 
@@ -612,11 +665,20 @@ var Scratchpad = {
    */
   setBrowserContext: function SP_setBrowserContext()
   {
+    if (this.executionContext == SCRATCHPAD_CONTEXT_BROWSER) {
+      return;
+    }
+
     let browser = document.getElementById("sp-menu-browser");
     document.getElementById("sp-menu-content").removeAttribute("checked");
     browser.setAttribute("checked", true);
     this.executionContext = SCRATCHPAD_CONTEXT_BROWSER;
-    this.statusbarStatus.label = browser.getAttribute("label");
+    this.notificationBox.appendNotification(
+      this.strings.GetStringFromName("browserContext.notification"),
+      SCRATCHPAD_CONTEXT_BROWSER,
+      null,
+      this.notificationBox.PRIORITY_WARNING_HIGH,
+      null);
     this.resetContext();
   },
 
@@ -657,17 +719,22 @@ var Scratchpad = {
       return;
     }
 
-    let chromeContextMenu = document.getElementById("sp-menu-browser");
-    let errorConsoleMenu = document.getElementById("sp-menu-errorConsole");
-    let errorConsoleCommand = document.getElementById("sp-cmd-errorConsole");
-    let chromeContextCommand = document.getElementById("sp-cmd-browserContext");
-
     let chrome = Services.prefs.getBoolPref(DEVTOOLS_CHROME_ENABLED);
     if (chrome) {
-      chromeContextMenu.removeAttribute("hidden");
-      errorConsoleMenu.removeAttribute("hidden");
-      errorConsoleCommand.removeAttribute("disabled");
+      let environmentMenu = document.getElementById("sp-environment-menu");
+      let errorConsoleCommand = document.getElementById("sp-cmd-errorConsole");
+      let chromeContextCommand = document.getElementById("sp-cmd-browserContext");
+      environmentMenu.removeAttribute("hidden");
       chromeContextCommand.removeAttribute("disabled");
+      errorConsoleCommand.removeAttribute("disabled");
+    }
+
+    let initialText = this.strings.GetStringFromName("scratchpadIntro");
+    if ("arguments" in window &&
+         window.arguments[0] instanceof Ci.nsIDialogParamBlock) {
+      let state = JSON.parse(window.arguments[0].GetString(0));
+      this.setState(state);
+      initialText = state.text;
     }
 
     this.editor = new SourceEditor();
@@ -675,7 +742,7 @@ var Scratchpad = {
     let config = {
       mode: SourceEditor.MODES.JAVASCRIPT,
       showLineNumbers: true,
-      placeholderText: this.strings.GetStringFromName("scratchpadIntro"),
+      placeholderText: initialText
     };
 
     let editorPlaceholder = document.getElementById("scratchpad-editor");
@@ -731,6 +798,8 @@ var Scratchpad = {
    */
   onEditPopupShowing: function SP_onEditPopupShowing()
   {
+    goUpdateGlobalEditMenuItems();
+
     let undo = document.getElementById("sp-cmd-undo");
     undo.setAttribute("disabled", !this.editor.canUndo());
 
