@@ -43,7 +43,6 @@
 #include "nsPresContext.h"
 #include "nsIPresShell.h"
 #include "nsISelection.h"
-#include "nsIDOMText.h"
 #include "nsIDOMRange.h"
 #include "nsRange.h"
 #include "nsGUIEvent.h"
@@ -59,7 +58,6 @@
 #include "nsISelectionPrivate.h"
 #include "nsContentUtils.h"
 #include "nsLayoutUtils.h"
-#include "nsISelection2.h"
 #include "nsIMEStateManager.h"
 #include "nsIObjectFrame.h"
 
@@ -127,11 +125,11 @@ nsContentEventHandler::Init(nsQueryContentEvent* aEvent)
   nsresult rv = InitCommon();
   NS_ENSURE_SUCCESS(rv, rv);
 
-  aEvent->mSucceeded = PR_FALSE;
+  aEvent->mSucceeded = false;
 
   aEvent->mReply.mContentsRoot = mRootContent.get();
 
-  PRBool isCollapsed;
+  bool isCollapsed;
   rv = mSelection->GetIsCollapsed(&isCollapsed);
   NS_ENSURE_SUCCESS(rv, NS_ERROR_NOT_AVAILABLE);
   aEvent->mReply.mHasSelection = !isCollapsed;
@@ -156,7 +154,7 @@ nsContentEventHandler::Init(nsSelectionEvent* aEvent)
   nsresult rv = InitCommon();
   NS_ENSURE_SUCCESS(rv, rv);
 
-  aEvent->mSucceeded = PR_FALSE;
+  aEvent->mSucceeded = false;
 
   return NS_OK;
 }
@@ -165,7 +163,7 @@ nsContentEventHandler::Init(nsSelectionEvent* aEvent)
 // have any text. This happens even for single line editors.
 // When we get text content and when we change the selection,
 // we don't want to include the bogus BRs at the end.
-static PRBool IsContentBR(nsIContent* aContent)
+static bool IsContentBR(nsIContent* aContent)
 {
   return aContent->IsHTML() &&
          aContent->Tag() == nsGkAtoms::br &&
@@ -188,15 +186,6 @@ static void ConvertToNativeNewlines(nsAFlatString& aString)
 #endif
 }
 
-static void ConvertToXPNewlines(nsAFlatString& aString)
-{
-#if defined(XP_MACOSX)
-  aString.ReplaceSubstring(NS_LITERAL_STRING("\r"), NS_LITERAL_STRING("\n"));
-#elif defined(XP_WIN)
-  aString.ReplaceSubstring(NS_LITERAL_STRING("\r\n"), NS_LITERAL_STRING("\n"));
-#endif
-}
-
 static void AppendString(nsAString& aString, nsIContent* aContent)
 {
   NS_ASSERTION(aContent->IsNodeOfType(nsINode::eTEXT),
@@ -218,28 +207,77 @@ static void AppendSubString(nsAString& aString, nsIContent* aContent,
   text->AppendTo(aString, PRInt32(aXPOffset), PRInt32(aXPLength));
 }
 
-static PRUint32 GetNativeTextLength(nsIContent* aContent)
+#if defined(XP_WIN)
+static PRUint32 CountNewlinesIn(nsIContent* aContent, PRUint32 aMaxOffset)
 {
-  nsAutoString str;
-  if (aContent->IsNodeOfType(nsINode::eTEXT))
-    AppendString(str, aContent);
-  else if (IsContentBR(aContent))
-    str.Assign(PRUnichar('\n'));
-  ConvertToNativeNewlines(str);
-  return str.Length();
+  NS_ASSERTION(aContent->IsNodeOfType(nsINode::eTEXT),
+               "aContent is not a text node!");
+  const nsTextFragment* text = aContent->GetText();
+  if (!text)
+    return 0;
+  if (aMaxOffset == PR_UINT32_MAX) {
+    // search the entire string
+    aMaxOffset = text->GetLength();
+  }
+  PRUint32 newlines = 0;
+  for (PRUint32 i = 0; i < aMaxOffset; ++i) {
+    if (text->CharAt(i) == '\n') {
+      ++newlines;
+    }
+  }
+  return newlines;
+}
+#endif
+
+static PRUint32 GetNativeTextLength(nsIContent* aContent, PRUint32 aMaxLength = PR_UINT32_MAX)
+{
+  if (aContent->IsNodeOfType(nsINode::eTEXT)) {
+    PRUint32 textLengthDifference =
+#if defined(XP_MACOSX)
+      // On Mac, the length of a native newline ("\r") is equal to the length of
+      // the XP newline ("\n"), so the native length is the same as the XP length.
+      0;
+#elif defined(XP_WIN)
+      // On Windows, the length of a native newline ("\r\n") is twice the length of
+      // the XP newline ("\n"), so XP length is equal to the length of the native
+      // offset plus the number of newlines encountered in the string.
+      CountNewlinesIn(aContent, aMaxLength);
+#else
+      // On other platforms, the native and XP newlines are the same.
+      0;
+#endif
+
+    const nsTextFragment* text = aContent->GetText();
+    if (!text)
+      return 0;
+    PRUint32 length = NS_MIN(text->GetLength(), aMaxLength);
+    return length + textLengthDifference;
+  } else if (IsContentBR(aContent)) {
+#if defined(XP_WIN)
+    // Length of \r\n
+    return 2;
+#else
+    return 1;
+#endif
+  }
+  return 0;
 }
 
 static PRUint32 ConvertToXPOffset(nsIContent* aContent, PRUint32 aNativeOffset)
 {
-
-  nsAutoString str;
-  AppendString(str, aContent);
-  ConvertToNativeNewlines(str);
-  NS_ASSERTION(aNativeOffset <= str.Length(),
-               "aOffsetForNativeLF is too large!");
-  str.Truncate(aNativeOffset);
-  ConvertToXPNewlines(str);
-  return str.Length();
+#if defined(XP_MACOSX)
+  // On Mac, the length of a native newline ("\r") is equal to the length of
+  // the XP newline ("\n"), so the native offset is the same as the XP offset.
+  return aNativeOffset;
+#elif defined(XP_WIN)
+  // On Windows, the length of a native newline ("\r\n") is twice the length of
+  // the XP newline ("\n"), so XP offset is equal to the length of the native
+  // offset minus the number of newlines encountered in the string.
+  return aNativeOffset - CountNewlinesIn(aContent, aNativeOffset);
+#else
+  // On other platforms, the native and XP newlines are the same.
+  return aNativeOffset;
+#endif
 }
 
 static nsresult GenerateFlatTextContent(nsIRange* aRange,
@@ -292,7 +330,7 @@ static nsresult GenerateFlatTextContent(nsIRange* aRange,
 
 nsresult
 nsContentEventHandler::ExpandToClusterBoundary(nsIContent* aContent,
-                                                    PRBool aForward,
+                                                    bool aForward,
                                                     PRUint32* aXPOffset)
 {
   // XXX This method assumes that the frame boundaries must be cluster
@@ -339,7 +377,7 @@ nsContentEventHandler::SetRangeFromFlatTextOffset(
                               nsIRange* aRange,
                               PRUint32 aNativeOffset,
                               PRUint32 aNativeLength,
-                              PRBool aExpandToClusterBoundaries)
+                              bool aExpandToClusterBoundaries)
 {
   nsCOMPtr<nsIContentIterator> iter;
   nsresult rv = NS_NewContentIterator(getter_AddRefs(iter));
@@ -374,7 +412,7 @@ nsContentEventHandler::SetRangeFromFlatTextOffset(
           ConvertToXPOffset(content, aNativeOffset - nativeOffset) : 0;
 
       if (aExpandToClusterBoundaries) {
-        rv = ExpandToClusterBoundary(content, PR_FALSE, &xpOffset);
+        rv = ExpandToClusterBoundary(content, false, &xpOffset);
         NS_ENSURE_SUCCESS(rv, rv);
       }
 
@@ -395,7 +433,7 @@ nsContentEventHandler::SetRangeFromFlatTextOffset(
       if (content->IsNodeOfType(nsINode::eTEXT)) {
         xpOffset = ConvertToXPOffset(content, nativeEndOffset - nativeOffset);
         if (aExpandToClusterBoundaries) {
-          rv = ExpandToClusterBoundary(content, PR_TRUE, &xpOffset);
+          rv = ExpandToClusterBoundary(content, true, &xpOffset);
           NS_ENSURE_SUCCESS(rv, rv);
         }
       } else {
@@ -470,7 +508,7 @@ nsContentEventHandler::OnQuerySelectedText(nsQueryContentEvent* aEvent)
     NS_ENSURE_SUCCESS(rv, rv);
   }
 
-  aEvent->mSucceeded = PR_TRUE;
+  aEvent->mSucceeded = true;
   return NS_OK;
 }
 
@@ -487,13 +525,13 @@ nsContentEventHandler::OnQueryTextContent(nsQueryContentEvent* aEvent)
   nsCOMPtr<nsIRange> range = new nsRange();
   NS_ENSURE_TRUE(range, NS_ERROR_OUT_OF_MEMORY);
   rv = SetRangeFromFlatTextOffset(range, aEvent->mInput.mOffset,
-                                  aEvent->mInput.mLength, PR_FALSE);
+                                  aEvent->mInput.mLength, false);
   NS_ENSURE_SUCCESS(rv, rv);
 
   rv = GenerateFlatTextContent(range, aEvent->mReply.mString);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  aEvent->mSucceeded = PR_TRUE;
+  aEvent->mSucceeded = true;
 
   return NS_OK;
 }
@@ -522,7 +560,7 @@ static nsINode* AdjustTextRectNode(nsINode* aNode,
 // but this is more flexible for OnQueryTextRect to use
 static nsresult GetFrameForTextRect(nsINode* aNode,
                                     PRInt32 aOffset,
-                                    PRBool aHint,
+                                    bool aHint,
                                     nsIFrame** aReturnFrame)
 {
   NS_ENSURE_TRUE(aNode && aNode->IsNodeOfType(nsINode::eCONTENT),
@@ -547,7 +585,7 @@ nsContentEventHandler::OnQueryTextRect(nsQueryContentEvent* aEvent)
     return NS_ERROR_OUT_OF_MEMORY;
   }
   rv = SetRangeFromFlatTextOffset(range, aEvent->mInput.mOffset,
-                                  aEvent->mInput.mLength, PR_TRUE);
+                                  aEvent->mInput.mLength, true);
   NS_ENSURE_SUCCESS(rv, rv);
 
   // used to iterate over all contents and their frames
@@ -564,7 +602,7 @@ nsContentEventHandler::OnQueryTextRect(nsQueryContentEvent* aEvent)
     node = AdjustTextRectNode(range->GetStartParent(), offset);
   }
   nsIFrame* firstFrame = nsnull;
-  rv = GetFrameForTextRect(node, offset, PR_TRUE, &firstFrame);
+  rv = GetFrameForTextRect(node, offset, true, &firstFrame);
   NS_ENSURE_SUCCESS(rv, rv);
 
   // get the starting frame rect
@@ -622,7 +660,7 @@ nsContentEventHandler::OnQueryTextRect(nsQueryContentEvent* aEvent)
   }
   aEvent->mReply.mRect =
       rect.ToOutsidePixels(mPresContext->AppUnitsPerDevPixel());
-  aEvent->mSucceeded = PR_TRUE;
+  aEvent->mSucceeded = true;
   return NS_OK;
 }
 
@@ -651,7 +689,7 @@ nsContentEventHandler::OnQueryEditorRect(nsQueryContentEvent* aEvent)
 
   aEvent->mReply.mRect =
       resultRect.ToOutsidePixels(mPresContext->AppUnitsPerDevPixel());
-  aEvent->mSucceeded = PR_TRUE;
+  aEvent->mSucceeded = true;
   return NS_OK;
 }
 
@@ -667,7 +705,7 @@ nsContentEventHandler::OnQueryCaretRect(nsQueryContentEvent* aEvent)
 
   // When the selection is collapsed and the queried offset is current caret
   // position, we should return the "real" caret rect.
-  PRBool selectionIsCollapsed;
+  bool selectionIsCollapsed;
   rv = mSelection->GetIsCollapsed(&selectionIsCollapsed);
   NS_ENSURE_SUCCESS(rv, rv);
 
@@ -684,7 +722,7 @@ nsContentEventHandler::OnQueryCaretRect(nsQueryContentEvent* aEvent)
       NS_ENSURE_SUCCESS(rv, rv);
       aEvent->mReply.mRect =
         rect.ToOutsidePixels(caretFrame->PresContext()->AppUnitsPerDevPixel());
-      aEvent->mSucceeded = PR_TRUE;
+      aEvent->mSucceeded = true;
       return NS_OK;
     }
   }
@@ -692,7 +730,7 @@ nsContentEventHandler::OnQueryCaretRect(nsQueryContentEvent* aEvent)
   // Otherwise, we should set the guessed caret rect.
   nsCOMPtr<nsIRange> range = new nsRange();
   NS_ENSURE_TRUE(range, NS_ERROR_OUT_OF_MEMORY);
-  rv = SetRangeFromFlatTextOffset(range, aEvent->mInput.mOffset, 0, PR_TRUE);
+  rv = SetRangeFromFlatTextOffset(range, aEvent->mInput.mOffset, 0, true);
   NS_ENSURE_SUCCESS(rv, rv);
 
   PRInt32 offsetInFrame;
@@ -715,7 +753,7 @@ nsContentEventHandler::OnQueryCaretRect(nsQueryContentEvent* aEvent)
 
   aEvent->mReply.mRect =
       rect.ToOutsidePixels(mPresContext->AppUnitsPerDevPixel());
-  aEvent->mSucceeded = PR_TRUE;
+  aEvent->mSucceeded = true;
   return NS_OK;
 }
 
@@ -726,7 +764,7 @@ nsContentEventHandler::OnQueryContentState(nsQueryContentEvent * aEvent)
   if (NS_FAILED(rv))
     return rv;
   
-  aEvent->mSucceeded = PR_TRUE;
+  aEvent->mSucceeded = true;
 
   return NS_OK;
 }
@@ -739,7 +777,7 @@ nsContentEventHandler::OnQuerySelectionAsTransferable(nsQueryContentEvent* aEven
     return rv;
 
   if (!aEvent->mReply.mHasSelection) {
-    aEvent->mSucceeded = PR_TRUE;
+    aEvent->mSucceeded = true;
     aEvent->mReply.mTransferable = nsnull;
     return NS_OK;
   }
@@ -750,7 +788,7 @@ nsContentEventHandler::OnQuerySelectionAsTransferable(nsQueryContentEvent* aEven
   rv = nsCopySupport::GetTransferableForSelection(mSelection, doc, getter_AddRefs(aEvent->mReply.mTransferable));
   NS_ENSURE_SUCCESS(rv, rv);
 
-  aEvent->mSucceeded = PR_TRUE;
+  aEvent->mSucceeded = true;
   return NS_OK;
 }
 
@@ -778,7 +816,7 @@ nsContentEventHandler::OnQueryCharacterAtPoint(nsQueryContentEvent* aEvent)
     NS_ENSURE_TRUE(rootWidget, NS_ERROR_FAILURE);
   }
 
-  nsQueryContentEvent eventOnRoot(PR_TRUE, NS_QUERY_CHARACTER_AT_POINT,
+  nsQueryContentEvent eventOnRoot(true, NS_QUERY_CHARACTER_AT_POINT,
                                   rootWidget);
   eventOnRoot.refPoint = aEvent->refPoint;
   if (rootWidget != aEvent->widget) {
@@ -795,7 +833,7 @@ nsContentEventHandler::OnQueryCharacterAtPoint(nsQueryContentEvent* aEvent)
                                              mRootContent)) {
     // there is no character at the point.
     aEvent->mReply.mOffset = nsQueryContentEvent::NOT_FOUND;
-    aEvent->mSucceeded = PR_TRUE;
+    aEvent->mSucceeded = true;
     return NS_OK;
   }
   nsPoint ptInTarget = ptInRoot + rootFrame->GetOffsetToCrossDoc(targetFrame);
@@ -812,7 +850,7 @@ nsContentEventHandler::OnQueryCharacterAtPoint(nsQueryContentEvent* aEvent)
                                 &nativeOffset);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  nsQueryContentEvent textRect(PR_TRUE, NS_QUERY_TEXT_RECT, aEvent->widget);
+  nsQueryContentEvent textRect(true, NS_QUERY_TEXT_RECT, aEvent->widget);
   textRect.InitForQueryTextRect(nativeOffset, 1);
   rv = OnQueryTextRect(&textRect);
   NS_ENSURE_SUCCESS(rv, rv);
@@ -821,7 +859,7 @@ nsContentEventHandler::OnQueryCharacterAtPoint(nsQueryContentEvent* aEvent)
   // currently, we don't need to get the actual text.
   aEvent->mReply.mOffset = nativeOffset;
   aEvent->mReply.mRect = textRect.mReply.mRect;
-  aEvent->mSucceeded = PR_TRUE;
+  aEvent->mSucceeded = true;
   return NS_OK;
 }
 
@@ -832,7 +870,7 @@ nsContentEventHandler::OnQueryDOMWidgetHittest(nsQueryContentEvent* aEvent)
   if (NS_FAILED(rv))
     return rv;
 
-  aEvent->mReply.mWidgetIsHit = PR_FALSE;
+  aEvent->mReply.mWidgetIsHit = false;
 
   NS_ENSURE_TRUE(aEvent->widget, NS_ERROR_FAILURE);
 
@@ -850,7 +888,7 @@ nsContentEventHandler::OnQueryDOMWidgetHittest(nsQueryContentEvent* aEvent)
   eventLoc.y -= docFrameRect.y;
 
   nsCOMPtr<nsIDOMElement> elementUnderMouse;
-  doc->ElementFromPointHelper(eventLoc.x, eventLoc.y, PR_FALSE, PR_FALSE,
+  doc->ElementFromPointHelper(eventLoc.x, eventLoc.y, false, false,
                               getter_AddRefs(elementUnderMouse));
   nsCOMPtr<nsIContent> contentUnderMouse = do_QueryInterface(elementUnderMouse);
   if (contentUnderMouse) {
@@ -863,10 +901,10 @@ nsContentEventHandler::OnQueryDOMWidgetHittest(nsQueryContentEvent* aEvent)
       targetWidget = targetFrame->GetNearestWidget();
     }
     if (aEvent->widget == targetWidget)
-      aEvent->mReply.mWidgetIsHit = PR_TRUE;
+      aEvent->mReply.mWidgetIsHit = true;
   }
 
-  aEvent->mSucceeded = PR_TRUE;
+  aEvent->mSucceeded = true;
   return NS_OK;
 }
 
@@ -889,10 +927,38 @@ nsContentEventHandler::GetFlatTextOffsetOfRange(nsIContent* aRootContent,
   NS_ASSERTION(startDOMNode, "startNode doesn't have nsIDOMNode");
   domPrev->SetEnd(startDOMNode, aNodeOffset);
 
-  nsAutoString prevStr;
-  nsresult rv = GenerateFlatTextContent(prev, prevStr);
+  nsCOMPtr<nsIContentIterator> iter;
+  nsresult rv = NS_NewContentIterator(getter_AddRefs(iter));
   NS_ENSURE_SUCCESS(rv, rv);
-  *aNativeOffset = prevStr.Length();
+  NS_ASSERTION(iter, "NS_NewContentIterator succeeded, but the result is null");
+  iter->Init(domPrev);
+
+  nsCOMPtr<nsINode> startNode = do_QueryInterface(startDOMNode);
+  nsINode* endNode = aNode;
+
+  *aNativeOffset = 0;
+  for (; !iter->IsDone(); iter->Next()) {
+    nsINode* node = iter->GetCurrentNode();
+    if (!node || !node->IsNodeOfType(nsINode::eCONTENT))
+      continue;
+    nsIContent* content = static_cast<nsIContent*>(node);
+
+    if (node->IsNodeOfType(nsINode::eTEXT)) {
+      // Note: our range always starts from offset 0
+      if (node == endNode)
+        *aNativeOffset += GetNativeTextLength(content, aNodeOffset);
+      else
+        *aNativeOffset += GetNativeTextLength(content);
+    } else if (IsContentBR(content)) {
+#if defined(XP_WIN)
+      // On Windows, the length of the newline is 2.
+      *aNativeOffset += 2;
+#else
+      // On other platforms, the length of the newline is 1.
+      *aNativeOffset += 1;
+#endif
+    }
+  }
   return NS_OK;
 }
 
@@ -970,7 +1036,7 @@ static void AdjustRangeForSelection(nsIContent* aRoot,
 nsresult
 nsContentEventHandler::OnSelectionEvent(nsSelectionEvent* aEvent)
 {
-  aEvent->mSucceeded = PR_FALSE;
+  aEvent->mSucceeded = false;
 
   // Get selection to manipulate
   // XXX why do we need to get them from ISM? This method should work fine
@@ -1003,8 +1069,7 @@ nsContentEventHandler::OnSelectionEvent(nsSelectionEvent* aEvent)
   nsCOMPtr<nsIDOMNode> endDomNode(do_QueryInterface(endNode));
   NS_ENSURE_TRUE(startDomNode && endDomNode, NS_ERROR_UNEXPECTED);
 
-  nsCOMPtr<nsISelectionPrivate> selPrivate = do_QueryInterface(mSelection);
-  NS_ENSURE_TRUE(selPrivate, NS_ERROR_UNEXPECTED);
+  nsCOMPtr<nsISelectionPrivate> selPrivate(do_QueryInterface(mSelection));
   selPrivate->StartBatchChanges();
 
   // Clear selection first before setting
@@ -1028,8 +1093,8 @@ nsContentEventHandler::OnSelectionEvent(nsSelectionEvent* aEvent)
   selPrivate->EndBatchChanges();
   NS_ENSURE_SUCCESS(rv, rv);
 
-  nsCOMPtr<nsISelection2>(do_QueryInterface(mSelection))->ScrollIntoView(
-      nsISelectionController::SELECTION_FOCUS_REGION, PR_FALSE, -1, -1);
-  aEvent->mSucceeded = PR_TRUE;
+  selPrivate->ScrollIntoView(
+      nsISelectionController::SELECTION_FOCUS_REGION, false, -1, -1);
+  aEvent->mSucceeded = true;
   return NS_OK;
 }
