@@ -38,6 +38,10 @@
  * ***** END LICENSE BLOCK ***** */
 
 #include "base/basictypes.h"
+
+/* This must occur *after* base/basictypes.h to avoid typedefs conflicts. */
+#include "mozilla/Util.h"
+
 #include "IPC/IPCMessageUtils.h"
 #include "nsCOMPtr.h"
 #include "nsDOMEvent.h"
@@ -61,7 +65,7 @@
 using namespace mozilla;
 
 static const char* const sEventNames[] = {
-  "mousedown", "mouseup", "click", "dblclick", "mouseover",
+  "mousedown", "mouseup", "click", "dblclick", "mouseenter", "mouseleave", "mouseover",
   "mouseout", "MozMouseHittest", "mousemove", "contextmenu", "keydown", "keyup", "keypress",
   "focus", "blur", "load", "popstate", "beforescriptexecute",
   "afterscriptexecute", "beforeunload", "unload",
@@ -81,9 +85,7 @@ static const char* const sEventNames[] = {
   "offline", "online", "copy", "cut", "paste", "open", "message", "show",
   "SVGLoad", "SVGUnload", "SVGAbort", "SVGError", "SVGResize", "SVGScroll",
   "SVGZoom",
-#ifdef MOZ_SMIL
   "beginEvent", "endEvent", "repeatEvent",
-#endif // MOZ_SMIL
 #ifdef MOZ_MEDIA
   "loadstart", "progress", "suspend", "emptied", "stalled", "play", "pause",
   "loadedmetadata", "loadeddata", "waiting", "playing", "canplay",
@@ -94,6 +96,7 @@ static const char* const sEventNames[] = {
   "MozBeforePaint",
   "MozBeforeResize",
   "mozfullscreenchange",
+  "mozfullscreenerror",
   "MozSwipeGesture",
   "MozMagnifyGestureStart",
   "MozMagnifyGestureUpdate",
@@ -121,14 +124,14 @@ static char *sPopupAllowedEvents;
 nsDOMEvent::nsDOMEvent(nsPresContext* aPresContext, nsEvent* aEvent)
 {
   mPresContext = aPresContext;
-  mPrivateDataDuplicated = PR_FALSE;
+  mPrivateDataDuplicated = false;
 
   if (aEvent) {
     mEvent = aEvent;
-    mEventIsInternal = PR_FALSE;
+    mEventIsInternal = false;
   }
   else {
-    mEventIsInternal = PR_TRUE;
+    mEventIsInternal = true;
     /*
       A derived class might want to allocate its own type of aEvent
       (derived from nsEvent). To do this, it should take care to pass
@@ -145,15 +148,15 @@ nsDOMEvent::nsDOMEvent(nsPresContext* aPresContext, nsEvent* aEvent)
         {
           ...
           if (aEvent) {
-            mEventIsInternal = PR_FALSE;
+            mEventIsInternal = false;
           }
           else {
-            mEventIsInternal = PR_TRUE;
+            mEventIsInternal = true;
           }
           ...
         }
      */
-    mEvent = new nsEvent(PR_FALSE, 0);
+    mEvent = new nsEvent(false, 0);
     mEvent->time = PR_Now();
   }
 
@@ -320,7 +323,7 @@ nsDOMEvent::GetTargetFromFrame()
 
   // get the real content
   nsCOMPtr<nsIContent> realEventContent;
-  targetFrame->GetContentForEvent(mPresContext, mEvent, getter_AddRefs(realEventContent));
+  targetFrame->GetContentForEvent(mEvent, getter_AddRefs(realEventContent));
   return realEventContent.forget();
 }
 
@@ -359,7 +362,7 @@ nsDOMEvent::GetOriginalTarget(nsIDOMEventTarget** aOriginalTarget)
 }
 
 NS_IMETHODIMP
-nsDOMEvent::SetTrusted(PRBool aTrusted)
+nsDOMEvent::SetTrusted(bool aTrusted)
 {
   if (aTrusted) {
     mEvent->flags |= NS_EVENT_FLAG_TRUSTED;
@@ -390,14 +393,14 @@ nsDOMEvent::GetEventPhase(PRUint16* aEventPhase)
 }
 
 NS_IMETHODIMP
-nsDOMEvent::GetBubbles(PRBool* aBubbles)
+nsDOMEvent::GetBubbles(bool* aBubbles)
 {
   *aBubbles = !(mEvent->flags & NS_EVENT_FLAG_CANT_BUBBLE);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsDOMEvent::GetCancelable(PRBool* aCancelable)
+nsDOMEvent::GetCancelable(bool* aCancelable)
 {
   *aCancelable = !(mEvent->flags & NS_EVENT_FLAG_CANT_CANCEL);
   return NS_OK;
@@ -417,11 +420,19 @@ nsDOMEvent::StopPropagation()
   return NS_OK;
 }
 
+NS_IMETHODIMP
+nsDOMEvent::StopImmediatePropagation()
+{
+  mEvent->flags |=
+    (NS_EVENT_FLAG_STOP_DISPATCH_IMMEDIATELY | NS_EVENT_FLAG_STOP_DISPATCH);
+  return NS_OK;
+}
+
 static nsIDocument* GetDocumentForReport(nsEvent* aEvent)
 {
   nsCOMPtr<nsINode> node = do_QueryInterface(aEvent->currentTarget);
   if (node)
-    return node->GetOwnerDoc();
+    return node->OwnerDoc();
 
   nsCOMPtr<nsPIDOMWindow> window = do_QueryInterface(aEvent->currentTarget);
   if (!window)
@@ -442,7 +453,7 @@ ReportUseOfDeprecatedMethod(nsEvent* aEvent, nsIDOMEvent* aDOMEvent,
   const PRUnichar *strings[] = { type.get() };
   nsContentUtils::ReportToConsole(nsContentUtils::eDOM_PROPERTIES,
                                   aWarning,
-                                  strings, NS_ARRAY_LENGTH(strings),
+                                  strings, ArrayLength(strings),
                                   nsnull,
                                   EmptyString(), 0, 0,
                                   nsIScriptError::warningFlag,
@@ -464,7 +475,7 @@ nsDOMEvent::PreventCapture()
 }
 
 NS_IMETHODIMP
-nsDOMEvent::GetIsTrusted(PRBool *aIsTrusted)
+nsDOMEvent::GetIsTrusted(bool *aIsTrusted)
 {
   *aIsTrusted = NS_IS_TRUSTED_EVENT(mEvent);
 
@@ -487,7 +498,7 @@ nsDOMEvent::PreventDefault()
           node = do_QueryInterface(win->GetExtantDocument());
         }
       }
-      if (node && !nsContentUtils::IsChromeDoc(node->GetOwnerDoc())) {
+      if (node && !nsContentUtils::IsChromeDoc(node->OwnerDoc())) {
         mEvent->flags |= NS_EVENT_FLAG_NO_DEFAULT_CALLED_IN_CONTENT;
       }
     }
@@ -506,7 +517,7 @@ nsDOMEvent::SetEventType(const nsAString& aEventTypeArg)
 }
 
 NS_IMETHODIMP
-nsDOMEvent::InitEvent(const nsAString& aEventTypeArg, PRBool aCanBubbleArg, PRBool aCancelableArg)
+nsDOMEvent::InitEvent(const nsAString& aEventTypeArg, bool aCanBubbleArg, bool aCancelableArg)
 {
   // Make sure this event isn't already being dispatched.
   NS_ENSURE_TRUE(!NS_IS_EVENT_IN_DISPATCH(mEvent), NS_ERROR_INVALID_ARG);
@@ -514,12 +525,12 @@ nsDOMEvent::InitEvent(const nsAString& aEventTypeArg, PRBool aCanBubbleArg, PRBo
   if (NS_IS_TRUSTED_EVENT(mEvent)) {
     // Ensure the caller is permitted to dispatch trusted DOM events.
 
-    PRBool enabled = PR_FALSE;
+    bool enabled = false;
     nsContentUtils::GetSecurityManager()->
       IsCapabilityEnabled("UniversalBrowserWrite", &enabled);
 
     if (!enabled) {
-      SetTrusted(PR_FALSE);
+      SetTrusted(false);
     }
   }
 
@@ -557,23 +568,23 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
 
   nsEvent* newEvent = nsnull;
   PRUint32 msg = mEvent->message;
-  PRBool isInputEvent = PR_FALSE;
+  bool isInputEvent = false;
 
   switch (mEvent->eventStructType) {
     case NS_EVENT:
     {
-      newEvent = new nsEvent(PR_FALSE, msg);
+      newEvent = new nsEvent(false, msg);
       break;
     }
     case NS_GUI_EVENT:
     {
       // Not copying widget, it is a weak reference.
-      newEvent = new nsGUIEvent(PR_FALSE, msg, nsnull);
+      newEvent = new nsGUIEvent(false, msg, nsnull);
       break;
     }
     case NS_SIZE_EVENT:
     {
-      nsSizeEvent* sizeEvent = new nsSizeEvent(PR_FALSE, msg, nsnull);
+      nsSizeEvent* sizeEvent = new nsSizeEvent(false, msg, nsnull);
       NS_ENSURE_TRUE(sizeEvent, NS_ERROR_OUT_OF_MEMORY);
       sizeEvent->mWinWidth = static_cast<nsSizeEvent*>(mEvent)->mWinWidth;
       sizeEvent->mWinHeight = static_cast<nsSizeEvent*>(mEvent)->mWinHeight;
@@ -582,7 +593,7 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     }
     case NS_SIZEMODE_EVENT:
     {
-      newEvent = new nsSizeModeEvent(PR_FALSE, msg, nsnull);
+      newEvent = new nsSizeModeEvent(false, msg, nsnull);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
       static_cast<nsSizeModeEvent*>(newEvent)->mSizeMode =
         static_cast<nsSizeModeEvent*>(mEvent)->mSizeMode;
@@ -590,7 +601,7 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     }
     case NS_ZLEVEL_EVENT:
     {
-      nsZLevelEvent* zLevelEvent = new nsZLevelEvent(PR_FALSE, msg, nsnull);
+      nsZLevelEvent* zLevelEvent = new nsZLevelEvent(false, msg, nsnull);
       NS_ENSURE_TRUE(zLevelEvent, NS_ERROR_OUT_OF_MEMORY);
       nsZLevelEvent* oldZLevelEvent = static_cast<nsZLevelEvent*>(mEvent);
       zLevelEvent->mPlacement = oldZLevelEvent->mPlacement;
@@ -601,7 +612,7 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     }
     case NS_SCROLLBAR_EVENT:
     {
-      newEvent = new nsScrollbarEvent(PR_FALSE, msg, nsnull);
+      newEvent = new nsScrollbarEvent(false, msg, nsnull);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
       static_cast<nsScrollbarEvent*>(newEvent)->position =
         static_cast<nsScrollbarEvent*>(mEvent)->position;
@@ -609,16 +620,16 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     }
     case NS_INPUT_EVENT:
     {
-      newEvent = new nsInputEvent(PR_FALSE, msg, nsnull);
-      isInputEvent = PR_TRUE;
+      newEvent = new nsInputEvent(false, msg, nsnull);
+      isInputEvent = true;
       break;
     }
     case NS_KEY_EVENT:
     {
-      nsKeyEvent* keyEvent = new nsKeyEvent(PR_FALSE, msg, nsnull);
+      nsKeyEvent* keyEvent = new nsKeyEvent(false, msg, nsnull);
       NS_ENSURE_TRUE(keyEvent, NS_ERROR_OUT_OF_MEMORY);
       nsKeyEvent* oldKeyEvent = static_cast<nsKeyEvent*>(mEvent);
-      isInputEvent = PR_TRUE;
+      isInputEvent = true;
       keyEvent->keyCode = oldKeyEvent->keyCode;
       keyEvent->charCode = oldKeyEvent->charCode;
       keyEvent->isChar = oldKeyEvent->isChar;
@@ -629,9 +640,9 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     {
       nsMouseEvent* oldMouseEvent = static_cast<nsMouseEvent*>(mEvent);
       nsMouseEvent* mouseEvent =
-        new nsMouseEvent(PR_FALSE, msg, nsnull, oldMouseEvent->reason);
+        new nsMouseEvent(false, msg, nsnull, oldMouseEvent->reason);
       NS_ENSURE_TRUE(mouseEvent, NS_ERROR_OUT_OF_MEMORY);
-      isInputEvent = PR_TRUE;
+      isInputEvent = true;
       mouseEvent->clickCount = oldMouseEvent->clickCount;
       mouseEvent->acceptActivation = oldMouseEvent->acceptActivation;
       mouseEvent->context = oldMouseEvent->context;
@@ -646,9 +657,9 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     {
       nsDragEvent* oldDragEvent = static_cast<nsDragEvent*>(mEvent);
       nsDragEvent* dragEvent =
-        new nsDragEvent(PR_FALSE, msg, nsnull);
+        new nsDragEvent(false, msg, nsnull);
       NS_ENSURE_TRUE(dragEvent, NS_ERROR_OUT_OF_MEMORY);
-      isInputEvent = PR_TRUE;
+      isInputEvent = true;
       dragEvent->dataTransfer = oldDragEvent->dataTransfer;
       dragEvent->clickCount = oldDragEvent->clickCount;
       dragEvent->acceptActivation = oldDragEvent->acceptActivation;
@@ -661,7 +672,7 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     }
     case NS_SCRIPT_ERROR_EVENT:
     {
-      newEvent = new nsScriptErrorEvent(PR_FALSE, msg);
+      newEvent = new nsScriptErrorEvent(false, msg);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
       static_cast<nsScriptErrorEvent*>(newEvent)->lineNr =
         static_cast<nsScriptErrorEvent*>(mEvent)->lineNr;
@@ -669,14 +680,14 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     }
     case NS_TEXT_EVENT:
     {
-      newEvent = new nsTextEvent(PR_FALSE, msg, nsnull);
-      isInputEvent = PR_TRUE;
+      newEvent = new nsTextEvent(false, msg, nsnull);
+      isInputEvent = true;
       break;
     }
     case NS_COMPOSITION_EVENT:
     {
       nsCompositionEvent* compositionEvent =
-        new nsCompositionEvent(PR_FALSE, msg, nsnull);
+        new nsCompositionEvent(false, msg, nsnull);
       nsCompositionEvent* oldCompositionEvent =
         static_cast<nsCompositionEvent*>(mEvent);
       compositionEvent->data = oldCompositionEvent->data;
@@ -686,9 +697,9 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     case NS_MOUSE_SCROLL_EVENT:
     {
       nsMouseScrollEvent* mouseScrollEvent =
-        new nsMouseScrollEvent(PR_FALSE, msg, nsnull);
+        new nsMouseScrollEvent(false, msg, nsnull);
       NS_ENSURE_TRUE(mouseScrollEvent, NS_ERROR_OUT_OF_MEMORY);
-      isInputEvent = PR_TRUE;
+      isInputEvent = true;
       nsMouseScrollEvent* oldMouseScrollEvent =
         static_cast<nsMouseScrollEvent*>(mEvent);
       mouseScrollEvent->scrollFlags = oldMouseScrollEvent->scrollFlags;
@@ -702,7 +713,7 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     }
     case NS_SCROLLPORT_EVENT:
     {
-      newEvent = new nsScrollPortEvent(PR_FALSE, msg, nsnull);
+      newEvent = new nsScrollPortEvent(false, msg, nsnull);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
       static_cast<nsScrollPortEvent*>(newEvent)->orient =
         static_cast<nsScrollPortEvent*>(mEvent)->orient;
@@ -711,7 +722,7 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     case NS_SCROLLAREA_EVENT:
     {
       nsScrollAreaEvent *newScrollAreaEvent = 
-        new nsScrollAreaEvent(PR_FALSE, msg, nsnull);
+        new nsScrollAreaEvent(false, msg, nsnull);
       NS_ENSURE_TRUE(newScrollAreaEvent, NS_ERROR_OUT_OF_MEMORY);
       newScrollAreaEvent->mArea =
         static_cast<nsScrollAreaEvent *>(mEvent)->mArea;
@@ -720,7 +731,7 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     }
     case NS_MUTATION_EVENT:
     {
-      nsMutationEvent* mutationEvent = new nsMutationEvent(PR_FALSE, msg);
+      nsMutationEvent* mutationEvent = new nsMutationEvent(false, msg);
       NS_ENSURE_TRUE(mutationEvent, NS_ERROR_OUT_OF_MEMORY);
       nsMutationEvent* oldMutationEvent =
         static_cast<nsMutationEvent*>(mEvent);
@@ -735,19 +746,19 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
 #ifdef ACCESSIBILITY
     case NS_ACCESSIBLE_EVENT:
     {
-      newEvent = new nsAccessibleEvent(PR_FALSE, msg, nsnull);
-      isInputEvent = PR_TRUE;
+      newEvent = new nsAccessibleEvent(false, msg, nsnull);
+      isInputEvent = true;
       break;
     }
 #endif
     case NS_FORM_EVENT:
     {
-      newEvent = new nsFormEvent(PR_FALSE, msg);
+      newEvent = new nsFormEvent(false, msg);
       break;
     }
     case NS_FOCUS_EVENT:
     {
-      nsFocusEvent* newFocusEvent = new nsFocusEvent(PR_FALSE, msg);
+      nsFocusEvent* newFocusEvent = new nsFocusEvent(false, msg);
       NS_ENSURE_TRUE(newFocusEvent, NS_ERROR_OUT_OF_MEMORY);
       nsFocusEvent* oldFocusEvent = static_cast<nsFocusEvent*>(mEvent);
       newFocusEvent->fromRaise = oldFocusEvent->fromRaise;
@@ -758,55 +769,53 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
 
     case NS_POPUP_EVENT:
     {
-      newEvent = new nsInputEvent(PR_FALSE, msg, nsnull);
+      newEvent = new nsInputEvent(false, msg, nsnull);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
-      isInputEvent = PR_TRUE;
+      isInputEvent = true;
       newEvent->eventStructType = NS_POPUP_EVENT;
       break;
     }
     case NS_COMMAND_EVENT:
     {
-      newEvent = new nsCommandEvent(PR_FALSE, mEvent->userType,
+      newEvent = new nsCommandEvent(false, mEvent->userType,
         static_cast<nsCommandEvent*>(mEvent)->command, nsnull);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
       break;
     }
     case NS_UI_EVENT:
     {
-      newEvent = new nsUIEvent(PR_FALSE, msg,
+      newEvent = new nsUIEvent(false, msg,
                                static_cast<nsUIEvent*>(mEvent)->detail);
       break;
     }
     case NS_SVG_EVENT:
     {
-      newEvent = new nsEvent(PR_FALSE, msg);
+      newEvent = new nsEvent(false, msg);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
       newEvent->eventStructType = NS_SVG_EVENT;
       break;
     }
     case NS_SVGZOOM_EVENT:
     {
-      newEvent = new nsGUIEvent(PR_FALSE, msg, nsnull);
+      newEvent = new nsGUIEvent(false, msg, nsnull);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
       newEvent->eventStructType = NS_SVGZOOM_EVENT;
       break;
     }
-#ifdef MOZ_SMIL
     case NS_SMIL_TIME_EVENT:
     {
-      newEvent = new nsUIEvent(PR_FALSE, msg, 0);
+      newEvent = new nsUIEvent(false, msg, 0);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
       newEvent->eventStructType = NS_SMIL_TIME_EVENT;
       break;
     }
-#endif // MOZ_SMIL
     case NS_SIMPLE_GESTURE_EVENT:
     {
       nsSimpleGestureEvent* oldSimpleGestureEvent = static_cast<nsSimpleGestureEvent*>(mEvent);
       nsSimpleGestureEvent* simpleGestureEvent = 
-        new nsSimpleGestureEvent(PR_FALSE, msg, nsnull, 0, 0.0);
+        new nsSimpleGestureEvent(false, msg, nsnull, 0, 0.0);
       NS_ENSURE_TRUE(simpleGestureEvent, NS_ERROR_OUT_OF_MEMORY);
-      isInputEvent = PR_TRUE;
+      isInputEvent = true;
       simpleGestureEvent->direction = oldSimpleGestureEvent->direction;
       simpleGestureEvent->delta = oldSimpleGestureEvent->delta;
       newEvent = simpleGestureEvent;
@@ -816,7 +825,7 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     {
       nsTransitionEvent* oldTransitionEvent =
         static_cast<nsTransitionEvent*>(mEvent);
-      newEvent = new nsTransitionEvent(PR_FALSE, msg,
+      newEvent = new nsTransitionEvent(false, msg,
                                        oldTransitionEvent->propertyName,
                                        oldTransitionEvent->elapsedTime);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
@@ -826,7 +835,7 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     {
       nsAnimationEvent* oldAnimationEvent =
         static_cast<nsAnimationEvent*>(mEvent);
-      newEvent = new nsAnimationEvent(PR_FALSE, msg,
+      newEvent = new nsAnimationEvent(false, msg,
                                       oldAnimationEvent->animationName,
                                       oldAnimationEvent->elapsedTime);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
@@ -834,10 +843,10 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
     }
     case NS_MOZTOUCH_EVENT:
     {
-      newEvent = new nsMozTouchEvent(PR_FALSE, msg, nsnull,
+      newEvent = new nsMozTouchEvent(false, msg, nsnull,
                                      static_cast<nsMozTouchEvent*>(mEvent)->streamId);
       NS_ENSURE_TRUE(newEvent, NS_ERROR_OUT_OF_MEMORY);
-      isInputEvent = PR_TRUE;
+      isInputEvent = true;
       break;
     }
     default:
@@ -868,8 +877,8 @@ NS_METHOD nsDOMEvent::DuplicatePrivateData()
 
   mEvent = newEvent;
   mPresContext = nsnull;
-  mEventIsInternal = PR_TRUE;
-  mPrivateDataDuplicated = PR_TRUE;
+  mEventIsInternal = true;
+  mPrivateDataDuplicated = true;
 
   return NS_OK;
 }
@@ -889,7 +898,7 @@ NS_METHOD nsDOMEvent::SetTarget(nsIDOMEventTarget* aTarget)
   return NS_OK;
 }
 
-NS_IMETHODIMP_(PRBool)
+NS_IMETHODIMP_(bool)
 nsDOMEvent::IsDispatchStopped()
 {
   return !!(mEvent->flags & NS_EVENT_FLAG_STOP_DISPATCH);
@@ -903,14 +912,14 @@ nsDOMEvent::GetInternalNSEvent()
 
 // return true if eventName is contained within events, delimited by
 // spaces
-static PRBool
+static bool
 PopupAllowedForEvent(const char *eventName)
 {
   if (!sPopupAllowedEvents) {
     nsDOMEvent::PopupAllowedEventsChanged();
 
     if (!sPopupAllowedEvents) {
-      return PR_FALSE;
+      return false;
     }
   }
 
@@ -924,12 +933,12 @@ PopupAllowedForEvent(const char *eventName)
     nsAFlatCString::const_iterator enditer(end);
 
     if (!FindInReadable(nsDependentCString(eventName), startiter, enditer))
-      return PR_FALSE;
+      return false;
 
     // the match is surrounded by spaces, or at a string boundary
     if ((startiter == start || *--startiter == ' ') &&
         (enditer == end || *enditer == ' ')) {
-      return PR_TRUE;
+      return true;
     }
 
     // Move on and see if there are other matches. (The delimitation
@@ -938,7 +947,7 @@ PopupAllowedForEvent(const char *eventName)
     startiter = enditer;
   }
 
-  return PR_FALSE;
+  return false;
 }
 
 // static
@@ -1117,6 +1126,10 @@ const char* nsDOMEvent::GetEventName(PRUint32 aEventType)
     return sEventNames[eDOMEvents_click];
   case NS_MOUSE_DOUBLECLICK:
     return sEventNames[eDOMEvents_dblclick];
+  case NS_MOUSEENTER:
+    return sEventNames[eDOMEvents_mouseenter];
+  case NS_MOUSELEAVE:
+    return sEventNames[eDOMEvents_mouseleave];
   case NS_MOUSE_ENTER_SYNTH:
     return sEventNames[eDOMEvents_mouseover];
   case NS_MOUSE_EXIT_SYNTH:
@@ -1281,14 +1294,12 @@ const char* nsDOMEvent::GetEventName(PRUint32 aEventType)
     return sEventNames[eDOMEvents_SVGScroll];
   case NS_SVG_ZOOM:
     return sEventNames[eDOMEvents_SVGZoom];
-#ifdef MOZ_SMIL
   case NS_SMIL_BEGIN:
     return sEventNames[eDOMEvents_beginEvent];
   case NS_SMIL_END:
     return sEventNames[eDOMEvents_endEvent];
   case NS_SMIL_REPEAT:
     return sEventNames[eDOMEvents_repeatEvent];
-#endif // MOZ_SMIL
 #ifdef MOZ_MEDIA
   case NS_LOADSTART:
     return sEventNames[eDOMEvents_loadstart];
@@ -1379,6 +1390,8 @@ const char* nsDOMEvent::GetEventName(PRUint32 aEventType)
     return sEventNames[eDOMEvents_deviceorientation];
   case NS_FULLSCREENCHANGE:
     return sEventNames[eDOMEvents_mozfullscreenchange];
+  case NS_FULLSCREENERROR:
+    return sEventNames[eDOMEvents_mozfullscreenerror];
   default:
     break;
   }
@@ -1391,7 +1404,7 @@ const char* nsDOMEvent::GetEventName(PRUint32 aEventType)
 }
 
 NS_IMETHODIMP
-nsDOMEvent::GetPreventDefault(PRBool* aReturn)
+nsDOMEvent::GetPreventDefault(bool* aReturn)
 {
   NS_ENSURE_ARG_POINTER(aReturn);
   *aReturn = mEvent && (mEvent->flags & NS_EVENT_FLAG_NO_DEFAULT);
@@ -1399,13 +1412,13 @@ nsDOMEvent::GetPreventDefault(PRBool* aReturn)
 }
 
 NS_IMETHODIMP
-nsDOMEvent::GetDefaultPrevented(PRBool* aReturn)
+nsDOMEvent::GetDefaultPrevented(bool* aReturn)
 {
   return GetPreventDefault(aReturn);
 }
 
 void
-nsDOMEvent::Serialize(IPC::Message* aMsg, PRBool aSerializeInterfaceType)
+nsDOMEvent::Serialize(IPC::Message* aMsg, bool aSerializeInterfaceType)
 {
   if (aSerializeInterfaceType) {
     IPC::WriteParam(aMsg, NS_LITERAL_STRING("event"));
@@ -1415,41 +1428,41 @@ nsDOMEvent::Serialize(IPC::Message* aMsg, PRBool aSerializeInterfaceType)
   GetType(type);
   IPC::WriteParam(aMsg, type);
 
-  PRBool bubbles = PR_FALSE;
+  bool bubbles = false;
   GetBubbles(&bubbles);
   IPC::WriteParam(aMsg, bubbles);
 
-  PRBool cancelable = PR_FALSE;
+  bool cancelable = false;
   GetCancelable(&cancelable);
   IPC::WriteParam(aMsg, cancelable);
 
-  PRBool trusted = PR_FALSE;
+  bool trusted = false;
   GetIsTrusted(&trusted);
   IPC::WriteParam(aMsg, trusted);
 
   // No timestamp serialization for now!
 }
 
-PRBool
+bool
 nsDOMEvent::Deserialize(const IPC::Message* aMsg, void** aIter)
 {
   nsString type;
-  NS_ENSURE_TRUE(IPC::ReadParam(aMsg, aIter, &type), PR_FALSE);
+  NS_ENSURE_TRUE(IPC::ReadParam(aMsg, aIter, &type), false);
 
-  PRBool bubbles = PR_FALSE;
-  NS_ENSURE_TRUE(IPC::ReadParam(aMsg, aIter, &bubbles), PR_FALSE);
+  bool bubbles = false;
+  NS_ENSURE_TRUE(IPC::ReadParam(aMsg, aIter, &bubbles), false);
 
-  PRBool cancelable = PR_FALSE;
-  NS_ENSURE_TRUE(IPC::ReadParam(aMsg, aIter, &cancelable), PR_FALSE);
+  bool cancelable = false;
+  NS_ENSURE_TRUE(IPC::ReadParam(aMsg, aIter, &cancelable), false);
 
-  PRBool trusted = PR_FALSE;
-  NS_ENSURE_TRUE(IPC::ReadParam(aMsg, aIter, &trusted), PR_FALSE);
+  bool trusted = false;
+  NS_ENSURE_TRUE(IPC::ReadParam(aMsg, aIter, &trusted), false);
 
   nsresult rv = InitEvent(type, bubbles, cancelable);
-  NS_ENSURE_SUCCESS(rv, PR_FALSE);
+  NS_ENSURE_SUCCESS(rv, false);
   SetTrusted(trusted);
 
-  return PR_TRUE;
+  return true;
 }
 
 
