@@ -96,7 +96,7 @@ public:
       if (!mTextEditorState->mSelectionRestoreEagerInit) {
         mTextEditorState->HideSelectionIfBlurred();
       }
-      mTextEditorState->mSelectionRestoreEagerInit = PR_FALSE;
+      mTextEditorState->mSelectionRestoreEagerInit = false;
     }
     mTextEditorState->FinishedRestoringSelection();
     return NS_OK;
@@ -113,7 +113,7 @@ private:
 };
 
 /*static*/
-PRBool
+bool
 nsITextControlElement::GetWrapPropertyEnum(nsIContent* aContent,
   nsITextControlElement::nsHTMLTextWrap& aWrapProp)
 {
@@ -134,16 +134,16 @@ nsITextControlElement::GetWrapPropertyEnum(nsIContent* aContent,
       case 1: aWrapProp = eHTMLTextWrap_Off; break;
     }
 
-    return PR_TRUE;
+    return true;
   }
 
-  return PR_FALSE;
+  return false;
 }
 
-static PRBool
+static bool
 SuppressEventHandlers(nsPresContext* aPresContext)
 {
-  PRBool suppressHandlers = PR_FALSE;
+  bool suppressHandlers = false;
 
   if (aPresContext)
   {
@@ -197,26 +197,26 @@ public:
   NS_IMETHOD ScrollSelectionIntoView(PRInt16 aType, PRInt16 aRegion, PRInt16 aFlags);
   NS_IMETHOD RepaintSelection(PRInt16 type);
   NS_IMETHOD RepaintSelection(nsPresContext* aPresContext, SelectionType aSelectionType);
-  NS_IMETHOD SetCaretEnabled(PRBool enabled);
-  NS_IMETHOD SetCaretReadOnly(PRBool aReadOnly);
-  NS_IMETHOD GetCaretEnabled(PRBool *_retval);
-  NS_IMETHOD GetCaretVisible(PRBool *_retval);
-  NS_IMETHOD SetCaretVisibilityDuringSelection(PRBool aVisibility);
-  NS_IMETHOD CharacterMove(PRBool aForward, PRBool aExtend);
+  NS_IMETHOD SetCaretEnabled(bool enabled);
+  NS_IMETHOD SetCaretReadOnly(bool aReadOnly);
+  NS_IMETHOD GetCaretEnabled(bool *_retval);
+  NS_IMETHOD GetCaretVisible(bool *_retval);
+  NS_IMETHOD SetCaretVisibilityDuringSelection(bool aVisibility);
+  NS_IMETHOD CharacterMove(bool aForward, bool aExtend);
   NS_IMETHOD CharacterExtendForDelete();
   NS_IMETHOD CharacterExtendForBackspace();
-  NS_IMETHOD WordMove(PRBool aForward, PRBool aExtend);
-  NS_IMETHOD WordExtendForDelete(PRBool aForward);
-  NS_IMETHOD LineMove(PRBool aForward, PRBool aExtend);
-  NS_IMETHOD IntraLineMove(PRBool aForward, PRBool aExtend);
-  NS_IMETHOD PageMove(PRBool aForward, PRBool aExtend);
-  NS_IMETHOD CompleteScroll(PRBool aForward);
-  NS_IMETHOD CompleteMove(PRBool aForward, PRBool aExtend);
-  NS_IMETHOD ScrollPage(PRBool aForward);
-  NS_IMETHOD ScrollLine(PRBool aForward);
-  NS_IMETHOD ScrollHorizontal(PRBool aLeft);
+  NS_IMETHOD WordMove(bool aForward, bool aExtend);
+  NS_IMETHOD WordExtendForDelete(bool aForward);
+  NS_IMETHOD LineMove(bool aForward, bool aExtend);
+  NS_IMETHOD IntraLineMove(bool aForward, bool aExtend);
+  NS_IMETHOD PageMove(bool aForward, bool aExtend);
+  NS_IMETHOD CompleteScroll(bool aForward);
+  NS_IMETHOD CompleteMove(bool aForward, bool aExtend);
+  NS_IMETHOD ScrollPage(bool aForward);
+  NS_IMETHOD ScrollLine(bool aForward);
+  NS_IMETHOD ScrollHorizontal(bool aLeft);
   NS_IMETHOD SelectAll(void);
-  NS_IMETHOD CheckVisibility(nsIDOMNode *node, PRInt16 startOffset, PRInt16 EndOffset, PRBool *_retval);
+  NS_IMETHOD CheckVisibility(nsIDOMNode *node, PRInt16 startOffset, PRInt16 EndOffset, bool *_retval);
 
 private:
   nsRefPtr<nsFrameSelection> mFrameSelection;
@@ -340,7 +340,7 @@ nsTextInputSelectionImpl::RepaintSelection(nsPresContext* aPresContext, Selectio
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::SetCaretEnabled(PRBool enabled)
+nsTextInputSelectionImpl::SetCaretEnabled(bool enabled)
 {
   if (!mPresShellWeak) return NS_ERROR_NOT_INITIALIZED;
 
@@ -357,7 +357,7 @@ nsTextInputSelectionImpl::SetCaretEnabled(PRBool enabled)
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::SetCaretReadOnly(PRBool aReadOnly)
+nsTextInputSelectionImpl::SetCaretReadOnly(bool aReadOnly)
 {
   if (!mPresShellWeak) return NS_ERROR_NOT_INITIALIZED;
   nsresult result;
@@ -377,13 +377,13 @@ nsTextInputSelectionImpl::SetCaretReadOnly(PRBool aReadOnly)
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::GetCaretEnabled(PRBool *_retval)
+nsTextInputSelectionImpl::GetCaretEnabled(bool *_retval)
 {
   return GetCaretVisible(_retval);
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::GetCaretVisible(PRBool *_retval)
+nsTextInputSelectionImpl::GetCaretVisible(bool *_retval)
 {
   if (!mPresShellWeak) return NS_ERROR_NOT_INITIALIZED;
   nsresult result;
@@ -402,7 +402,7 @@ nsTextInputSelectionImpl::GetCaretVisible(PRBool *_retval)
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::SetCaretVisibilityDuringSelection(PRBool aVisibility)
+nsTextInputSelectionImpl::SetCaretVisibilityDuringSelection(bool aVisibility)
 {
   if (!mPresShellWeak) return NS_ERROR_NOT_INITIALIZED;
   nsresult result;
@@ -422,7 +422,7 @@ nsTextInputSelectionImpl::SetCaretVisibilityDuringSelection(PRBool aVisibility)
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::CharacterMove(PRBool aForward, PRBool aExtend)
+nsTextInputSelectionImpl::CharacterMove(bool aForward, bool aExtend)
 {
   if (mFrameSelection)
     return mFrameSelection->CharacterMove(aForward, aExtend);
@@ -446,7 +446,7 @@ nsTextInputSelectionImpl::CharacterExtendForBackspace()
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::WordMove(PRBool aForward, PRBool aExtend)
+nsTextInputSelectionImpl::WordMove(bool aForward, bool aExtend)
 {
   if (mFrameSelection)
     return mFrameSelection->WordMove(aForward, aExtend);
@@ -454,7 +454,7 @@ nsTextInputSelectionImpl::WordMove(PRBool aForward, PRBool aExtend)
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::WordExtendForDelete(PRBool aForward)
+nsTextInputSelectionImpl::WordExtendForDelete(bool aForward)
 {
   if (mFrameSelection)
     return mFrameSelection->WordExtendForDelete(aForward);
@@ -462,7 +462,7 @@ nsTextInputSelectionImpl::WordExtendForDelete(PRBool aForward)
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::LineMove(PRBool aForward, PRBool aExtend)
+nsTextInputSelectionImpl::LineMove(bool aForward, bool aExtend)
 {
   if (mFrameSelection)
   {
@@ -476,7 +476,7 @@ nsTextInputSelectionImpl::LineMove(PRBool aForward, PRBool aExtend)
 
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::IntraLineMove(PRBool aForward, PRBool aExtend)
+nsTextInputSelectionImpl::IntraLineMove(bool aForward, bool aExtend)
 {
   if (mFrameSelection)
     return mFrameSelection->IntraLineMove(aForward, aExtend);
@@ -485,7 +485,7 @@ nsTextInputSelectionImpl::IntraLineMove(PRBool aForward, PRBool aExtend)
 
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::PageMove(PRBool aForward, PRBool aExtend)
+nsTextInputSelectionImpl::PageMove(bool aForward, bool aExtend)
 {
   // expected behavior for PageMove is to scroll AND move the caret
   // and to remain relative position of the caret in view. see Bug 4302.
@@ -500,7 +500,7 @@ nsTextInputSelectionImpl::PageMove(PRBool aForward, PRBool aExtend)
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::CompleteScroll(PRBool aForward)
+nsTextInputSelectionImpl::CompleteScroll(bool aForward)
 {
   if (!mScrollFrame)
     return NS_ERROR_NOT_INITIALIZED;
@@ -512,7 +512,7 @@ nsTextInputSelectionImpl::CompleteScroll(PRBool aForward)
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::CompleteMove(PRBool aForward, PRBool aExtend)
+nsTextInputSelectionImpl::CompleteMove(bool aForward, bool aExtend)
 {
   // grab the parent / root DIV for this text widget
   nsIContent* parentDIV = mFrameSelection->GetLimiter();
@@ -542,14 +542,14 @@ nsTextInputSelectionImpl::CompleteMove(PRBool aForward, PRBool aExtend)
   }
 
   mFrameSelection->HandleClick(parentDIV, offset, offset, aExtend,
-                               PR_FALSE, hint);
+                               false, hint);
 
   // if we got this far, attempt to scroll no matter what the above result is
   return CompleteScroll(aForward);
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::ScrollPage(PRBool aForward)
+nsTextInputSelectionImpl::ScrollPage(bool aForward)
 {
   if (!mScrollFrame)
     return NS_ERROR_NOT_INITIALIZED;
@@ -561,7 +561,7 @@ nsTextInputSelectionImpl::ScrollPage(PRBool aForward)
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::ScrollLine(PRBool aForward)
+nsTextInputSelectionImpl::ScrollLine(bool aForward)
 {
   if (!mScrollFrame)
     return NS_ERROR_NOT_INITIALIZED;
@@ -573,7 +573,7 @@ nsTextInputSelectionImpl::ScrollLine(PRBool aForward)
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::ScrollHorizontal(PRBool aLeft)
+nsTextInputSelectionImpl::ScrollHorizontal(bool aLeft)
 {
   if (!mScrollFrame)
     return NS_ERROR_NOT_INITIALIZED;
@@ -593,7 +593,7 @@ nsTextInputSelectionImpl::SelectAll()
 }
 
 NS_IMETHODIMP
-nsTextInputSelectionImpl::CheckVisibility(nsIDOMNode *node, PRInt16 startOffset, PRInt16 EndOffset, PRBool *_retval)
+nsTextInputSelectionImpl::CheckVisibility(nsIDOMNode *node, PRInt16 startOffset, PRInt16 EndOffset, bool *_retval)
 {
   if (!mPresShellWeak) return NS_ERROR_NOT_INITIALIZED;
   nsresult result;
@@ -624,7 +624,7 @@ public:
    */
   void SetFrame(nsTextControlFrame *aFrame){mFrame = aFrame;}
 
-  void SettingValue(PRBool aValue) { mSettingValue = aValue; }
+  void SettingValue(bool aValue) { mSettingValue = aValue; }
 
   NS_DECL_ISUPPORTS
 
@@ -646,22 +646,22 @@ protected:
 
   nsITextControlElement* const mTxtCtrlElement;
 
-  PRPackedBool    mSelectionWasCollapsed;
+  bool            mSelectionWasCollapsed;
   /**
    * Whether we had undo items or not the last time we got EditAction()
    * notification (when this state changes we update undo and redo menus)
    */
-  PRPackedBool    mHadUndoItems;
+  bool            mHadUndoItems;
   /**
    * Whether we had redo items or not the last time we got EditAction()
    * notification (when this state changes we update undo and redo menus)
    */
-  PRPackedBool    mHadRedoItems;
+  bool            mHadRedoItems;
   /**
    * Whether we're in the process of a SetValue call, and should therefore
    * refrain from calling OnValueChanged.
    */
-  PRPackedBool mSettingValue;
+  bool mSettingValue;
 };
 
 
@@ -672,10 +672,10 @@ protected:
 nsTextInputListener::nsTextInputListener(nsITextControlElement* aTxtCtrlElement)
 : mFrame(nsnull)
 , mTxtCtrlElement(aTxtCtrlElement)
-, mSelectionWasCollapsed(PR_TRUE)
-, mHadUndoItems(PR_FALSE)
-, mHadRedoItems(PR_FALSE)
-, mSettingValue(PR_FALSE)
+, mSelectionWasCollapsed(true)
+, mHadUndoItems(false)
+, mHadRedoItems(false)
+, mSettingValue(false)
 {
 }
 
@@ -694,7 +694,7 @@ NS_IMPL_ISUPPORTS4(nsTextInputListener,
 NS_IMETHODIMP
 nsTextInputListener::NotifySelectionChanged(nsIDOMDocument* aDoc, nsISelection* aSel, PRInt16 aReason)
 {
-  PRBool collapsed;
+  bool collapsed;
   nsWeakFrame weakFrame = mFrame;
 
   if (!aDoc || !aSel || NS_FAILED(aSel->GetIsCollapsed(&collapsed)))
@@ -728,7 +728,7 @@ nsTextInputListener::NotifySelectionChanged(nsIDOMDocument* aDoc, nsISelection*
         if (presShell) 
         {
           nsEventStatus status = nsEventStatus_eIgnore;
-          nsEvent event(PR_TRUE, NS_FORM_SELECTED);
+          nsEvent event(true, NS_FORM_SELECTED);
 
           presShell->HandleEventWithTarget(&event, mFrame, content, &status);
         }
@@ -793,9 +793,9 @@ nsTextInputListener::HandleEvent(nsIDOMEvent* aEvent)
   nsNativeKeyEvent nativeEvent;
   nsINativeKeyBindings *bindings = GetKeyBindings();
   if (bindings &&
-      nsContentUtils::DOMEventToNativeKeyEvent(keyEvent, &nativeEvent, PR_FALSE)) {
+      nsContentUtils::DOMEventToNativeKeyEvent(keyEvent, &nativeEvent, false)) {
 
-    PRBool handled = PR_FALSE;
+    bool handled = false;
     if (eventType.EqualsLiteral("keydown")) {
       handled = bindings->KeyDown(nativeEvent, DoCommandCallback, mFrame);
     }
@@ -856,14 +856,14 @@ nsTextInputListener::EditAction()
 
   // Make sure we know we were changed (do NOT set this to false if there are
   // no undo items; JS could change the value and we'd still need to save it)
-  frame->SetValueChanged(PR_TRUE);
+  frame->SetValueChanged(true);
 
   if (!mSettingValue) {
-    mTxtCtrlElement->OnValueChanged(PR_TRUE);
+    mTxtCtrlElement->OnValueChanged(true);
   }
 
   // Fire input event
-  PRBool trusted = PR_FALSE;
+  bool trusted = false;
   editor->GetLastKeypressEventTrusted(&trusted);
   frame->FireOnInput(trusted);
 
@@ -895,27 +895,27 @@ nsINativeKeyBindings*
 nsTextInputListener::GetKeyBindings()
 {
   if (mTxtCtrlElement->IsTextArea()) {
-    static PRBool sNoTextAreaBindings = PR_FALSE;
+    static bool sNoTextAreaBindings = false;
 
     if (!sNativeTextAreaBindings && !sNoTextAreaBindings) {
       CallGetService(NS_NATIVEKEYBINDINGS_CONTRACTID_PREFIX "textarea",
                      &sNativeTextAreaBindings);
 
       if (!sNativeTextAreaBindings) {
-        sNoTextAreaBindings = PR_TRUE;
+        sNoTextAreaBindings = true;
       }
     }
 
     return sNativeTextAreaBindings;
   }
 
-  static PRBool sNoInputBindings = PR_FALSE;
+  static bool sNoInputBindings = false;
   if (!sNativeInputBindings && !sNoInputBindings) {
     CallGetService(NS_NATIVEKEYBINDINGS_CONTRACTID_PREFIX "input",
                    &sNativeInputBindings);
 
     if (!sNativeInputBindings) {
-      sNoInputBindings = PR_TRUE;
+      sNoInputBindings = true;
     }
   }
 
@@ -931,12 +931,12 @@ nsTextEditorState::nsTextEditorState(nsITextControlElement* aOwningElement)
     mRestoringSelection(nsnull),
     mBoundFrame(nsnull),
     mTextListener(nsnull),
-    mEverInited(PR_FALSE),
-    mEditorInitialized(PR_FALSE),
-    mInitializing(PR_FALSE),
-    mValueTransferInProgress(PR_FALSE),
-    mSelectionCached(PR_TRUE),
-    mSelectionRestoreEagerInit(PR_FALSE)
+    mEverInited(false),
+    mEditorInitialized(false),
+    mInitializing(false),
+    mValueTransferInProgress(false),
+    mSelectionCached(true),
+    mSelectionRestoreEagerInit(false)
 {
   MOZ_COUNT_CTOR(nsTextEditorState);
 }
@@ -1015,7 +1015,7 @@ public:
     , mOwnerContent(aOwnerContent)
     , mCurrentValue(aCurrentValue)
   {
-    mState.mValueTransferInProgress = PR_TRUE;
+    mState.mValueTransferInProgress = true;
   }
 
   NS_IMETHOD Run() {
@@ -1027,7 +1027,7 @@ public:
 
     mState.PrepareEditor(value);
 
-    mState.mValueTransferInProgress = PR_FALSE;
+    mState.mValueTransferInProgress = false;
 
     return NS_OK;
   }
@@ -1051,7 +1051,7 @@ nsTextEditorState::BindToFrame(nsTextControlFrame* aFrame)
   // binding to the frame.
   nsAutoString currentValue;
   if (mEditor) {
-    GetValue(currentValue, PR_TRUE);
+    GetValue(currentValue, true);
   }
 
   mBoundFrame = aFrame;
@@ -1106,9 +1106,9 @@ nsTextEditorState::BindToFrame(nsTextControlFrame* aFrame)
     nsresult rv = mEditor->GetFlags(&flags);
     NS_ENSURE_SUCCESS(rv, rv);
     if (flags & nsIPlaintextEditor::eEditorRightToLeft) {
-      rootNode->SetAttr(kNameSpaceID_None, nsGkAtoms::dir, NS_LITERAL_STRING("rtl"), PR_FALSE);
+      rootNode->SetAttr(kNameSpaceID_None, nsGkAtoms::dir, NS_LITERAL_STRING("rtl"), false);
     } else if (flags & nsIPlaintextEditor::eEditorLeftToRight) {
-      rootNode->SetAttr(kNameSpaceID_None, nsGkAtoms::dir, NS_LITERAL_STRING("ltr"), PR_FALSE);
+      rootNode->SetAttr(kNameSpaceID_None, nsGkAtoms::dir, NS_LITERAL_STRING("ltr"), false);
     } else {
       // otherwise, inherit the content node's direction
     }
@@ -1163,24 +1163,28 @@ nsTextEditorState::PrepareEditor(const nsAString *aValue)
   // Use async reflow and painting for text widgets to improve
   // performance.
   editorFlags |= nsIPlaintextEditor::eEditorUseAsyncUpdatesMask;
+  
+  // Spell check is diabled at creation time. It is enabled once
+  // the editor comes into focus.
+  editorFlags |= nsIPlaintextEditor::eEditorSkipSpellCheck;
 
-  PRBool shouldInitializeEditor = PR_FALSE;
+  bool shouldInitializeEditor = false;
   nsCOMPtr<nsIEditor> newEditor; // the editor that we might create
   nsresult rv;
   if (!mEditor) {
-    shouldInitializeEditor = PR_TRUE;
+    shouldInitializeEditor = true;
 
     // Create an editor
     newEditor = do_CreateInstance(kTextEditorCID, &rv);
     NS_ENSURE_SUCCESS(rv, rv);
 
     // Make sure we clear out the non-breaking space before we initialize the editor
-    rv = mBoundFrame->UpdateValueDisplay(PR_FALSE, PR_TRUE);
+    rv = mBoundFrame->UpdateValueDisplay(false, true);
     NS_ENSURE_SUCCESS(rv, rv);
   } else {
     if (aValue || !mEditorInitialized) {
       // Set the correct value in the root node
-      rv = mBoundFrame->UpdateValueDisplay(PR_TRUE, !mEditorInitialized, aValue);
+      rv = mBoundFrame->UpdateValueDisplay(true, !mEditorInitialized, aValue);
       NS_ENSURE_SUCCESS(rv, rv);
     }
 
@@ -1234,7 +1238,7 @@ nsTextEditorState::PrepareEditor(const nsAString *aValue)
 
     if (controllers) {
       PRUint32 numControllers;
-      PRBool found = PR_FALSE;
+      bool found = false;
       rv = controllers->GetControllerCount(&numControllers);
       for (PRUint32 i = 0; i < numControllers; i ++) {
         nsCOMPtr<nsIController> controller;
@@ -1244,7 +1248,7 @@ nsTextEditorState::PrepareEditor(const nsAString *aValue)
             do_QueryInterface(controller);
           if (editController) {
             editController->SetCommandContext(newEditor);
-            found = PR_TRUE;
+            found = true;
           }
         }
       }
@@ -1296,7 +1300,7 @@ nsTextEditorState::PrepareEditor(const nsAString *aValue)
   if (aValue) {
     defaultValue = *aValue;
   } else {
-    GetValue(defaultValue, PR_TRUE);
+    GetValue(defaultValue, true);
   }
 
   if (shouldInitializeEditor) {
@@ -1323,12 +1327,12 @@ nsTextEditorState::PrepareEditor(const nsAString *aValue)
     // value, and turn it back on afterwards. This will make sure we can't undo
     // past the default value.
 
-    rv = newEditor->EnableUndo(PR_FALSE);
+    rv = newEditor->EnableUndo(false);
     NS_ENSURE_SUCCESS(rv, rv);
 
-    SetValue(defaultValue, PR_FALSE);
+    SetValue(defaultValue, false);
 
-    rv = newEditor->EnableUndo(PR_TRUE);
+    rv = newEditor->EnableUndo(true);
     NS_ASSERTION(NS_SUCCEEDED(rv),"Transaction Manager must have failed");
 
     // Now restore the original editor flags.
@@ -1348,13 +1352,13 @@ nsTextEditorState::PrepareEditor(const nsAString *aValue)
     // default value don't screw us up.
     // Since changing the control type does a reframe, we don't have to worry
     // about dynamic type changes here.
-    newEditor->EnableUndo(PR_FALSE);
+    newEditor->EnableUndo(false);
   }
 
   if (!mEditorInitialized) {
     newEditor->PostCreate();
-    mEverInited = PR_TRUE;
-    mEditorInitialized = PR_TRUE;
+    mEverInited = true;
+    mEditorInitialized = true;
   }
 
   if (mTextListener)
@@ -1371,7 +1375,7 @@ nsTextEditorState::PrepareEditor(const nsAString *aValue)
   }
 
   // The selection cache is no longer going to be valid
-  mSelectionCached = PR_FALSE;
+  mSelectionCached = false;
 
   return rv;
 }
@@ -1384,8 +1388,8 @@ nsTextEditorState::DestroyEditor()
     if (mTextListener)
       mEditor->RemoveEditorObserver(mTextListener);
 
-    mEditor->PreDestroy(PR_TRUE);
-    mEditorInitialized = PR_FALSE;
+    mEditor->PreDestroy(true);
+    mEditorInitialized = false;
   }
 }
 
@@ -1401,7 +1405,7 @@ nsTextEditorState::UnbindFromFrame(nsTextControlFrame* aFrame)
   // We need to start storing the value outside of the editor if we're not
   // going to use it anymore, so retrieve it for now.
   nsAutoString value;
-  GetValue(value, PR_TRUE);
+  GetValue(value, true);
 
   if (mRestoringSelection) {
     mRestoringSelection->Revoke();
@@ -1418,7 +1422,7 @@ nsTextEditorState::UnbindFromFrame(nsTextControlFrame* aFrame)
     mBoundFrame->GetSelectionRange(&mSelectionProperties.mStart,
                                    &mSelectionProperties.mEnd,
                                    &mSelectionProperties.mDirection);
-    mSelectionCached = PR_TRUE;
+    mSelectionCached = true;
   }
 
   // Destroy our editor
@@ -1485,7 +1489,7 @@ nsTextEditorState::UnbindFromFrame(nsTextControlFrame* aFrame)
 
     nsCOMPtr<nsIDOMEventTarget> target = do_QueryInterface(mTextCtrlElement);
     nsEventListenerManager* manager =
-      target->GetListenerManager(PR_FALSE);
+      target->GetListenerManager(false);
     if (manager) {
       manager->RemoveEventListenerByType(mTextListener,
                                          NS_LITERAL_STRING("keydown"),
@@ -1510,7 +1514,7 @@ nsTextEditorState::UnbindFromFrame(nsTextControlFrame* aFrame)
   // Now that we don't have a frame any more, store the value in the text buffer.
   // The only case where we don't do this is if a value transfer is in progress.
   if (!mValueTransferInProgress) {
-    SetValue(value, PR_FALSE);
+    SetValue(value, false);
   }
 
   if (mRootNode && mMutationObserver) {
@@ -1580,10 +1584,10 @@ nsTextEditorState::InitializeRootNode()
     }
   }
   nsresult rv = mRootNode->SetAttr(kNameSpaceID_None, nsGkAtoms::_class,
-                                   classValue, PR_FALSE);
+                                   classValue, false);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  return mBoundFrame->UpdateValueDisplay(PR_FALSE);
+  return mBoundFrame->UpdateValueDisplay(false);
 }
 
 nsresult
@@ -1634,38 +1638,38 @@ be called if @placeholder is the empty string when trimmed from line breaks");
   rv = NS_NewTextNode(getter_AddRefs(placeholderText), pNodeInfoManager);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  rv = mPlaceholderDiv->AppendChildTo(placeholderText, PR_FALSE);
+  rv = mPlaceholderDiv->AppendChildTo(placeholderText, false);
   NS_ENSURE_SUCCESS(rv, rv);
 
   // initialize the text
-  UpdatePlaceholderText(PR_FALSE);
+  UpdatePlaceholderText(false);
 
   return NS_OK;
 }
 
-PRBool
+bool
 nsTextEditorState::GetMaxLength(PRInt32* aMaxLength)
 {
   nsCOMPtr<nsIContent> content = do_QueryInterface(mTextCtrlElement);
-  NS_ENSURE_TRUE(content, PR_FALSE);
+  NS_ENSURE_TRUE(content, false);
   nsGenericHTMLElement* element = nsGenericHTMLElement::FromContent(content);
-  NS_ENSURE_TRUE(element, PR_FALSE);
+  NS_ENSURE_TRUE(element, false);
 
   const nsAttrValue* attr = element->GetParsedAttr(nsGkAtoms::maxlength);
   if (attr && attr->Type() == nsAttrValue::eInteger) {
     *aMaxLength = attr->GetIntegerValue();
 
-    return PR_TRUE;
+    return true;
   }
 
-  return PR_FALSE;
+  return false;
 }
 
 void
-nsTextEditorState::GetValue(nsAString& aValue, PRBool aIgnoreWrap) const
+nsTextEditorState::GetValue(nsAString& aValue, bool aIgnoreWrap) const
 {
   if (mEditor && mBoundFrame && (mEditorInitialized || !IsSingleLineTextControl())) {
-    PRBool canCache = aIgnoreWrap && !IsSingleLineTextControl();
+    bool canCache = aIgnoreWrap && !IsSingleLineTextControl();
     if (canCache && !mCachedValue.IsEmpty()) {
       aValue = mCachedValue;
       return;
@@ -1726,7 +1730,7 @@ nsTextEditorState::GetValue(nsAString& aValue, PRBool aIgnoreWrap) const
 }
 
 void
-nsTextEditorState::SetValue(const nsAString& aValue, PRBool aUserInput)
+nsTextEditorState::SetValue(const nsAString& aValue, bool aUserInput)
 {
   if (mEditor && mBoundFrame) {
     // The InsertText call below might flush pending notifications, which
@@ -1736,9 +1740,9 @@ nsTextEditorState::SetValue(const nsAString& aValue, PRBool aUserInput)
     // PrepareEditor cannot be called prematurely.
     nsAutoScriptBlocker scriptBlocker;
 
-    PRBool fireChangeEvent = mBoundFrame->GetFireChangeEventState();
+    bool fireChangeEvent = mBoundFrame->GetFireChangeEventState();
     if (aUserInput) {
-      mBoundFrame->SetFireChangeEventState(PR_TRUE);
+      mBoundFrame->SetFireChangeEventState(true);
     }
 
 #ifdef DEBUG
@@ -1814,7 +1818,7 @@ nsTextEditorState::SetValue(const nsAString& aValue, PRBool aUserInput)
           mSelCon->SelectAll();
         } else {
           // Collapse selection to the end so that we can append data.
-          mBoundFrame->SelectAllOrCollapseToEndOfText(PR_FALSE);
+          mBoundFrame->SelectAllOrCollapseToEndOfText(false);
         }
         const nsAString& insertValue =
           StringTail(newValue, newlength - currentLength);
@@ -1837,7 +1841,7 @@ nsTextEditorState::SetValue(const nsAString& aValue, PRBool aUserInput)
         flags |= nsIPlaintextEditor::eEditorDontEchoPassword;
         mEditor->SetFlags(flags);
 
-        mTextListener->SettingValue(PR_TRUE);
+        mTextListener->SettingValue(true);
 
         // Also don't enforce max-length here
         PRInt32 savedMaxLength;
@@ -1850,7 +1854,7 @@ nsTextEditorState::SetValue(const nsAString& aValue, PRBool aUserInput)
           plaintextEditor->InsertText(insertValue);
         }
 
-        mTextListener->SettingValue(PR_FALSE);
+        mTextListener->SettingValue(false);
 
         if (!weakFrame.IsAlive()) {
           // If the frame was destroyed because of a flush somewhere inside
@@ -1859,7 +1863,7 @@ nsTextEditorState::SetValue(const nsAString& aValue, PRBool aUserInput)
           // the existing selection -- see bug 574558), in which case we don't
           // need to reset the value here.
           if (!mBoundFrame) {
-            SetValue(newValue, PR_FALSE);
+            SetValue(newValue, false);
           }
           valueSetter.Cancel();
           return;
@@ -1901,7 +1905,7 @@ nsTextEditorState::SetValue(const nsAString& aValue, PRBool aUserInput)
 
     // Update the frame display if needed
     if (mBoundFrame) {
-      mBoundFrame->UpdateValueDisplay(PR_TRUE);
+      mBoundFrame->UpdateValueDisplay(true);
     }
   }
 
@@ -1917,7 +1921,7 @@ nsTextEditorState::InitializeKeyboardEventListeners()
 {
   //register key listeners
   nsCOMPtr<nsIDOMEventTarget> target = do_QueryInterface(mTextCtrlElement);
-  nsEventListenerManager* manager = target->GetListenerManager(PR_TRUE);
+  nsEventListenerManager* manager = target->GetListenerManager(true);
   if (manager) {
     manager->AddEventListenerByType(mTextListener,
                                     NS_LITERAL_STRING("keydown"),
@@ -1944,27 +1948,27 @@ nsTextEditorState::ShutDown()
 }
 
 void
-nsTextEditorState::ValueWasChanged(PRBool aNotify)
+nsTextEditorState::ValueWasChanged(bool aNotify)
 {
   // placeholder management
   if (!mPlaceholderDiv) {
     return;
   }
 
-  PRBool showPlaceholder = PR_FALSE;
+  bool showPlaceholder = false;
   nsCOMPtr<nsIContent> content = do_QueryInterface(mTextCtrlElement);
   if (!nsContentUtils::IsFocusedContent(content)) {
     // If the content is focused, we don't care about the changes because
     // the placeholder is going to be hidden/shown on blur.
     nsAutoString valueString;
-    GetValue(valueString, PR_TRUE);
+    GetValue(valueString, true);
     showPlaceholder = valueString.IsEmpty();
   }
   SetPlaceholderClass(showPlaceholder, aNotify);
 }
 
 void
-nsTextEditorState::UpdatePlaceholderText(PRBool aNotify)
+nsTextEditorState::UpdatePlaceholderText(bool aNotify)
 {
   NS_ASSERTION(mPlaceholderDiv, "This function should not be called if "
                                 "mPlaceholderDiv isn't set");
@@ -1984,8 +1988,8 @@ nsTextEditorState::UpdatePlaceholderText(PRBool aNotify)
 }
 
 void
-nsTextEditorState::SetPlaceholderClass(PRBool aVisible,
-                                       PRBool aNotify)
+nsTextEditorState::SetPlaceholderClass(bool aVisible,
+                                       bool aNotify)
 {
   NS_ASSERTION(mPlaceholderDiv, "This function should not be called if "
                                 "mPlaceholderDiv isn't set");
