@@ -64,7 +64,7 @@
 #include "nsContentPolicyUtils.h"
 #include "nsPIDOMWindow.h"
 #include "nsIDOMElement.h"
-#include "nsIDOMNSHTMLElement.h"
+#include "nsIDOMHTMLElement.h"
 #include "nsContentErrors.h"
 #include "nsURILoader.h"
 #include "nsIDocShell.h"
@@ -115,12 +115,12 @@ public:
                                      nsILoadGroup*       aLoadGroup,
                                      nsISupports*        aContainer,
                                      nsIStreamListener** aDocListener,
-                                     PRBool              aReset = PR_TRUE,
+                                     bool                aReset = true,
                                      nsIContentSink*     aSink = nsnull);
 
   virtual void SetScriptGlobalObject(nsIScriptGlobalObject* aScriptGlobalObject);
   virtual void Destroy();
-  virtual void OnPageShow(PRBool aPersisted,
+  virtual void OnPageShow(bool aPersisted,
                           nsIDOMEventTarget* aDispatchStartTarget);
 
   NS_DECL_NSIIMAGEDOCUMENT
@@ -142,11 +142,11 @@ public:
 protected:
   virtual nsresult CreateSyntheticDocument();
 
-  nsresult CheckOverflowing(PRBool changeState);
+  nsresult CheckOverflowing(bool changeState);
 
   void UpdateTitleAndCharset();
 
-  nsresult ScrollImageTo(PRInt32 aX, PRInt32 aY, PRBool restoreImage);
+  nsresult ScrollImageTo(PRInt32 aX, PRInt32 aY, bool restoreImage);
 
   float GetRatio() {
     return NS_MIN((float)mVisibleWidth / mImageWidth,
@@ -163,18 +163,18 @@ protected:
   PRInt32                       mImageWidth;
   PRInt32                       mImageHeight;
 
-  PRPackedBool                  mResizeImageByDefault;
-  PRPackedBool                  mClickResizingEnabled;
-  PRPackedBool                  mImageIsOverflowing;
+  bool                          mResizeImageByDefault;
+  bool                          mClickResizingEnabled;
+  bool                          mImageIsOverflowing;
   // mImageIsResized is true if the image is currently resized
-  PRPackedBool                  mImageIsResized;
+  bool                          mImageIsResized;
   // mShouldResize is true if the image should be resized when it doesn't fit
   // mImageIsResized cannot be true when this is false, but mImageIsResized
   // can be false when this is true
-  PRPackedBool                  mShouldResize;
-  PRPackedBool                  mFirstResize;
+  bool                          mShouldResize;
+  bool                          mFirstResize;
   // mObservingImageLoader is true while the observer is set.
-  PRPackedBool                  mObservingImageLoader;
+  bool                          mObservingImageLoader;
 
   float                         mOriginalZoomLevel;
 };
@@ -236,7 +236,7 @@ ImageListener::OnStartRequest(nsIRequest* request, nsISupports *ctxt)
   NS_ENSURE_TRUE(imageLoader, NS_ERROR_UNEXPECTED);
 
   imageLoader->AddObserver(imgDoc);
-  imgDoc->mObservingImageLoader = PR_TRUE;
+  imgDoc->mObservingImageLoader = true;
   imageLoader->LoadImageWithChannel(channel, getter_AddRefs(mNextStream));
 
   return MediaDocumentStreamListener::OnStartRequest(request, ctxt);
@@ -289,7 +289,7 @@ ImageDocument::Init()
   mResizeImageByDefault = Preferences::GetBool(AUTOMATIC_IMAGE_RESIZING_PREF);
   mClickResizingEnabled = Preferences::GetBool(CLICK_IMAGE_RESIZING_PREF);
   mShouldResize = mResizeImageByDefault;
-  mFirstResize = PR_TRUE;
+  mFirstResize = true;
 
   return NS_OK;
 }
@@ -300,7 +300,7 @@ ImageDocument::StartDocumentLoad(const char*         aCommand,
                                  nsILoadGroup*       aLoadGroup,
                                  nsISupports*        aContainer,
                                  nsIStreamListener** aDocListener,
-                                 PRBool              aReset,
+                                 bool                aReset,
                                  nsIContentSink*     aSink)
 {
   nsresult rv =
@@ -311,7 +311,7 @@ ImageDocument::StartDocumentLoad(const char*         aCommand,
   }
 
   mOriginalZoomLevel =
-    Preferences::GetBool(SITE_SPECIFIC_ZOOM, PR_FALSE) ? 1.0 : GetZoomLevel();
+    Preferences::GetBool(SITE_SPECIFIC_ZOOM, false) ? 1.0 : GetZoomLevel();
 
   NS_ASSERTION(aDocListener, "null aDocListener");
   *aDocListener = new ImageListener(this);
@@ -326,7 +326,7 @@ ImageDocument::Destroy()
   if (mImageContent) {
     // Remove our event listener from the image content.
     nsCOMPtr<nsIDOMEventTarget> target = do_QueryInterface(mImageContent);
-    target->RemoveEventListener(NS_LITERAL_STRING("click"), this, PR_FALSE);
+    target->RemoveEventListener(NS_LITERAL_STRING("click"), this, false);
 
     // Break reference cycle with mImageContent, if we have one
     if (mObservingImageLoader) {
@@ -356,9 +356,9 @@ ImageDocument::SetScriptGlobalObject(nsIScriptGlobalObject* aScriptGlobalObject)
   if (mScriptGlobalObject &&
       aScriptGlobalObject != mScriptGlobalObject) {
     target = do_QueryInterface(mScriptGlobalObject);
-    target->RemoveEventListener(NS_LITERAL_STRING("resize"), this, PR_FALSE);
+    target->RemoveEventListener(NS_LITERAL_STRING("resize"), this, false);
     target->RemoveEventListener(NS_LITERAL_STRING("keypress"), this,
-                                PR_FALSE);
+                                false);
   }
 
   // Set the script global object on the superclass before doing
@@ -375,42 +375,42 @@ ImageDocument::SetScriptGlobalObject(nsIScriptGlobalObject* aScriptGlobalObject)
       NS_ASSERTION(NS_SUCCEEDED(rv), "failed to create synthetic document");
 
       target = do_QueryInterface(mImageContent);
-      target->AddEventListener(NS_LITERAL_STRING("click"), this, PR_FALSE);
+      target->AddEventListener(NS_LITERAL_STRING("click"), this, false);
     }
 
     target = do_QueryInterface(aScriptGlobalObject);
-    target->AddEventListener(NS_LITERAL_STRING("resize"), this, PR_FALSE);
-    target->AddEventListener(NS_LITERAL_STRING("keypress"), this, PR_FALSE);
+    target->AddEventListener(NS_LITERAL_STRING("resize"), this, false);
+    target->AddEventListener(NS_LITERAL_STRING("keypress"), this, false);
   }
 }
 
 void
-ImageDocument::OnPageShow(PRBool aPersisted,
+ImageDocument::OnPageShow(bool aPersisted,
                           nsIDOMEventTarget* aDispatchStartTarget)
 {
   if (aPersisted) {
     mOriginalZoomLevel =
-      Preferences::GetBool(SITE_SPECIFIC_ZOOM, PR_FALSE) ? 1.0 : GetZoomLevel();
+      Preferences::GetBool(SITE_SPECIFIC_ZOOM, false) ? 1.0 : GetZoomLevel();
   }
   MediaDocument::OnPageShow(aPersisted, aDispatchStartTarget);
 }
 
 NS_IMETHODIMP
-ImageDocument::GetImageResizingEnabled(PRBool* aImageResizingEnabled)
+ImageDocument::GetImageResizingEnabled(bool* aImageResizingEnabled)
 {
-  *aImageResizingEnabled = PR_TRUE;
+  *aImageResizingEnabled = true;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-ImageDocument::GetImageIsOverflowing(PRBool* aImageIsOverflowing)
+ImageDocument::GetImageIsOverflowing(bool* aImageIsOverflowing)
 {
   *aImageIsOverflowing = mImageIsOverflowing;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-ImageDocument::GetImageIsResized(PRBool* aImageIsResized)
+ImageDocument::GetImageIsResized(bool* aImageIsResized)
 {
   *aImageIsResized = mImageIsResized;
   return NS_OK;
@@ -448,12 +448,12 @@ ImageDocument::ShrinkToFit()
   
   // The view might have been scrolled when zooming in, scroll back to the
   // origin now that we're showing a shrunk-to-window version.
-  (void) ScrollImageTo(0, 0, PR_FALSE);
+  (void) ScrollImageTo(0, 0, false);
 
   imageContent->SetAttr(kNameSpaceID_None, nsGkAtoms::style,
-                        NS_LITERAL_STRING("cursor: -moz-zoom-in"), PR_TRUE);
+                        NS_LITERAL_STRING("cursor: -moz-zoom-in"), true);
   
-  mImageIsResized = PR_TRUE;
+  mImageIsResized = true;
   
   UpdateTitleAndCharset();
 
@@ -463,11 +463,11 @@ ImageDocument::ShrinkToFit()
 NS_IMETHODIMP
 ImageDocument::RestoreImageTo(PRInt32 aX, PRInt32 aY)
 {
-  return ScrollImageTo(aX, aY, PR_TRUE);
+  return ScrollImageTo(aX, aY, true);
 }
 
 nsresult
-ImageDocument::ScrollImageTo(PRInt32 aX, PRInt32 aY, PRBool restoreImage)
+ImageDocument::ScrollImageTo(PRInt32 aX, PRInt32 aY, bool restoreImage)
 {
   float ratio = GetRatio();
 
@@ -499,18 +499,18 @@ ImageDocument::RestoreImage()
   }
   // Keep image content alive while changing the attributes.
   nsCOMPtr<nsIContent> imageContent = mImageContent;
-  imageContent->UnsetAttr(kNameSpaceID_None, nsGkAtoms::width, PR_TRUE);
-  imageContent->UnsetAttr(kNameSpaceID_None, nsGkAtoms::height, PR_TRUE);
+  imageContent->UnsetAttr(kNameSpaceID_None, nsGkAtoms::width, true);
+  imageContent->UnsetAttr(kNameSpaceID_None, nsGkAtoms::height, true);
   
   if (mImageIsOverflowing) {
     imageContent->SetAttr(kNameSpaceID_None, nsGkAtoms::style,
-                          NS_LITERAL_STRING("cursor: -moz-zoom-out"), PR_TRUE);
+                          NS_LITERAL_STRING("cursor: -moz-zoom-out"), true);
   }
   else {
-    imageContent->UnsetAttr(kNameSpaceID_None, nsGkAtoms::style, PR_TRUE);
+    imageContent->UnsetAttr(kNameSpaceID_None, nsGkAtoms::style, true);
   }
   
-  mImageIsResized = PR_FALSE;
+  mImageIsResized = false;
   
   UpdateTitleAndCharset();
 
@@ -520,9 +520,9 @@ ImageDocument::RestoreImage()
 NS_IMETHODIMP
 ImageDocument::ToggleImageSize()
 {
-  mShouldResize = PR_TRUE;
+  mShouldResize = true;
   if (mImageIsResized) {
-    mShouldResize = PR_FALSE;
+    mShouldResize = false;
     ResetZoomLevel();
     RestoreImage();
   }
@@ -556,7 +556,7 @@ ImageDocument::OnStopDecode(imgIRequest *aRequest,
 
   nsCOMPtr<nsIImageLoadingContent> imageLoader = do_QueryInterface(mImageContent);
   if (imageLoader) {
-    mObservingImageLoader = PR_FALSE;
+    mObservingImageLoader = false;
     imageLoader->RemoveObserver(this);
   }
 
@@ -571,7 +571,7 @@ ImageDocument::OnStopDecode(imgIRequest *aRequest,
     mStringBundle->FormatStringFromName(str.get(), formatString, 1,
                                         getter_Copies(errorMsg));
 
-    mImageContent->SetAttr(kNameSpaceID_None, nsGkAtoms::alt, errorMsg, PR_FALSE);
+    mImageContent->SetAttr(kNameSpaceID_None, nsGkAtoms::alt, errorMsg, false);
   }
 
   return NS_OK;
@@ -583,11 +583,11 @@ ImageDocument::HandleEvent(nsIDOMEvent* aEvent)
   nsAutoString eventType;
   aEvent->GetType(eventType);
   if (eventType.EqualsLiteral("resize")) {
-    CheckOverflowing(PR_FALSE);
+    CheckOverflowing(false);
   }
   else if (eventType.EqualsLiteral("click") && mClickResizingEnabled) {
     ResetZoomLevel();
-    mShouldResize = PR_TRUE;
+    mShouldResize = true;
     if (mImageIsResized) {
       PRInt32 x = 0, y = 0;
       nsCOMPtr<nsIDOMMouseEvent> event(do_QueryInterface(aEvent));
@@ -595,13 +595,14 @@ ImageDocument::HandleEvent(nsIDOMEvent* aEvent)
         event->GetClientX(&x);
         event->GetClientY(&y);
         PRInt32 left = 0, top = 0;
-        nsCOMPtr<nsIDOMNSHTMLElement> nsElement(do_QueryInterface(mImageContent));
-        nsElement->GetOffsetLeft(&left);
-        nsElement->GetOffsetTop(&top);
+        nsCOMPtr<nsIDOMHTMLElement> htmlElement =
+          do_QueryInterface(mImageContent);
+        htmlElement->GetOffsetLeft(&left);
+        htmlElement->GetOffsetTop(&top);
         x -= left;
         y -= top;
       }
-      mShouldResize = PR_FALSE;
+      mShouldResize = false;
       RestoreImageTo(x, y);
     }
     else if (mImageIsOverflowing) {
@@ -611,14 +612,14 @@ ImageDocument::HandleEvent(nsIDOMEvent* aEvent)
   else if (eventType.EqualsLiteral("keypress")) {
     nsCOMPtr<nsIDOMKeyEvent> keyEvent = do_QueryInterface(aEvent);
     PRUint32 charCode;
-    PRBool ctrlKey, metaKey, altKey;
+    bool ctrlKey, metaKey, altKey;
     keyEvent->GetCharCode(&charCode);
     keyEvent->GetCtrlKey(&ctrlKey);
     keyEvent->GetMetaKey(&metaKey);
     keyEvent->GetAltKey(&altKey);
     // plus key
     if (charCode == 0x2B && !ctrlKey && !metaKey && !altKey) {
-      mShouldResize = PR_FALSE;
+      mShouldResize = false;
       if (mImageIsResized) {
         ResetZoomLevel();
         RestoreImage();
@@ -626,7 +627,7 @@ ImageDocument::HandleEvent(nsIDOMEvent* aEvent)
     }
     // minus key
     else if (charCode == 0x2D && !ctrlKey && !metaKey && !altKey) {
-      mShouldResize = PR_TRUE;
+      mShouldResize = true;
       if (mImageIsOverflowing) {
         ResetZoomLevel();
         ShrinkToFit();
@@ -667,7 +668,7 @@ ImageDocument::CreateSyntheticDocument()
   }
 
   styleContent->SetTextContent(NS_LITERAL_STRING("img { display: block; }"));
-  head->AppendChildTo(styleContent, PR_FALSE);
+  head->AppendChildTo(styleContent, false);
 
   // Add the image element
   Element* body = GetBodyElement();
@@ -699,18 +700,18 @@ ImageDocument::CreateSyntheticDocument()
 
   NS_ConvertUTF8toUTF16 srcString(src);
   // Make sure not to start the image load from here...
-  imageLoader->SetLoadingEnabled(PR_FALSE);
-  mImageContent->SetAttr(kNameSpaceID_None, nsGkAtoms::src, srcString, PR_FALSE);
-  mImageContent->SetAttr(kNameSpaceID_None, nsGkAtoms::alt, srcString, PR_FALSE);
+  imageLoader->SetLoadingEnabled(false);
+  mImageContent->SetAttr(kNameSpaceID_None, nsGkAtoms::src, srcString, false);
+  mImageContent->SetAttr(kNameSpaceID_None, nsGkAtoms::alt, srcString, false);
 
-  body->AppendChildTo(mImageContent, PR_FALSE);
-  imageLoader->SetLoadingEnabled(PR_TRUE);
+  body->AppendChildTo(mImageContent, false);
+  imageLoader->SetLoadingEnabled(true);
 
   return NS_OK;
 }
 
 nsresult
-ImageDocument::CheckOverflowing(PRBool changeState)
+ImageDocument::CheckOverflowing(bool changeState)
 {
   /* Create a scope so that the style context gets destroyed before we might
    * call RebuildStyleData.  Also, holding onto pointers to the
@@ -746,10 +747,10 @@ ImageDocument::CheckOverflowing(PRBool changeState)
     mVisibleHeight = nsPresContext::AppUnitsToIntCSSPixels(visibleArea.height);
   }
 
-  PRBool imageWasOverflowing = mImageIsOverflowing;
+  bool imageWasOverflowing = mImageIsOverflowing;
   mImageIsOverflowing =
     mImageWidth > mVisibleWidth || mImageHeight > mVisibleHeight;
-  PRBool windowBecameBigEnough = imageWasOverflowing && !mImageIsOverflowing;
+  bool windowBecameBigEnough = imageWasOverflowing && !mImageIsOverflowing;
 
   if (changeState || mShouldResize || mFirstResize ||
       windowBecameBigEnough) {
@@ -760,7 +761,7 @@ ImageDocument::CheckOverflowing(PRBool changeState)
       RestoreImage();
     }
   }
-  mFirstResize = PR_FALSE;
+  mFirstResize = false;
 
   return NS_OK;
 }
