@@ -37,24 +37,28 @@
  *
  * ***** END LICENSE BLOCK ***** */
 /*
-Each video element based on nsBuiltinDecoder has at least one thread
-dedicated to decoding video.
+Each video element based on nsBuiltinDecoder has a state machine to manage
+its play state and keep the current frame up to date. All state machines
+share time in a single shared thread. Each decoder also has one thread
+dedicated to decoding audio and video data. This thread is shutdown when
+playback is paused. Each decoder also has a thread to push decoded audio
+to the hardware. This thread is not created until playback starts, but
+currently is not destroyed when paused, only when playback ends.
 
-This thread (called the state machine thread owns the resources for
-downloading and reading the media file. nsDecoderStateMachine is the
-class that needs to be implemented and it gets run on the state
-machine thread.
+The decoder owns the resources for downloading the media file, and the
+high level state. It holds an owning reference to the state machine
+(a subclass of nsDecoderStateMachine; nsBuiltinDecoderStateMachine) that
+owns all the resources related to decoding data, and manages the low level
+decoding operations and A/V sync. 
 
-The state machine thread has one event that is dispatched to it (the
-implementation of nsDecoderStateMachine) and that event runs for the
-lifetime of the playback of the resource. State shared between threads
-is synchronised with the main thread via a monitor held by the
-nsBuiltinDecoder object.
-
-The state machine thread event consist of a Run method which is an
-infinite loop that performs the decoding operation and checks the
-state that the state machine is in and processes operations on that
-state.
+Each state machine runs on the shared state machine thread. Every time some
+action is required for a state machine, it is scheduled to run on the shared
+the state machine thread. The state machine runs one "cycle" on the state
+machine thread, and then returns. If necessary, it will schedule itself to
+run again in future. While running this cycle, it must not block the
+thread, as other state machines' events may need to run. State shared
+between a state machine's threads is synchronised via the monitor owned
+by its nsBuiltinDecoder object.
 
 The Main thread controls the decode state machine by setting the value
 of a mPlayState variable and notifying on the monitor based on the
@@ -85,32 +89,44 @@ SHUTDOWN
 State transition occurs when the Media Element calls the Play, Seek,
 etc methods on the nsBuiltinDecoder object. When the transition
 occurs nsBuiltinDecoder then calls the methods on the decoder state
-machine object to cause it to behave appropriate to the play state.
+machine object to cause it to behave as required by the play state.
+State transitions will likely schedule the state machine to run to
+affect the change.
 
 An implementation of the nsDecoderStateMachine class is the event
-that gets dispatched to the state machine thread. It has the following states:
+that gets dispatched to the state machine thread. Each time the event is run,
+the state machine must cycle the state machine once, and then return.
+
+The state machine has the following states:
 
 DECODING_METADATA
   The media headers are being loaded, and things like framerate, etc are
   being determined, and the first frame of audio/video data is being decoded.
 DECODING
-  The decode and audio threads are started and video frames displayed at
-  the required time. 
+  The decode has started. If the PlayState is PLAYING, the decode thread
+  should be alive and decoding video and audio frame, the audio thread
+  should be playing audio, and the state machine should run periodically
+  to update the video frames being displayed.
 SEEKING
-  A seek operation is in progress.
+  A seek operation is in progress. The decode thread should be seeking.
 BUFFERING
-  Decoding is paused while data is buffered for smooth playback.
+  Decoding is paused while data is buffered for smooth playback. If playback
+  is paused (PlayState transitions to PAUSED) we'll destory the decode thread.
 COMPLETED
-  The resource has completed decoding, but not finished playback. 
+  The resource has completed decoding, but possibly not finished playback.
+  The decode thread will be destroyed. Once playback finished, the audio
+  thread will also be destroyed.
 SHUTDOWN
-  The decoder object is about to be destroyed.
+  The decoder object and its state machine are about to be destroyed.
+  Once the last state machine has been destroyed, the shared state machine
+  thread will also be destroyed. It will be recreated later if needed.
 
 The following result in state transitions.
 
 Shutdown()
   Clean up any resources the nsDecoderStateMachine owns.
-Decode()
-  Start decoding media data.
+Play()
+  Start decoding and playback of media data.
 Buffer
   This is not user initiated. It occurs when the
   available data in the stream drops below a certain point.
@@ -130,13 +146,13 @@ DECODING_METADATA
   |---------------->----->------------------------|        v
 DECODING             |          |  |              |        |
   ^                  v Seek(t)  |  |              |        |
-  |         Decode() |          v  |              |        |
+  |         Play()   |          v  |              |        |
   ^-----------<----SEEKING      |  v Complete     v        v
   |                  |          |  |              |        |
   |                  |          |  COMPLETED    SHUTDOWN-<-|
   ^                  ^          |  |Shutdown()    |
   |                  |          |  >-------->-----^
-  |         Decode() |Seek(t)   |Buffer()         |
+  |          Play()  |Seek(t)   |Buffer()         |
   -----------<--------<-------BUFFERING           |
                                 |                 ^
                                 v Shutdown()      |
@@ -157,41 +173,41 @@ player SHUTDOWN  decoder SHUTDOWN
 The general sequence of events is:
 
 1) The video element calls Load on nsMediaDecoder. This creates the
-   state machine thread and starts the channel for downloading the
-   file. It instantiates and starts the nsDecoderStateMachine. The
+   state machine and starts the channel for downloading the
+   file. It instantiates and schedules the nsDecoderStateMachine. The
    high level LOADING state is entered, which results in the decode
-   state machine to start decoding metadata. These are the headers
-   that give the video size, framerate, etc.  It returns immediately
-   to the calling video element.
+   thread being created and starting to decode metadata. These are
+   the headers that give the video size, framerate, etc. Load() returns
+   immediately to the calling video element.
 
-2) When the metadata has been loaded by the decode thread it will call
-   a method on the video element object to inform it that this step is
-   done, so it can do the things required by the video specification
-   at this stage. The decoder then continues to decode the first frame
+2) When the metadata has been loaded by the decode thread, the state machine
+   will call a method on the video element object to inform it that this
+   step is done, so it can do the things required by the video specification
+   at this stage. The decode thread then continues to decode the first frame
    of data.
 
-3) When the first frame of data has been successfully decoded it calls
-   a method on the video element object to inform it that this step
-   has been done, once again so it can do the required things by the
-   video specification at this stage.
+3) When the first frame of data has been successfully decoded the state
+   machine calls a method on the video element object to inform it that
+   this step has been done, once again so it can do the required things
+   by the video specification at this stage.
 
    This results in the high level state changing to PLAYING or PAUSED
    depending on any user action that may have occurred.
 
-   The decode thread plays audio and video, if the correct frame time
-   comes around and the decoder play state is PLAYING.
-   
-a/v synchronisation is handled by the nsDecoderStateMachine implementation.
+   While the play state is PLAYING, the decode thread will decode
+   data, and the audio thread will push audio data to the hardware to
+   be played. The state machine will run periodically on the shared
+   state machine thread to ensure video frames are played at the 
+   correct time; i.e. the state machine manages A/V sync.
 
-The Shutdown method on nsBuiltinDecoder can spin the event loop as it
-waits for threads to complete. Spinning the event loop is a bad thing
-to happen during certain times like destruction of the media
-element. To work around this the Shutdown method does nothing but
-queue an event to the main thread to perform the actual Shutdown. This
-way the shutdown can occur at a safe time.
+The Shutdown method on nsBuiltinDecoder closes the download channel, and
+signals to the state machine that it should shutdown. The state machine
+shuts down asynchronously, and will release the owning reference to the
+state machine once its threads are shutdown.
+
+The owning object of a nsBuiltinDecoder object *MUST* call Shutdown when
+destroying the nsBuiltinDecoder object.
 
-This means the owning object of a nsBuiltinDecoder object *MUST* call
-Shutdown when destroying the nsBuiltinDecoder object.  
 */
 #if !defined(nsBuiltinDecoder_h_)
 #define nsBuiltinDecoder_h_
@@ -212,11 +228,11 @@ Shutdown when destroying the nsBuiltinDecoder object.
 #include "nsMediaStream.h"
 #include "nsMediaDecoder.h"
 #include "nsHTMLMediaElement.h"
-#include "mozilla/Monitor.h"
+#include "mozilla/ReentrantMonitor.h"
 
 class nsAudioStream;
 
-static inline PRBool IsCurrentThread(nsIThread* aThread) {
+static inline bool IsCurrentThread(nsIThread* aThread) {
   return NS_GetCurrentThread() == aThread;
 }
 
@@ -250,25 +266,37 @@ public:
   virtual void Shutdown() = 0;
 
   // Called from the main thread to get the duration. The decoder monitor
-  // must be obtained before calling this. It is in units of milliseconds.
+  // must be obtained before calling this. It is in units of microseconds.
   virtual PRInt64 GetDuration() = 0;
 
   // Called from the main thread to set the duration of the media resource
   // if it is able to be obtained via HTTP headers. Called from the 
   // state machine thread to set the duration if it is obtained from the
   // media metadata. The decoder monitor must be obtained before calling this.
+  // aDuration is in microseconds.
   virtual void SetDuration(PRInt64 aDuration) = 0;
 
+  // Called while decoding metadata to set the end time of the media
+  // resource. The decoder monitor must be obtained before calling this.
+  // aEndTime is in microseconds.
+  virtual void SetEndTime(PRInt64 aEndTime) = 0;
+
+  // Set the media fragment end time. aEndTime is in microseconds.
+  virtual void SetFragmentEndTime(PRInt64 aEndTime) = 0;
+
   // Functions used by assertions to ensure we're calling things
   // on the appropriate threads.
-  virtual PRBool OnDecodeThread() = 0;
+  virtual bool OnDecodeThread() const = 0;
+
+  // Returns true if the current thread is the state machine thread.
+  virtual bool OnStateMachineThread() const = 0;
 
   virtual nsHTMLMediaElement::NextFrameStatus GetNextFrameStatus() = 0;
 
   // Cause state transitions. These methods obtain the decoder monitor
   // to synchronise the change of state, and to notify other threads
   // that the state has changed.
-  virtual void Decode() = 0;
+  virtual void Play() = 0;
 
   // Seeks to aTime in seconds
   virtual void Seek(double aTime) = 0;
@@ -276,7 +304,7 @@ public:
   // Returns the current playback position in seconds.
   // Called from the main thread to get the current frame time. The decoder
   // monitor must be obtained before calling this.
-  virtual double GetCurrentTime() = 0;
+  virtual double GetCurrentTime() const = 0;
 
   // Clear the flag indicating that a playback position change event
   // is currently queued. This is called from the main thread and must
@@ -284,8 +312,14 @@ public:
   virtual void ClearPositionChangeFlag() = 0;
 
   // Called from the main thread to set whether the media resource can
-  // be seeked. The decoder monitor must be obtained before calling this.
-  virtual void SetSeekable(PRBool aSeekable) = 0;
+  // seek into unbuffered ranges. The decoder monitor must be obtained
+  // before calling this.
+  virtual void SetSeekable(bool aSeekable) = 0;
+
+  // Returns true if the media resource can seek into unbuffered ranges,
+  // as set by SetSeekable(). The decoder monitor must be obtained before
+  // calling this.
+  virtual bool IsSeekable() = 0;
 
   // Update the playback position. This can result in a timeupdate event
   // and an invalidate of the frame being dispatched asynchronously if
@@ -296,6 +330,9 @@ public:
 
   virtual nsresult GetBuffered(nsTimeRanges* aBuffered) = 0;
 
+  virtual PRInt64 VideoQueueMemoryInUse() = 0;
+  virtual PRInt64 AudioQueueMemoryInUse() = 0;
+
   virtual void NotifyDataArrived(const char* aBuffer, PRUint32 aLength, PRUint32 aOffset) = 0;
 
   // Causes the state machine to switch to buffering state, and to
@@ -304,7 +341,9 @@ public:
   // the main thread.
   virtual void StartBuffering() = 0;
 
-  virtual void NotifyDataExhausted() = 0;
+  // Sets the current size of the framebuffer used in MozAudioAvailable events.
+  // Called on the state machine thread and the main thread.
+  virtual void SetFrameBufferLength(PRUint32 aLength) = 0;
 };
 
 class nsBuiltinDecoder : public nsMediaDecoder
@@ -316,7 +355,7 @@ class nsBuiltinDecoder : public nsMediaDecoder
   NS_DECL_NSIOBSERVER
 
  public:
-  typedef mozilla::Monitor Monitor;
+  typedef mozilla::ReentrantMonitor ReentrantMonitor;
 
   // Enumeration for the valid play states (see mPlayState)
   enum PlayState {
@@ -332,7 +371,7 @@ class nsBuiltinDecoder : public nsMediaDecoder
   nsBuiltinDecoder();
   ~nsBuiltinDecoder();
   
-  virtual PRBool Init(nsHTMLMediaElement* aElement);
+  virtual bool Init(nsHTMLMediaElement* aElement);
 
   // This method must be called by the owning object before that
   // object disposes of this decoder object.
@@ -359,6 +398,9 @@ class nsBuiltinDecoder : public nsMediaDecoder
   virtual void SetVolume(double aVolume);
   virtual double GetDuration();
 
+  virtual void SetInfinite(bool aInfinite);
+  virtual bool IsInfinite();
+
   virtual nsMediaStream* GetCurrentStream();
   virtual already_AddRefed<nsIPrincipal> GetCurrentPrincipal();
 
@@ -369,10 +411,6 @@ class nsBuiltinDecoder : public nsMediaDecoder
   // from the resource.
   void NotifyBytesConsumed(PRInt64 aBytes);
 
-  void NotifyDataExhausted() {
-    mDecoderStateMachine->NotifyDataExhausted();
-  }
-
   // Called when the video file has completed downloading.
   // Call on the main thread only.
   void ResourceLoaded();
@@ -381,24 +419,30 @@ class nsBuiltinDecoder : public nsMediaDecoder
   // Call on the main thread only.
   virtual void NetworkError();
 
-  // Call from any thread safely. Return PR_TRUE if we are currently
+  // Call from any thread safely. Return true if we are currently
   // seeking in the media resource.
-  virtual PRBool IsSeeking() const;
+  virtual bool IsSeeking() const;
 
-  // Return PR_TRUE if the decoder has reached the end of playback.
+  // Return true if the decoder has reached the end of playback.
   // Call on the main thread only.
-  virtual PRBool IsEnded() const;
+  virtual bool IsEnded() const;
 
-  // Set the duration of the media resource in units of milliseconds.
+  // Set the duration of the media resource in units of seconds.
   // This is called via a channel listener if it can pick up the duration
   // from a content header. Must be called from the main thread only.
-  virtual void SetDuration(PRInt64 aDuration);
+  virtual void SetDuration(double aDuration);
 
   // Set a flag indicating whether seeking is supported
-  virtual void SetSeekable(PRBool aSeekable);
+  virtual void SetSeekable(bool aSeekable);
 
-  // Return PR_TRUE if seeking is supported.
-  virtual PRBool GetSeekable();
+  // Return true if seeking is supported.
+  virtual bool IsSeekable();
+
+  virtual nsresult GetSeekable(nsTimeRanges* aSeekable);
+
+  // Set the end time of the media resource. When playback reaches
+  // this point the media pauses. aTime is in seconds.
+  virtual void SetEndTime(double aTime);
 
   virtual Statistics GetStatistics();
 
@@ -410,33 +454,27 @@ class nsBuiltinDecoder : public nsMediaDecoder
   // Resume any media downloads that have been suspended. Called by the
   // media element when it is restored from the bfcache. Call on the
   // main thread only.
-  virtual void Resume(PRBool aForceBuffering);
+  virtual void Resume(bool aForceBuffering);
 
   // Tells our nsMediaStream to put all loads in the background.
   virtual void MoveLoadsToBackground();
 
-  // Stop the state machine thread and drop references to the thread and
-  // state machine.
-  void Stop();
-
   void AudioAvailable(float* aFrameBuffer, PRUint32 aFrameBufferLength, float aTime);
 
   // Called by the state machine to notify the decoder that the duration
   // has changed.
   void DurationChanged();
 
-  PRBool OnStateMachineThread() {
-    return IsCurrentThread(mStateMachineThread);
-  }
+  bool OnStateMachineThread() const;
 
-  PRBool OnDecodeThread() {
+  bool OnDecodeThread() const {
     return mDecoderStateMachine->OnDecodeThread();
   }
 
   // Returns the monitor for other threads to synchronise access to
   // state.
-  Monitor& GetMonitor() { 
-    return mMonitor; 
+  ReentrantMonitor& GetReentrantMonitor() { 
+    return mReentrantMonitor; 
   }
 
   // Constructs the time ranges representing what segments of the media
@@ -448,10 +486,30 @@ class nsBuiltinDecoder : public nsMediaDecoder
     return NS_ERROR_FAILURE;
   }
 
-  virtual void NotifyDataArrived(const char* aBuffer, PRUint32 aLength, PRUint32 aOffset) {
-    return mDecoderStateMachine->NotifyDataArrived(aBuffer, aLength, aOffset);
+  virtual PRInt64 VideoQueueMemoryInUse() {
+    if (mDecoderStateMachine) {
+      return mDecoderStateMachine->VideoQueueMemoryInUse();
+    }
+    return 0;
   }
 
+  virtual PRInt64 AudioQueueMemoryInUse() {
+    if (mDecoderStateMachine) {
+      return mDecoderStateMachine->AudioQueueMemoryInUse();
+    }
+    return 0;
+  }
+
+  virtual void NotifyDataArrived(const char* aBuffer, PRUint32 aLength, PRUint32 aOffset) {
+    if (mDecoderStateMachine) {
+      return mDecoderStateMachine->NotifyDataArrived(aBuffer, aLength, aOffset);
+    }
+  }
+
+  // Sets the length of the framebuffer used in MozAudioAvailable events.
+  // The new size must be between 512 and 16384.
+  virtual nsresult RequestFrameBufferLength(PRUint32 aLength);
+
  public:
   // Return the current state. Can be called on any thread. If called from
   // a non-main thread, the decoder monitor must be held.
@@ -473,7 +531,7 @@ class nsBuiltinDecoder : public nsMediaDecoder
   void UpdatePlaybackRate();
 
   // The actual playback rate computation. The monitor must be held.
-  double ComputePlaybackRate(PRPackedBool* aReliable);
+  double ComputePlaybackRate(bool* aReliable);
 
   // Make the decoder state machine update the playback position. Called by
   // the reader on the decoder thread (Assertions for this checked by 
@@ -497,8 +555,7 @@ class nsBuiltinDecoder : public nsMediaDecoder
   // Called when the metadata from the media file has been read.
   // Call on the main thread only.
   void MetadataLoaded(PRUint32 aChannels,
-                      PRUint32 aRate,
-                      PRUint32 aFrameBufferLength);
+                      PRUint32 aRate);
 
   // Called when the first frame has been loaded.
   // Call on the main thread only.
@@ -550,13 +607,16 @@ class nsBuiltinDecoder : public nsMediaDecoder
   // obtained before calling this.
   nsDecoderStateMachine::State GetDecodeState() { return mDecoderStateMachine->GetState(); }
 
+  // Drop reference to state machine.  Only called during shutdown dance.
+  void ReleaseStateMachine() { mDecoderStateMachine = nsnull; }
+
 public:
   // Notifies the element that decoding has failed.
   void DecodeError();
 
-  // Ensures the state machine thread is running, starting a new one
-  // if necessary.
-  nsresult StartStateMachineThread();
+  // Schedules the state machine to run one cycle on the shared state
+  // machine thread. Main thread only.
+  nsresult ScheduleStateMachineThread();
 
   /******
    * The following members should be accessed with the decoder lock held.
@@ -577,9 +637,6 @@ public:
   // time of the last decoded video frame).
   nsChannelStatistics mPlaybackStatistics;
 
-  // Thread to manage playback state machine.
-  nsCOMPtr<nsIThread> mStateMachineThread;
-
   // The current playback position of the media resource in units of
   // seconds. This is updated approximately at the framerate of the
   // video (if it is a video) or the callback period of the audio.
@@ -592,7 +649,7 @@ public:
 
   // Position to seek to when the seek notification is received by the
   // decode thread. Written by the main thread and read via the
-  // decode thread. Synchronised using mMonitor. If the
+  // decode thread. Synchronised using mReentrantMonitor. If the
   // value is negative then no seek has been requested. When a seek is
   // started this is reset to negative.
   double mRequestedSeekTime;
@@ -604,7 +661,7 @@ public:
 
   // True if the media resource is seekable (server supports byte range
   // requests).
-  PRPackedBool mSeekable;
+  bool mSeekable;
 
   /******
    * The following member variables can be accessed from any thread.
@@ -620,13 +677,13 @@ public:
   // Stream of media data.
   nsAutoPtr<nsMediaStream> mStream;
 
-  // Monitor for detecting when the video play state changes. A call
+  // ReentrantMonitor for detecting when the video play state changes. A call
   // to Wait on this monitor will block the thread until the next
   // state change.
-  Monitor mMonitor;
+  ReentrantMonitor mReentrantMonitor;
 
   // Set to one of the valid play states. It is protected by the
-  // monitor mMonitor. This monitor must be acquired when reading or
+  // monitor mReentrantMonitor. This monitor must be acquired when reading or
   // writing the state. Any change to the state on the main thread
   // must call NotifyAll on the monitor so the decode thread can wake up.
   PlayState mPlayState;
@@ -640,14 +697,17 @@ public:
   // True when we have fully loaded the resource and reported that
   // to the element (i.e. reached NETWORK_LOADED state).
   // Accessed on the main thread only.
-  PRPackedBool mResourceLoaded;
+  bool mResourceLoaded;
 
   // True when seeking or otherwise moving the play position around in
   // such a manner that progress event data is inaccurate. This is set
   // during seek and duration operations to prevent the progress indicator
   // from jumping around. Read/Write from any thread. Must have decode monitor
   // locked before accessing.
-  PRPackedBool mIgnoreProgressData;
+  bool mIgnoreProgressData;
+
+  // True if the stream is infinite (e.g. a webradio).
+  bool mInfiniteStream;
 };
 
 #endif
