@@ -51,82 +51,92 @@
 #include "nsIContent.h"
 #include "nsContentUtils.h"
 #include "nsWhitespaceTokenizer.h"
-#include "nsCommaSeparatedTokenizer.h"
+#include "nsCharSeparatedTokenizer.h"
 #include "nsStyleUtil.h"
 #include "nsSVGUtils.h"
+#include "nsServiceManagerUtils.h"
+#include "mozilla/Preferences.h"
 
-/*static*/ PRBool
-nsSVGFeatures::HaveFeature(const nsAString& aFeature)
+using namespace mozilla;
+
+/*static*/ bool
+nsSVGFeatures::HaveFeature(nsISupports* aObject, const nsAString& aFeature)
 {
-  if (!NS_SVGEnabled()) {
-    return PR_FALSE;
+  if (aFeature.EqualsLiteral("http://www.w3.org/TR/SVG11/feature#Script")) {
+    nsCOMPtr<nsIContent> content(do_QueryInterface(aObject));
+    if (content) {
+      nsIDocument *doc = content->GetCurrentDoc();
+      if (doc && doc->IsResourceDoc()) {
+        // no scripting in SVG images or external resource documents
+        return false;
+      }
+    }
+    return Preferences::GetBool("javascript.enabled", false);
   }
-
-#define SVG_SUPPORTED_FEATURE(str) if (aFeature.Equals(NS_LITERAL_STRING(str).get())) return PR_TRUE;
+#define SVG_SUPPORTED_FEATURE(str) if (aFeature.EqualsLiteral(str)) return true;
 #define SVG_UNSUPPORTED_FEATURE(str)
 #include "nsSVGFeaturesList.h"
 #undef SVG_SUPPORTED_FEATURE
 #undef SVG_UNSUPPORTED_FEATURE
-  return PR_FALSE;
+  return false;
 }
 
-/*static*/ PRBool
-nsSVGFeatures::HaveFeatures(const nsSubstring& aFeatures)
+/*static*/ bool
+nsSVGFeatures::HaveFeatures(nsISupports* aObject, const nsSubstring& aFeatures)
 {
   nsWhitespaceTokenizer tokenizer(aFeatures);
   while (tokenizer.hasMoreTokens()) {
-    if (!HaveFeature(tokenizer.nextToken())) {
-      return PR_FALSE;
+    if (!HaveFeature(aObject, tokenizer.nextToken())) {
+      return false;
     }
   }
-  return PR_TRUE;
+  return true;
 }
 
-/*static*/ PRBool
+/*static*/ bool
 nsSVGFeatures::HaveExtension(const nsAString& aExtension)
 {
-#define SVG_SUPPORTED_EXTENSION(str) if (aExtension.Equals(NS_LITERAL_STRING(str).get())) return PR_TRUE;
+#define SVG_SUPPORTED_EXTENSION(str) if (aExtension.EqualsLiteral(str)) return true;
   SVG_SUPPORTED_EXTENSION("http://www.w3.org/1999/xhtml")
-#ifdef MOZ_MATHML
   SVG_SUPPORTED_EXTENSION("http://www.w3.org/1998/Math/MathML")
-#endif
 #undef SVG_SUPPORTED_EXTENSION
 
-  return PR_FALSE;
+  return false;
 }
 
-/*static*/ PRBool
+/*static*/ bool
 nsSVGFeatures::HaveExtensions(const nsSubstring& aExtensions)
 {
   nsWhitespaceTokenizer tokenizer(aExtensions);
   while (tokenizer.hasMoreTokens()) {
     if (!HaveExtension(tokenizer.nextToken())) {
-      return PR_FALSE;
+      return false;
     }
   }
-  return PR_TRUE;
+  return true;
 }
 
-/*static*/ PRBool
+/*static*/ bool
 nsSVGFeatures::MatchesLanguagePreferences(const nsSubstring& aAttribute,
                                           const nsSubstring& aAcceptLangs) 
 {
   const nsDefaultStringComparator defaultComparator;
 
-  nsCommaSeparatedTokenizer attributeTokenizer(aAttribute);
+  nsCharSeparatedTokenizerTemplate<IsSVGWhitespace>
+    attributeTokenizer(aAttribute, ',');
 
   while (attributeTokenizer.hasMoreTokens()) {
     const nsSubstring &attributeToken = attributeTokenizer.nextToken();
-    nsCommaSeparatedTokenizer languageTokenizer(aAcceptLangs);
+    nsCharSeparatedTokenizer languageTokenizer(aAcceptLangs, ',');
     while (languageTokenizer.hasMoreTokens()) {
       if (nsStyleUtil::DashMatchCompare(attributeToken,
                                         languageTokenizer.nextToken(),
                                         defaultComparator)) {
-        return PR_TRUE;
+        return true;
       }
     }
   }
-  return PR_FALSE;
+  return false;
 }
 
 /*static*/ PRInt32
@@ -135,17 +145,17 @@ nsSVGFeatures::GetBestLanguagePreferenceRank(const nsSubstring& aAttribute,
 {
   const nsDefaultStringComparator defaultComparator;
 
-  nsCommaSeparatedTokenizer attributeTokenizer(aAttribute);
+  nsCharSeparatedTokenizer attributeTokenizer(aAttribute, ',');
   PRInt32 lowestRank = -1;
 
   while (attributeTokenizer.hasMoreTokens()) {
     const nsSubstring &attributeToken = attributeTokenizer.nextToken();
-    nsCommaSeparatedTokenizer languageTokenizer(aAcceptLangs);
+    nsCharSeparatedTokenizer languageTokenizer(aAcceptLangs, ',');
     PRInt32 index = 0;
     while (languageTokenizer.hasMoreTokens()) {
       const nsSubstring &languageToken = languageTokenizer.nextToken();
-      PRBool exactMatch = (languageToken == attributeToken);
-      PRBool prefixOnlyMatch =
+      bool exactMatch = (languageToken == attributeToken);
+      bool prefixOnlyMatch =
         !exactMatch &&
         nsStyleUtil::DashMatchCompare(attributeToken,
                                       languageTokenizer.nextToken(),
@@ -164,34 +174,34 @@ nsSVGFeatures::GetBestLanguagePreferenceRank(const nsSubstring& aAttribute,
   return lowestRank;
 }
 
-/*static*/ PRBool
+/*static*/ bool
 nsSVGFeatures::ElementSupportsAttributes(const nsIAtom *aTagName, PRUint16 aAttr)
 {
 #define SVG_ELEMENT(_atom, _supports) if (aTagName == nsGkAtoms::_atom) return (_supports & aAttr) != 0;
 #include "nsSVGElementList.h"
 #undef SVG_ELEMENT
-  return PR_FALSE;
+  return false;
 }
 
 const nsString * const nsSVGFeatures::kIgnoreSystemLanguage = (nsString *) 0x01;
 
-/*static*/ PRBool
+/*static*/ bool
 nsSVGFeatures::PassesConditionalProcessingTests(nsIContent *aContent,
                                                 const nsString *aAcceptLangs)
 {
-  if (!aContent->IsNodeOfType(nsINode::eELEMENT)) {
-    return PR_FALSE;
+  if (!aContent->IsElement()) {
+    return false;
   }
 
   if (!ElementSupportsAttributes(aContent->Tag(), ATTRS_CONDITIONAL)) {
-    return PR_TRUE;
+    return true;
   }
 
   // Required Features
   nsAutoString value;
   if (aContent->GetAttr(kNameSpaceID_None, nsGkAtoms::requiredFeatures, value)) {
-    if (value.IsEmpty() || !HaveFeatures(value)) {
-      return PR_FALSE;
+    if (value.IsEmpty() || !HaveFeatures(aContent, value)) {
+      return false;
     }
   }
 
@@ -204,17 +214,14 @@ nsSVGFeatures::PassesConditionalProcessingTests(nsIContent *aContent,
   // For now, claim that mozilla's SVG implementation supports XHTML and MathML.
   if (aContent->GetAttr(kNameSpaceID_None, nsGkAtoms::requiredExtensions, value)) {
     if (value.IsEmpty() || !HaveExtensions(value)) {
-      return PR_FALSE;
+      return false;
     }
   }
 
   if (aAcceptLangs == kIgnoreSystemLanguage) {
-    return PR_TRUE;
+    return true;
   }
 
-  const nsString& acceptLangs = aAcceptLangs ? *aAcceptLangs :
-    nsContentUtils::GetLocalizedStringPref("intl.accept_languages");
-
   // systemLanguage
   //
   // Evaluates to "true" if one of the languages indicated by user preferences
@@ -224,6 +231,10 @@ nsSVGFeatures::PassesConditionalProcessingTests(nsIContent *aContent,
   // that the first tag character following the prefix is "-".
   if (aContent->GetAttr(kNameSpaceID_None, nsGkAtoms::systemLanguage,
                         value)) {
+
+    const nsAutoString acceptLangs(aAcceptLangs ? *aAcceptLangs :
+      Preferences::GetLocalizedString("intl.accept_languages"));
+
     // Get our language preferences
     if (!acceptLangs.IsEmpty()) {
       return MatchesLanguagePreferences(value, acceptLangs);
@@ -234,5 +245,5 @@ nsSVGFeatures::PassesConditionalProcessingTests(nsIContent *aContent,
     }
   }
 
-  return PR_TRUE;
+  return true;
 }
