@@ -86,7 +86,7 @@
 #include "nsNodeInfoManager.h"
 #include "nsContentCreatorFunctions.h"
 #include "nsIContentPolicy.h"
-#include "nsIDocumentViewer.h"
+#include "nsIContentViewer.h"
 #include "nsContentPolicyUtils.h"
 #include "nsContentErrors.h"
 #include "nsIDOMProcessingInstruction.h"
@@ -132,8 +132,8 @@ NS_NewXMLContentSink(nsIXMLContentSink** aResult,
 }
 
 nsXMLContentSink::nsXMLContentSink()
-  : mConstrainSize(PR_TRUE),
-    mPrettyPrintXML(PR_TRUE)
+  : mConstrainSize(true),
+    mPrettyPrintXML(true)
 {
 }
 
@@ -155,10 +155,10 @@ nsXMLContentSink::Init(nsIDocument* aDoc,
   NS_ENSURE_SUCCESS(rv, rv);
 
   aDoc->AddObserver(this);
-  mIsDocumentObserver = PR_TRUE;
+  mIsDocumentObserver = true;
 
   if (!mDocShell) {
-    mPrettyPrintXML = PR_FALSE;
+    mPrettyPrintXML = false;
   }
   
   mState = eXMLContentSinkState_InProlog;
@@ -209,14 +209,14 @@ nsXMLContentSink::WillBuildModel(nsDTDMode aDTDMode)
     nsCAutoString command;
     mParser->GetCommand(command);
     if (!command.EqualsLiteral("view")) {
-      mPrettyPrintXML = PR_FALSE;
+      mPrettyPrintXML = false;
     }
   }
   
   return NS_OK;
 }
 
-PRBool
+bool
 nsXMLContentSink::CanStillPrettyPrint()
 {
   return mPrettyPrintXML &&
@@ -227,25 +227,25 @@ nsresult
 nsXMLContentSink::MaybePrettyPrint()
 {
   if (!CanStillPrettyPrint()) {
-    mPrettyPrintXML = PR_FALSE;
+    mPrettyPrintXML = false;
 
     return NS_OK;
   }
 
   // stop observing in order to avoid crashing when replacing content
   mDocument->RemoveObserver(this);
-  mIsDocumentObserver = PR_FALSE;
+  mIsDocumentObserver = false;
 
   // Reenable the CSSLoader so that the prettyprinting stylesheets can load
   if (mCSSLoader) {
-    mCSSLoader->SetEnabled(PR_TRUE);
+    mCSSLoader->SetEnabled(true);
   }
   
   nsCOMPtr<nsXMLPrettyPrinter> printer;
   nsresult rv = NS_NewXMLPrettyPrinter(getter_AddRefs(printer));
   NS_ENSURE_SUCCESS(rv, rv);
 
-  PRBool isPrettyPrinting;
+  bool isPrettyPrinting;
   rv = printer->PrettyPrint(mDocument, &isPrettyPrinting);
   NS_ENSURE_SUCCESS(rv, rv);
 
@@ -283,10 +283,10 @@ CheckXSLTParamPI(nsIDOMProcessingInstruction* aPi,
     nsParserUtils::GetQuotedAttributeValue(data, nsGkAtoms::_namespace,
                                            namespaceAttr);
     if (!nsParserUtils::GetQuotedAttributeValue(data, nsGkAtoms::select, select)) {
-      select.SetIsVoid(PR_TRUE);
+      select.SetIsVoid(true);
     }
     if (!nsParserUtils::GetQuotedAttributeValue(data, nsGkAtoms::value, value)) {
-      value.SetIsVoid(PR_TRUE);
+      value.SetIsVoid(true);
     }
     if (!name.IsEmpty()) {
       nsCOMPtr<nsIDOMNode> doc = do_QueryInterface(aDocument);
@@ -296,14 +296,14 @@ CheckXSLTParamPI(nsIDOMProcessingInstruction* aPi,
 }
 
 NS_IMETHODIMP
-nsXMLContentSink::DidBuildModel(PRBool aTerminated)
+nsXMLContentSink::DidBuildModel(bool aTerminated)
 {
   DidBuildModelImpl(aTerminated);
 
   if (mXSLTProcessor) {
     // stop observing in order to avoid crashing when replacing content
     mDocument->RemoveObserver(this);
-    mIsDocumentObserver = PR_FALSE;
+    mIsDocumentObserver = false;
 
     // Check for xslt-param and xslt-param-namespace PIs
     for (nsIContent* child = mDocument->GetFirstChild();
@@ -332,7 +332,7 @@ nsXMLContentSink::DidBuildModel(PRBool aTerminated)
     // Check if we want to prettyprint
     MaybePrettyPrint();
 
-    PRBool startLayout = PR_TRUE;
+    bool startLayout = true;
     
     if (mPrettyPrinting) {
       NS_ASSERTION(!mPendingSheetCount, "Shouldn't have pending sheets here!");
@@ -342,18 +342,18 @@ nsXMLContentSink::DidBuildModel(PRBool aTerminated)
       if (mDocument->CSSLoader()->HasPendingLoads() &&
           NS_SUCCEEDED(mDocument->CSSLoader()->AddObserver(this))) {
         // wait for those sheets to load
-        startLayout = PR_FALSE;
+        startLayout = false;
       }
     }
     
     if (startLayout) {
-      StartLayout(PR_FALSE);
+      StartLayout(false);
 
       ScrollToRef();
     }
 
     mDocument->RemoveObserver(this);
-    mIsDocumentObserver = PR_FALSE;
+    mIsDocumentObserver = false;
 
     mDocument->EndLoad();
   }
@@ -370,14 +370,13 @@ nsXMLContentSink::OnDocumentCreated(nsIDocument* aResultDocument)
 
   nsCOMPtr<nsIHTMLDocument> htmlDoc = do_QueryInterface(aResultDocument);
   if (htmlDoc) {
-    htmlDoc->SetDocWriteDisabled(PR_TRUE);
+    htmlDoc->SetDocWriteDisabled(true);
   }
 
   nsCOMPtr<nsIContentViewer> contentViewer;
   mDocShell->GetContentViewer(getter_AddRefs(contentViewer));
-  nsCOMPtr<nsIDocumentViewer> docViewer = do_QueryInterface(contentViewer);
-  if (docViewer) {
-    return docViewer->SetDocumentInternal(aResultDocument, PR_TRUE);
+  if (contentViewer) {
+    return contentViewer->SetDocumentInternal(aResultDocument, true);
   }
   return NS_OK;
 }
@@ -397,7 +396,7 @@ nsXMLContentSink::OnTransformDone(nsresult aResult,
   if (NS_FAILED(aResult) && contentViewer) {
     // Transform failed.
     if (domDoc) {
-      aResultDocument->SetMayStartLayout(PR_FALSE);
+      aResultDocument->SetMayStartLayout(false);
       // We have an error document.
       contentViewer->SetDOMDocument(domDoc);
     }
@@ -416,7 +415,7 @@ nsXMLContentSink::OnTransformDone(nsresult aResult,
     mDocument = aResultDocument;
     nsCOMPtr<nsIHTMLDocument> htmlDoc = do_QueryInterface(mDocument);
     if (htmlDoc) {
-      htmlDoc->SetDocWriteDisabled(PR_FALSE);
+      htmlDoc->SetDocWriteDisabled(false);
     }
   }
 
@@ -437,7 +436,7 @@ nsXMLContentSink::OnTransformDone(nsresult aResult,
   }
 
   // Start the layout process
-  StartLayout(PR_FALSE);
+  StartLayout(false);
 
   ScrollToRef();
 
@@ -448,7 +447,7 @@ nsXMLContentSink::OnTransformDone(nsresult aResult,
 
 NS_IMETHODIMP
 nsXMLContentSink::StyleSheetLoaded(nsCSSStyleSheet* aSheet,
-                                   PRBool aWasAlternate,
+                                   bool aWasAlternate,
                                    nsresult aStatus)
 {
   if (!mPrettyPrinting) {
@@ -457,7 +456,7 @@ nsXMLContentSink::StyleSheetLoaded(nsCSSStyleSheet* aSheet,
 
   if (!mDocument->CSSLoader()->HasPendingLoads()) {
     mDocument->CSSLoader()->RemoveObserver(this);
-    StartLayout(PR_FALSE);
+    StartLayout(false);
     ScrollToRef();
   }
 
@@ -487,13 +486,13 @@ nsXMLContentSink::SetParser(nsIParser* aParser)
 nsresult
 nsXMLContentSink::CreateElement(const PRUnichar** aAtts, PRUint32 aAttsCount,
                                 nsINodeInfo* aNodeInfo, PRUint32 aLineNumber,
-                                nsIContent** aResult, PRBool* aAppendContent,
+                                nsIContent** aResult, bool* aAppendContent,
                                 FromParser aFromParser)
 {
   NS_ASSERTION(aNodeInfo, "can't create element without nodeinfo");
 
   *aResult = nsnull;
-  *aAppendContent = PR_TRUE;
+  *aAppendContent = true;
   nsresult rv = NS_OK;
 
   nsCOMPtr<nsINodeInfo> ni = aNodeInfo;
@@ -508,12 +507,12 @@ nsXMLContentSink::CreateElement(const PRUnichar** aAtts, PRUint32 aAttsCount,
     nsCOMPtr<nsIScriptElement> sele = do_QueryInterface(content);
     sele->SetScriptLineNumber(aLineNumber);
     sele->SetCreatorParser(mParser);
-    mConstrainSize = PR_FALSE;
+    mConstrainSize = false;
   }
 
   // XHTML needs some special attention
   if (aNodeInfo->NamespaceEquals(kNameSpaceID_XHTML)) {
-    mPrettyPrintHasFactoredElements = PR_TRUE;
+    mPrettyPrintHasFactoredElements = true;
   }
   else {
     // If we care, find out if we just used a special factory.
@@ -536,9 +535,9 @@ nsXMLContentSink::CreateElement(const PRUnichar** aAtts, PRUint32 aAttsCount,
       aNodeInfo->Equals(nsGkAtoms::style, kNameSpaceID_SVG)) {
     nsCOMPtr<nsIStyleSheetLinkingElement> ssle(do_QueryInterface(content));
     if (ssle) {
-      ssle->InitStyleLinkElement(PR_FALSE);
+      ssle->InitStyleLinkElement(false);
       if (aFromParser) {
-        ssle->SetEnableUpdates(PR_FALSE);
+        ssle->SetEnableUpdates(false);
       }
       if (!aNodeInfo->Equals(nsGkAtoms::link, kNameSpaceID_XHTML)) {
         ssle->SetLineNumber(aFromParser ? aLineNumber : 0);
@@ -592,7 +591,7 @@ nsXMLContentSink::CloseElement(nsIContent* aContent)
   if (nodeInfo->Equals(nsGkAtoms::script, kNameSpaceID_XHTML)
       || nodeInfo->Equals(nsGkAtoms::script, kNameSpaceID_SVG)
     ) {
-    mConstrainSize = PR_TRUE; 
+    mConstrainSize = true; 
 
     if (mPreventScriptExecution) {
       nsCOMPtr<nsIScriptElement> sele = do_QueryInterface(aContent);
@@ -604,7 +603,7 @@ nsXMLContentSink::CloseElement(nsIContent* aContent)
     // Now tell the script that it's ready to go. This may execute the script
     // or return NS_ERROR_HTMLPARSER_BLOCK. Or neither if the script doesn't
     // need executing.
-    rv = aContent->DoneAddingChildren(PR_TRUE);
+    rv = aContent->DoneAddingChildren(true);
 
     // If the act of insertion evaluated the script, we're fine.
     // Else, block the parser till the script has loaded.
@@ -635,9 +634,9 @@ nsXMLContentSink::CloseElement(nsIContent* aContent)
            nodeInfo->Equals(nsGkAtoms::style, kNameSpaceID_SVG)) {
     nsCOMPtr<nsIStyleSheetLinkingElement> ssle(do_QueryInterface(aContent));
     if (ssle) {
-      ssle->SetEnableUpdates(PR_TRUE);
-      PRBool willNotify;
-      PRBool isAlternate;
+      ssle->SetEnableUpdates(true);
+      bool willNotify;
+      bool isAlternate;
       rv = ssle->UpdateStyleSheet(mFragmentMode ? nsnull : this,
                                   &willNotify,
                                   &isAlternate);
@@ -655,7 +654,7 @@ nsXMLContentSink::CloseElement(nsIContent* aContent)
         // XXX seems overkill to generate this string array
         nsAutoTArray<nsString, 4> linkTypes;
         nsStyleLinkElement::ParseLinkTypes(relVal, linkTypes);
-        PRBool hasPrefetch = linkTypes.Contains(NS_LITERAL_STRING("prefetch"));
+        bool hasPrefetch = linkTypes.Contains(NS_LITERAL_STRING("prefetch"));
         if (hasPrefetch || linkTypes.Contains(NS_LITERAL_STRING("next"))) {
           nsAutoString hrefVal;
           aContent->GetAttr(kNameSpaceID_None, nsGkAtoms::href, hrefVal);
@@ -685,13 +684,13 @@ nsXMLContentSink::AddContentAsLeaf(nsIContent *aContent)
   if ((eXMLContentSinkState_InProlog == mState) ||
       (eXMLContentSinkState_InEpilog == mState)) {
     NS_ASSERTION(mDocument, "Fragments have no prolog or epilog");
-    mDocument->AppendChildTo(aContent, PR_FALSE);
+    mDocument->AppendChildTo(aContent, false);
   }
   else {
     nsCOMPtr<nsIContent> parent = GetCurrentContent();
 
     if (parent) {
-      result = parent->AppendChildTo(aContent, PR_FALSE);
+      result = parent->AppendChildTo(aContent, false);
     }
   }
   return result;
@@ -731,13 +730,13 @@ nsXMLContentSink::LoadXSLStyleSheet(nsIURI* aUrl)
 nsresult
 nsXMLContentSink::ProcessStyleLink(nsIContent* aElement,
                                    const nsSubstring& aHref,
-                                   PRBool aAlternate,
+                                   bool aAlternate,
                                    const nsSubstring& aTitle,
                                    const nsSubstring& aType,
                                    const nsSubstring& aMedia)
 {
   nsresult rv = NS_OK;
-  mPrettyPrintXML = PR_FALSE;
+  mPrettyPrintXML = false;
 
   nsCAutoString cmd;
   if (mParser)
@@ -817,14 +816,14 @@ nsXMLContentSink::GetTarget()
   return mDocument;
 }
 
-PRBool
+bool
 nsXMLContentSink::IsScriptExecuting()
 {
   return IsScriptExecutingImpl();
 }
 
 nsresult
-nsXMLContentSink::FlushText(PRBool aReleaseTextNode)
+nsXMLContentSink::FlushText(bool aReleaseTextNode)
 {
   nsresult rv = NS_OK;
 
@@ -835,7 +834,7 @@ nsXMLContentSink::FlushText(PRBool aReleaseTextNode)
         mLastTextNode = nsnull;
         FlushText(aReleaseTextNode);
       } else {
-        PRBool notify = HaveNotifiedForCurrentContent();
+        bool notify = HaveNotifiedForCurrentContent();
         // We could probably always increase mInNotification here since
         // if AppendText doesn't notify it shouldn't trigger evil code.
         // But just in case it does, we don't want to mask any notifications.
@@ -859,7 +858,7 @@ nsXMLContentSink::FlushText(PRBool aReleaseTextNode)
       mLastTextNode = textContent;
       
       // Set the text in the text node
-      textContent->SetText(mText, mTextLength, PR_FALSE);
+      textContent->SetText(mText, mTextLength, false);
       mLastTextNodeSize += mTextLength;
       mTextLength = 0;
 
@@ -918,7 +917,7 @@ nsXMLContentSink::PopContent()
   mContentStack.RemoveElementAt(count - 1);
 }
 
-PRBool
+bool
 nsXMLContentSink::HaveNotifiedForCurrentContent() const
 {
   PRUint32 stackLength = mContentStack.Length();
@@ -927,11 +926,11 @@ nsXMLContentSink::HaveNotifiedForCurrentContent() const
     nsIContent* parent = stackNode.mContent;
     return stackNode.mNumFlushed == parent->GetChildCount();
   }
-  return PR_TRUE;
+  return true;
 }
 
 void
-nsXMLContentSink::MaybeStartLayout(PRBool aIgnorePendingSheets)
+nsXMLContentSink::MaybeStartLayout(bool aIgnorePendingSheets)
 {
   // XXXbz if aIgnorePendingSheets is true, what should we do when
   // mXSLTProcessor or CanStillPrettyPrint()?
@@ -943,13 +942,13 @@ nsXMLContentSink::MaybeStartLayout(PRBool aIgnorePendingSheets)
 
 ////////////////////////////////////////////////////////////////////////
 
-PRBool
+bool
 nsXMLContentSink::SetDocElement(PRInt32 aNameSpaceID,
                                 nsIAtom* aTagName,
                                 nsIContent *aContent)
 {
   if (mDocElement)
-    return PR_FALSE;
+    return false;
 
   // check for root elements that needs special handling for
   // prettyprinting
@@ -958,13 +957,13 @@ nsXMLContentSink::SetDocElement(PRInt32 aNameSpaceID,
       (aNameSpaceID == kNameSpaceID_XSLT &&
        (aTagName == nsGkAtoms::stylesheet ||
         aTagName == nsGkAtoms::transform))) {
-    mPrettyPrintHasSpecialRoot = PR_TRUE;
+    mPrettyPrintHasSpecialRoot = true;
     if (mPrettyPrintXML) {
       // In this case, disable script execution, stylesheet
       // loading, and auto XLinks since we plan to prettyprint.
-      mDocument->ScriptLoader()->SetEnabled(PR_FALSE);
+      mDocument->ScriptLoader()->SetEnabled(false);
       if (mCSSLoader) {
-        mCSSLoader->SetEnabled(PR_FALSE);
+        mCSSLoader->SetEnabled(false);
       }
     }        
   }
@@ -973,9 +972,9 @@ nsXMLContentSink::SetDocElement(PRInt32 aNameSpaceID,
   NS_ADDREF(mDocElement);
   nsresult rv = mDocument->AppendChildTo(mDocElement, NotifyForDocElement());
   if (NS_FAILED(rv)) {
-    // If we return PR_FALSE here, the caller will bail out because it won't
+    // If we return false here, the caller will bail out because it won't
     // find a parent content node to append to, which is fine.
-    return PR_FALSE;
+    return false;
   }
 
   if (aTagName == nsGkAtoms::html &&
@@ -983,7 +982,7 @@ nsXMLContentSink::SetDocElement(PRInt32 aNameSpaceID,
     ProcessOfflineManifest(aContent);
   }
 
-  return PR_TRUE;
+  return true;
 }
 
 NS_IMETHODIMP
@@ -994,7 +993,7 @@ nsXMLContentSink::HandleStartElement(const PRUnichar *aName,
                                      PRUint32 aLineNumber)
 {
   return HandleStartElement(aName, aAtts, aAttsCount, aIndex, aLineNumber,
-                            PR_TRUE);
+                            true);
 }
 
 nsresult
@@ -1003,7 +1002,7 @@ nsXMLContentSink::HandleStartElement(const PRUnichar *aName,
                                      PRUint32 aAttsCount,
                                      PRInt32 aIndex,
                                      PRUint32 aLineNumber,
-                                     PRBool aInterruptable)
+                                     bool aInterruptable)
 {
   NS_PRECONDITION(aIndex >= -1, "Bogus aIndex");
   NS_PRECONDITION(aAttsCount % 2 == 0, "incorrect aAttsCount");
@@ -1011,7 +1010,7 @@ nsXMLContentSink::HandleStartElement(const PRUnichar *aName,
   aAttsCount /= 2;
 
   nsresult result = NS_OK;
-  PRBool appendContent = PR_TRUE;
+  bool appendContent = true;
   nsCOMPtr<nsIContent> content;
 
   // XXX Hopefully the parser will flag this before we get
@@ -1076,7 +1075,7 @@ nsXMLContentSink::HandleStartElement(const PRUnichar *aName,
     if (!SetDocElement(nameSpaceID, localName, content) && appendContent) {
       NS_ENSURE_TRUE(parent, NS_ERROR_UNEXPECTED);
 
-      parent->AppendChildTo(content, PR_FALSE);
+      parent->AppendChildTo(content, false);
     }
   }
 
@@ -1099,7 +1098,7 @@ nsXMLContentSink::HandleStartElement(const PRUnichar *aName,
   if (content != mDocElement && !mCurrentHead) {
     // This isn't the root and we're not inside an XHTML <head>.
     // Might need to start layout
-    MaybeStartLayout(PR_FALSE);
+    MaybeStartLayout(false);
   }
 
   if (content == mDocElement) {
@@ -1113,12 +1112,12 @@ nsXMLContentSink::HandleStartElement(const PRUnichar *aName,
 NS_IMETHODIMP
 nsXMLContentSink::HandleEndElement(const PRUnichar *aName)
 {
-  return HandleEndElement(aName, PR_TRUE);
+  return HandleEndElement(aName, true);
 }
 
 nsresult
 nsXMLContentSink::HandleEndElement(const PRUnichar *aName,
-                                   PRBool aInterruptable)
+                                   bool aInterruptable)
 {
   nsresult result = NS_OK;
 
@@ -1163,7 +1162,7 @@ nsXMLContentSink::HandleEndElement(const PRUnichar *aName,
     mState = eXMLContentSinkState_InEpilog;
 
     // We might have had no occasion to start layout yet.  Do so now.
-    MaybeStartLayout(PR_FALSE);
+    MaybeStartLayout(false);
   }
 
   PRInt32 stackLen = mContentStack.Length();
@@ -1196,7 +1195,7 @@ nsXMLContentSink::HandleComment(const PRUnichar *aName)
   nsCOMPtr<nsIContent> comment;
   nsresult rv = NS_NewCommentNode(getter_AddRefs(comment), mNodeInfoManager);
   if (comment) {
-    comment->SetText(nsDependentString(aName), PR_FALSE);
+    comment->SetText(nsDependentString(aName), false);
     rv = AddContentAsLeaf(comment);
     DidAddContent();
   }
@@ -1219,7 +1218,7 @@ nsXMLContentSink::HandleCDataSection(const PRUnichar *aData,
   nsCOMPtr<nsIContent> cdata;
   nsresult rv = NS_NewXMLCDATASection(getter_AddRefs(cdata), mNodeInfoManager);
   if (cdata) {
-    cdata->SetText(aData, aLength, PR_FALSE);
+    cdata->SetText(aData, aLength, false);
     rv = AddContentAsLeaf(cdata);
     DidAddContent();
   }
@@ -1257,7 +1256,7 @@ nsXMLContentSink::HandleDoctypeDecl(const nsAString & aSubset,
     nsCOMPtr<nsIURI> uri(do_QueryInterface(aCatalogData));
     if (uri) {
       nsRefPtr<nsCSSStyleSheet> sheet;
-      mCSSLoader->LoadSheetSync(uri, PR_TRUE, PR_TRUE, getter_AddRefs(sheet));
+      mCSSLoader->LoadSheetSync(uri, true, true, getter_AddRefs(sheet));
 
 #ifdef NS_DEBUG
       nsCAutoString uriStr;
@@ -1275,7 +1274,7 @@ nsXMLContentSink::HandleDoctypeDecl(const nsAString & aSubset,
   nsCOMPtr<nsIContent> content = do_QueryInterface(docType);
   NS_ASSERTION(content, "doctype isn't content?");
 
-  rv = mDocument->AppendChildTo(content, PR_FALSE);
+  rv = mDocument->AppendChildTo(content, false);
   DidAddContent();
   return NS_SUCCEEDED(rv) ? DidProcessATokenImpl() : rv;
 }
@@ -1284,12 +1283,12 @@ NS_IMETHODIMP
 nsXMLContentSink::HandleCharacterData(const PRUnichar *aData, 
                                       PRUint32 aLength)
 {
-  return HandleCharacterData(aData, aLength, PR_TRUE);
+  return HandleCharacterData(aData, aLength, true);
 }
 
 nsresult
 nsXMLContentSink::HandleCharacterData(const PRUnichar *aData, PRUint32 aLength,
-                                      PRBool aInterruptable)
+                                      bool aInterruptable)
 {
   nsresult rv = NS_OK;
   if (aData && mState != eXMLContentSinkState_InProlog &&
@@ -1316,9 +1315,9 @@ nsXMLContentSink::HandleProcessingInstruction(const PRUnichar *aTarget,
 
   nsCOMPtr<nsIStyleSheetLinkingElement> ssle(do_QueryInterface(node));
   if (ssle) {
-    ssle->InitStyleLinkElement(PR_FALSE);
-    ssle->SetEnableUpdates(PR_FALSE);
-    mPrettyPrintXML = PR_FALSE;
+    ssle->InitStyleLinkElement(false);
+    ssle->SetEnableUpdates(false);
+    mPrettyPrintXML = false;
   }
 
   rv = AddContentAsLeaf(node);
@@ -1328,9 +1327,9 @@ nsXMLContentSink::HandleProcessingInstruction(const PRUnichar *aTarget,
   if (ssle) {
     // This is an xml-stylesheet processing instruction... but it might not be
     // a CSS one if the type is set to something else.
-    ssle->SetEnableUpdates(PR_TRUE);
-    PRBool willNotify;
-    PRBool isAlternate;
+    ssle->SetEnableUpdates(true);
+    bool willNotify;
+    bool isAlternate;
     rv = ssle->UpdateStyleSheet(mFragmentMode ? nsnull : this,
                                 &willNotify,
                                 &isAlternate);
@@ -1359,7 +1358,7 @@ nsXMLContentSink::HandleProcessingInstruction(const PRUnichar *aTarget,
   }
 
   nsAutoString href, title, media;
-  PRBool isAlternate = PR_FALSE;
+  bool isAlternate = false;
 
   // If there was no href, we can't do anything with this PI
   if (!ParsePIData(data, href, title, media, isAlternate)) {
@@ -1371,14 +1370,14 @@ nsXMLContentSink::HandleProcessingInstruction(const PRUnichar *aTarget,
 }
 
 /* static */
-PRBool
+bool
 nsXMLContentSink::ParsePIData(const nsString &aData, nsString &aHref,
                               nsString &aTitle, nsString &aMedia,
-                              PRBool &aIsAlternate)
+                              bool &aIsAlternate)
 {
   // If there was no href, we can't do anything with this PI
   if (!nsParserUtils::GetQuotedAttributeValue(aData, nsGkAtoms::href, aHref)) {
-    return PR_FALSE;
+    return false;
   }
 
   nsParserUtils::GetQuotedAttributeValue(aData, nsGkAtoms::title, aTitle);
@@ -1390,7 +1389,7 @@ nsXMLContentSink::ParsePIData(const nsString &aData, nsString &aHref,
 
   aIsAlternate = alternate.EqualsLiteral("yes");
 
-  return PR_TRUE;
+  return true;
 }
 
 NS_IMETHODIMP
@@ -1407,15 +1406,15 @@ NS_IMETHODIMP
 nsXMLContentSink::ReportError(const PRUnichar* aErrorText, 
                               const PRUnichar* aSourceText,
                               nsIScriptError *aError,
-                              PRBool *_retval)
+                              bool *_retval)
 {
   NS_PRECONDITION(aError && aSourceText && aErrorText, "Check arguments!!!");
   nsresult rv = NS_OK;
 
   // The expat driver should report the error.  We're just cleaning up the mess.
-  *_retval = PR_TRUE;
+  *_retval = true;
   
-  mPrettyPrintXML = PR_FALSE;
+  mPrettyPrintXML = false;
 
   mState = eXMLContentSinkState_InProlog;
 
@@ -1423,7 +1422,7 @@ nsXMLContentSink::ReportError(const PRUnichar* aErrorText,
 
   // stop observing in order to avoid crashing when removing content
   mDocument->RemoveObserver(this);
-  mIsDocumentObserver = PR_FALSE;
+  mIsDocumentObserver = false;
 
   // Clear the current content and
   // prepare to set <parsererror> as the document root
@@ -1468,10 +1467,10 @@ nsXMLContentSink::ReportError(const PRUnichar* aErrorText,
   parsererror.AppendLiteral("parsererror");
   
   rv = HandleStartElement(parsererror.get(), noAtts, 0, -1, (PRUint32)-1,
-                          PR_FALSE);
+                          false);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  rv = HandleCharacterData(aErrorText, nsCRT::strlen(aErrorText), PR_FALSE);
+  rv = HandleCharacterData(aErrorText, nsCRT::strlen(aErrorText), false);
   NS_ENSURE_SUCCESS(rv, rv);  
   
   nsAutoString sourcetext(errorNs);
@@ -1479,16 +1478,16 @@ nsXMLContentSink::ReportError(const PRUnichar* aErrorText,
   sourcetext.AppendLiteral("sourcetext");
 
   rv = HandleStartElement(sourcetext.get(), noAtts, 0, -1, (PRUint32)-1,
-                          PR_FALSE);
+                          false);
   NS_ENSURE_SUCCESS(rv, rv);
   
-  rv = HandleCharacterData(aSourceText, nsCRT::strlen(aSourceText), PR_FALSE);
+  rv = HandleCharacterData(aSourceText, nsCRT::strlen(aSourceText), false);
   NS_ENSURE_SUCCESS(rv, rv);
   
-  rv = HandleEndElement(sourcetext.get(), PR_FALSE);
+  rv = HandleEndElement(sourcetext.get(), false);
   NS_ENSURE_SUCCESS(rv, rv); 
   
-  rv = HandleEndElement(parsererror.get(), PR_FALSE);
+  rv = HandleEndElement(parsererror.get(), false);
   NS_ENSURE_SUCCESS(rv, rv);
 
   FlushTags();
@@ -1509,7 +1508,7 @@ nsXMLContentSink::AddAttributes(const PRUnichar** aAtts,
 
     // Add attribute to content
     aContent->SetAttr(nameSpaceID, localName, prefix,
-                      nsDependentString(aAtts[1]), PR_FALSE);
+                      nsDependentString(aAtts[1]), false);
     aAtts += 2;
   }
 
@@ -1582,13 +1581,13 @@ nsXMLContentSink::FlushPendingNotifications(mozFlushType aType)
         FlushTags();
       }
       else {
-        FlushText(PR_FALSE);
+        FlushText(false);
       }
     }
     if (aType >= Flush_InterruptibleLayout) {
       // Make sure that layout has started so that the reflow flush
       // will actually happen.
-      MaybeStartLayout(PR_TRUE);
+      MaybeStartLayout(true);
     }
   }
 }
@@ -1605,19 +1604,19 @@ nsXMLContentSink::FlushPendingNotifications(mozFlushType aType)
 nsresult
 nsXMLContentSink::FlushTags()
 {
-  mDeferredFlushTags = PR_FALSE;
-  PRBool oldBeganUpdate = mBeganUpdate;
+  mDeferredFlushTags = false;
+  bool oldBeganUpdate = mBeganUpdate;
   PRUint32 oldUpdates = mUpdatesInNotification;
 
   mUpdatesInNotification = 0;
   ++mInNotification;
   {
     // Scope so we call EndUpdate before we decrease mInNotification
-    mozAutoDocUpdate updateBatch(mDocument, UPDATE_CONTENT_MODEL, PR_TRUE);
-    mBeganUpdate = PR_TRUE;
+    mozAutoDocUpdate updateBatch(mDocument, UPDATE_CONTENT_MODEL, true);
+    mBeganUpdate = true;
 
     // Don't release last text node in case we need to add to it again
-    FlushText(PR_FALSE);
+    FlushText(false);
 
     // Start from the base of the stack (growing downward) and do
     // a notification from the node that is closest to the root of
@@ -1625,7 +1624,7 @@ nsXMLContentSink::FlushTags()
 
     PRInt32 stackPos;
     PRInt32 stackLen = mContentStack.Length();
-    PRBool flushed = PR_FALSE;
+    bool flushed = false;
     PRUint32 childCount;
     nsIContent* content;
 
@@ -1635,7 +1634,7 @@ nsXMLContentSink::FlushTags()
 
       if (!flushed && (mContentStack[stackPos].mNumFlushed < childCount)) {
         NotifyAppend(content, mContentStack[stackPos].mNumFlushed);
-        flushed = PR_TRUE;
+        flushed = true;
       }
 
       mContentStack[stackPos].mNumFlushed = childCount;
@@ -1676,7 +1675,7 @@ nsXMLContentSink::UpdateChildCounts()
   mNotifyLevel = stackLen - 1;
 }
 
-PRBool
+bool
 nsXMLContentSink::IsMonolithicContainer(nsINodeInfo* aNodeInfo)
 {
   return ((aNodeInfo->NamespaceID() == kNameSpaceID_XHTML &&
