@@ -75,6 +75,7 @@
 #include "nsStyledElement.h"
 #include "nsDOMScriptObjectHolder.h"
 #include "nsIFrameLoader.h"
+#include "jspubtd.h"
 
 class nsIDocument;
 class nsString;
@@ -244,10 +245,10 @@ public:
         : nsXULPrototypeNode(eType_Element),
           mNumAttributes(0),
           mAttributes(nsnull),
-          mHasIdAttribute(PR_FALSE),
-          mHasClassAttribute(PR_FALSE),
-          mHasStyleAttribute(PR_FALSE),
-          mHoldsScriptObject(PR_FALSE),
+          mHasIdAttribute(false),
+          mHasClassAttribute(false),
+          mHasStyleAttribute(false),
+          mHoldsScriptObject(false),
           mScriptTypeID(nsIProgrammingLanguage::UNKNOWN)
     {
     }
@@ -291,10 +292,10 @@ public:
     PRUint32                 mNumAttributes;
     nsXULPrototypeAttribute* mAttributes;         // [OWNER]
     
-    PRPackedBool             mHasIdAttribute:1;
-    PRPackedBool             mHasClassAttribute:1;
-    PRPackedBool             mHasStyleAttribute:1;
-    PRPackedBool             mHoldsScriptObject:1;
+    bool                     mHasIdAttribute:1;
+    bool                     mHasClassAttribute:1;
+    bool                     mHasStyleAttribute:1;
+    bool                     mHoldsScriptObject:1;
 
     // The language ID can not be set on a per-node basis, but is tracked
     // so that the language ID from the originating root can be used
@@ -341,9 +342,9 @@ public:
                      "Wrong language, this will leak the previous object.");
 
         mScriptObject.mLangID = aHolder.getScriptTypeID();
-        Set((void*)aHolder);
+        Set(aHolder.getScript());
     }
-    void Set(void *aObject);
+    void Set(JSScript* aObject);
 
     struct ScriptObjectHolder
     {
@@ -352,12 +353,12 @@ public:
         {
         }
         PRUint32 mLangID;
-        void* mObject;
+        JSScript* mObject;
     };
     nsCOMPtr<nsIURI>         mSrcURI;
     PRUint32                 mLineNo;
-    PRPackedBool             mSrcLoading;
-    PRPackedBool             mOutOfLine;
+    bool                     mSrcLoading;
+    bool                     mOutOfLine;
     nsXULDocument*           mSrcLoadWaiters;   // [OWNER] but not COMPtr
     PRUint32                 mLangVersion;
     ScriptObjectHolder       mScriptObject;
@@ -466,7 +467,7 @@ public:
 
     static nsresult
     Create(nsXULPrototypeElement* aPrototype, nsIDocument* aDocument,
-           PRBool aIsScriptable, mozilla::dom::Element** aResult);
+           bool aIsScriptable, mozilla::dom::Element** aResult);
 
     // nsISupports
     NS_DECL_ISUPPORTS_INHERITED
@@ -479,16 +480,16 @@ public:
     // nsIContent
     virtual nsresult BindToTree(nsIDocument* aDocument, nsIContent* aParent,
                                 nsIContent* aBindingParent,
-                                PRBool aCompileEventHandlers);
-    virtual void UnbindFromTree(PRBool aDeep, PRBool aNullParent);
-    virtual nsresult RemoveChildAt(PRUint32 aIndex, PRBool aNotify);
-    virtual PRBool GetAttr(PRInt32 aNameSpaceID, nsIAtom* aName,
+                                bool aCompileEventHandlers);
+    virtual void UnbindFromTree(bool aDeep, bool aNullParent);
+    virtual nsresult RemoveChildAt(PRUint32 aIndex, bool aNotify);
+    virtual bool GetAttr(PRInt32 aNameSpaceID, nsIAtom* aName,
                            nsAString& aResult) const;
-    virtual PRBool HasAttr(PRInt32 aNameSpaceID, nsIAtom* aName) const;
-    virtual PRBool AttrValueIs(PRInt32 aNameSpaceID, nsIAtom* aName,
+    virtual bool HasAttr(PRInt32 aNameSpaceID, nsIAtom* aName) const;
+    virtual bool AttrValueIs(PRInt32 aNameSpaceID, nsIAtom* aName,
                                const nsAString& aValue,
                                nsCaseTreatment aCaseSensitive) const;
-    virtual PRBool AttrValueIs(PRInt32 aNameSpaceID, nsIAtom* aName,
+    virtual bool AttrValueIs(PRInt32 aNameSpaceID, nsIAtom* aName,
                                nsIAtom* aValue,
                                nsCaseTreatment aCaseSensitive) const;
     virtual PRInt32 FindAttrValueIn(PRInt32 aNameSpaceID,
@@ -496,25 +497,25 @@ public:
                                     AttrValuesArray* aValues,
                                     nsCaseTreatment aCaseSensitive) const;
     virtual nsresult UnsetAttr(PRInt32 aNameSpaceID, nsIAtom* aName,
-                               PRBool aNotify);
+                               bool aNotify);
     virtual const nsAttrName* GetAttrNameAt(PRUint32 aIndex) const;
     virtual PRUint32 GetAttrCount() const;
     virtual void DestroyContent();
 
 #ifdef DEBUG
     virtual void List(FILE* out, PRInt32 aIndent) const;
-    virtual void DumpContent(FILE* out, PRInt32 aIndent,PRBool aDumpAll) const
+    virtual void DumpContent(FILE* out, PRInt32 aIndent,bool aDumpAll) const
     {
     }
 #endif
 
-    virtual void PerformAccesskey(PRBool aKeyCausesActivation,
-                                  PRBool aIsTrustedEvent);
+    virtual void PerformAccesskey(bool aKeyCausesActivation,
+                                  bool aIsTrustedEvent);
     nsresult ClickWithInputSource(PRUint16 aInputSource);
 
     virtual nsIContent *GetBindingParent() const;
-    virtual PRBool IsNodeOfType(PRUint32 aFlags) const;
-    virtual PRBool IsFocusable(PRInt32 *aTabIndex = nsnull, PRBool aWithMouse = PR_FALSE);
+    virtual bool IsNodeOfType(PRUint32 aFlags) const;
+    virtual bool IsFocusable(PRInt32 *aTabIndex = nsnull, bool aWithMouse = false);
     virtual nsIAtom* DoGetID() const;
     virtual const nsAttrValue* DoGetClasses() const;
 
@@ -522,7 +523,7 @@ public:
     virtual mozilla::css::StyleRule* GetInlineStyleRule();
     virtual nsChangeHint GetAttributeChangeHint(const nsIAtom* aAttribute,
                                                 PRInt32 aModType) const;
-    NS_IMETHOD_(PRBool) IsAttributeMapped(const nsIAtom* aAttribute) const;
+    NS_IMETHOD_(bool) IsAttributeMapped(const nsIAtom* aAttribute) const;
 
     // XUL element methods
     /**
@@ -531,7 +532,7 @@ public:
      */
     void SetTemplateGenerated() { SetFlags(XUL_ELEMENT_TEMPLATE_GENERATED); }
     void ClearTemplateGenerated() { UnsetFlags(XUL_ELEMENT_TEMPLATE_GENERATED); }
-    PRBool GetTemplateGenerated() { return HasFlag(XUL_ELEMENT_TEMPLATE_GENERATED); }
+    bool GetTemplateGenerated() { return HasFlag(XUL_ELEMENT_TEMPLATE_GENERATED); }
 
     // nsIDOMNode
     NS_FORWARD_NSIDOMNODE(nsGenericElement::)
@@ -625,19 +626,19 @@ protected:
     }
 
     virtual nsresult BeforeSetAttr(PRInt32 aNamespaceID, nsIAtom* aName,
-                                   const nsAString* aValue, PRBool aNotify);
+                                   const nsAString* aValue, bool aNotify);
     virtual nsresult AfterSetAttr(PRInt32 aNamespaceID, nsIAtom* aName,
-                                  const nsAString* aValue, PRBool aNotify);
+                                  const nsAString* aValue, bool aNotify);
 
-    virtual void UpdateEditableState(PRBool aNotify);
+    virtual void UpdateEditableState(bool aNotify);
 
-    virtual PRBool ParseAttribute(PRInt32 aNamespaceID,
+    virtual bool ParseAttribute(PRInt32 aNamespaceID,
                                   nsIAtom* aAttribute,
                                   const nsAString& aValue,
                                   nsAttrValue& aResult);
 
     virtual nsEventListenerManager*
-      GetEventListenerManagerForAttr(nsIAtom* aAttrName, PRBool* aDefer);
+      GetEventListenerManagerForAttr(nsIAtom* aAttrName, bool* aDefer);
   
     /**
      * Return our prototype's attribute, if one exists.
@@ -648,18 +649,18 @@ protected:
      * Add a listener for the specified attribute, if appropriate.
      */
     void AddListenerFor(const nsAttrName& aName,
-                        PRBool aCompileEventHandlers);
+                        bool aCompileEventHandlers);
     void MaybeAddPopupListener(nsIAtom* aLocalName);
 
     nsIWidget* GetWindowWidget();
 
     // attribute setters for widget
-    nsresult HideWindowChrome(PRBool aShouldHide);
+    nsresult HideWindowChrome(bool aShouldHide);
     void SetChromeMargins(const nsAString* aValue);
     void ResetChromeMargins();
-    void SetTitlebarColor(nscolor aColor, PRBool aActive);
+    void SetTitlebarColor(nscolor aColor, bool aActive);
 
-    void SetDrawsInTitlebar(PRBool aState);
+    void SetDrawsInTitlebar(bool aState);
 
     const nsAttrName* InternalGetExistingAttrNameFromQName(const nsAString& aStr) const;
 
@@ -674,7 +675,7 @@ protected:
     }
 
     void UnregisterAccessKey(const nsAString& aOldValue);
-    PRBool BoolAttrIsTrue(nsIAtom* aName);
+    bool BoolAttrIsTrue(nsIAtom* aName);
 
     friend nsresult
     NS_NewXULElement(nsIContent** aResult, nsINodeInfo *aNodeInfo);
@@ -683,7 +684,7 @@ protected:
 
     static already_AddRefed<nsXULElement>
     Create(nsXULPrototypeElement* aPrototype, nsINodeInfo *aNodeInfo,
-           PRBool aIsScriptable);
+           bool aIsScriptable);
 
     friend class nsScriptEventHandlerOwnerTearoff;
 
