@@ -115,7 +115,7 @@ public:
    *
    * aWindow and aFocusedWindow must both be non-null.
    */
-  static nsIContent* GetFocusedDescendant(nsPIDOMWindow* aWindow, PRBool aDeep,
+  static nsIContent* GetFocusedDescendant(nsPIDOMWindow* aWindow, bool aDeep,
                                           nsPIDOMWindow** aFocusedWindow);
 
   /**
@@ -137,7 +137,7 @@ public:
    */
   static PRUint32 GetFocusMoveReason(PRUint32 aFlags);
 
-  static PRBool sMouseFocusesFormControl;
+  static bool sMouseFocusesFormControl;
 
 protected:
 
@@ -162,13 +162,13 @@ protected:
    * to those that update the focus in an inactive window for instance).
    */
   void SetFocusInner(nsIContent* aNewContent, PRInt32 aFlags,
-                     PRBool aFocusChanged, PRBool aAdjustWidget);
+                     bool aFocusChanged, bool aAdjustWidget);
 
   /**
    * Returns true if aPossibleAncestor is the same as aWindow or an
    * ancestor of aWindow.
    */
-  PRBool IsSameOrAncestor(nsPIDOMWindow* aPossibleAncestor,
+  bool IsSameOrAncestor(nsPIDOMWindow* aPossibleAncestor,
                           nsPIDOMWindow* aWindow);
 
   /**
@@ -184,12 +184,12 @@ protected:
    * the active top-level window and navigate down the currently focused
    * elements for each frame in the tree to get to aNewWindow.
    */
-  void AdjustWindowFocus(nsPIDOMWindow* aNewWindow, PRBool aCheckPermission);
+  void AdjustWindowFocus(nsPIDOMWindow* aNewWindow, bool aCheckPermission);
 
   /**
    * Returns true if aWindow is visible.
    */
-  PRBool IsWindowVisible(nsPIDOMWindow* aWindow);
+  bool IsWindowVisible(nsPIDOMWindow* aWindow);
 
   /**
    * Returns true if aContent is a root element and not focusable.
@@ -198,7 +198,7 @@ protected:
    *
    * @param aContent must not be null and must be in a document.
    */
-  PRBool IsNonFocusableRoot(nsIContent* aContent);
+  bool IsNonFocusableRoot(nsIContent* aContent);
 
   /**
    * Checks and returns aContent if it may be focused, another content node if
@@ -235,10 +235,10 @@ protected:
    *
    * If aAdjustWidget is false, don't change the widget focus state.
    */
-  PRBool Blur(nsPIDOMWindow* aWindowToClear,
+  bool Blur(nsPIDOMWindow* aWindowToClear,
               nsPIDOMWindow* aAncestorWindowToFocus,
-              PRBool aIsLeavingDocument,
-              PRBool aAdjustWidget);
+              bool aIsLeavingDocument,
+              bool aAdjustWidget);
 
   /**
    * Focus an element in the active window and child frame.
@@ -269,10 +269,10 @@ protected:
   void Focus(nsPIDOMWindow* aWindow,
              nsIContent* aContent,
              PRUint32 aFlags,
-             PRBool aIsNewDocument,
-             PRBool aFocusChanged,
-             PRBool aWindowRaised,
-             PRBool aAdjustWidget);
+             bool aIsNewDocument,
+             bool aFocusChanged,
+             bool aWindowRaised,
+             bool aAdjustWidget);
 
   /**
    * Fires a focus or blur event at aTarget.
@@ -287,8 +287,8 @@ protected:
                             nsIDocument* aDocument,
                             nsISupports* aTarget,
                             PRUint32 aFocusMethod,
-                            PRBool aWindowRaised,
-                            PRBool aIsRefocus = PR_FALSE);
+                            bool aWindowRaised,
+                            bool aIsRefocus = false);
 
   /**
    * Scrolls aContent into view unless the FLAG_NOSCROLL flag is set.
@@ -310,8 +310,8 @@ protected:
    * aUpdateVisibility should be true to update whether the caret is
    * visible or not.
    */
-  void UpdateCaret(PRBool aMoveCaretToFocus,
-                   PRBool aUpdateVisibility,
+  void UpdateCaret(bool aMoveCaretToFocus,
+                   bool aUpdateVisibility,
                    nsIContent* aContent);
 
   /**
@@ -323,7 +323,7 @@ protected:
    * Makes the caret visible or not, depending on aVisible.
    */
   nsresult SetCaretVisible(nsIPresShell* aPresShell,
-                           PRBool aVisible,
+                           bool aVisible,
                            nsIContent* aContent);
 
 
@@ -385,9 +385,9 @@ protected:
                                   nsIContent* aRootContent,
                                   nsIContent* aOriginalStartContent,
                                   nsIContent* aStartContent,
-                                  PRBool aForward,
+                                  bool aForward,
                                   PRInt32 aCurrentTabIndex,
-                                  PRBool aIgnoreTabIndex,
+                                  bool aIgnoreTabIndex,
                                   nsIContent** aResultContent);
 
   /**
@@ -402,7 +402,7 @@ protected:
    *
    * aStartContent is the current image map area.
    */
-  nsIContent* GetNextTabbableMapArea(PRBool aForward,
+  nsIContent* GetNextTabbableMapArea(bool aForward,
                                      PRInt32 aCurrentTabIndex,
                                      nsIContent* aImageContent,
                                      nsIContent* aStartContent);
@@ -414,7 +414,7 @@ protected:
    */
   PRInt32 GetNextTabIndex(nsIContent* aParent,
                           PRInt32 aCurrentTabIndex,
-                          PRBool aForward);
+                          bool aForward);
 
   /**
    * Retrieves and returns the root node from aDocument to be focused. Will
@@ -428,8 +428,8 @@ protected:
    */
   nsIContent* GetRootForFocus(nsPIDOMWindow* aWindow,
                               nsIDocument* aDocument,
-                              PRBool aIsForDocNavigation,
-                              PRBool aCheckVisibility);
+                              bool aIsForDocNavigation,
+                              bool aCheckVisibility);
 
   /**
    * Get the TabParent associated with aContent if it is a remote browser,
@@ -465,7 +465,7 @@ protected:
    * This method would be used for document navigation, which is typically
    * invoked by pressing F6.
    */
-  nsIContent* GetNextTabbableDocument(PRBool aForward);
+  nsIContent* GetNextTabbableDocument(bool aForward);
 
   /**
    * Retreives a focusable element within the current selection of aWindow.
@@ -490,8 +490,8 @@ private:
   // focus rings: in the losing focus case that information could be
   // wrong..
   static void NotifyFocusStateChange(nsIContent* aContent,
-                                     PRBool aWindowShouldShowFocusRing,
-                                     PRBool aGettingFocus);
+                                     bool aWindowShouldShowFocusRing,
+                                     bool aGettingFocus);
 
   // the currently active and front-most top-most window
   nsCOMPtr<nsPIDOMWindow> mActiveWindow;
