@@ -80,8 +80,8 @@ class nsIArray;
 class nsPIWindowRoot;
 
 #define NS_PIDOMWINDOW_IID \
-{ 0xeee816d2, 0x2f08, 0x4b34, \
-  { 0x97, 0x47, 0x5e, 0x5a, 0xcd, 0xc3, 0x56, 0xfa } }
+{ 0x8ce567b5, 0xcc8d, 0x410b, \
+  { 0xa2, 0x7b, 0x07, 0xaf, 0x31, 0xc0, 0x33, 0xb8 } }
 
 class nsPIDOMWindow : public nsIDOMWindowInternal
 {
@@ -90,28 +90,36 @@ public:
 
   virtual nsPIDOMWindow* GetPrivateRoot() = 0;
 
-  virtual void ActivateOrDeactivate(PRBool aActivate) = 0;
+  virtual void ActivateOrDeactivate(bool aActivate) = 0;
 
   // this is called GetTopWindowRoot to avoid conflicts with nsIDOMWindow::GetWindowRoot
   virtual already_AddRefed<nsPIWindowRoot> GetTopWindowRoot() = 0;
 
-  virtual void SetActive(PRBool aActive)
+  virtual void SetActive(bool aActive)
   {
+    NS_PRECONDITION(IsOuterWindow(),
+                    "active state is only maintained on outer windows");
     mIsActive = aActive;
   }
 
-  PRBool IsActive()
+  bool IsActive()
   {
+    NS_PRECONDITION(IsOuterWindow(),
+                    "active state is only maintained on outer windows");
     return mIsActive;
   }
 
-  virtual void SetIsBackground(PRBool aIsBackground)
+  virtual void SetIsBackground(bool aIsBackground)
   {
+    NS_PRECONDITION(IsOuterWindow(),
+                    "background state is only maintained on outer windows");
     mIsBackground = aIsBackground;
   }
 
-  PRBool IsBackground()
+  bool IsBackground()
   {
+    NS_PRECONDITION(IsOuterWindow(),
+                    "background state is only maintained on outer windows");
     return mIsBackground;
   }
 
@@ -130,7 +138,7 @@ public:
     return mParentTarget;
   }
 
-  PRBool HasMutationListeners(PRUint32 aMutationEventType) const
+  bool HasMutationListeners(PRUint32 aMutationEventType) const
   {
     const nsPIDOMWindow *win;
 
@@ -140,13 +148,13 @@ public:
       if (!win) {
         NS_ERROR("No current inner window available!");
 
-        return PR_FALSE;
+        return false;
       }
     } else {
       if (!mOuterWindow) {
         NS_ERROR("HasMutationListeners() called on orphan inner window!");
 
-        return PR_FALSE;
+        return false;
       }
 
       win = this;
@@ -221,7 +229,7 @@ public:
     mOuterWindow->SetFrameElementInternal(aFrameElement);
   }
 
-  PRBool IsLoadingOrRunningTimeout() const
+  bool IsLoadingOrRunningTimeout() const
   {
     const nsPIDOMWindow *win = GetCurrentInnerWindow();
 
@@ -233,7 +241,7 @@ public:
   }
 
   // Check whether a document is currently loading
-  PRBool IsLoading() const
+  bool IsLoading() const
   {
     const nsPIDOMWindow *win;
 
@@ -243,13 +251,13 @@ public:
       if (!win) {
         NS_ERROR("No current inner window available!");
 
-        return PR_FALSE;
+        return false;
       }
     } else {
       if (!mOuterWindow) {
         NS_ERROR("IsLoading() called on orphan inner window!");
 
-        return PR_FALSE;
+        return false;
       }
 
       win = this;
@@ -258,7 +266,7 @@ public:
     return !win->mIsDocumentLoaded;
   }
 
-  PRBool IsHandlingResizeEvent() const
+  bool IsHandlingResizeEvent() const
   {
     const nsPIDOMWindow *win;
 
@@ -268,13 +276,13 @@ public:
       if (!win) {
         NS_ERROR("No current inner window available!");
 
-        return PR_FALSE;
+        return false;
       }
     } else {
       if (!mOuterWindow) {
         NS_ERROR("IsHandlingResizeEvent() called on orphan inner window!");
 
-        return PR_FALSE;
+        return false;
       }
 
       win = this;
@@ -293,7 +301,7 @@ public:
   virtual nsIPrincipal* GetOpenerScriptPrincipal() = 0;
 
   virtual PopupControlState PushPopupControlState(PopupControlState aState,
-                                                  PRBool aForce) const = 0;
+                                                  bool aForce) const = 0;
   virtual void PopPopupControlState(PopupControlState state) const = 0;
   virtual PopupControlState GetPopupControlState() const = 0;
 
@@ -306,10 +314,10 @@ public:
 
   // Suspend timeouts in this window and in child windows.
   virtual void SuspendTimeouts(PRUint32 aIncrease = 1,
-                               PRBool aFreezeChildren = PR_TRUE) = 0;
+                               bool aFreezeChildren = true) = 0;
 
   // Resume suspended timeouts in this window and in child windows.
-  virtual nsresult ResumeTimeouts(PRBool aThawChildren = PR_TRUE) = 0;
+  virtual nsresult ResumeTimeouts(bool aThawChildren = true) = 0;
 
   virtual PRUint32 TimeoutSuspendCount() = 0;
 
@@ -317,12 +325,12 @@ public:
   // the window was frozen.
   virtual nsresult FireDelayedDOMEvents() = 0;
 
-  virtual PRBool IsFrozen() const = 0;
+  virtual bool IsFrozen() const = 0;
 
   // Add a timeout to this window.
   virtual nsresult SetTimeoutOrInterval(nsIScriptTimeoutHandler *aHandler,
                                         PRInt32 interval,
-                                        PRBool aIsInterval, PRInt32 *aReturn) = 0;
+                                        bool aIsInterval, PRInt32 *aReturn) = 0;
 
   // Clear a timeout from this window.
   virtual nsresult ClearTimeoutOrInterval(PRInt32 aTimerID) = 0;
@@ -346,17 +354,17 @@ public:
     return GetCurrentInnerWindow();
   }
 
-  PRBool IsInnerWindow() const
+  bool IsInnerWindow() const
   {
     return mIsInnerWindow;
   }
 
-  PRBool IsOuterWindow() const
+  bool IsOuterWindow() const
   {
     return !IsInnerWindow();
   }
 
-  virtual PRBool WouldReuseInnerWindow(nsIDocument *aNewDocument) = 0;
+  virtual bool WouldReuseInnerWindow(nsIDocument *aNewDocument) = 0;
 
   /**
    * Get the docshell in this window.
@@ -387,7 +395,7 @@ public:
    */
   virtual nsresult SetNewDocument(nsIDocument *aDocument,
                                   nsISupports *aState,
-                                  PRBool aForceReuseInnerWindow) = 0;
+                                  bool aForceReuseInnerWindow) = 0;
 
   /**
    * Set the opener window.  aOriginalOpener is true if and only if this is the
@@ -397,7 +405,7 @@ public:
    * window does not have an opener when it's created.
    */
   virtual void SetOpenerWindow(nsIDOMWindow* aOpener,
-                               PRBool aOriginalOpener) = 0;
+                               bool aOriginalOpener) = 0;
 
   virtual void EnsureSizeUpToDate() = 0;
 
@@ -408,10 +416,10 @@ public:
   virtual nsIDOMWindow *EnterModalState() = 0;
   virtual void LeaveModalState(nsIDOMWindow *) = 0;
 
-  virtual PRBool CanClose() = 0;
+  virtual bool CanClose() = 0;
   virtual nsresult ForceClose() = 0;
 
-  PRBool IsModalContentWindow() const
+  bool IsModalContentWindow() const
   {
     return mIsModalContentWindow;
   }
@@ -422,14 +430,14 @@ public:
    */
   void SetHasPaintEventListeners()
   {
-    mMayHavePaintEventListener = PR_TRUE;
+    mMayHavePaintEventListener = true;
   }
 
   /**
    * Call this to check whether some node (this window, its document,
    * or content in that document) has a paint event listener.
    */
-  PRBool HasPaintEventListeners()
+  bool HasPaintEventListeners()
   {
     return mMayHavePaintEventListener;
   }
@@ -440,11 +448,11 @@ public:
    */
   void SetHasTouchEventListeners()
   {
-    mMayHaveTouchEventListener = PR_TRUE;
+    mMayHaveTouchEventListener = true;
     MaybeUpdateTouchState();
   }
 
-  PRBool HasTouchEventListeners()
+  bool HasTouchEventListeners()
   {
     return mMayHaveTouchEventListener;
   }
@@ -453,7 +461,7 @@ public:
    * Call this to check whether some node (this window, its document,
    * or content in that document) has a MozAudioAvailable event listener.
    */
-  PRBool HasAudioAvailableEventListeners()
+  bool HasAudioAvailableEventListeners()
   {
     return mMayHaveAudioAvailableEventListener;
   }
@@ -464,9 +472,27 @@ public:
    */
   void SetHasAudioAvailableEventListeners()
   {
-    mMayHaveAudioAvailableEventListener = PR_TRUE;
+    mMayHaveAudioAvailableEventListener = true;
   }
 
+  /**
+   * Call this to check whether some node (this window, its document,
+   * or content in that document) has a mouseenter/leave event listener.
+   */
+  bool HasMouseEnterLeaveEventListeners()
+  {
+    return mMayHaveMouseEnterLeaveEventListener;
+  }
+
+  /**
+   * Call this to indicate that some node (this window, its document,
+   * or content in that document) has a mouseenter/leave event listener.
+   */
+  void SetHasMouseEnterLeaveEventListeners()
+  {
+    mMayHaveMouseEnterLeaveEventListener = true;
+  }  
+
   /**
    * Initialize window.java and window.Packages.
    */
@@ -493,7 +519,7 @@ public:
   }
   virtual void SetFocusedNode(nsIContent* aNode,
                               PRUint32 aFocusMethod = 0,
-                              PRBool aNeedsFocus = PR_FALSE) = 0;
+                              bool aNeedsFocus = false) = 0;
 
   /**
    * Retrieves the method that was used to focus the current node.
@@ -510,7 +536,7 @@ public:
    * aFocusMethod may be set to one of the focus method constants in
    * nsIFocusManager to indicate how focus was set.
    */
-  virtual PRBool TakeFocus(PRBool aFocus, PRUint32 aFocusMethod) = 0;
+  virtual bool TakeFocus(bool aFocus, PRUint32 aFocusMethod) = 0;
 
   /**
    * Indicates that the window may now accept a document focus event. This
@@ -521,7 +547,7 @@ public:
   /**
    * Whether the focused content within the window should show a focus ring.
    */
-  virtual PRBool ShouldShowFocusRing() = 0;
+  virtual bool ShouldShowFocusRing() = 0;
 
   /**
    * Set the keyboard indicator state for accelerators and focus rings.
@@ -532,8 +558,8 @@ public:
   /**
    * Get the keyboard indicator state for accelerators and focus rings.
    */
-  virtual void GetKeyboardIndicators(PRBool* aShowAccelerators,
-                                     PRBool* aShowFocusRings) = 0;
+  virtual void GetKeyboardIndicators(bool* aShowAccelerators,
+                                     bool* aShowFocusRings) = 0;
 
   /**
    * Indicates that the page in the window has been hidden. This is used to
@@ -558,6 +584,11 @@ public:
    */
   virtual void SetHasOrientationEventListener() = 0;
 
+  /**
+   * Tell this window that we remove an orientation listener
+   */
+  virtual void RemoveOrientationEventListener() = 0;
+
   /**
    * Set a arguments for this window. This will be set on the window
    * right away (if there's an existing document) and it will also be
@@ -583,7 +614,7 @@ public:
    * Dispatch a custom event with name aEventName targeted at this window.
    * Returns whether the default action should be performed.
    */
-  virtual PRBool DispatchCustomEvent(const char *aEventName) = 0;
+  virtual bool DispatchCustomEvent(const char *aEventName) = 0;
 
 protected:
   // The nsPIDOMWindow constructor. The aOuterWindow argument should
@@ -621,25 +652,26 @@ protected:
 
   PRUint32               mMutationBits;
 
-  PRPackedBool           mIsDocumentLoaded;
-  PRPackedBool           mIsHandlingResizeEvent;
-  PRPackedBool           mIsInnerWindow;
-  PRPackedBool           mMayHavePaintEventListener;
-  PRPackedBool           mMayHaveTouchEventListener;
-  PRPackedBool           mMayHaveAudioAvailableEventListener;
+  bool                   mIsDocumentLoaded;
+  bool                   mIsHandlingResizeEvent;
+  bool                   mIsInnerWindow;
+  bool                   mMayHavePaintEventListener;
+  bool                   mMayHaveTouchEventListener;
+  bool                   mMayHaveAudioAvailableEventListener;
+  bool                   mMayHaveMouseEnterLeaveEventListener;
 
   // This variable is used on both inner and outer windows (and they
   // should match).
-  PRPackedBool           mIsModalContentWindow;
+  bool                   mIsModalContentWindow;
 
   // Tracks activation state that's used for :-moz-window-inactive.
   // Only used on outer windows.
-  PRPackedBool           mIsActive;
+  bool                   mIsActive;
 
   // Tracks whether our docshell is active.  If it is, mIsBackground
   // is false.  Too bad we have so many different concepts of
   // "active".  Only used on outer windows.
-  PRPackedBool           mIsBackground;
+  bool                   mIsBackground;
 
   // And these are the references between inner and outer windows.
   nsPIDOMWindow         *mInnerWindow;
@@ -655,7 +687,7 @@ protected:
 
   // This is only used by the inner window. Set to true once we've sent
   // the (chrome|content)-document-global-created notification.
-  PRPackedBool mHasNotifiedGlobalCreated;
+  bool mHasNotifiedGlobalCreated;
 };
 
 
@@ -663,7 +695,7 @@ NS_DEFINE_STATIC_IID_ACCESSOR(nsPIDOMWindow, NS_PIDOMWINDOW_IID)
 
 #ifdef _IMPL_NS_LAYOUT
 PopupControlState
-PushPopupControlState(PopupControlState aState, PRBool aForce);
+PushPopupControlState(PopupControlState aState, bool aForce);
 
 void
 PopPopupControlState(PopupControlState aState);
@@ -683,7 +715,7 @@ class NS_AUTO_POPUP_STATE_PUSHER
 {
 public:
 #ifdef _IMPL_NS_LAYOUT
-  NS_AUTO_POPUP_STATE_PUSHER(PopupControlState aState, PRBool aForce = PR_FALSE)
+  NS_AUTO_POPUP_STATE_PUSHER(PopupControlState aState, bool aForce = false)
     : mOldState(::PushPopupControlState(aState, aForce))
   {
   }
@@ -697,7 +729,7 @@ public:
     : mWindow(aWindow), mOldState(openAbused)
   {
     if (aWindow) {
-      mOldState = aWindow->PushPopupControlState(aState, PR_FALSE);
+      mOldState = aWindow->PushPopupControlState(aState, false);
     }
   }
 
