@@ -236,6 +236,10 @@ public:
 
     void InvalidateRect(NPRect* aInvalidRect);
 
+#ifdef MOZ_WIDGET_COCOA
+    void Invalidate();
+#endif // definied(MOZ_WIDGET_COCOA)
+
     uint32_t ScheduleTimer(uint32_t interval, bool repeat, TimerFunc func);
     void UnscheduleTimer(uint32_t id);
 
@@ -281,7 +285,7 @@ private:
     void SetupFlashMsgThrottle();
     void UnhookWinlessFlashThrottle();
     void HookSetWindowLongPtr();
-    static inline PRBool SetWindowLongHookCheck(HWND hWnd,
+    static inline bool SetWindowLongHookCheck(HWND hWnd,
                                                 int nIndex,
                                                 LONG_PTR newLong);
     void FlashThrottleMessage(HWND, UINT, WPARAM, LPARAM, bool);
@@ -426,6 +430,9 @@ private:
     nsCARenderer          mCARenderer;
     void                 *mCGLayer;
 
+    // Core Animation drawing model requires a refresh timer.
+    uint32_t mCARefreshTimer;
+
 public:
     const NPCocoaEvent* getCurrentEvent() {
         return mCurrentEvent;
@@ -594,7 +601,7 @@ private:
 #if (MOZ_PLATFORM_MAEMO == 5) || (MOZ_PLATFORM_MAEMO == 6)
     // Maemo5 Flash does not remember WindowlessLocal state
     // we should listen for NPP values negotiation and remember it
-    PRPackedBool          mMaemoImageRendering;
+    bool                  mMaemoImageRendering;
 #endif
 };
 
