@@ -62,8 +62,6 @@
 #include "nsITimer.h"
 #include "nsWeakReference.h"
 
-#define NS_DOMSTORAGE_FLUSH_TIMER_OBSERVER "domstorage-flush-timer"
-
 #include "nsDOMStorageDBWrapper.h"
 
 #define IS_PERMISSION_ALLOWED(perm) \
@@ -125,7 +123,7 @@ public:
 
   nsresult ClearAllStorages();
 
-  PRBool InPrivateBrowsingMode() { return mInPrivateBrowsing; }
+  bool InPrivateBrowsingMode() { return mInPrivateBrowsing; }
 
   static nsresult Initialize();
   static nsDOMStorageManager* GetInstance();
@@ -134,14 +132,14 @@ public:
   /**
    * Checks whether there is any data waiting to be flushed from a temp table.
    */
-  PRBool UnflushedDataExists();
+  bool UnflushedDataExists();
 
   static nsDOMStorageManager* gStorageManager;
 
 protected:
 
   nsTHashtable<nsDOMStorageEntry> mStorages;
-  PRBool mInPrivateBrowsing;
+  bool mInPrivateBrowsing;
 };
 
 class DOMStorageBase : public nsISupports
@@ -171,7 +169,7 @@ public:
   // This call relies on mSessionOnly, and should only be used
   // after a CacheStoragePermissions() call.  See the comments
   // for mSessionOnly below.
-  PRBool UseDB() {
+  bool UseDB() {
     return mUseDB;
   }
 
@@ -179,7 +177,7 @@ public:
   virtual nsresult
   GetDBValue(const nsAString& aKey,
              nsAString& aValue,
-             PRBool* aSecure) = 0;
+             bool* aSecure) = 0;
 
   // set the value corresponding to a key in the storage. If
   // aSecure is false, then attempts to modify a secure value
@@ -187,11 +185,11 @@ public:
   virtual nsresult
   SetDBValue(const nsAString& aKey,
              const nsAString& aValue,
-             PRBool aSecure) = 0;
+             bool aSecure) = 0;
 
   // set the value corresponding to a key as secure.
   virtual nsresult
-  SetSecure(const nsAString& aKey, PRBool aSecure) = 0;
+  SetSecure(const nsAString& aKey, bool aSecure) = 0;
 
   virtual nsresult
   CloneFrom(bool aCallerSecure, DOMStorageBase* aThat) = 0;
@@ -203,7 +201,7 @@ public:
 
   // e.g. "moc.rab.%" - reversed eTLD+1 subpart of the domain or
   // reversed offline application allowed domain.
-  nsCString& GetQuotaDomainDBKey(PRBool aOfflineAllowed)
+  nsCString& GetQuotaDomainDBKey(bool aOfflineAllowed)
   {
     return aOfflineAllowed ? mQuotaDomainDBKey : mQuotaETLDplus1DomainDBKey;
   }
@@ -217,14 +215,14 @@ protected:
   nsPIDOMStorage::nsDOMStorageType mStorageType;
   
   // true if the storage database should be used for values
-  PRPackedBool mUseDB;
+  bool mUseDB;
 
   // true if the preferences indicates that this storage should be
   // session only. This member is updated by
   // CacheStoragePermissions(), using the current principal.
   // CacheStoragePermissions() must be called at each entry point to
   // make sure this stays up to date.
-  PRPackedBool mSessionOnly;
+  bool mSessionOnly;
 
   // domain this store is associated with
   nsCString mDomain;
@@ -253,7 +251,7 @@ public:
   virtual void InitAsLocalStorage(nsIURI* aDomainURI, bool aCanUseChromePersist);
   virtual void InitAsGlobalStorage(const nsACString& aDomainDemanded);
 
-  PRBool SessionOnly() {
+  bool SessionOnly() {
     return mSessionOnly;
   }
 
@@ -283,13 +281,13 @@ public:
   nsresult
   GetCachedValue(const nsAString& aKey,
                  nsAString& aValue,
-                 PRBool* aSecure);
+                 bool* aSecure);
 
   // retrieve the value and secure state corresponding to a key out of storage.
   virtual nsresult
   GetDBValue(const nsAString& aKey,
              nsAString& aValue,
-             PRBool* aSecure);
+             bool* aSecure);
 
   // set the value corresponding to a key in the storage. If
   // aSecure is false, then attempts to modify a secure value
@@ -297,11 +295,11 @@ public:
   virtual nsresult
   SetDBValue(const nsAString& aKey,
              const nsAString& aValue,
-             PRBool aSecure);
+             bool aSecure);
 
   // set the value corresponding to a key as secure.
   virtual nsresult
-  SetSecure(const nsAString& aKey, PRBool aSecure);
+  SetSecure(const nsAString& aKey, bool aSecure);
 
   // clear all values from the store
   void ClearAll();
@@ -365,10 +363,10 @@ public:
   virtual nsresult InitAsGlobalStorage(const nsACString &aDomainDemanded);
   virtual already_AddRefed<nsIDOMStorage> Clone();
   virtual already_AddRefed<nsIDOMStorage> Fork(const nsSubstring &aDocumentURI);
-  virtual PRBool IsForkOf(nsIDOMStorage* aThat);
+  virtual bool IsForkOf(nsIDOMStorage* aThat);
   virtual nsTArray<nsString> *GetKeys();
   virtual nsIPrincipal* Principal();
-  virtual PRBool CanAccess(nsIPrincipal *aPrincipal);
+  virtual bool CanAccess(nsIPrincipal *aPrincipal);
   virtual nsDOMStorageType StorageType();
   virtual void BroadcastChangeNotification(const nsSubstring &aKey,
                                            const nsSubstring &aOldValue,
@@ -376,18 +374,18 @@ public:
 
   // Check whether storage may be used by the caller, and whether it
   // is session only.  Returns true if storage may be used.
-  static PRBool
-  CanUseStorage(PRPackedBool* aSessionOnly);
+  static bool
+  CanUseStorage(bool* aSessionOnly);
 
   // Check whether this URI can use chrome persist storage.  This kind of
   // storage can bypass cookies limits, private browsing and uses the offline
   // apps quota.
-  static PRBool
+  static bool
   URICanUseChromePersist(nsIURI* aURI);
   
   // Check whether storage may be used.  Updates mSessionOnly based on
   // the result of CanUseStorage.
-  PRBool
+  bool
   CacheStoragePermissions();
 
   nsIDOMStorageItem* GetNamedItem(const nsAString& aKey, nsresult* aResult);
@@ -397,7 +395,7 @@ public:
     return static_cast<nsDOMStorage*>(static_cast<nsIDOMStorageObsolete*>(aSupports));
   }
 
-  nsresult SetSecure(const nsAString& aKey, PRBool aSecure)
+  nsresult SetSecure(const nsAString& aKey, bool aSecure)
   {
     return mStorageImpl->SetSecure(aKey, aSecure);
   }
@@ -410,7 +408,7 @@ public:
 
   nsRefPtr<DOMStorageBase> mStorageImpl;
 
-  PRBool CanAccessSystem(nsIPrincipal *aPrincipal);
+  bool CanAccessSystem(nsIPrincipal *aPrincipal);
 
   // document URI of the document this storage is bound to
   nsString mDocumentURI;
@@ -445,10 +443,10 @@ public:
   virtual nsresult InitAsGlobalStorage(const nsACString &aDomainDemanded);
   virtual already_AddRefed<nsIDOMStorage> Clone();
   virtual already_AddRefed<nsIDOMStorage> Fork(const nsSubstring &aDocumentURI);
-  virtual PRBool IsForkOf(nsIDOMStorage* aThat);
+  virtual bool IsForkOf(nsIDOMStorage* aThat);
   virtual nsTArray<nsString> *GetKeys();
   virtual nsIPrincipal* Principal();
-  virtual PRBool CanAccess(nsIPrincipal *aPrincipal);
+  virtual bool CanAccess(nsIPrincipal *aPrincipal);
   virtual nsDOMStorageType StorageType();
   virtual void BroadcastChangeNotification(const nsSubstring &aKey,
                                            const nsSubstring &aOldValue,
@@ -490,7 +488,7 @@ public:
   /**
    * Check whether aCurrentDomain has access to aRequestedDomain
    */
-  static PRBool
+  static bool
   CanAccessDomain(const nsACString& aRequestedDomain,
                   const nsACString& aCurrentDomain);
 
@@ -509,13 +507,13 @@ protected:
   nsIDOMStorageObsolete*
   GetStorageForDomain(const nsACString& aRequestedDomain,
                       const nsACString& aCurrentDomain,
-                      PRBool aNoCurrentDomainCheck,
+                      bool aNoCurrentDomainCheck,
                       nsresult* aResult);
 
   /**
    * Convert the domain into an array of its component parts.
    */
-  static PRBool
+  static bool
   ConvertDomainToArray(const nsACString& aDomain,
                        nsTArray<nsCString>* aArray);
 
@@ -529,7 +527,7 @@ public:
   nsDOMStorageItem(DOMStorageBase* aStorage,
                    const nsAString& aKey,
                    const nsAString& aValue,
-                   PRBool aSecure);
+                   bool aSecure);
   virtual ~nsDOMStorageItem();
 
   // nsISupports
@@ -542,12 +540,12 @@ public:
   // nsIDOMToString
   NS_DECL_NSIDOMTOSTRING
 
-  PRBool IsSecure()
+  bool IsSecure()
   {
     return mSecure;
   }
 
-  void SetSecureInternal(PRBool aSecure)
+  void SetSecureInternal(bool aSecure)
   {
     mSecure = aSecure;
   }
@@ -570,7 +568,7 @@ public:
 protected:
 
   // true if this value is for secure sites only
-  PRBool mSecure;
+  bool mSecure;
 
   // key for the item
   nsString mKey;
@@ -645,7 +643,7 @@ NS_NewDOMStorageList(nsIDOMStorageList** aResult);
 PRUint32
 GetOfflinePermission(const nsACString &aDomain);
 
-PRBool
+bool
 IsOfflineAllowed(const nsACString &aDomain);
 
 #endif /* nsDOMStorage_h___ */
