@@ -36,6 +36,7 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
+#include "mozilla/Util.h"
 
 #include "nsHTMLEditor.h"
 #include "nsHTMLEditRules.h"
@@ -139,8 +140,7 @@ static NS_DEFINE_CID(kCParserCID,     NS_PARSER_CID);
 #define NS_FOUND_TARGET NS_ERROR_GENERATE_FAILURE(NS_ERROR_MODULE_EDITOR, 3)
 
 // some little helpers
-static PRBool FindIntegerAfterString(const char *aLeadingString, 
-                                     nsCString &aCStr, PRInt32 &foundNumber);
+static PRInt32 FindPositiveIntegerAfterString(const char *aLeadingString, nsCString &aCStr);
 static nsresult RemoveFragComments(nsCString &theStr);
 static void RemoveBodyAndHead(nsIDOMNode *aNode);
 static nsresult FindTargetNode(nsIDOMNode *aStart, nsCOMPtr<nsIDOMNode> &aResult);
@@ -189,13 +189,13 @@ NS_IMETHODIMP nsHTMLEditor::LoadHTML(const nsAString & aInputString)
   NS_ENSURE_SUCCESS(res, res);
   
   nsTextRulesInfo ruleInfo(nsTextEditRules::kLoadHTML);
-  PRBool cancel, handled;
+  bool cancel, handled;
   res = mRules->WillDoAction(selection, &ruleInfo, &cancel, &handled);
   NS_ENSURE_SUCCESS(res, res);
   if (cancel) return NS_OK; // rules canceled the operation
   if (!handled)
   {
-    PRBool isCollapsed;
+    bool isCollapsed;
     res = selection->GetIsCollapsed(&isCollapsed);
     NS_ENSURE_SUCCESS(res, res);
 
@@ -248,7 +248,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertHTML(const nsAString & aInString)
   const nsAFlatString& empty = EmptyString();
 
   return InsertHTMLWithContext(aInString, empty, empty, empty,
-                               nsnull,  nsnull, 0, PR_TRUE);
+                               nsnull,  nsnull, 0, true);
 }
 
 
@@ -260,11 +260,11 @@ nsHTMLEditor::InsertHTMLWithContext(const nsAString & aInputString,
                                     nsIDOMDocument *aSourceDoc,
                                     nsIDOMNode *aDestNode,
                                     PRInt32 aDestOffset,
-                                    PRBool aDeleteSelection)
+                                    bool aDeleteSelection)
 {
   return DoInsertHTMLWithContext(aInputString, aContextStr, aInfoStr,
       aFlavor, aSourceDoc, aDestNode, aDestOffset, aDeleteSelection,
-      PR_TRUE);
+      true);
 }
 
 nsresult
@@ -275,8 +275,8 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
                                       nsIDOMDocument *aSourceDoc,
                                       nsIDOMNode *aDestNode,
                                       PRInt32 aDestOffset,
-                                      PRBool aDeleteSelection,
-                                      PRBool aTrustedInput)
+                                      bool aDeleteSelection,
+                                      bool aTrustedInput)
 {
   NS_ENSURE_TRUE(mRules, NS_ERROR_NOT_INITIALIZED);
 
@@ -321,7 +321,7 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
     targetOffset = aDestOffset;
   }
 
-  PRBool doContinue = PR_TRUE;
+  bool doContinue = true;
 
   res = DoContentFilterCallback(aFlavor, aSourceDoc, aDeleteSelection,
                                 (nsIDOMNode **)address_of(fragmentAsNode), 
@@ -379,12 +379,12 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
   PRInt32 offsetOfNewNode;
   
   // check for table cell selection mode
-  PRBool cellSelectionMode = PR_FALSE;
+  bool cellSelectionMode = false;
   nsCOMPtr<nsIDOMElement> cell;
   res = GetFirstSelectedCell(nsnull, getter_AddRefs(cell));
   if (NS_SUCCEEDED(res) && cell)
   {
-    cellSelectionMode = PR_TRUE;
+    cellSelectionMode = true;
   }
   
   if (cellSelectionMode)
@@ -396,7 +396,7 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
     // indicate results.
     nsIDOMNode* firstNode = nodeList[0];
     if (!nsHTMLEditUtils::IsTableElement(firstNode))
-      cellSelectionMode = PR_FALSE;
+      cellSelectionMode = false;
   }
 
   if (!cellSelectionMode)
@@ -424,7 +424,7 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
   
   // give rules a chance to handle or cancel
   nsTextRulesInfo ruleInfo(nsTextEditRules::kInsertElement);
-  PRBool cancel, handled;
+  bool cancel, handled;
   res = mRules->WillDoAction(selection, &ruleInfo, &cancel, &handled);
   NS_ENSURE_SUCCESS(res, res);
   if (cancel) return NS_OK; // rules canceled the operation
@@ -451,7 +451,7 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
     }
     
     // remeber if we are in a link.  
-    PRBool bStartedInLink = IsInLink(parentNode);
+    bool bStartedInLink = IsInLink(parentNode);
   
     // are we in a text node?  If so, split it.
     if (IsTextNode(parentNode))
@@ -467,7 +467,7 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
     // build up list of parents of first node in list that are either
     // lists or tables.  First examine front of paste node list.
     nsCOMArray<nsIDOMNode> startListAndTableArray;
-    res = GetListAndTableParents(PR_FALSE, nodeList, startListAndTableArray);
+    res = GetListAndTableParents(false, nodeList, startListAndTableArray);
     NS_ENSURE_SUCCESS(res, res);
     
     // remember number of lists and tables above us
@@ -483,13 +483,13 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
     // table or list contents outside the table or list.
     if (highWaterMark >= 0)
     {
-      res = ReplaceOrphanedStructure(PR_FALSE, nodeList, startListAndTableArray, highWaterMark);
+      res = ReplaceOrphanedStructure(false, nodeList, startListAndTableArray, highWaterMark);
       NS_ENSURE_SUCCESS(res, res);
     }
     
     // Now go through the same process again for the end of the paste node list.
     nsCOMArray<nsIDOMNode> endListAndTableArray;
-    res = GetListAndTableParents(PR_TRUE, nodeList, endListAndTableArray);
+    res = GetListAndTableParents(true, nodeList, endListAndTableArray);
     NS_ENSURE_SUCCESS(res, res);
     highWaterMark = -1;
    
@@ -503,7 +503,7 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
     // don't orphan partial list or table structure
     if (highWaterMark >= 0)
     {
-      res = ReplaceOrphanedStructure(PR_TRUE, nodeList, endListAndTableArray, highWaterMark);
+      res = ReplaceOrphanedStructure(true, nodeList, endListAndTableArray, highWaterMark);
       NS_ENSURE_SUCCESS(res, res);
     }
 
@@ -518,7 +518,7 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
       
     for (j=0; j<listCount; j++)
     {
-      PRBool bDidInsert = PR_FALSE;
+      bool bDidInsert = false;
       nsCOMPtr<nsIDOMNode> curNode = nodeList[j];
 
       NS_ENSURE_TRUE(curNode, NS_ERROR_FAILURE);
@@ -543,11 +543,11 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
         curNode->GetFirstChild(getter_AddRefs(child));
         while (child)
         {
-          res = InsertNodeAtPoint(child, address_of(parentNode), &offsetOfNewNode, PR_TRUE);
+          res = InsertNodeAtPoint(child, address_of(parentNode), &offsetOfNewNode, true);
           if (NS_FAILED(res))
             break;
 
-          bDidInsert = PR_TRUE;
+          bDidInsert = true;
           lastInsertNode = child;
           offsetOfNewNode++;
 
@@ -571,8 +571,8 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
             // delete it and paste into parent list instead.
             if (nsHTMLEditUtils::IsListItem(parentNode))
             {
-              PRBool isEmpty;
-              res = IsEmptyNode(parentNode, &isEmpty, PR_TRUE);
+              bool isEmpty;
+              res = IsEmptyNode(parentNode, &isEmpty, true);
               if ((NS_SUCCEEDED(res)) && isEmpty)
               {
                 nsCOMPtr<nsIDOMNode> listNode;
@@ -586,11 +586,11 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
                 }
               }
             } 
-            res = InsertNodeAtPoint(child, address_of(parentNode), &offsetOfNewNode, PR_TRUE);
+            res = InsertNodeAtPoint(child, address_of(parentNode), &offsetOfNewNode, true);
             if (NS_FAILED(res))
               break;
 
-            bDidInsert = PR_TRUE;
+            bDidInsert = true;
             lastInsertNode = child;
             offsetOfNewNode++;
           }
@@ -609,11 +609,11 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
         curNode->GetFirstChild(getter_AddRefs(child));
         while (child)
         {
-          res = InsertNodeAtPoint(child, address_of(parentNode), &offsetOfNewNode, PR_TRUE);
+          res = InsertNodeAtPoint(child, address_of(parentNode), &offsetOfNewNode, true);
           if (NS_FAILED(res))
             break;
 
-          bDidInsert = PR_TRUE;
+          bDidInsert = true;
           lastInsertNode = child;
           offsetOfNewNode++;
 
@@ -624,10 +624,10 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
       if (!bDidInsert || NS_FAILED(res))
       {
         // try to insert
-        res = InsertNodeAtPoint(curNode, address_of(parentNode), &offsetOfNewNode, PR_TRUE);
+        res = InsertNodeAtPoint(curNode, address_of(parentNode), &offsetOfNewNode, true);
         if (NS_SUCCEEDED(res)) 
         {
-          bDidInsert = PR_TRUE;
+          bDidInsert = true;
           lastInsertNode = curNode;
         }
 
@@ -639,10 +639,10 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
           curNode->GetParentNode(getter_AddRefs(parent));
           if (parent && !nsTextEditUtils::IsBody(parent))
           {
-            res = InsertNodeAtPoint(parent, address_of(parentNode), &offsetOfNewNode, PR_TRUE);
+            res = InsertNodeAtPoint(parent, address_of(parentNode), &offsetOfNewNode, true);
             if (NS_SUCCEEDED(res)) 
             {
-              bDidInsert = PR_TRUE;
+              bDidInsert = true;
               insertedContextParent = parent;
               lastInsertNode = GetChildAt(parentNode, offsetOfNewNode);
             }
@@ -745,7 +745,7 @@ nsHTMLEditor::DoInsertHTMLWithContext(const nsAString & aInputString,
         // inside that.  So I split it instead.
         nsCOMPtr<nsIDOMNode> leftLink;
         PRInt32 linkOffset;
-        res = SplitNodeDeep(link, selNode, selOffset, &linkOffset, PR_TRUE, address_of(leftLink));
+        res = SplitNodeDeep(link, selNode, selOffset, &linkOffset, true, address_of(leftLink));
         NS_ENSURE_SUCCESS(res, res);
         res = GetNodeLocation(leftLink, address_of(selNode), &selOffset);
         NS_ENSURE_SUCCESS(res, res);
@@ -961,7 +961,7 @@ nsHTMLEditor::RelativizeURIInFragmentList(const nsCOMArray<nsIDOMNode> &aNodeLis
     nsCOMPtr<nsIDOMTreeWalker> walker;
     nsresult rv = domDoc->CreateTreeWalker(somenode,
                                            nsIDOMNodeFilter::SHOW_ELEMENT,
-                                           nsnull, PR_TRUE,
+                                           nsnull, true,
                                            getter_AddRefs(walker));
     NS_ENSURE_SUCCESS(rv, rv);
 
@@ -1008,7 +1008,7 @@ nsHTMLEditor::RemoveInsertionListener(nsIContentFilter *aListener)
 nsresult
 nsHTMLEditor::DoContentFilterCallback(const nsAString &aFlavor, 
                                       nsIDOMDocument *sourceDoc,
-                                      PRBool aWillDeleteSelection,
+                                      bool aWillDeleteSelection,
                                       nsIDOMNode **aFragmentAsNode, 
                                       nsIDOMNode **aFragStartNode, 
                                       PRInt32 *aFragStartOffset,
@@ -1016,9 +1016,9 @@ nsHTMLEditor::DoContentFilterCallback(const nsAString &aFlavor,
                                       PRInt32 *aFragEndOffset,
                                       nsIDOMNode **aTargetNode,
                                       PRInt32 *aTargetOffset,
-                                      PRBool *aDoContinue)
+                                      bool *aDoContinue)
 {
-  *aDoContinue = PR_TRUE;
+  *aDoContinue = true;
 
   PRInt32 i;
   nsIContentFilter *listener;
@@ -1036,10 +1036,10 @@ nsHTMLEditor::DoContentFilterCallback(const nsAString &aFlavor,
   return NS_OK;
 }
 
-PRBool
+bool
 nsHTMLEditor::IsInLink(nsIDOMNode *aNode, nsCOMPtr<nsIDOMNode> *outLink)
 {
-  NS_ENSURE_TRUE(aNode, PR_FALSE);
+  NS_ENSURE_TRUE(aNode, false);
   if (outLink)
     *outLink = nsnull;
   nsCOMPtr<nsIDOMNode> tmp, node = aNode;
@@ -1049,17 +1049,17 @@ nsHTMLEditor::IsInLink(nsIDOMNode *aNode, nsCOMPtr<nsIDOMNode> *outLink)
     {
       if (outLink)
         *outLink = node;
-      return PR_TRUE;
+      return true;
     }
     tmp = node;
     tmp->GetParentNode(getter_AddRefs(node));
   }
-  return PR_FALSE;
+  return false;
 }
 
 
 nsresult
-nsHTMLEditor::StripFormattingNodes(nsIDOMNode *aNode, PRBool aListOnly)
+nsHTMLEditor::StripFormattingNodes(nsIDOMNode *aNode, bool aListOnly)
 {
   NS_ENSURE_TRUE(aNode, NS_ERROR_NULL_POINTER);
 
@@ -1100,7 +1100,7 @@ NS_IMETHODIMP nsHTMLEditor::PrepareTransferable(nsITransferable **transferable)
 }
 
 NS_IMETHODIMP nsHTMLEditor::PrepareHTMLTransferable(nsITransferable **aTransferable, 
-                                                    PRBool aHavePrivFlavor)
+                                                    bool aHavePrivFlavor)
 {
   // Create generic Transferable for getting the data
   nsresult rv = CallCreateInstance("@mozilla.org/widget/transferable;1", aTransferable);
@@ -1148,24 +1148,22 @@ NS_IMETHODIMP nsHTMLEditor::PrepareHTMLTransferable(nsITransferable **aTransfera
   return NS_OK;
 }
 
-PRBool
-FindIntegerAfterString(const char *aLeadingString, 
-                       nsCString &aCStr, PRInt32 &foundNumber)
+PRInt32
+FindPositiveIntegerAfterString(const char *aLeadingString, nsCString &aCStr)
 {
   // first obtain offsets from cfhtml str
   PRInt32 numFront = aCStr.Find(aLeadingString);
   if (numFront == -1)
-    return PR_FALSE;
+    return -1;
   numFront += strlen(aLeadingString); 
   
   PRInt32 numBack = aCStr.FindCharInSet(CRLF, numFront);
   if (numBack == -1)
-    return PR_FALSE;
+    return -1;
    
   nsCAutoString numStr(Substring(aCStr, numFront, numBack-numFront));
   PRInt32 errorCode;
-  foundNumber = numStr.ToInteger(&errorCode);
-  return PR_TRUE;
+  return numStr.ToInteger(&errorCode);
 }
 
 nsresult
@@ -1175,14 +1173,14 @@ RemoveFragComments(nsCString & aStr)
   PRInt32 startCommentIndx = aStr.Find("<!--StartFragment");
   if (startCommentIndx >= 0)
   {
-    PRInt32 startCommentEnd = aStr.Find("-->", PR_FALSE, startCommentIndx);
+    PRInt32 startCommentEnd = aStr.Find("-->", false, startCommentIndx);
     if (startCommentEnd > startCommentIndx)
       aStr.Cut(startCommentIndx, (startCommentEnd+3)-startCommentIndx);
   }  
   PRInt32 endCommentIndx = aStr.Find("<!--EndFragment");
   if (endCommentIndx >= 0)
   {
-    PRInt32 endCommentEnd = aStr.Find("-->", PR_FALSE, endCommentIndx);
+    PRInt32 endCommentEnd = aStr.Find("-->", false, endCommentIndx);
     if (endCommentEnd > endCommentIndx)
       aStr.Cut(endCommentIndx, (endCommentEnd+3)-endCommentIndx);
   }  
@@ -1192,36 +1190,14 @@ RemoveFragComments(nsCString & aStr)
 nsresult
 nsHTMLEditor::ParseCFHTML(nsCString & aCfhtml, PRUnichar **aStuffToPaste, PRUnichar **aCfcontext)
 {
-  // First obtain offsets from cfhtml str.
-  PRInt32 startHTML, endHTML, startFragment, endFragment;
-  if (!FindIntegerAfterString("StartHTML:", aCfhtml, startHTML) || 
-      startHTML < -1)
-    return NS_ERROR_FAILURE;
-  if (!FindIntegerAfterString("EndHTML:", aCfhtml, endHTML) || 
-      endHTML < -1) 
-    return NS_ERROR_FAILURE;
-  if (!FindIntegerAfterString("StartFragment:", aCfhtml, startFragment) || 
-      startFragment < 0) 
-    return NS_ERROR_FAILURE;
-  if (!FindIntegerAfterString("EndFragment:", aCfhtml, endFragment) || 
-      startFragment < 0)
-    return NS_ERROR_FAILURE;
+  // first obtain offsets from cfhtml str
+  PRInt32 startHTML     = FindPositiveIntegerAfterString("StartHTML:", aCfhtml);
+  PRInt32 endHTML       = FindPositiveIntegerAfterString("EndHTML:", aCfhtml);
+  PRInt32 startFragment = FindPositiveIntegerAfterString("StartFragment:", aCfhtml);
+  PRInt32 endFragment   = FindPositiveIntegerAfterString("EndFragment:", aCfhtml);
 
-  // The StartHTML and EndHTML markers are allowed to be -1 to include everything.
-  //   See Reference: MSDN doc entitled "HTML Clipboard Format"
-  //   http://msdn.microsoft.com/en-us/library/aa767917(VS.85).aspx#unknown_854
-  if (startHTML == -1) {
-    startHTML = aCfhtml.Find("<!--StartFragment-->");
-    if (startHTML == -1)
-      return PR_FALSE;
-  }
-  if (endHTML == -1) {
-    const char endFragmentMarker[] = "<!--EndFragment-->";
-    endHTML = aCfhtml.Find(endFragmentMarker);
-    if (endHTML == -1)
-      return PR_FALSE;
-    endHTML += NS_ARRAY_LENGTH(endFragmentMarker) - 1;
-  }
+  if ((startHTML<0) || (endHTML<0) || (startFragment<0) || (endFragment<0))
+    return NS_ERROR_FAILURE;
 
   // create context string
   nsCAutoString contextUTF8(Substring(aCfhtml, startHTML, startFragment - startHTML) +
@@ -1302,7 +1278,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromTransferable(nsITransferable *transferable
                                                    const nsAString & aInfoStr,
                                                    nsIDOMNode *aDestinationNode,
                                                    PRInt32 aDestOffset,
-                                                   PRBool aDoDeleteSelection)
+                                                   bool aDoDeleteSelection)
 {
   nsresult rv = NS_OK;
   nsXPIDLCString bestFlavor;
@@ -1319,7 +1295,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromTransferable(nsITransferable *transferable
 #endif
 
     // Try to determine whether we should use a sanitizing fragment sink
-    PRBool isSafe = PR_FALSE;
+    bool isSafe = false;
     nsCOMPtr<nsIDOMDocument> destdomdoc;
     rv = GetDocument(getter_AddRefs(destdomdoc));
     NS_ENSURE_SUCCESS(rv, rv);
@@ -1346,7 +1322,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromTransferable(nsITransferable *transferable
     }
 
     // Check to see if we can insert an image file
-    PRBool insertAsImage = PR_FALSE;
+    bool insertAsImage = false;
     nsCOMPtr<nsIURI> fileURI;
     if (0 == nsCRT::strcmp(bestFlavor, kFileMime))
     {
@@ -1364,7 +1340,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromTransferable(nsITransferable *transferable
 
         // Accept any image type fed to us
         if (StringBeginsWith(contentType, NS_LITERAL_CSTRING("image/"))) {
-          insertAsImage = PR_TRUE;
+          insertAsImage = true;
           bestFlavor = contentType;
         }
       }
@@ -1473,7 +1449,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromTransferable(nsITransferable *transferable
   // After ScrollSelectionIntoView(), the pending notifications might be
   // flushed and PresShell/PresContext/Frames may be dead. See bug 418470.
   if (NS_SUCCEEDED(rv))
-    ScrollSelectionIntoView(PR_FALSE);
+    ScrollSelectionIntoView(false);
 
   return rv;
 }
@@ -1497,7 +1473,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromDrop(nsIDOMEvent* aDropEvent)
 
   // find out if we have our internal html flavor on the clipboard.  We don't want to mess
   // around with cfhtml if we do.
-  PRBool bHavePrivateHTMLFlavor = PR_FALSE;
+  bool bHavePrivateHTMLFlavor = false;
   rv = dragSession->IsDataFlavorSupported(kHTMLContext, &bHavePrivateHTMLFlavor);
   NS_ENSURE_SUCCESS(rv, rv);
   
@@ -1515,7 +1491,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromDrop(nsIDOMEvent* aDropEvent)
   nsAutoEditBatch beginBatching(this);
 
   // We never have to delete if selection is already collapsed
-  PRBool deleteSelection = PR_FALSE;
+  bool deleteSelection = false;
   nsCOMPtr<nsIDOMNode> newSelectionParent;
   PRInt32 newSelectionOffset = 0;
 
@@ -1525,7 +1501,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromDrop(nsIDOMEvent* aDropEvent)
   NS_ENSURE_SUCCESS(rv, rv);
 
   PRUint32 i; 
-  PRBool doPlaceCaret = PR_TRUE;
+  bool doPlaceCaret = true;
   for (i = 0; i < numItems; ++i)
   {
     rv = dragSession->GetData(trans, i);
@@ -1574,7 +1550,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromDrop(nsIDOMEvent* aDropEvent)
     {
       // check if the user pressed the key to force a copy rather than a move
       // if we run into problems here, we'll just assume the user doesn't want a copy
-      PRBool userWantsCopy = PR_FALSE;
+      bool userWantsCopy = false;
 
       nsCOMPtr<nsIDOMUIEvent> uiEvent = do_QueryInterface(aDropEvent);
       NS_ENSURE_TRUE(uiEvent, NS_ERROR_FAILURE);
@@ -1598,7 +1574,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromDrop(nsIDOMEvent* aDropEvent)
       NS_ENSURE_SUCCESS(rv, rv);
       NS_ENSURE_TRUE(selection, NS_ERROR_FAILURE);
 
-      PRBool isCollapsed;
+      bool isCollapsed;
       rv = selection->GetIsCollapsed(&isCollapsed);
       NS_ENSURE_SUCCESS(rv, rv);
       
@@ -1636,7 +1612,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromDrop(nsIDOMEvent* aDropEvent)
       }
 
       // We never have to delete if selection is already collapsed
-      PRBool cursorIsInSelection = PR_FALSE;
+      bool cursorIsInSelection = false;
 
       // Check if mouse is in the selection
       if (!isCollapsed)
@@ -1671,7 +1647,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromDrop(nsIDOMEvent* aDropEvent)
           // Dragging from another window onto a selection
           // XXX Decision made to NOT do this,
           //     note that 4.x does replace if dropped on
-          //deleteSelection = PR_TRUE;
+          //deleteSelection = true;
         }
         else 
         {
@@ -1684,13 +1660,13 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromDrop(nsIDOMEvent* aDropEvent)
           else
           {
             // Different source doc: Don't delete
-            deleteSelection = PR_FALSE;
+            deleteSelection = false;
           }
         }
       }
 
       // We have to figure out whether to delete/relocate caret only once
-      doPlaceCaret = PR_FALSE;
+      doPlaceCaret = false;
     }
     
     // handle transferable hooks
@@ -1707,7 +1683,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromDrop(nsIDOMEvent* aDropEvent)
   return rv;
 }
 
-NS_IMETHODIMP nsHTMLEditor::CanDrag(nsIDOMEvent *aDragEvent, PRBool *aCanDrag)
+NS_IMETHODIMP nsHTMLEditor::CanDrag(nsIDOMEvent *aDragEvent, bool *aCanDrag)
 {
   return nsPlaintextEditor::CanDrag(aDragEvent, aCanDrag);
 }
@@ -1820,22 +1796,22 @@ NS_IMETHODIMP nsHTMLEditor::DoDrag(nsIDOMEvent *aDragEvent)
   return nsPlaintextEditor::DoDrag(aDragEvent);
 }
 
-PRBool nsHTMLEditor::HavePrivateHTMLFlavor(nsIClipboard *aClipboard)
+bool nsHTMLEditor::HavePrivateHTMLFlavor(nsIClipboard *aClipboard)
 {
   // check the clipboard for our special kHTMLContext flavor.  If that is there, we know
   // we have our own internal html format on clipboard.
   
-  NS_ENSURE_TRUE(aClipboard, PR_FALSE);
-  PRBool bHavePrivateHTMLFlavor = PR_FALSE;
+  NS_ENSURE_TRUE(aClipboard, false);
+  bool bHavePrivateHTMLFlavor = false;
   
   const char* flavArray[] = { kHTMLContext };
   
   if (NS_SUCCEEDED(aClipboard->HasDataMatchingFlavors(flavArray,
-    NS_ARRAY_LENGTH(flavArray), nsIClipboard::kGlobalClipboard,
+    ArrayLength(flavArray), nsIClipboard::kGlobalClipboard,
     &bHavePrivateHTMLFlavor )))
     return bHavePrivateHTMLFlavor;
     
-  return PR_FALSE;
+  return false;
 }
 
 
@@ -1851,7 +1827,7 @@ NS_IMETHODIMP nsHTMLEditor::Paste(PRInt32 aSelectionType)
   
   // find out if we have our internal html flavor on the clipboard.  We don't want to mess
   // around with cfhtml if we do.
-  PRBool bHavePrivateHTMLFlavor = HavePrivateHTMLFlavor(clipboard);
+  bool bHavePrivateHTMLFlavor = HavePrivateHTMLFlavor(clipboard);
 
   // Get the nsITransferable interface for getting the data from the clipboard
   nsCOMPtr<nsITransferable> trans;
@@ -1913,7 +1889,7 @@ NS_IMETHODIMP nsHTMLEditor::Paste(PRInt32 aSelectionType)
       // Beware! This may flush notifications via synchronous
       // ScrollSelectionIntoView.
       rv = InsertFromTransferable(trans, nsnull, contextStr, infoStr,
-                                  nsnull, 0, PR_TRUE);
+                                  nsnull, 0, true);
     }
   }
 
@@ -1935,7 +1911,7 @@ NS_IMETHODIMP nsHTMLEditor::PasteTransferable(nsITransferable *aTransferable)
   // ScrollSelectionIntoView.
   nsAutoString contextStr, infoStr;
   return InsertFromTransferable(aTransferable, nsnull, contextStr, infoStr,
-                                nsnull, 0, PR_TRUE);
+                                nsnull, 0, true);
 }
 
 // 
@@ -1963,7 +1939,7 @@ NS_IMETHODIMP nsHTMLEditor::PasteNoFormatting(PRInt32 aSelectionType)
       // Beware! This may flush notifications via synchronous
       // ScrollSelectionIntoView.
       rv = InsertFromTransferable(trans, nsnull, empty, empty, nsnull, 0,
-                                  PR_TRUE);
+                                  true);
     }
   }
 
@@ -1979,10 +1955,10 @@ static const char* textHtmlEditorFlavors[] = { kUnicodeMime, kHTMLMime,
                                                kJPEGImageMime, kPNGImageMime,
                                                kGIFImageMime };
 
-NS_IMETHODIMP nsHTMLEditor::CanPaste(PRInt32 aSelectionType, PRBool *aCanPaste)
+NS_IMETHODIMP nsHTMLEditor::CanPaste(PRInt32 aSelectionType, bool *aCanPaste)
 {
   NS_ENSURE_ARG_POINTER(aCanPaste);
-  *aCanPaste = PR_FALSE;
+  *aCanPaste = false;
 
   // can't paste if readonly
   if (!IsModifiable())
@@ -1992,16 +1968,16 @@ NS_IMETHODIMP nsHTMLEditor::CanPaste(PRInt32 aSelectionType, PRBool *aCanPaste)
   nsCOMPtr<nsIClipboard> clipboard(do_GetService("@mozilla.org/widget/clipboard;1", &rv));
   NS_ENSURE_SUCCESS(rv, rv);
 
-  PRBool haveFlavors;
+  bool haveFlavors;
 
   // Use the flavors depending on the current editor mask
   if (IsPlaintextEditor())
     rv = clipboard->HasDataMatchingFlavors(textEditorFlavors,
-                                           NS_ARRAY_LENGTH(textEditorFlavors),
+                                           ArrayLength(textEditorFlavors),
                                            aSelectionType, &haveFlavors);
   else
     rv = clipboard->HasDataMatchingFlavors(textHtmlEditorFlavors,
-                                           NS_ARRAY_LENGTH(textHtmlEditorFlavors),
+                                           ArrayLength(textHtmlEditorFlavors),
                                            aSelectionType, &haveFlavors);
   
   NS_ENSURE_SUCCESS(rv, rv);
@@ -2010,19 +1986,19 @@ NS_IMETHODIMP nsHTMLEditor::CanPaste(PRInt32 aSelectionType, PRBool *aCanPaste)
   return NS_OK;
 }
 
-NS_IMETHODIMP nsHTMLEditor::CanPasteTransferable(nsITransferable *aTransferable, PRBool *aCanPaste)
+NS_IMETHODIMP nsHTMLEditor::CanPasteTransferable(nsITransferable *aTransferable, bool *aCanPaste)
 {
   NS_ENSURE_ARG_POINTER(aCanPaste);
 
   // can't paste if readonly
   if (!IsModifiable()) {
-    *aCanPaste = PR_FALSE;
+    *aCanPaste = false;
     return NS_OK;
   }
 
   // If |aTransferable| is null, assume that a paste will succeed.
   if (!aTransferable) {
-    *aCanPaste = PR_TRUE;
+    *aCanPaste = true;
     return NS_OK;
   }
 
@@ -2033,10 +2009,10 @@ NS_IMETHODIMP nsHTMLEditor::CanPasteTransferable(nsITransferable *aTransferable,
   unsigned length;
   if (IsPlaintextEditor()) {
     flavors = textEditorFlavors;
-    length = NS_ARRAY_LENGTH(textEditorFlavors);
+    length = ArrayLength(textEditorFlavors);
   } else {
     flavors = textHtmlEditorFlavors;
-    length = NS_ARRAY_LENGTH(textHtmlEditorFlavors);
+    length = ArrayLength(textHtmlEditorFlavors);
   }
 
   for (unsigned int i = 0; i < length; i++, flavors++) {
@@ -2046,12 +2022,12 @@ NS_IMETHODIMP nsHTMLEditor::CanPasteTransferable(nsITransferable *aTransferable,
                                                  getter_AddRefs(data),
                                                  &dataLen);
     if (NS_SUCCEEDED(rv) && data) {
-      *aCanPaste = PR_TRUE;
+      *aCanPaste = true;
       return NS_OK;
     }
   }
   
-  *aCanPaste = PR_FALSE;
+  *aCanPaste = false;
   return NS_OK;
 }
 
@@ -2082,7 +2058,7 @@ NS_IMETHODIMP nsHTMLEditor::PasteAsCitedQuotation(const nsAString & aCitation,
 
   // give rules a chance to handle or cancel
   nsTextRulesInfo ruleInfo(nsTextEditRules::kInsertElement);
-  PRBool cancel, handled;
+  bool cancel, handled;
   res = mRules->WillDoAction(selection, &ruleInfo, &cancel, &handled);
   NS_ENSURE_SUCCESS(res, res);
   if (cancel) return NS_OK; // rules canceled the operation
@@ -2164,7 +2140,7 @@ NS_IMETHODIMP nsHTMLEditor::PasteAsPlaintextQuotation(PRInt32 aSelectionType)
         textDataObj->GetData(stuffToPaste);
         NS_ASSERTION(stuffToPaste.Length() <= (len/2), "Invalid length!");
         nsAutoEditBatch beginBatching(this);
-        rv = InsertAsPlaintextQuotation(stuffToPaste, PR_TRUE, 0);
+        rv = InsertAsPlaintextQuotation(stuffToPaste, true, 0);
       }
     }
     NS_Free(flav);
@@ -2188,7 +2164,7 @@ nsHTMLEditor::InsertTextWithQuotations(const nsAString &aStringToInsert)
   // we will insert the hunk all at once, quoted or non.
 
   static const PRUnichar cite('>');
-  PRBool curHunkIsQuoted = (aStringToInsert.First() == cite);
+  bool curHunkIsQuoted = (aStringToInsert.First() == cite);
 
   nsAString::const_iterator hunkStart, strEnd;
   aStringToInsert.BeginReading(hunkStart);
@@ -2202,7 +2178,7 @@ nsHTMLEditor::InsertTextWithQuotations(const nsAString &aStringToInsert)
 #ifdef DEBUG
   nsAString::const_iterator dbgStart (hunkStart);
   if (FindCharInReadable('\r', dbgStart, strEnd))
-    NS_ASSERTION(PR_FALSE,
+    NS_ASSERTION(false,
             "Return characters in DOM! InsertTextWithQuotations may be wrong");
 #endif /* DEBUG */
 
@@ -2212,8 +2188,8 @@ nsHTMLEditor::InsertTextWithQuotations(const nsAString &aStringToInsert)
   while (1)   // we will break from inside when we run out of newlines
   {
     // Search for the end of this line (dom newlines, see above):
-    PRBool found = FindCharInReadable('\n', lineStart, strEnd);
-    PRBool quoted = PR_FALSE;
+    bool found = FindCharInReadable('\n', lineStart, strEnd);
+    bool quoted = false;
     if (found)
     {
       // if there's another newline, lineStart now points there.
@@ -2247,7 +2223,7 @@ nsHTMLEditor::InsertTextWithQuotations(const nsAString &aStringToInsert)
            NS_LossyConvertUTF16toASCII(curHunk).get());
 #endif
     if (curHunkIsQuoted)
-      rv = InsertAsPlaintextQuotation(curHunk, PR_FALSE,
+      rv = InsertAsPlaintextQuotation(curHunk, false,
                                       getter_AddRefs(dummyNode));
     else
       rv = InsertText(curHunk);
@@ -2268,10 +2244,10 @@ NS_IMETHODIMP nsHTMLEditor::InsertAsQuotation(const nsAString & aQuotedText,
                                               nsIDOMNode **aNodeInserted)
 {
   if (IsPlaintextEditor())
-    return InsertAsPlaintextQuotation(aQuotedText, PR_TRUE, aNodeInserted);
+    return InsertAsPlaintextQuotation(aQuotedText, true, aNodeInserted);
 
   nsAutoString citation;
-  return InsertAsCitedQuotation(aQuotedText, citation, PR_FALSE,
+  return InsertAsCitedQuotation(aQuotedText, citation, false,
                                 aNodeInserted);
 }
 
@@ -2281,7 +2257,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertAsQuotation(const nsAString & aQuotedText,
 // in order to preserve the original line wrapping.
 NS_IMETHODIMP
 nsHTMLEditor::InsertAsPlaintextQuotation(const nsAString & aQuotedText,
-                                         PRBool aAddCites,
+                                         bool aAddCites,
                                          nsIDOMNode **aNodeInserted)
 {
   if (mWrapToWindow)
@@ -2291,7 +2267,7 @@ nsHTMLEditor::InsertAsPlaintextQuotation(const nsAString & aQuotedText,
 
   // The quotesPreformatted pref is a temporary measure. See bug 69638.
   // Eventually we'll pick one way or the other.
-  PRBool quotesInPre = PR_FALSE;
+  bool quotesInPre = false;
   nsCOMPtr<nsIPrefBranch> prefBranch =
     do_GetService(NS_PREFSERVICE_CONTRACTID, &rv);
   if (NS_SUCCEEDED(rv) && prefBranch)
@@ -2313,7 +2289,7 @@ nsHTMLEditor::InsertAsPlaintextQuotation(const nsAString & aQuotedText,
 
     // give rules a chance to handle or cancel
     nsTextRulesInfo ruleInfo(nsTextEditRules::kInsertElement);
-    PRBool cancel, handled;
+    bool cancel, handled;
     rv = mRules->WillDoAction(selection, &ruleInfo, &cancel, &handled);
     NS_ENSURE_SUCCESS(rv, rv);
     if (cancel) return NS_OK; // rules canceled the operation
@@ -2393,7 +2369,7 @@ nsHTMLEditor::StripCites()
 }
 
 NS_IMETHODIMP    
-nsHTMLEditor::Rewrap(PRBool aRespectNewlines)
+nsHTMLEditor::Rewrap(bool aRespectNewlines)
 {
   return nsPlaintextEditor::Rewrap(aRespectNewlines);
 }
@@ -2401,14 +2377,14 @@ nsHTMLEditor::Rewrap(PRBool aRespectNewlines)
 NS_IMETHODIMP
 nsHTMLEditor::InsertAsCitedQuotation(const nsAString & aQuotedText,
                                      const nsAString & aCitation,
-                                     PRBool aInsertHTML,
+                                     bool aInsertHTML,
                                      nsIDOMNode **aNodeInserted)
 {
   // Don't let anyone insert html into a "plaintext" editor:
   if (IsPlaintextEditor())
   {
     NS_ASSERTION(!aInsertHTML, "InsertAsCitedQuotation: trying to insert html into plaintext editor");
-    return InsertAsPlaintextQuotation(aQuotedText, PR_TRUE, aNodeInserted);
+    return InsertAsPlaintextQuotation(aQuotedText, true, aNodeInserted);
   }
 
   nsCOMPtr<nsIDOMNode> newNode;
@@ -2429,7 +2405,7 @@ nsHTMLEditor::InsertAsCitedQuotation(const nsAString & aQuotedText,
 
     // give rules a chance to handle or cancel
     nsTextRulesInfo ruleInfo(nsTextEditRules::kInsertElement);
-    PRBool cancel, handled;
+    bool cancel, handled;
     res = mRules->WillDoAction(selection, &ruleInfo, &cancel, &handled);
     NS_ENSURE_SUCCESS(res, res);
     if (cancel) return NS_OK; // rules canceled the operation
@@ -2594,7 +2570,7 @@ nsresult nsHTMLEditor::CreateDOMFragmentFromPaste(const nsAString &aInputString,
                                                   nsCOMPtr<nsIDOMNode> *outEndNode,
                                                   PRInt32 *outStartOffset,
                                                   PRInt32 *outEndOffset,
-                                                  PRBool aTrustedInput)
+                                                  bool aTrustedInput)
 {
   NS_ENSURE_TRUE(outFragNode && outStartNode && outEndNode, NS_ERROR_NULL_POINTER);
   nsCOMPtr<nsIDOMDocumentFragment> docfrag;
@@ -2657,7 +2633,7 @@ nsresult nsHTMLEditor::CreateDOMFragmentFromPaste(const nsAString &aInputString,
     *outFragNode = contextAsNode;
   }
 
-  res = StripFormattingNodes(*outFragNode, PR_TRUE);
+  res = StripFormattingNodes(*outFragNode, true);
   NS_ENSURE_SUCCESS(res, res);
 
   // If there was no context, then treat all of the data we did get as the
@@ -2705,7 +2681,7 @@ nsresult nsHTMLEditor::ParseFragment(const nsAString & aFragStr,
                                      nsIAtom* aContextLocalName,
                                      nsIDocument* aTargetDocument,
                                      nsCOMPtr<nsIDOMNode> *outNode,
-                                     PRBool aTrustedInput)
+                                     bool aTrustedInput)
 {
   nsresult rv;
   nsCOMPtr<nsIDOMDocumentFragment> frag;
@@ -2717,8 +2693,8 @@ nsresult nsHTMLEditor::ParseFragment(const nsAString & aFragStr,
                                          aContextLocalName ?
                                            aContextLocalName : nsGkAtoms::body,
                                         kNameSpaceID_XHTML,
-                                        PR_FALSE,
-                                        PR_TRUE);
+                                        false,
+                                        true);
   if (!aTrustedInput) {
     nsTreeSanitizer sanitizer(!!aContextLocalName, !aContextLocalName);
     sanitizer.Sanitize(fragment);
@@ -2772,7 +2748,7 @@ nsresult nsHTMLEditor::CreateListOfNodesToPaste(nsIDOMNode  *aFragmentAsNode,
 }
 
 nsresult 
-nsHTMLEditor::GetListAndTableParents(PRBool aEnd, 
+nsHTMLEditor::GetListAndTableParents(bool aEnd, 
                                      nsCOMArray<nsIDOMNode>& aListOfNodes,
                                      nsCOMArray<nsIDOMNode>& outArray)
 {
@@ -2859,7 +2835,7 @@ nsHTMLEditor::DiscoverPartialListsAndTables(nsCOMArray<nsIDOMNode>& aPasteNodes,
 }
 
 nsresult
-nsHTMLEditor::ScanForListAndTableStructure( PRBool aEnd,
+nsHTMLEditor::ScanForListAndTableStructure( bool aEnd,
                                             nsCOMArray<nsIDOMNode>& aNodes,
                                             nsIDOMNode *aListOrTable,
                                             nsCOMPtr<nsIDOMNode> *outReplaceNode)
@@ -2872,7 +2848,7 @@ nsHTMLEditor::ScanForListAndTableStructure( PRBool aEnd,
   // look upward from first/last paste node for a piece of this list/table
   PRInt32 listCount = aNodes.Count(), idx = 0;
   if (aEnd) idx = listCount-1;
-  PRBool bList = nsHTMLEditUtils::IsList(aListOrTable);
+  bool bList = nsHTMLEditUtils::IsList(aListOrTable);
   
   nsCOMPtr<nsIDOMNode>  pNode = aNodes[idx];
   nsCOMPtr<nsIDOMNode>  originalNode = pNode;
@@ -2901,7 +2877,7 @@ nsHTMLEditor::ScanForListAndTableStructure( PRBool aEnd,
 }    
 
 nsresult
-nsHTMLEditor::ReplaceOrphanedStructure(PRBool aEnd,
+nsHTMLEditor::ReplaceOrphanedStructure(bool aEnd,
                                        nsCOMArray<nsIDOMNode>& aNodeArray,
                                        nsCOMArray<nsIDOMNode>& aListAndTableArray,
                                        PRInt32 aHighWaterMark)
@@ -2939,7 +2915,7 @@ nsHTMLEditor::ReplaceOrphanedStructure(PRBool aEnd,
   return NS_OK;
 }
 
-nsIDOMNode* nsHTMLEditor::GetArrayEndpoint(PRBool aEnd,
+nsIDOMNode* nsHTMLEditor::GetArrayEndpoint(bool aEnd,
                                            nsCOMArray<nsIDOMNode>& aNodeArray)
 {
   PRInt32 listCount = aNodeArray.Count();
