@@ -50,6 +50,8 @@
 //
 //
 
+#include "mozilla/Util.h"
+
 #include "prlink.h"
 #include "nsCOMPtr.h"
 #include "nsIPrefService.h"
@@ -76,6 +78,8 @@ typedef KLStatus (*KLCacheHasValidTickets_type)(
 #include <resolv.h>
 #endif
 
+using namespace mozilla;
+
 //-----------------------------------------------------------------------------
 
 // We define GSS_C_NT_HOSTBASED_SERVICE explicitly since it may be referenced
@@ -90,35 +94,35 @@ static const char kNegotiateAuthGssLib[] =
 static const char kNegotiateAuthNativeImp[] = 
    "network.negotiate-auth.using-native-gsslib";
 
-static const char *gssFuncStr[] = {
-    "gss_display_status", 
-    "gss_init_sec_context", 
-    "gss_indicate_mechs",
-    "gss_release_oid_set",
-    "gss_delete_sec_context",
-    "gss_import_name",
-    "gss_release_buffer",
-    "gss_release_name",
-    "gss_wrap",
-    "gss_unwrap"
+static struct GSSFunction {
+    const char *str;
+    PRFuncPtr func;
+} gssFuncs[] = {
+    { "gss_display_status", NULL },
+    { "gss_init_sec_context", NULL },
+    { "gss_indicate_mechs", NULL },
+    { "gss_release_oid_set", NULL },
+    { "gss_delete_sec_context", NULL },
+    { "gss_import_name", NULL },
+    { "gss_release_buffer", NULL },
+    { "gss_release_name", NULL },
+    { "gss_wrap", NULL },
+    { "gss_unwrap", NULL }
 };
 
-#define gssFuncItems NS_ARRAY_LENGTH(gssFuncStr)
-
-static PRFuncPtr gssFunPtr[gssFuncItems]; 
-static PRBool    gssNativeImp = PR_TRUE;
+static bool      gssNativeImp = true;
 static PRLibrary* gssLibrary = nsnull;
 
-#define gss_display_status_ptr      ((gss_display_status_type)*gssFunPtr[0])
-#define gss_init_sec_context_ptr    ((gss_init_sec_context_type)*gssFunPtr[1])
-#define gss_indicate_mechs_ptr      ((gss_indicate_mechs_type)*gssFunPtr[2])
-#define gss_release_oid_set_ptr     ((gss_release_oid_set_type)*gssFunPtr[3])
-#define gss_delete_sec_context_ptr  ((gss_delete_sec_context_type)*gssFunPtr[4])
-#define gss_import_name_ptr         ((gss_import_name_type)*gssFunPtr[5])
-#define gss_release_buffer_ptr      ((gss_release_buffer_type)*gssFunPtr[6])
-#define gss_release_name_ptr        ((gss_release_name_type)*gssFunPtr[7])
-#define gss_wrap_ptr                ((gss_wrap_type)*gssFunPtr[8])
-#define gss_unwrap_ptr              ((gss_unwrap_type)*gssFunPtr[9])
+#define gss_display_status_ptr      ((gss_display_status_type)*gssFuncs[0].func)
+#define gss_init_sec_context_ptr    ((gss_init_sec_context_type)*gssFuncs[1].func)
+#define gss_indicate_mechs_ptr      ((gss_indicate_mechs_type)*gssFuncs[2].func)
+#define gss_release_oid_set_ptr     ((gss_release_oid_set_type)*gssFuncs[3].func)
+#define gss_delete_sec_context_ptr  ((gss_delete_sec_context_type)*gssFuncs[4].func)
+#define gss_import_name_ptr         ((gss_import_name_type)*gssFuncs[5].func)
+#define gss_release_buffer_ptr      ((gss_release_buffer_type)*gssFuncs[6].func)
+#define gss_release_name_ptr        ((gss_release_name_type)*gssFuncs[7].func)
+#define gss_wrap_ptr                ((gss_wrap_type)*gssFuncs[8].func)
+#define gss_unwrap_ptr              ((gss_unwrap_type)*gssFuncs[9].func)
 
 #ifdef XP_MACOSX
 static PRFuncPtr KLCacheHasValidTicketsPtr;
@@ -140,7 +144,7 @@ gssInit()
 
     if (!libPath.IsEmpty()) {
         LOG(("Attempting to load user specified library [%s]\n", libPath.get()));
-        gssNativeImp = PR_FALSE;
+        gssNativeImp = false;
         lib = PR_LoadLibrary(libPath.get());
     }
     else {
@@ -164,7 +168,7 @@ gssInit()
             "libgssapi.so.1"       /* Heimdal - Suse9, CITI - FC, MDK, Suse10*/
         };
 
-        for (size_t i = 0; i < NS_ARRAY_LENGTH(verLibNames) && !lib; ++i) {
+        for (size_t i = 0; i < ArrayLength(verLibNames) && !lib; ++i) {
             lib = PR_LoadLibrary(verLibNames[i]);
  
             /* The CITI libgssapi library calls exit() during
@@ -183,7 +187,7 @@ gssInit()
             }
         }
 
-        for (size_t i = 0; i < NS_ARRAY_LENGTH(libNames) && !lib; ++i) {
+        for (size_t i = 0; i < ArrayLength(libNames) && !lib; ++i) {
             char *libName = PR_GetLibraryName(NULL, libNames[i]);
             if (libName) {
                 lib = PR_LoadLibrary(libName);
@@ -209,10 +213,10 @@ gssInit()
 
     LOG(("Attempting to load gss functions\n"));
 
-    for (size_t i = 0; i < gssFuncItems; ++i) {
-        gssFunPtr[i] = PR_FindFunctionSymbol(lib, gssFuncStr[i]);
-        if (!gssFunPtr[i]) {
-            LOG(("Fail to load %s function from gssapi library\n", gssFuncStr[i]));
+    for (size_t i = 0; i < ArrayLength(gssFuncs); ++i) {
+        gssFuncs[i].func = PR_FindFunctionSymbol(lib, gssFuncs[i].str);
+        if (!gssFuncs[i].func) {
+            LOG(("Fail to load %s function from gssapi library\n", gssFuncs[i].str));
             PR_UnloadLibrary(lib);
             return NS_ERROR_FAILURE;
         }
@@ -298,7 +302,7 @@ nsAuthGSSAPI::nsAuthGSSAPI(pType package)
 
     LOG(("entering nsAuthGSSAPI::nsAuthGSSAPI()\n"));
 
-    mComplete = PR_FALSE;
+    mComplete = false;
 
     if (!gssLibrary && NS_FAILED(gssInit()))
         return;
@@ -349,7 +353,7 @@ nsAuthGSSAPI::Reset()
         gss_delete_sec_context_ptr(&minor_status, &mCtx, GSS_C_NO_BUFFER);
     }
     mCtx = GSS_C_NO_CONTEXT;
-    mComplete = PR_FALSE;
+    mComplete = false;
 }
 
 /* static */ void
@@ -454,7 +458,7 @@ nsAuthGSSAPI::GetNextToken(const void *inToken,
     // We can only use Mac OS X specific kerb functions if we are using 
     // the native lib
     KLBoolean found;    
-    PRBool doingMailTask = mServiceName.Find("imap@") ||
+    bool doingMailTask = mServiceName.Find("imap@") ||
                            mServiceName.Find("pop@") ||
                            mServiceName.Find("smtp@") ||
                            mServiceName.Find("ldap@");
@@ -490,7 +494,7 @@ nsAuthGSSAPI::GetNextToken(const void *inToken,
     if (major_status == GSS_S_COMPLETE) {
         // Mark ourselves as being complete, so that if we're called again
         // we know to start afresh.
-        mComplete = PR_TRUE;
+        mComplete = true;
     }
     else if (major_status == GSS_S_CONTINUE_NEEDED) {
         //
@@ -562,7 +566,7 @@ nsAuthGSSAPI::Unwrap(const void *inToken,
 NS_IMETHODIMP
 nsAuthGSSAPI::Wrap(const void *inToken,
                    PRUint32    inTokenLen,
-                   PRBool      confidential,
+                   bool        confidential,
                    void      **outToken,
                    PRUint32   *outTokenLen)
 {
