@@ -46,7 +46,6 @@
 #include "nsIObserver.h"
 #include "nsWeakReference.h"
 #include "nsTHashtable.h"
-#include "nsTArray.h"
 #include "nsCRT.h"
 #include "nsCycleCollectionParticipant.h"
 
@@ -76,12 +75,12 @@ public:
   }
  
   KeyType GetKey() const { return mKey; }
-  PRBool KeyEquals(KeyTypePointer aKey) const { return !nsCRT::strcmp(mKey, aKey); }
+  bool KeyEquals(KeyTypePointer aKey) const { return !nsCRT::strcmp(mKey, aKey); }
   static KeyTypePointer KeyToPointer(KeyType aKey) { return aKey; }
 
   static PLDHashNumber HashKey(KeyTypePointer aKey) { return nsCRT::HashCode(aKey); }
 
-  enum { ALLOW_MEMMOVE = PR_TRUE };
+  enum { ALLOW_MEMMOVE = true };
 
 private:
   PRUnichar *mKey;
@@ -104,8 +103,7 @@ public:
   nsresult Init();
 
 protected:
-  nsTArray<nsString>  mDictionary;  /* use something a little smarter eventually*/
-  PRBool         mDirty;       /* has the dictionary been modified */
+  bool           mDirty;       /* has the dictionary been modified */
   nsTHashtable<nsUniCharEntry> mDictionaryTable;
   nsTHashtable<nsUniCharEntry> mIgnoreTable;
   nsCOMPtr<nsIUnicodeEncoder>  mEncoder; /*Encoder to use to compare with spellchecker word */
