@@ -39,6 +39,8 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
+#include "mozilla/Util.h"
+
 #if defined(XP_UNIX)
 
 #ifdef MOZ_WIDGET_GTK2
@@ -233,15 +235,15 @@ static class EGLLibrary
 {
 public:
     EGLLibrary() 
-        : mInitialized(PR_FALSE),
+        : mInitialized(false),
           mEGLLibrary(nsnull)
     {
-        mIsANGLE = PR_FALSE;
-        mHave_EGL_KHR_image_base = PR_FALSE;
-        mHave_EGL_KHR_image_pixmap = PR_FALSE;
-        mHave_EGL_KHR_gl_texture_2D_image = PR_FALSE;
-        mHave_EGL_KHR_lock_surface = PR_FALSE;
-        mHave_EGL_ANGLE_surface_d3d_texture_2d_share_handle = PR_FALSE;
+        mIsANGLE = false;
+        mHave_EGL_KHR_image_base = false;
+        mHave_EGL_KHR_image_pixmap = false;
+        mHave_EGL_KHR_gl_texture_2D_image = false;
+        mHave_EGL_KHR_lock_surface = false;
+        mHave_EGL_ANGLE_surface_d3d_texture_2d_share_handle = false;
     }
 
     typedef EGLDisplay (GLAPIENTRY * pfnGetDisplay)(void *display_id);
@@ -315,10 +317,10 @@ public:
     typedef void (GLAPIENTRY * pfnImageTargetTexture2DOES)(GLenum target, GLeglImageOES image);
     pfnImageTargetTexture2DOES fImageTargetTexture2DOES;
 
-    PRBool EnsureInitialized()
+    bool EnsureInitialized()
     {
         if (mInitialized) {
-            return PR_TRUE;
+            return true;
         }
 
         mozilla::ScopedGfxFeatureReporter reporter("EGL");
@@ -362,7 +364,7 @@ public:
 
         if (!mEGLLibrary) {
             NS_WARNING("Couldn't load EGL LIB.");
-            return PR_FALSE;
+            return false;
         }
 
 #define SYMBOL(name) \
@@ -399,7 +401,7 @@ public:
 
         if (!LibrarySymbolLoader::LoadSymbols(mEGLLibrary, &earlySymbols[0])) {
             NS_WARNING("Couldn't find required entry points in EGL library (early init)");
-            return PR_FALSE;
+            return false;
         }
 
 #if defined(MOZ_X11) && defined(MOZ_EGL_XRENDER_COMPOSITE)
@@ -408,11 +410,11 @@ public:
         mEGLDisplay = fGetDisplay(EGL_DEFAULT_DISPLAY);
 #endif
         if (!fInitialize(mEGLDisplay, NULL, NULL))
-            return PR_FALSE;
+            return false;
 
         const char *vendor = (const char*) fQueryString(mEGLDisplay, LOCAL_EGL_VENDOR);
         if (vendor && strstr(vendor, "TransGaming") != 0) {
-            mIsANGLE = PR_TRUE;
+            mIsANGLE = true;
         }
         
         const char *extensions = (const char*) fQueryString(mEGLDisplay, LOCAL_EGL_EXTENSIONS);
@@ -426,29 +428,29 @@ public:
         // EGL_KHR_image in the middle of the string, or right at the
         // end.  It's a prefix for other extensions, so we have to do
         // this...
-        PRBool hasKHRImage = PR_FALSE;
+        bool hasKHRImage = false;
         if (strstr(extensions, "EGL_KHR_image ") ||
             (strlen(extensions) >= strlen("EGL_KHR_image") &&
              strcmp(extensions+(strlen(extensions)-strlen("EGL_KHR_image")), "EGL_KHR_image")))
         {
-            hasKHRImage = PR_TRUE;
+            hasKHRImage = true;
         }
 
         if (strstr(extensions, "EGL_KHR_image_base")) {
-            mHave_EGL_KHR_image_base = PR_TRUE;
+            mHave_EGL_KHR_image_base = true;
         }
             
         if (strstr(extensions, "EGL_KHR_image_pixmap")) {
-            mHave_EGL_KHR_image_pixmap = PR_TRUE;
+            mHave_EGL_KHR_image_pixmap = true;
             
         }
 
         if (strstr(extensions, "EGL_KHR_gl_texture_2D_image")) {
-            mHave_EGL_KHR_gl_texture_2D_image = PR_TRUE;
+            mHave_EGL_KHR_gl_texture_2D_image = true;
         }
 
         if (strstr(extensions, "EGL_KHR_lock_surface")) {
-            mHave_EGL_KHR_lock_surface = PR_TRUE;
+            mHave_EGL_KHR_lock_surface = true;
         }
 
         if (hasKHRImage) {
@@ -473,18 +475,18 @@ public:
             LibrarySymbolLoader::LoadSymbols(mEGLLibrary, &lockSymbols[0],
                                              (LibrarySymbolLoader::PlatformLookupFunction)fGetProcAddress);
             if (!fLockSurfaceKHR) {
-                mHave_EGL_KHR_lock_surface = PR_FALSE;
+                mHave_EGL_KHR_lock_surface = false;
             }
         }
 
         if (!fCreateImageKHR) {
-            mHave_EGL_KHR_image_base = PR_FALSE;
-            mHave_EGL_KHR_image_pixmap = PR_FALSE;
-            mHave_EGL_KHR_gl_texture_2D_image = PR_FALSE;
+            mHave_EGL_KHR_image_base = false;
+            mHave_EGL_KHR_image_pixmap = false;
+            mHave_EGL_KHR_gl_texture_2D_image = false;
         }
 
         if (!fImageTargetTexture2DOES) {
-            mHave_EGL_KHR_gl_texture_2D_image = PR_FALSE;
+            mHave_EGL_KHR_gl_texture_2D_image = false;
         }
 
         if (strstr(extensions, "EGL_ANGLE_surface_d3d_texture_2d_share_handle")) {
@@ -496,40 +498,40 @@ public:
             LibrarySymbolLoader::LoadSymbols(mEGLLibrary, &d3dSymbols[0],
                                              (LibrarySymbolLoader::PlatformLookupFunction)fGetProcAddress);
             if (fQuerySurfacePointerANGLE) {
-                mHave_EGL_ANGLE_surface_d3d_texture_2d_share_handle = PR_TRUE;
+                mHave_EGL_ANGLE_surface_d3d_texture_2d_share_handle = true;
             }
         }
 
-        mInitialized = PR_TRUE;
+        mInitialized = true;
         reporter.SetSuccessful();
-        return PR_TRUE;
+        return true;
     }
 
     EGLDisplay Display() {
         return mEGLDisplay;
     }
 
-    PRBool IsANGLE() {
+    bool IsANGLE() {
         return mIsANGLE;
     }
 
-    PRBool HasKHRImageBase() {
+    bool HasKHRImageBase() {
         return mHave_EGL_KHR_image_base;
     }
 
-    PRBool HasKHRImagePixmap() {
+    bool HasKHRImagePixmap() {
         return mHave_EGL_KHR_image_pixmap;
     }
 
-    PRBool HasKHRImageTexture2D() {
+    bool HasKHRImageTexture2D() {
         return mHave_EGL_KHR_gl_texture_2D_image;
     }
 
-    PRBool HasKHRLockSurface() {
+    bool HasKHRLockSurface() {
         return mHave_EGL_KHR_lock_surface;
     }
 
-    PRBool HasANGLESurfaceD3DTexture2DShareHandle() {
+    bool HasANGLESurfaceD3DTexture2DShareHandle() {
         return mHave_EGL_ANGLE_surface_d3d_texture_2d_share_handle;
     }
 
@@ -602,17 +604,17 @@ public:
     }
 
 private:
-    PRBool mInitialized;
+    bool mInitialized;
     PRLibrary *mEGLLibrary;
     EGLDisplay mEGLDisplay;
 
-    PRPackedBool mIsANGLE;
+    bool mIsANGLE;
 
-    PRPackedBool mHave_EGL_KHR_image_base;
-    PRPackedBool mHave_EGL_KHR_image_pixmap;
-    PRPackedBool mHave_EGL_KHR_gl_texture_2D_image;
-    PRPackedBool mHave_EGL_KHR_lock_surface;
-    PRPackedBool mHave_EGL_ANGLE_surface_d3d_texture_2d_share_handle;
+    bool mHave_EGL_KHR_image_base;
+    bool mHave_EGL_KHR_image_pixmap;
+    bool mHave_EGL_KHR_gl_texture_2D_image;
+    bool mHave_EGL_KHR_lock_surface;
+    bool mHave_EGL_ANGLE_surface_d3d_texture_2d_share_handle;
 } sEGLLibrary;
 
 class GLContextEGL : public GLContext
@@ -624,7 +626,7 @@ class GLContextEGL : public GLContext
                     EGLSurface surface,
                     EGLConfig config,
                     GLContextEGL *shareContext,
-                    PRBool aIsOffscreen = PR_FALSE)
+                    bool aIsOffscreen = false)
     {
         EGLContext context;
         static EGLint cxattribs[] = {
@@ -666,19 +668,19 @@ public:
                  EGLConfig aConfig,
                  EGLSurface aSurface,
                  EGLContext aContext,
-                 PRBool aIsOffscreen = PR_FALSE)
+                 bool aIsOffscreen = false)
         : GLContext(aFormat, aIsOffscreen, aShareContext)
         , mConfig(aConfig) 
         , mSurface(aSurface), mContext(aContext)
         , mPlatformContext(nsnull)
         , mThebesSurface(nsnull)
-        , mBound(PR_FALSE)
-        , mIsPBuffer(PR_FALSE)
-        , mIsDoubleBuffered(PR_FALSE)
-        , mPBufferCanBindToTexture(PR_FALSE)
+        , mBound(false)
+        , mIsPBuffer(false)
+        , mIsDoubleBuffered(false)
+        , mPBufferCanBindToTexture(false)
     {
         // any EGL contexts will always be GLESv2
-        SetIsGLES2(PR_TRUE);
+        SetIsGLES2(true);
 
 #ifdef DEBUG
         printf_stderr("Initializing context %p surface %p on display %p\n", mContext, mSurface, EGL_DISPLAY());
@@ -709,37 +711,40 @@ public:
         return ContextTypeEGL;
     }
 
-    PRBool Init()
+    bool Init()
     {
         if (!OpenLibrary(GLES2_LIB)) {
             NS_WARNING("Couldn't load EGL LIB.");
-            return PR_FALSE;
+            return false;
         }
 
-        PRBool current = MakeCurrent();
+        bool current = MakeCurrent();
         if (!current) {
             gfx::LogFailure(NS_LITERAL_CSTRING(
                 "Couldn't get device attachments for device."));
-            return PR_FALSE;
+            return false;
         }
 
-        PRBool ok = InitWithPrefix("gl", PR_TRUE);
+        bool ok = InitWithPrefix("gl", true);
+
+        PR_STATIC_ASSERT(sizeof(GLint) >= sizeof(int32_t));
+        mMaxTextureImageSize = PR_INT32_MAX;
 #if 0
         if (ok) {
             EGLint v;
             sEGLLibrary.fQueryContext(EGL_DISPLAY(), mContext, LOCAL_EGL_RENDER_BUFFER, &v);
             if (v == LOCAL_EGL_BACK_BUFFER)
-                mIsDoubleBuffered = PR_TRUE;
+                mIsDoubleBuffered = true;
         }
 #endif
         return ok;
     }
 
-    PRBool IsDoubleBuffered() {
+    bool IsDoubleBuffered() {
         return mIsDoubleBuffered;
     }
 
-    void SetIsDoubleBuffered(PRBool aIsDB) {
+    void SetIsDoubleBuffered(bool aIsDB) {
         mIsDoubleBuffered = aIsDB;
     }
 
@@ -749,49 +754,49 @@ public:
       return mThebesSurface;
     }
     
-    virtual PRBool WaitNative() {
+    virtual bool WaitNative() {
       return sEGLLibrary.fWaitNative(LOCAL_EGL_CORE_NATIVE_ENGINE);
     }
 #endif
 
-    PRBool BindTexImage()
+    bool BindTexImage()
     {
         if (!mSurface)
-            return PR_FALSE;
+            return false;
 
         if (mBound && !ReleaseTexImage())
-            return PR_FALSE;
+            return false;
 
         EGLBoolean success = sEGLLibrary.fBindTexImage(EGL_DISPLAY(),
             (EGLSurface)mSurface, LOCAL_EGL_BACK_BUFFER);
         if (success == LOCAL_EGL_FALSE)
-            return PR_FALSE;
+            return false;
 
-        mBound = PR_TRUE;
-        return PR_TRUE;
+        mBound = true;
+        return true;
     }
 
-    PRBool ReleaseTexImage()
+    bool ReleaseTexImage()
     {
         if (!mBound)
-            return PR_TRUE;
+            return true;
 
         if (!mSurface)
-            return PR_FALSE;
+            return false;
 
         EGLBoolean success;
         success = sEGLLibrary.fReleaseTexImage(EGL_DISPLAY(),
                                                (EGLSurface)mSurface,
                                                LOCAL_EGL_BACK_BUFFER);
         if (success == LOCAL_EGL_FALSE)
-            return PR_FALSE;
+            return false;
 
-        mBound = PR_FALSE;
-        return PR_TRUE;
+        mBound = false;
+        return true;
     }
 
-    PRBool MakeCurrentImpl(PRBool aForce = PR_FALSE) {
-        PRBool succeeded = PR_TRUE;
+    bool MakeCurrentImpl(bool aForce = false) {
+        bool succeeded = true;
 
         // Assume that EGL has the same problem as WGL does,
         // where MakeCurrent with an already-current context is
@@ -801,7 +806,7 @@ public:
             EGLConfig config;
             CreateConfig(&config);
             mSurface = CreateSurfaceForWindow(NULL, config);
-            aForce = PR_TRUE;
+            aForce = true;
         }
 #endif
         if (aForce || sEGLLibrary.fGetCurrentContext() != mContext) {
@@ -815,13 +820,13 @@ public:
     }
 
 #ifdef MOZ_WIDGET_QT
-    virtual PRBool
+    virtual bool
     RenewSurface() {
         /* We don't support renewing on QT because we don't create the surface ourselves */
-        return PR_FALSE;
+        return false;
     }
 #else
-    virtual PRBool
+    virtual bool
     RenewSurface() {
         ReleaseSurface();
         EGLConfig config;
@@ -844,10 +849,10 @@ public:
         }
     }
 
-    PRBool SetupLookupFunction()
+    bool SetupLookupFunction()
     {
         mLookupFunc = (PlatformLookupFunction)sEGLLibrary.fGetProcAddress;
-        return PR_TRUE;
+        return true;
     }
 
     void *GetNativeData(NativeDataType aType)
@@ -861,12 +866,12 @@ public:
         }
     }
 
-    PRBool SwapBuffers()
+    bool SwapBuffers()
     {
         if (mSurface && !mPlatformContext) {
             return sEGLLibrary.fSwapBuffers(EGL_DISPLAY(), mSurface);
         } else {
-            return PR_FALSE;
+            return false;
         }
     }
     // GLContext interface - returns Tiled Texture Image in our case
@@ -874,13 +879,13 @@ public:
     CreateTextureImage(const nsIntSize& aSize,
                        TextureImage::ContentType aContentType,
                        GLenum aWrapMode,
-                       PRBool aUseNearestFilter=PR_FALSE);
+                       bool aUseNearestFilter=false);
 
     // a function to generate Tiles for Tiled Texture Image
     virtual already_AddRefed<TextureImage>
     TileGenFunc(const nsIntSize& aSize,
                 TextureImage::ContentType aContentType,
-                PRBool aUseNearestFilter = PR_FALSE);
+                bool aUseNearestFilter = false);
     // hold a reference to the given surface
     // for the lifetime of this context.
     void HoldSurface(gfxASurface *aSurf) {
@@ -895,22 +900,22 @@ public:
         return mContext;
     }
 
-    PRBool BindTex2DOffscreen(GLContext *aOffscreen);
+    bool BindTex2DOffscreen(GLContext *aOffscreen);
     void UnbindTex2DOffscreen(GLContext *aOffscreen);
-    PRBool ResizeOffscreen(const gfxIntSize& aNewSize);
+    bool ResizeOffscreen(const gfxIntSize& aNewSize);
     void BindOffscreenFramebuffer();
 
     static already_AddRefed<GLContextEGL>
     CreateEGLPixmapOffscreenContext(const gfxIntSize& aSize,
                                     const ContextFormat& aFormat,
-                                    PRBool aShare);
+                                    bool aShare);
 
 #if defined(MOZ_X11) && defined(MOZ_EGL_XRENDER_COMPOSITE)
     static already_AddRefed<GLContextEGL>
     CreateBasicEGLPixmapOffscreenContext(const gfxIntSize& aSize,
                                          const ContextFormat& aFormat);
 
-    PRBool ResizeOffscreenPixmapSurface(const gfxIntSize& aNewSize);
+    bool ResizeOffscreenPixmapSurface(const gfxIntSize& aNewSize);
 #endif
 
     static already_AddRefed<GLContextEGL>
@@ -952,11 +957,11 @@ protected:
     EGLContext mContext;
     void *mPlatformContext;
     nsRefPtr<gfxASurface> mThebesSurface;
-    PRBool mBound;
+    bool mBound;
 
-    PRPackedBool mIsPBuffer;
-    PRPackedBool mIsDoubleBuffered;
-    PRPackedBool mPBufferCanBindToTexture;
+    bool mIsPBuffer;
+    bool mIsDoubleBuffered;
+    bool mPBufferCanBindToTexture;
 
     static EGLSurface CreatePBufferSurfaceTryingPowerOfTwo(EGLConfig config,
                                                            EGLenum bindToTextureFormat,
@@ -1002,18 +1007,18 @@ protected:
     }
 };
 
-PRBool
+bool
 GLContextEGL::BindTex2DOffscreen(GLContext *aOffscreen)
 {
     if (aOffscreen->GetContextType() != ContextTypeEGL) {
         NS_WARNING("non-EGL context");
-        return PR_FALSE;
+        return false;
     }
 
     GLContextEGL *offs = static_cast<GLContextEGL*>(aOffscreen);
 
     if (offs->mIsPBuffer && offs->mPBufferCanBindToTexture) {
-        PRBool ok = sEGLLibrary.fBindTexImage(EGL_DISPLAY(),
+        bool ok = sEGLLibrary.fBindTexImage(EGL_DISPLAY(),
                                               offs->mSurface,
                                               LOCAL_EGL_BACK_BUFFER);
         return ok;
@@ -1023,16 +1028,16 @@ GLContextEGL::BindTex2DOffscreen(GLContext *aOffscreen)
         if (offs->GetSharedContext() != GLContextProviderEGL::GetGlobalContext())
         {
             NS_WARNING("offscreen FBO context can only be bound with context sharing!");
-            return PR_FALSE;
+            return false;
         }
 
         fBindTexture(LOCAL_GL_TEXTURE_2D, offs->mOffscreenTexture);
-        return PR_TRUE;
+        return true;
     }
 
     NS_WARNING("don't know how to bind this!");
 
-    return PR_FALSE;
+    return false;
 }
 
 void
@@ -1049,9 +1054,12 @@ GLContextEGL::UnbindTex2DOffscreen(GLContext *aOffscreen)
     }
 }
 
-PRBool
+bool
 GLContextEGL::ResizeOffscreen(const gfxIntSize& aNewSize)
 {
+    if (!IsOffscreenSizeAllowed(aNewSize))
+        return false;
+
     if (mIsPBuffer) {
         gfxIntSize pbsize(aNewSize);
 
@@ -1065,9 +1073,12 @@ GLContextEGL::ResizeOffscreen(const gfxIntSize& aNewSize)
                                                  pbsize);
         if (!surface) {
             NS_WARNING("Failed to resize pbuffer");
-            return nsnull;
+            return false;
         }
 
+        if (!ResizeOffscreenFBO(pbsize, false))
+            return false;
+
         SetOffscreenSize(aNewSize, pbsize);
 
         if (mSurface && !mPlatformContext) {
@@ -1076,16 +1087,16 @@ GLContextEGL::ResizeOffscreen(const gfxIntSize& aNewSize)
 
         mSurface = surface;
 
-        MakeCurrent(PR_TRUE);
+        MakeCurrent(true);
         ClearSafely();
 
-        return PR_TRUE;
+        return true;
     }
 
 #ifdef MOZ_X11
     if (gUseBackingSurface && mThebesSurface) {
         if (aNewSize == mThebesSurface->GetSize()) {
-            return PR_TRUE;
+            return true;
         }
 
         EGLNativePixmapType pixmap = 0;
@@ -1098,11 +1109,11 @@ GLContextEGL::ResizeOffscreen(const gfxIntSize& aNewSize)
         XSync(DefaultXDisplay(), False);
 
         if (xsurface->CairoStatus() != 0) {
-            return PR_FALSE;
+            return false;
         }
         pixmap = (EGLNativePixmapType)xsurface->XDrawable();
         if (!pixmap) {
-            return PR_FALSE;
+            return false;
         }
 
         EGLSurface surface;
@@ -1110,19 +1121,25 @@ GLContextEGL::ResizeOffscreen(const gfxIntSize& aNewSize)
         int depth = gfxUtils::ImageFormatToDepth(gfxPlatform::GetPlatform()->GetOffscreenFormat());
         surface = CreateEGLSurfaceForXSurface(xsurface, &config, depth);
         if (!config) {
-            return PR_FALSE;
+            return false;
         }
+        if (!ResizeOffscreenFBO(aNewSize, true))
+            return false;
+
         mThebesSurface = xsurface;
 
-        return PR_TRUE;
+        return true;
     }
 #endif
 
 #if defined(MOZ_X11) && defined(MOZ_EGL_XRENDER_COMPOSITE)
-    return ResizeOffscreenPixmapSurface(aNewSize);
+    if (ResizeOffscreenPixmapSurface(aNewSize)) {
+        if (ResizeOffscreenFBO(aNewSize, true))
+            return true;
+    }
 #endif
 
-    return ResizeOffscreenFBO(aNewSize);
+    return ResizeOffscreenFBO(aNewSize, true);
 }
 
 
@@ -1183,8 +1200,8 @@ public:
         , mTexture(aTexture)
         , mImageKHR(nsnull)
         , mTextureState(Created)
-        , mBound(PR_FALSE)
-        , mIsLocked(PR_FALSE)
+        , mBound(false)
+        , mIsLocked(false)
     {
         mUpdateFormat = gfxASurface::FormatFromContent(GetContentType());
 
@@ -1207,7 +1224,7 @@ public:
             // for RGB24.  No easy way to upload that to GL.
             // 
             // Note that if we start using RGB565 here, we'll need to
-            // watch for a) setting mIsRGBFormat to TRUE; and b) getting
+            // watch for a) setting the correct format; and b) getting
             // the stride right.
             if (mUpdateFormat == gfxASurface::ImageFormatRGB24) {
                 mUpdateFormat = gfxASurface::ImageFormatARGB32;
@@ -1275,9 +1292,6 @@ public:
             return mUpdateSurface;
         }
 
-        // if we get this far, then we're using Cairo's byte order
-        mIsRGBFormat = PR_FALSE;
-
         //printf_stderr("creating image surface %dx%d format %d\n", mUpdateRect.width, mUpdateRect.height, mUpdateFormat);
 
         mUpdateSurface =
@@ -1401,7 +1415,7 @@ public:
                                                  mTexture,
                                                  mTextureState == Created,
                                                  bounds.TopLeft() + aFrom,
-                                                 PR_FALSE);
+                                                 false);
         }
 
         mTextureState = Valid;
@@ -1429,7 +1443,7 @@ public:
         return mTexture;
     };
 
-    virtual PRBool InUpdate() const { return !!mUpdateSurface; }
+    virtual bool InUpdate() const { return !!mUpdateSurface; }
 
     virtual void Resize(const nsIntSize& aSize)
     {
@@ -1463,10 +1477,10 @@ public:
         mSize = aSize;
     }
 
-    PRBool BindTexImage()
+    bool BindTexImage()
     {
         if (mBound && !ReleaseTexImage())
-            return PR_FALSE;
+            return false;
 
         EGLBoolean success =
             sEGLLibrary.fBindTexImage(EGL_DISPLAY(),
@@ -1474,16 +1488,16 @@ public:
                                       LOCAL_EGL_BACK_BUFFER);
 
         if (success == LOCAL_EGL_FALSE)
-            return PR_FALSE;
+            return false;
 
-        mBound = PR_TRUE;
-        return PR_TRUE;
+        mBound = true;
+        return true;
     }
 
-    PRBool ReleaseTexImage()
+    bool ReleaseTexImage()
     {
         if (!mBound)
-            return PR_TRUE;
+            return true;
 
         EGLBoolean success =
             sEGLLibrary.fReleaseTexImage(EGL_DISPLAY(),
@@ -1491,10 +1505,10 @@ public:
                                          LOCAL_EGL_BACK_BUFFER);
 
         if (success == LOCAL_EGL_FALSE)
-            return PR_FALSE;
+            return false;
 
-        mBound = PR_FALSE;
-        return PR_TRUE;
+        mBound = false;
+        return true;
     }
 
     virtual already_AddRefed<gfxImageSurface> GetLockSurface()
@@ -1522,7 +1536,7 @@ public:
 
         sEGLLibrary.fLockSurfaceKHR(EGL_DISPLAY(), mSurface, lock_attribs);
 
-        mIsLocked = PR_TRUE;
+        mIsLocked = true;
 
         unsigned char *data = nsnull;
         int pitch = 0;
@@ -1549,7 +1563,7 @@ public:
         }
 
         sEGLLibrary.fUnlockSurfaceKHR(EGL_DISPLAY(), mSurface);
-        mIsLocked = PR_FALSE;
+        mIsLocked = false;
     }
 
     virtual already_AddRefed<gfxASurface> GetBackingSurface()
@@ -1558,34 +1572,34 @@ public:
         return copy.forget();
     }
 
-    virtual PRBool CreateEGLSurface(gfxASurface* aSurface)
+    virtual bool CreateEGLSurface(gfxASurface* aSurface)
     {
 #ifdef MOZ_X11
         if (!aSurface) {
             NS_WARNING("no surface");
-            return PR_FALSE;
+            return false;
         }
 
         if (aSurface->GetType() != gfxASurface::SurfaceTypeXlib) {
             NS_WARNING("wrong surface type, must be xlib");
-            return PR_FALSE;
+            return false;
         }
 
         if (mSurface) {
-            return PR_TRUE;
+            return true;
         }
 
         EGLSurface surface = CreateEGLSurfaceForXSurface(aSurface, &mConfig);
 
         if (!surface) {
             NS_WARNING("couldn't find X config for surface");
-            return PR_FALSE;
+            return false;
         }
 
         mSurface = surface;
-        return PR_TRUE;
+        return true;
 #else
-        return PR_FALSE;
+        return false;
 #endif
     }
 
@@ -1598,7 +1612,7 @@ public:
         mSurface = nsnull;
     }
 
-    virtual PRBool CreateBackingSurface(const gfxIntSize& aSize)
+    virtual bool CreateBackingSurface(const gfxIntSize& aSize)
     {
         ReleaseTexImage();
         DestroyEGLSurface();
@@ -1627,7 +1641,7 @@ public:
 
             if (!mImageKHR) {
                 printf_stderr("couldn't create EGL image: ERROR (0x%04x)\n", sEGLLibrary.fGetError());
-                return PR_FALSE;
+                return false;
             }
             mGLContext->fBindTexture(LOCAL_GL_TEXTURE_2D, mTexture);
             sEGLLibrary.fImageTargetTexture2DOES(LOCAL_GL_TEXTURE_2D, mImageKHR);
@@ -1636,17 +1650,16 @@ public:
         } else {
             if (!CreateEGLSurface(xsurface)) {
                 printf_stderr("ProviderEGL Failed create EGL surface: ERROR (0x%04x)\n", sEGLLibrary.fGetError());
-                return PR_FALSE;
+                return false;
             }
 
             if (!BindTexImage()) {
                 printf_stderr("ProviderEGL Failed to bind teximage: ERROR (0x%04x)\n", sEGLLibrary.fGetError());
-                return PR_FALSE;
+                return false;
             }
         }
 
         mBackingSurface = xsurface;
-        mIsRGBFormat = PR_TRUE;
 #endif
 
         return mBackingSurface != nsnull;
@@ -1667,24 +1680,29 @@ protected:
     EGLImageKHR mImageKHR;
     TextureState mTextureState;
 
-    PRPackedBool mBound;
-    PRPackedBool mIsLocked;
+    bool mBound;
+    bool mIsLocked;
+
+    virtual void ApplyFilter()
+    {
+        mGLContext->ApplyFilterToBoundTexture(mFilter);
+    }
 };
 
 already_AddRefed<TextureImage>
 GLContextEGL::CreateTextureImage(const nsIntSize& aSize,
                                  TextureImage::ContentType aContentType,
                                  GLenum aWrapMode,
-                                 PRBool aUseNearestFilter)
+                                 bool aUseNearestFilter)
 {
-    nsRefPtr<TextureImage> t = new gl::TiledTextureImage(this, aSize, aContentType);
+    nsRefPtr<TextureImage> t = new gl::TiledTextureImage(this, aSize, aContentType, aUseNearestFilter);
     return t.forget();
 };
 
 already_AddRefed<TextureImage>
 GLContextEGL::TileGenFunc(const nsIntSize& aSize,
                                  TextureImage::ContentType aContentType,
-                                 PRBool aUseNearestFilter)
+                                 bool aUseNearestFilter)
 {
   MakeCurrent();
 
@@ -1741,7 +1759,7 @@ GLContextProviderEGL::CreateForWindow(nsIWidget *aWidget)
                              NULL,
                              sEGLLibrary.fGetCurrentSurface(LOCAL_EGL_DRAW), // just use same surface for read and draw
                              sEGLLibrary.fGetCurrentContext(),
-                             PR_FALSE);
+                             false);
 
         if (!glContext->Init())
             return nsnull;
@@ -1785,6 +1803,13 @@ static const EGLint kEGLConfigAttribsRGBA32[] = {
     LOCAL_EGL_NONE
 };
 
+// This struct is used only by CreateConfig below, but ISO C++98 forbids
+// instantiating a template dependent on a locally-defined type.  Boo-urns!
+struct EGLAttribs {
+    gfxASurface::gfxImageFormat mFormat;
+    const EGLint* mAttribs;
+};
+
 // Return true if a suitable EGLConfig was found and pass it out
 // through aConfig.  Return false otherwise.
 //
@@ -1793,10 +1818,7 @@ static const EGLint kEGLConfigAttribsRGBA32[] = {
 static bool
 CreateConfig(EGLConfig* aConfig)
 {
-    struct EGLAttribs {
-        gfxASurface::gfxImageFormat mFormat;
-        const EGLint* mAttribs;
-    } attribsToTry[] = {
+    EGLAttribs attribsToTry[] = {
 #ifdef MOZ_GFX_OPTIMIZE_MOBILE
         // Prefer r5g6b5 for potential savings in memory bandwidth.
         // This needs to be reevaluated for newer devices.
@@ -1806,9 +1828,9 @@ CreateConfig(EGLConfig* aConfig)
     };
 
     EGLConfig configs[64];
-    for (unsigned i = 0; i < NS_ARRAY_LENGTH(attribsToTry); ++i) {
+    for (unsigned i = 0; i < ArrayLength(attribsToTry); ++i) {
         const EGLAttribs& attribs = attribsToTry[i];
-        EGLint ncfg = NS_ARRAY_LENGTH(configs);
+        EGLint ncfg = ArrayLength(configs);
 
         if (!sEGLLibrary.fChooseConfig(EGL_DISPLAY(), attribs.mAttribs,
                                        configs, ncfg, &ncfg) ||
@@ -1912,14 +1934,14 @@ GLContextProviderEGL::CreateForWindow(nsIWidget *aWidget)
                                       surface,
                                       config,
                                       shareContext,
-                                      PR_FALSE);
+                                      false);
 
     if (!glContext) {
         return nsnull;
     }
 
 #if defined(XP_WIN) || defined(ANDROID) || defined(MOZ_PLATFORM_MAEMO)
-    glContext->SetIsDoubleBuffered(PR_TRUE);
+    glContext->SetIsDoubleBuffered(true);
 #endif
 
     return glContext.forget();
@@ -1992,13 +2014,15 @@ GLContextEGL::CreateEGLPBufferOffscreenContext(const gfxIntSize& aSize,
     nsTArray<EGLint> attribs(32);
     int attribAttempt = 0;
 
+    int tryDepthSize = (aFormat.depth > 0) ? 24 : 0;
+
 TRY_ATTRIBS_AGAIN:
     switch (attribAttempt) {
     case 0:
-        FillPBufferAttribs(attribs, aFormat, configCanBindToTexture, 8, 24);
+        FillPBufferAttribs(attribs, aFormat, configCanBindToTexture, 8, tryDepthSize);
         break;
     case 1:
-        FillPBufferAttribs(attribs, aFormat, configCanBindToTexture, -1, 24);
+        FillPBufferAttribs(attribs, aFormat, configCanBindToTexture, -1, tryDepthSize);
         break;
     case 2:
         FillPBufferAttribs(attribs, aFormat, configCanBindToTexture, -1, -1);
@@ -2064,14 +2088,14 @@ TRY_ATTRIBS_AGAIN:
 
     nsRefPtr<GLContextEGL> glContext = new GLContextEGL(aFormat, nsnull,
                                                         config, surface, context,
-                                                        PR_TRUE);
+                                                        true);
 
     if (!glContext->Init()) {
         return nsnull;
     }
 
     glContext->SetOffscreenSize(aSize, pbsize);
-    glContext->mIsPBuffer = PR_TRUE;
+    glContext->mIsPBuffer = true;
     glContext->mPBufferCanBindToTexture = configCanBindToTexture;
 
     return glContext.forget();
@@ -2082,7 +2106,7 @@ EGLSurface
 CreateEGLSurfaceForXSurface(gfxASurface* aSurface, EGLConfig* aConfig, EGLenum aDepth)
 {
     gfxXlibSurface* xsurface = static_cast<gfxXlibSurface*>(aSurface);
-    PRBool opaque =
+    bool opaque =
         aSurface->GetContentType() == gfxASurface::CONTENT_COLOR;
 
     static EGLint pixmap_config_rgb[] = {
@@ -2169,7 +2193,7 @@ CreateEGLSurfaceForXSurface(gfxASurface* aSurface, EGLConfig* aConfig, EGLenum a
 already_AddRefed<GLContextEGL>
 GLContextEGL::CreateEGLPixmapOffscreenContext(const gfxIntSize& aSize,
                                               const ContextFormat& aFormat,
-                                              PRBool aShare)
+                                              bool aShare)
 {
     gfxASurface *thebesSurface = nsnull;
     EGLNativePixmapType pixmap = 0;
@@ -2212,7 +2236,7 @@ GLContextEGL::CreateEGLPixmapOffscreenContext(const gfxIntSize& aSize,
                                       surface,
                                       config,
                                       shareContext,
-                                      PR_TRUE);
+                                      true);
 
     glContext->HoldSurface(thebesSurface);
 
@@ -2232,12 +2256,30 @@ GLContextProviderEGL::CreateOffscreen(const gfxIntSize& aSize,
     }
 
 #if defined(ANDROID) || defined(XP_WIN)
-    return GLContextEGL::CreateEGLPBufferOffscreenContext(aSize, aFormat);
+    nsRefPtr<GLContextEGL> glContext =
+        GLContextEGL::CreateEGLPBufferOffscreenContext(aSize, aFormat);
+
+    if (!glContext)
+        return nsnull;
+
+    if (!glContext->ResizeOffscreenFBO(glContext->OffscreenActualSize(), false))
+        return nsnull;
+
+    return glContext.forget();
 #elif defined(MOZ_X11) && defined(MOZ_EGL_XRENDER_COMPOSITE)
-  return GLContextEGL::CreateBasicEGLPixmapOffscreenContext(aSize, aFormat);
+    nsRefPtr<GLContextEGL> glContext =
+        GLContextEGL::CreateBasicEGLPixmapOffscreenContext(aSize, aFormat);
+
+    if (!glContext)
+        return nsnull;
+
+    if (!glContext->ResizeOffscreenFBO(glContext->OffscreenActualSize(), true))
+        return nsnull;
+
+    return glContext.forget();
 #elif defined(MOZ_X11)
     nsRefPtr<GLContextEGL> glContext =
-        GLContextEGL::CreateEGLPixmapOffscreenContext(aSize, aFormat, PR_TRUE);
+        GLContextEGL::CreateEGLPixmapOffscreenContext(aSize, aFormat, true);
 
     if (!glContext) {
         return nsnull;
@@ -2247,7 +2289,7 @@ GLContextProviderEGL::CreateOffscreen(const gfxIntSize& aSize,
         // render from this
         return nsnull;
     }
-    if (!gUseBackingSurface && !glContext->ResizeOffscreenFBO(aSize)) {
+    if (!gUseBackingSurface && !glContext->ResizeOffscreenFBO(glContext->OffscreenActualSize(), true)) {
         // we weren't able to create the initial
         // offscreen FBO, so this is dead
         return nsnull;
@@ -2283,7 +2325,7 @@ GLContextProviderEGL::CreateForNativePixmapSurface(gfxASurface* aSurface)
 
     nsRefPtr<GLContextEGL> glContext =
         GLContextEGL::CreateGLContext(DepthToGLFormat(xsurface->XRenderFormat()->depth),
-                                      surface, config, shareContext, PR_FALSE);
+                                      surface, config, shareContext, false);
 
     glContext->HoldSurface(aSurface);
 
@@ -2305,9 +2347,9 @@ GLContextProviderEGL::GetGlobalContext()
         gGlobalContext =
             GLContextEGL::CreateEGLPixmapOffscreenContext(gfxIntSize(16, 16),
                                                           ContextFormat(ContextFormat::BasicRGB24),
-                                                          PR_FALSE);
+                                                          false);
         if (gGlobalContext)
-            gGlobalContext->SetIsGlobalSharedContext(PR_TRUE);
+            gGlobalContext->SetIsGlobalSharedContext(true);
     }
 
     return gGlobalContext;
@@ -2331,7 +2373,7 @@ CreateBasicEGLSurfaceForXSurface(gfxASurface* aSurface, EGLConfig* aConfig)
 {
   gfxXlibSurface* xsurface = static_cast<gfxXlibSurface*>(aSurface);
 
-  PRBool opaque =
+  bool opaque =
     aSurface->GetContentType() == gfxASurface::CONTENT_COLOR;
 
   EGLSurface surface = nsnull;
@@ -2437,7 +2479,7 @@ GLContextEGL::CreateBasicEGLPixmapOffscreenContext(const gfxIntSize& aSize,
 
   nsRefPtr<GLContextEGL> glContext = new GLContextEGL(aFormat, nsnull,
                                                       config, surface, context,
-                                                      PR_TRUE);
+                                                      true);
 
   if (!glContext->Init())
   {
@@ -2449,7 +2491,7 @@ GLContextEGL::CreateBasicEGLPixmapOffscreenContext(const gfxIntSize& aSize,
   return glContext.forget();
 }
 
-PRBool GLContextEGL::ResizeOffscreenPixmapSurface(const gfxIntSize& aNewSize)
+bool GLContextEGL::ResizeOffscreenPixmapSurface(const gfxIntSize& aNewSize)
 {
   gfxASurface *thebesSurface = nsnull;
   EGLNativePixmapType pixmap = 0;
@@ -2487,9 +2529,9 @@ PRBool GLContextEGL::ResizeOffscreenPixmapSurface(const gfxIntSize& aNewSize)
   mSurface = surface;
   HoldSurface(thebesSurface);
   SetOffscreenSize(aNewSize, aNewSize);
-  MakeCurrent(PR_TRUE);
+  MakeCurrent(true);
 
-  return PR_TRUE;
+  return true;
 }
 
 #endif
