@@ -57,7 +57,6 @@
 #include "jsstdint.h"
 
 #include "jstypes.h"
-#include "jsarena.h"
 #include "jsutil.h"
 #include "jsclist.h"
 #include "jsprf.h"
@@ -78,16 +77,15 @@
 #include "jsobj.h"
 #include "jsopcode.h"
 #include "jspubtd.h"
-#include "jsscan.h"
 #include "jsscope.h"
 #include "jsscript.h"
-#include "jsstaticcheck.h"
 #include "jsstr.h"
 #include "jstracer.h"
 
 #ifdef JS_METHODJIT
 # include "assembler/assembler/MacroAssembler.h"
 #endif
+#include "frontend/TokenStream.h"
 #include "frontend/ParseMaps.h"
 
 #include "jsatominlines.h"
@@ -112,6 +110,7 @@ ThreadData::ThreadData()
     maxCodeCacheBytes(DEFAULT_JIT_CACHE_SIZE),
 #endif
     waiveGCQuota(false),
+    tempLifoAlloc(TEMP_LIFO_ALLOC_PRIMARY_CHUNK_SIZE),
     dtoaState(NULL),
     nativeStackBase(GetNativeStackBase()),
     pendingProxyOperation(NULL),
@@ -316,40 +315,23 @@ js_PurgeThreads(JSContext *cx)
 #endif
 }
 
-static const size_t ARENA_HEADER_SIZE_HACK = 40;
-static const size_t TEMP_POOL_CHUNK_SIZE = 4096 - ARENA_HEADER_SIZE_HACK;
-
 JSContext *
 js_NewContext(JSRuntime *rt, size_t stackChunkSize)
 {
-    JSContext *cx;
-    JSBool first;
-    JSContextCallback cxCallback;
+    JS_AbortIfWrongThread(rt);
 
     /*
      * We need to initialize the new context fully before adding it to the
      * runtime list. After that it can be accessed from another thread via
      * js_ContextIterator.
      */
-    void *mem = OffTheBooks::calloc_(sizeof *cx);
-    if (!mem)
+    JSContext *cx = OffTheBooks::new_<JSContext>(rt);
+    if (!cx)
         return NULL;
 
-    cx = new (mem) JSContext(rt);
-    cx->debugHooks = &rt->globalDebugHooks;
-#if JS_STACK_GROWTH_DIRECTION > 0
-    cx->stackLimit = (jsuword) -1;
-#endif
-    cx->iterValue.setMagic(JS_NO_ITER_VALUE);
-    JS_STATIC_ASSERT(JSVERSION_DEFAULT == 0);
     JS_ASSERT(cx->findVersion() == JSVERSION_DEFAULT);
     VOUCH_DOES_NOT_REQUIRE_STACK();
 
-    JS_InitArenaPool(&cx->tempPool, "temp", TEMP_POOL_CHUNK_SIZE, sizeof(jsdouble));
-    JS_InitArenaPool(&cx->regExpPool, "regExp", TEMP_POOL_CHUNK_SIZE, sizeof(int));
-
-    JS_ASSERT(cx->resolveFlags == 0);
-
     if (!cx->busyArrays.init()) {
         Foreground::delete_(cx);
         return NULL;
@@ -366,15 +348,16 @@ js_NewContext(JSRuntime *rt, size_t stackChunkSize)
      * Here the GC lock is still held after js_InitContextThreadAndLockGC took it and
      * the GC is not running on another thread.
      */
+    bool first;
     for (;;) {
         if (rt->state == JSRTS_UP) {
             JS_ASSERT(!JS_CLIST_IS_EMPTY(&rt->contextList));
-            first = JS_FALSE;
+            first = false;
             break;
         }
         if (rt->state == JSRTS_DOWN) {
             JS_ASSERT(JS_CLIST_IS_EMPTY(&rt->contextList));
-            first = JS_TRUE;
+            first = true;
             rt->state = JSRTS_LAUNCHING;
             break;
         }
@@ -423,7 +406,7 @@ js_NewContext(JSRuntime *rt, size_t stackChunkSize)
         JS_NOTIFY_ALL_CONDVAR(rt->stateChange);
     }
 
-    cxCallback = rt->cxCallback;
+    JSContextCallback cxCallback = rt->cxCallback;
     if (cxCallback && !cxCallback(cx, JSCONTEXT_NEW)) {
         js_DestroyContext(cx, JSDCM_NEW_FAILED);
         return NULL;
@@ -435,13 +418,14 @@ js_NewContext(JSRuntime *rt, size_t stackChunkSize)
 void
 js_DestroyContext(JSContext *cx, JSDestroyContextMode mode)
 {
-    JSRuntime *rt;
+    JSRuntime *rt = cx->runtime;
+    JS_AbortIfWrongThread(rt);
+
     JSContextCallback cxCallback;
     JSBool last;
 
     JS_ASSERT(!cx->enumerators);
 
-    rt = cx->runtime;
 #ifdef JS_THREADSAFE
     /*
      * For API compatibility we allow to destroy contexts without a thread in
@@ -494,10 +478,10 @@ js_DestroyContext(JSContext *cx, JSDestroyContextMode mode)
         ) {
         JS_ASSERT(!rt->gcRunning);
 
-        JS_UNLOCK_GC(rt);
 #ifdef JS_THREADSAFE
-        rt->gcHelperThread.waitBackgroundSweepEnd(rt);
+        rt->gcHelperThread.waitBackgroundSweepEnd();
 #endif
+        JS_UNLOCK_GC(rt);
 
         if (last) {
 #ifdef JS_THREADSAFE
@@ -551,21 +535,18 @@ js_DestroyContext(JSContext *cx, JSDestroyContextMode mode)
 #endif
 
         if (last) {
-            GCREASON(LASTCONTEXT);
-            js_GC(cx, NULL, GC_LAST_CONTEXT);
+            js_GC(cx, NULL, GC_LAST_CONTEXT, gcstats::LASTCONTEXT);
 
             /* Take the runtime down, now that it has no contexts or atoms. */
             JS_LOCK_GC(rt);
             rt->state = JSRTS_DOWN;
             JS_NOTIFY_ALL_CONDVAR(rt->stateChange);
         } else {
-            if (mode == JSDCM_FORCE_GC) {
-                GCREASON(DESTROYCONTEXT);
-                js_GC(cx, NULL, GC_NORMAL);
-            } else if (mode == JSDCM_MAYBE_GC) {
-                GCREASON(DESTROYCONTEXT);
+            if (mode == JSDCM_FORCE_GC)
+                js_GC(cx, NULL, GC_NORMAL, gcstats::DESTROYCONTEXT);
+            else if (mode == JSDCM_MAYBE_GC)
                 JS_MaybeGC(cx);
-            }
+
             JS_LOCK_GC(rt);
             js_WaitForGC(rt);
         }
@@ -577,10 +558,10 @@ js_DestroyContext(JSContext *cx, JSDestroyContextMode mode)
     js_ClearContextThread(cx);
     JS_ASSERT_IF(JS_CLIST_IS_EMPTY(&t->contextList), !t->data.requestDepth);
 #endif
-    JS_UNLOCK_GC(rt);
 #ifdef JS_THREADSAFE
-    rt->gcHelperThread.waitBackgroundSweepEnd(rt);
+    rt->gcHelperThread.waitBackgroundSweepEnd();
 #endif
+    JS_UNLOCK_GC(rt);
     Foreground::delete_(cx);
 }
 
@@ -1183,7 +1164,7 @@ js_InvokeOperationCallback(JSContext *cx)
     JS_UNLOCK_GC(rt);
 
     if (rt->gcIsNeeded) {
-        js_GC(cx, rt->gcTriggerCompartment, GC_NORMAL);
+        js_GC(cx, rt->gcTriggerCompartment, GC_NORMAL, rt->gcTriggerReason);
 
         /*
          * On trace we can exceed the GC quota, see comments in NewGCArena. So
@@ -1195,7 +1176,10 @@ js_InvokeOperationCallback(JSContext *cx)
             * We have to wait until the background thread is done in order
             * to get a correct answer.
             */
-            rt->gcHelperThread.waitBackgroundSweepEnd(rt);
+            {
+                AutoLockGC lock(rt);
+                rt->gcHelperThread.waitBackgroundSweepEnd();
+            }
             if (checkOutOfMemory(rt)) {
                 js_ReportOutOfMemory(cx);
                 return false;
@@ -1352,15 +1336,69 @@ DSTOffsetCache::DSTOffsetCache()
 }
 
 JSContext::JSContext(JSRuntime *rt)
-  : hasVersionOverride(false),
+  : defaultVersion(JSVERSION_DEFAULT),
+    hasVersionOverride(false),
+    throwing(false),
+    exception(UndefinedValue()),
+    runOptions(0),
+    reportGranularity(JS_DEFAULT_JITREPORT_GRANULARITY),
+    localeCallbacks(NULL),
+    resolvingList(NULL),
+    generatingError(false),
+#if JS_STACK_GROWTH_DIRECTION > 0
+    stackLimit((jsuword)-1),
+#else
+    stackLimit(0),
+#endif
     runtime(rt),
     compartment(NULL),
-    stack(thisDuringConstruction()),
-    busyArrays()
+#ifdef JS_THREADSAFE
+    thread_(NULL),
+#endif
+    stack(thisDuringConstruction()),  /* depends on cx->thread_ */
+    parseMapPool_(NULL),
+    globalObject(NULL),
+    argumentFormatMap(NULL),
+    lastMessage(NULL),
+    errorReporter(NULL),
+    operationCallback(NULL),
+    data(NULL),
+    data2(NULL),
+#ifdef JS_THREADSAFE
+    outstandingRequests(0),
+#endif
+    autoGCRooters(NULL),
+    debugHooks(&rt->globalDebugHooks),
+    securityCallbacks(NULL),
+    resolveFlags(0),
+    rngSeed(0),
+    iterValue(MagicValue(JS_NO_ITER_VALUE)),
+#ifdef JS_TRACER
+    traceJitEnabled(false),
+#endif
+#ifdef JS_METHODJIT
+    methodJitEnabled(false),
+    profilingEnabled(false),
+#endif
+    inferenceEnabled(false),
+#ifdef MOZ_TRACE_JSCALLS
+    functionCallback(NULL),
+#endif
+    enumerators(NULL),
+#ifdef JS_THREADSAFE
+    gcBackgroundFree(NULL),
+#endif
+    activeCompilations(0)
 #ifdef DEBUG
     , stackIterAssertionEnabled(true)
 #endif
-{}
+{
+    PodZero(&sharpObjectMap);
+    PodZero(&link);
+#ifdef JS_THREADSAFE
+    PodZero(&threadLinks);
+#endif
+}
 
 JSContext::~JSContext()
 {
@@ -1373,9 +1411,6 @@ JSContext::~JSContext()
     if (parseMapPool_)
         Foreground::delete_<ParseMapPool>(parseMapPool_);
 
-    JS_FinishArenaPool(&regExpPool);
-    JS_FinishArenaPool(&tempPool);
-
     if (lastMessage)
         Foreground::free_(lastMessage);
 
@@ -1479,15 +1514,23 @@ JSRuntime::onTooMuchMalloc()
      */
     js_WaitForGC(this);
 #endif
-    GCREASON(TOOMUCHMALLOC);
-    TriggerGC(this);
+    TriggerGC(this, gcstats::TOOMUCHMALLOC);
 }
 
 JS_FRIEND_API(void *)
 JSRuntime::onOutOfMemory(void *p, size_t nbytes, JSContext *cx)
 {
+    /*
+     * Retry when we are done with the background sweeping and have stopped
+     * all the allocations and released the empty GC chunks.
+     */
+    {
 #ifdef JS_THREADSAFE
-    gcHelperThread.waitBackgroundSweepEnd(this);
+        AutoLockGC lock(this);
+        gcHelperThread.waitBackgroundSweepOrAllocEnd();
+#endif
+        gcChunkPool.expire(this, true);
+    }
     if (!p)
         p = OffTheBooks::malloc_(nbytes);
     else if (p == reinterpret_cast<void *>(1))
@@ -1496,31 +1539,14 @@ JSRuntime::onOutOfMemory(void *p, size_t nbytes, JSContext *cx)
       p = OffTheBooks::realloc_(p, nbytes);
     if (p)
         return p;
-#endif
     if (cx)
         js_ReportOutOfMemory(cx);
     return NULL;
 }
 
-/*
- * Release pool's arenas if the stackPool has existed for longer than the
- * limit specified by gcEmptyArenaPoolLifespan.
- */
-static void
-FreeOldArenas(JSRuntime *rt, JSArenaPool *pool)
-{
-    JSArena *a = pool->current;
-    if (a == pool->first.next && a->avail == a->base + sizeof(int64)) {
-        int64 age = JS_Now() - *(int64 *) a->base;
-        if (age > int64(rt->gcEmptyArenaPoolLifespan) * 1000)
-            JS_FreeArenaPool(pool);
-    }
-}
-
 void
 JSContext::purge()
 {
-    FreeOldArenas(runtime, &regExpPool);
     if (!activeCompilations) {
         Foreground::delete_<ParseMapPool>(parseMapPool_);
         parseMapPool_ = NULL;
@@ -1648,4 +1674,13 @@ CanLeaveTrace(JSContext *cx)
 #endif
 }
 
+AutoEnumStateRooter::~AutoEnumStateRooter()
+{
+    if (!stateValue.isNull()) {
+        DebugOnly<JSBool> ok =
+            obj->enumerate(context, JSENUMERATE_DESTROY, &stateValue, 0);
+        JS_ASSERT(ok);
+    }
+}
+
 } /* namespace js */
