@@ -49,12 +49,10 @@
 #include "jsstdint.h"
 #include "jsutil.h"
 #include "jsclist.h"
-#include "jshashtable.h"
 #include "jsapi.h"
 #include "jscntxt.h"
 #include "jsversion.h"
 #include "jsdbgapi.h"
-#include "jsemit.h"
 #include "jsfun.h"
 #include "jsgc.h"
 #include "jsgcmark.h"
@@ -62,13 +60,14 @@
 #include "jslock.h"
 #include "jsobj.h"
 #include "jsopcode.h"
-#include "jsparse.h"
 #include "jsscope.h"
 #include "jsscript.h"
-#include "jsstaticcheck.h"
 #include "jsstr.h"
 #include "jswatchpoint.h"
 #include "jswrapper.h"
+
+#include "frontend/BytecodeEmitter.h"
+#include "frontend/Parser.h"
 #include "vm/Debugger.h"
 
 #include "jsatominlines.h"
@@ -178,34 +177,6 @@ JS_SetSingleStepMode(JSContext *cx, JSScript *script, JSBool singleStep)
     return script->setStepModeFlag(cx, singleStep);
 }
 
-jsbytecode *
-js_UntrapScriptCode(JSContext *cx, JSScript *script)
-{
-    jsbytecode *code = script->code;
-    BreakpointSiteMap &sites = script->compartment()->breakpointSites;
-    for (BreakpointSiteMap::Range r = sites.all(); !r.empty(); r.popFront()) {
-        BreakpointSite *site = r.front().value;
-        if (site->script == script && size_t(site->pc - script->code) < script->length) {
-            if (code == script->code) {
-                size_t nbytes = script->length * sizeof(jsbytecode);
-                jssrcnote *notes = script->notes();
-                jssrcnote *sn;
-                for (sn = notes; !SN_IS_TERMINATOR(sn); sn = SN_NEXT(sn))
-                    continue;
-                nbytes += (sn - notes + 1) * sizeof *sn;
-
-                code = (jsbytecode *) cx->malloc_(nbytes);
-                if (!code)
-                    break;
-                memcpy(code, script->code, nbytes);
-                GetGSNCache(cx)->purge();
-            }
-            code[site->pc - script->code] = site->realOpcode;
-        }
-    }
-    return code;
-}
-
 JS_PUBLIC_API(JSBool)
 JS_SetTrap(JSContext *cx, JSScript *script, jsbytecode *pc, JSTrapHandler handler, jsval closure)
 {
@@ -438,7 +409,7 @@ JS_GetLinePCs(JSContext *cx, JSScript *script,
     uintN i = 0;
     for (jssrcnote *sn = script->notes(); !SN_IS_TERMINATOR(sn); sn = SN_NEXT(sn)) {
         offset += SN_DELTA(sn);
-        JSSrcNoteType type = (JSSrcNoteType) SN_TYPE(sn);
+        SrcNoteType type = (SrcNoteType) SN_TYPE(sn);
         if (type == SRC_SETLINE || type == SRC_NEWLINE) {
             if (type == SRC_SETLINE)
                 lineno = (uintN) js_GetSrcNoteOffset(sn, 0);
@@ -488,10 +459,9 @@ JS_GetFunctionLocalNameArray(JSContext *cx, JSFunction *fun, void **markp)
         return NULL;
 
     /* Munge data into the API this method implements.  Avert your eyes! */
-    *markp = JS_ARENA_MARK(&cx->tempPool);
+    *markp = cx->tempLifoAlloc().mark();
 
-    jsuword *names;
-    JS_ARENA_ALLOCATE_CAST(names, jsuword *, &cx->tempPool, localNames.length() * sizeof *names);
+    jsuword *names = cx->tempLifoAlloc().newArray<jsuword>(localNames.length());
     if (!names) {
         js_ReportOutOfMemory(cx);
         return NULL;
@@ -516,7 +486,7 @@ JS_AtomKey(JSAtom *atom)
 extern JS_PUBLIC_API(void)
 JS_ReleaseFunctionLocalNameArray(JSContext *cx, void *mark)
 {
-    JS_ARENA_RELEASE(&cx->tempPool, mark);
+    cx->tempLifoAlloc().release(mark);
 }
 
 JS_PUBLIC_API(JSScript *)
@@ -610,13 +580,6 @@ JS_IsScriptFrame(JSContext *cx, JSStackFrame *fp)
     return !Valueify(fp)->isDummyFrame();
 }
 
-/* this is deprecated, use JS_GetFrameScopeChain instead */
-JS_PUBLIC_API(JSObject *)
-JS_GetFrameObject(JSContext *cx, JSStackFrame *fp)
-{
-    return &Valueify(fp)->scopeChain();
-}
-
 JS_PUBLIC_API(JSObject *)
 JS_GetFrameScopeChain(JSContext *cx, JSStackFrame *fpArg)
 {
@@ -851,14 +814,14 @@ JS_PropertyIterator(JSObject *obj, JSScopeProperty **iteratorp)
 
     /* The caller passes null in *iteratorp to get things started. */
     shape = (Shape *) *iteratorp;
-    if (!shape) {
+    if (!shape)
         shape = obj->lastProperty();
-    } else {
+    else
         shape = shape->previous();
-        if (!shape->previous()) {
-            JS_ASSERT(JSID_IS_EMPTY(shape->propid));
-            shape = NULL;
-        }
+
+    if (!shape->previous()) {
+        JS_ASSERT(JSID_IS_EMPTY(shape->propid));
+        shape = NULL;
     }
 
     return *iteratorp = reinterpret_cast<JSScopeProperty *>(const_cast<Shape *>(shape));
@@ -1077,8 +1040,6 @@ JS_GetFunctionTotalSize(JSContext *cx, JSFunction *fun)
     return nbytes;
 }
 
-#include "jsemit.h"
-
 JS_PUBLIC_API(size_t)
 JS_GetScriptTotalSize(JSContext *cx, JSScript *script)
 {
@@ -1088,9 +1049,6 @@ JS_GetScriptTotalSize(JSContext *cx, JSScript *script)
     JSPrincipals *principals;
 
     nbytes = sizeof *script;
-    if (script->u.object)
-        nbytes += JS_GetObjectTotalSize(cx, script->u.object);
-
     nbytes += script->length * sizeof script->code[0];
     nbytes += script->natoms * sizeof script->atoms[0];
     for (size_t i = 0; i < script->natoms; i++)
@@ -2170,9 +2128,9 @@ JS_PUBLIC_API(void)
 JS_DumpBytecode(JSContext *cx, JSScript *script)
 {
 #if defined(DEBUG)
-    AutoArenaAllocator mark(&cx->tempPool);
+    LifoAlloc lifoAlloc(1024);
     Sprinter sprinter;
-    INIT_SPRINTER(cx, &sprinter, &cx->tempPool, 0);
+    INIT_SPRINTER(cx, &sprinter, &lifoAlloc, 0);
 
     fprintf(stdout, "--- SCRIPT %s:%d ---\n", script->filename, script->lineno);
     js_Disassemble(cx, script, true, &sprinter);
@@ -2196,3 +2154,9 @@ JS_DumpCompartmentBytecode(JSContext *cx)
 {
     IterateCells(cx, cx->compartment, gc::FINALIZE_SCRIPT, NULL, DumpBytecodeScriptCallback);
 }
+
+JS_PUBLIC_API(JSObject *)
+JS_UnwrapObject(JSObject *obj)
+{
+    return UnwrapObject(obj);
+}
