@@ -1083,8 +1083,10 @@ FrameState::frameSlot(ActiveFrame *a, const FrameEntry *fe) const
 }
 
 inline JSC::MacroAssembler::Address
-FrameState::addressForInlineReturn() const
+FrameState::addressForInlineReturn()
 {
+    if (a->callee_->isTracked())
+        discardFe(a->callee_);
     return addressOf(a->callee_);
 }
 
