@@ -231,6 +231,23 @@ namespace nanojit
         LabelState *get(LIns *);
     };
 
+    /**
+     * Some architectures (i386, X64) can emit two branches that need patching
+     * in some situations. This is returned by asm_branch() implementations
+     * with 0, 1 or 2 of these fields set to a non-NULL value. (If only 1 is set, 
+     * it must be patch1, not patch2.)
+     */
+    struct Branches 
+    {
+        NIns* const branch1;
+        NIns* const branch2;
+        inline explicit Branches(NIns* b1 = NULL, NIns* b2 = NULL) 
+            : branch1(b1)
+            , branch2(b2)
+        {
+        }
+    };
+
     /** map tracking the register allocation state at each bailout point
      *  (represented by SideExit*) in a trace fragment. */
     typedef HashMap<SideExit*, RegAlloc*> RegAllocMap;
@@ -481,7 +498,7 @@ namespace nanojit
             void        asm_nongp_copy(Register r, Register s);
             void        asm_call(LIns*);
             Register    asm_binop_rhs_reg(LIns* ins);
-            NIns*       asm_branch(bool branchOnFalse, LIns* cond, NIns* targ);
+            Branches    asm_branch(bool branchOnFalse, LIns* cond, NIns* targ);
             NIns*       asm_branch_ov(LOpcode op, NIns* targ);
             void        asm_jtbl(LIns* ins, NIns** table);
             void        asm_insert_random_nop();
@@ -512,24 +529,6 @@ namespace nanojit
             DECLARE_PLATFORM_ASSEMBLER()
 
         private:
-#ifdef NANOJIT_IA32
-            debug_only( int32_t _fpuStkDepth; )
-            debug_only( int32_t _sv_fpuStkDepth; )
-
-            // The FPU stack depth is the number of pushes in excess of the number of pops.
-            // Since we generate backwards, we track the FPU stack depth as a negative number.
-            // We use the top of the x87 stack as the single allocatable FP register, FST0.
-            // Thus, between LIR instructions, the depth of the FPU stack must be either 0 or -1,
-            // depending on whether FST0 is in use.  Within the expansion of a single LIR
-            // instruction, however, deeper levels of the stack may be used as unmanaged
-            // temporaries.  Hence, we allow for all eight levels in the assertions below.
-            inline void fpu_push() {
-                debug_only( ++_fpuStkDepth; NanoAssert(_fpuStkDepth <= 0); )
-            }
-            inline void fpu_pop() {
-                debug_only( --_fpuStkDepth; NanoAssert(_fpuStkDepth >= -7); )
-            }
-#endif
             const Config& _config;
     };
 
