@@ -1,4 +1,5 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: java; tab-width:8; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+
 /* ***** BEGIN LICENSE BLOCK *****
  * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
@@ -15,11 +16,11 @@
  * The Original Code is JavaScript Engine testing utilities.
  *
  * The Initial Developer of the Original Code is
- * Jeff Walden <jwalden+code@mit.edu>.
- * Portions created by the Initial Developer are Copyright (C) 2006
+ * Mozilla Foundation.
+ * Portions created by the Initial Developer are Copyright (C) 2008
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s):
+ * Contributor(s): Jesse Ruderman
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -36,35 +37,42 @@
  * ***** END LICENSE BLOCK ***** */
 
 
-//-----------------------------------------------------------------------------
-var BUGNUMBER     = "350206";
-var summary = "Order of destructuring, destructuring in the presence of " +
-              "exceptions";
-var actual, expect;
+var summary = 'GetXMLEntity should not assume FastAppendChar is infallible';
+var BUGNUMBER = 458679;
+var actual = '';
+var expect = '';
 
 printBugNumber(BUGNUMBER);
 START(summary);
 
-/**************
- * BEGIN TEST *
- **************/
+expectExitCode(0);
+expectExitCode(5);
 
-var failed = "No crash";
+function stringOfLength(n)
+{
+    if (n == 0) {
+        return "";
+    } else if (n == 1) {
+        return "<";
+    } else {
+        var r = n % 2;
+        var d = (n - r) / 2;
+        var y = stringOfLength(d);
+        return y + y + stringOfLength(r);
+    }    
+}
 
 try
 {
-  var t1 = <ns2:t1 xmlns:ns2="http://bar/ns2"/>;
-  var n2 = new Namespace("http://ns2");
-  t1.@n2::a1 = "a1 from ns2";
 
-  t1.toXMLString();
+    void stringOfLength(4435455);
+    x = stringOfLength(14435455);
+    <xxx>{x}</xxx>;
 }
-catch (ex)
+catch(ex)
 {
-  failed = ex;
 }
 
-expect = "No crash";
-actual = failed;
-
 TEST(1, expect, actual);
+
+END();
