@@ -38,27 +38,42 @@
 
 
 /**
-   File Name:          15.6.4.2-3.js
-   ECMA Section:       15.6.4.2 Boolean.prototype.toString()
-   Description:        Returns this boolean value.
+   File Name:          15.6.4.js
+   ECMA Section:       Properties of the Boolean Prototype Object
+   Description:
+   The Boolean prototype object is itself a Boolean object (its [[Class]] is "
+   Boolean") whose value is false.
 
-   The toString function is not generic; it generates
-   a runtime error if its this value is not a Boolean
-   object.  Therefore it cannot be transferred to other
-   kinds of objects for use as a method.
+   The value of the internal [[Prototype]] property of the Boolean prototype
+   object is the Object prototype object (15.2.3.1).
+
+   In following descriptions of functions that are properties of the Boolean
+   prototype object, the phrase "this Boolean object" refers to the object that
+   is the this value for the invocation of the function; it is an error if
+   this does not refer to an object for which the value of the internal
+   [[Class]] property is "Boolean". Also, the phrase "this boolean value"
+   refers to the boolean value represented by this Boolean object, that is,
+   the value of the internal [[Value]] property of this Boolean object.
 
    Author:             christine@netscape.com
-   Date:               june 27, 1997
+   Date:               12 november 1997
 */
 
-
-var SECTION = "15.6.4.2-3";
+var SECTION = "15.6.4";
 var VERSION = "ECMA_1";
 startTest();
-var TITLE   = "Boolean.prototype.toString()"
-  writeHeaderToLog( SECTION + TITLE );
+var TITLE   = "Properties of the Boolean Prototype Object";
 
-new TestCase( SECTION, "tostr=Boolean.prototype.toString; x=true; x.toString=tostr;x.toString()", "true", eval("tostr=Boolean.prototype.toString; x=true; x.toString=tostr;x.toString()") );
-new TestCase( SECTION, "tostr=Boolean.prototype.toString; x=false; x.toString=tostr;x.toString()", "false", eval("tostr=Boolean.prototype.toString; x=false; x.toString=tostr;x.toString()") );
+writeHeaderToLog( SECTION + " "+ TITLE);
+
+new TestCase( SECTION,
+	      "Boolean.prototype == false",
+	      true,
+	      Boolean.prototype == false );
+
+new TestCase( SECTION,
+	      "Boolean.prototype.toString = Object.prototype.toString; Boolean.prototype.toString()",
+	      "[object Boolean]",
+	      eval("Boolean.prototype.toString = Object.prototype.toString; Boolean.prototype.toString()") );
 
 test();
