@@ -38,47 +38,53 @@
 
 
 /**
-   File Name:          10.2.1.js
-   ECMA Section:       10.2.1 Global Code
+   File Name:          10.1.5-4.js
+   ECMA Section:       10.1.5 Global Object
    Description:
+   There is a unique global object which is created before control enters
+   any execution context. Initially the global object has the following
+   properties:
 
-   The scope chain is created and initialized to contain the global object and
-   no others.
+   Built-in objects such as Math, String, Date, parseInt, etc. These have
+   attributes { DontEnum }.
 
-   Variable instantiation is performed using the global object as the variable
-   object and using empty property attributes.
+   Additional host defined properties. This may include a property whose
+   value is the global object itself, for example window in HTML.
+
+   As control enters execution contexts, and as ECMAScript code is executed,
+   additional properties may be added to the global object and the initial
+   properties may be changed.
 
-   The this value is the global object.
    Author:             christine@netscape.com
    Date:               12 november 1997
 */
-
-var SECTION = "10.2.1";
+var SECTION = "10.5.1-4";
 var VERSION = "ECMA_1";
 startTest();
-var TITLE   = "Global Code";
 
-writeHeaderToLog( SECTION + " "+ TITLE);
+writeHeaderToLog( SECTION + " Global Object");
 
-var THIS = this;
+new TestCase( "SECTION", "Anonymous Code check" );
 
-new TestCase( SECTION,
-	      "this +''",
-	      GLOBAL,
-	      THIS + "" );
 
-var GLOBAL_PROPERTIES = new Array();
-var i = 0;
+var EVAL_STRING = 'if ( Object == null ) { gTestcases[0].reason += " Object == null" ; }' +
+  'if ( Function == null ) { gTestcases[0].reason += " Function == null"; }' +
+  'if ( String == null ) { gTestcases[0].reason += " String == null"; }'   +
+  'if ( Array == null ) { gTestcases[0].reason += " Array == null"; }'     +
+  'if ( Number == null ) { gTestcases[0].reason += " Function == null";}'  +
+  'if ( Math == null ) { gTestcases[0].reason += " Math == null"; }'       +
+  'if ( Boolean == null ) { gTestcases[0].reason += " Boolean == null"; }' +
+  'if ( Date  == null ) { gTestcases[0].reason += " Date == null"; }'      +
+  'if ( eval == null ) { gTestcases[0].reason += " eval == null"; }'       +
+  'if ( parseInt == null ) { gTestcases[0].reason += " parseInt == null"; }' ;
 
-for ( p in this ) {
-  GLOBAL_PROPERTIES[i++] = p;
-}
+var NEW_FUNCTION = new Function( EVAL_STRING );
 
-for ( i = 0; i < GLOBAL_PROPERTIES.length; i++ ) {
-  new TestCase( SECTION,
-		GLOBAL_PROPERTIES[i] +" == void 0",
-		false,
-		eval("GLOBAL_PROPERTIES["+i+"] == void 0"));
+if ( gTestcases[0].reason != "" ) {
+  gTestcases[0].actual = "fail";
+} else {
+  gTestcases[0].actual = "pass";
 }
+gTestcases[0].expect = "pass";
 
 test();
