@@ -36,10 +36,10 @@
  * ***** END LICENSE BLOCK ***** */
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 460886;
-var summary = 'Do not crash @ js_NewStringCopy';
-var actual = '';
-var expect = '';
+var BUGNUMBER = 456477;
+var summary = 'Do not assert with JIT: (m != JSVAL_INT) || isInt32(*vp)" with (0/0)%(-1)';
+var actual = 'No Crash';
+var expect = 'No Crash';
 
 
 //-----------------------------------------------------------------------------
@@ -51,9 +51,13 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
-
-  for (var j = 0; j < 5; ++j) { "".substring(-60000); } 
  
+  jit(true);
+
+  for (var j = 0; j < 5; ++j) { var t = (0 / 0) % (-1); }
+
+  jit(false);
+
   reportCompare(expect, actual, summary);
 
   exitFunc ('test');
