@@ -16,10 +16,10 @@
  *
  * The Initial Developer of the Original Code is
  * Mozilla Foundation.
- * Portions created by the Initial Developer are Copyright (C) 2008
+ * Portions created by the Initial Developer are Copyright (C) 2006
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s): Mathieu Fenniak
+ * Contributor(s): Jesse Ruderman
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -36,10 +36,10 @@
  * ***** END LICENSE BLOCK ***** */
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 457093;
-var summary = 'Do not assert: newtop <= oldtop, decompiling function';
-var actual = 'No Crash';
-var expect = 'No Crash';
+var BUGNUMBER = 355049;
+var summary = 'decompilation of destructing into two hole';
+var actual = '';
+var expect = '';
 
 
 //-----------------------------------------------------------------------------
@@ -52,24 +52,9 @@ function test()
   printBugNumber(BUGNUMBER);
   printStatus (summary);
  
-  function Test(object)
-  {
-    for (var i in object)
-    {
-      try
-      {
-      }
-      catch(E) {}
-    }
-  }
-
-  var x = Test.toString();
-  
-  print(x);
-
-  expect = 'function Test ( object ) { for ( var i in object ) { try { } catch ( E ) { } } }';
-  actual = Test + '';
-
+  var f = function () { [3 for ([, , ] in null)] }
+  expect = 'function () { [3 for ([, , ] in null)]; }';
+  actual = f + '';
   compareSource(expect, actual, summary);
 
   exitFunc ('test');
