@@ -40,8 +40,6 @@
 #ifndef tracejit_Writer_h___
 #define tracejit_Writer_h___
 
-#include "jsiter.h"
-#include "jsobj.h"
 #include "jsstr.h"
 #include "jstypedarray.h"
 #include "nanojit.h"
@@ -55,7 +53,7 @@ namespace nj = nanojit;
 #define JS_JIT_SPEW
 #endif
 
-#if defined(JS_JIT_SPEW) || defined(NJ_NO_VARIADIC_MACROS)
+#if defined(JS_JIT_SPEW)
 
 enum LC_TMBits {
     /*
@@ -106,16 +104,16 @@ enum LC_TMBits {
  * - ACCSET_EOS:           The globals area.
  * - ACCSET_ALLOC:         All memory blocks allocated with LIR_allocp (in
  *                         other words, this region is the AR space).
- * - ACCSET_FRAMEREGS:     All JSFrameRegs structs.
- * - ACCSET_STACKFRAME:    All JSStackFrame objects.
+ * - ACCSET_FRAMEREGS:     All FrameRegs structs.
+ * - ACCSET_STACKFRAME:    All StackFrame objects.
  * - ACCSET_RUNTIME:       The JSRuntime object.
  * - ACCSET_OBJ_CLASP:     The 'clasp'    field of all JSObjects.
  * - ACCSET_OBJ_FLAGS:     The 'flags'    field of all JSObjects.
  * - ACCSET_OBJ_SHAPE:     The 'shape'    field of all JSObjects.
- * - ACCSET_OBJ_PROTO:     The 'proto'    field of all JSObjects.
+ * - ACCSET_OBJ_TYPE:      The 'type'     field of all JSObjects, and the 'proto' field of TypeObjects.
  * - ACCSET_OBJ_PARENT:    The 'parent'   field of all JSObjects.
  * - ACCSET_OBJ_PRIVATE:   The 'private'  field of all JSObjects.
- * - ACCSET_OBJ_CAPACITY:  The 'capacity' field of all JSObjects.
+ * - ACCSET_OBJ_CAPACITY:  The 'capacity' or 'initializedLength' field of all JSObjects.
  * - ACCSET_OBJ_SLOTS:     The 'slots'    field of all JSObjects.
  * - ACCSET_SLOTS:         The slots (be they fixed or dynamic) of all JSObjects.
  * - ACCSET_TARRAY:        All TypedArray structs.
@@ -127,6 +125,7 @@ enum LC_TMBits {
  * - ACCSET_TYPEMAP:       All typemaps form a single region.
  * - ACCSET_FCSLOTS:       All fcslots arrays form a single region.
  * - ACCSET_ARGS_DATA:     All Arguments data arrays form a single region.
+ * - ACCSET_SEG:           All StackSegment structs.
  */
 static const nanojit::AccSet ACCSET_STATE         = (1 <<  0);
 static const nanojit::AccSet ACCSET_STACK         = (1 <<  1);
@@ -143,7 +142,7 @@ static const nanojit::AccSet ACCSET_RUNTIME       = (1 <<  9);
 static const nanojit::AccSet ACCSET_OBJ_CLASP     = (1 << 10);
 static const nanojit::AccSet ACCSET_OBJ_FLAGS     = (1 << 11);
 static const nanojit::AccSet ACCSET_OBJ_SHAPE     = (1 << 12);
-static const nanojit::AccSet ACCSET_OBJ_PROTO     = (1 << 13);
+static const nanojit::AccSet ACCSET_OBJ_TYPE      = (1 << 13);
 static const nanojit::AccSet ACCSET_OBJ_PARENT    = (1 << 14);
 static const nanojit::AccSet ACCSET_OBJ_PRIVATE   = (1 << 15);
 static const nanojit::AccSet ACCSET_OBJ_CAPACITY  = (1 << 16);
@@ -159,8 +158,9 @@ static const nanojit::AccSet ACCSET_STRING_MCHARS = (1 << 24);
 static const nanojit::AccSet ACCSET_TYPEMAP       = (1 << 25);
 static const nanojit::AccSet ACCSET_FCSLOTS       = (1 << 26);
 static const nanojit::AccSet ACCSET_ARGS_DATA     = (1 << 27);
+static const nanojit::AccSet ACCSET_SEG           = (1 << 28);
 
-static const uint8_t TM_NUM_USED_ACCS = 28; // number of access regions used by TraceMonkey
+static const uint8_t TM_NUM_USED_ACCS = 29; // number of access regions used by TraceMonkey
 
 /*
  * An Address describes everything about a loaded/stored memory location.  One
@@ -427,6 +427,13 @@ class Writer
     #define ldpConstContextField(fieldname) \
         name(w.ldpContextFieldHelper(cx_ins, offsetof(JSContext, fieldname), LOAD_CONST), \
              #fieldname)
+    nj::LIns *ldpContextRegs(nj::LIns *cx) const {
+        int32 segOff = offsetof(JSContext, stack) + ContextStack::offsetOfSeg();
+        nj::LIns *seg = ldpContextFieldHelper(cx, segOff, nj::LOAD_CONST);
+        int32 regsOff = StackSegment::offsetOfRegs();
+        return name(lir->insLoad(nj::LIR_ldp, seg, regsOff, ACCSET_SEG, nj::LOAD_CONST), "cx->regs()");
+
+    }
 
     nj::LIns *stContextField(nj::LIns *value, nj::LIns *cx, int32 offset) const {
         return lir->insStore(value, cx, offset, ACCSET_CX);
@@ -457,11 +464,11 @@ class Writer
     }
 
     nj::LIns *ldpFrameFp(nj::LIns *regs) const {
-        return lir->insLoad(nj::LIR_ldp, regs, offsetof(JSFrameRegs, fp), ACCSET_FRAMEREGS);
+        return lir->insLoad(nj::LIR_ldp, regs, FrameRegs::offsetOfFp, ACCSET_FRAMEREGS);
     }
 
     nj::LIns *ldpStackFrameScopeChain(nj::LIns *frame) const {
-        return lir->insLoad(nj::LIR_ldp, frame, JSStackFrame::offsetOfScopeChain(),
+        return lir->insLoad(nj::LIR_ldp, frame, StackFrame::offsetOfScopeChain(),
                             ACCSET_STACKFRAME);
     }
 
@@ -472,7 +479,7 @@ class Writer
     }
 
     nj::LIns *ldpObjClasp(nj::LIns *obj, nj::LoadQual loadQual) const {
-        return name(lir->insLoad(nj::LIR_ldp, obj, offsetof(JSObject, clasp), ACCSET_OBJ_CLASP,
+        return name(lir->insLoad(nj::LIR_ldp, obj, JSObject::offsetOfClassPointer(), ACCSET_OBJ_CLASP,
                                  loadQual),
                     "clasp");
     }
@@ -488,7 +495,9 @@ class Writer
     }
 
     nj::LIns *ldpObjProto(nj::LIns *obj) const {
-        return name(lir->insLoad(nj::LIR_ldp, obj, offsetof(JSObject, proto), ACCSET_OBJ_PROTO),
+        nj::LIns *type = name(lir->insLoad(nj::LIR_ldp, obj, JSObject::offsetOfType(), ACCSET_OBJ_TYPE),
+                              "type");
+        return name(lir->insLoad(nj::LIR_ldp, type, offsetof(types::TypeObject, proto), ACCSET_OBJ_TYPE),
                     "proto");
     }
 
@@ -515,27 +524,35 @@ class Writer
                     "private_uint32");
     }
 
-    nj::LIns *ldiDenseArrayCapacity(nj::LIns *array) const {
-        return name(lir->insLoad(nj::LIR_ldi, array, offsetof(JSObject, capacity),
+    nj::LIns *ldiDenseArrayInitializedLength(nj::LIns *array) const {
+        return name(lir->insLoad(nj::LIR_ldi, array, offsetof(JSObject, initializedLength),
                                  ACCSET_OBJ_CAPACITY),
                     "capacity");
     }
 
     nj::LIns *ldpObjSlots(nj::LIns *obj) const {
-        return name(lir->insLoad(nj::LIR_ldp, obj, offsetof(JSObject, slots), ACCSET_OBJ_SLOTS),
+        return name(lir->insLoad(nj::LIR_ldp, obj, JSObject::offsetOfSlots(), ACCSET_OBJ_SLOTS),
                     "slots");
     }
 
-    nj::LIns *ldiConstTypedArrayLength(nj::LIns *array) const {
-        return name(lir->insLoad(nj::LIR_ldi, array, js::TypedArray::lengthOffset(), ACCSET_TARRAY,
+    nj::LIns *ldpObjFixedSlots(nj::LIns *obj) const {
+        //return name(lir->insLoad(nj::LIR_ldp, obj, sizeof(JSObject), ACCSET_SLOTS),
+#if JS_BITS_PER_WORD == 32
+        return name(lir->ins2(nj::LIR_addp, obj, lir->insImmI(sizeof(JSObject))),
+#else
+        return name(lir->ins2(nj::LIR_addp, obj, lir->insImmQ(sizeof(JSObject))),
+#endif
+                "fixed_slots");
+    }
+
+    nj::LIns *ldiConstTypedArrayLength(nj::LIns *obj) const {
+        return name(lir->insLoad(nj::LIR_ldi, obj, TypedArray::lengthOffset() + sPayloadOffset, ACCSET_TARRAY,
                                  nj::LOAD_CONST),
                     "typedArrayLength");
     }
 
-    nj::LIns *ldpConstTypedArrayData(nj::LIns *array) const {
-        return name(lir->insLoad(nj::LIR_ldp, array, js::TypedArray::dataOffset(), ACCSET_TARRAY,
-                                 nj::LOAD_CONST),
-                    "typedElems");
+    nj::LIns *ldpConstTypedArrayData(nj::LIns *obj) const {
+        return name(lir->insLoad(nj::LIR_ldp, obj, offsetof(JSObject, privateData), ACCSET_TARRAY, nj::LOAD_CONST), "typedArrayData");
     }
 
     nj::LIns *ldc2iTypedArrayElement(nj::LIns *elems, nj::LIns *index) const {
@@ -590,22 +607,9 @@ class Writer
                              ACCSET_TARRAY_DATA);
     }
 
-    nj::LIns *ldpIterCursor(nj::LIns *iter) const {
-        return name(lir->insLoad(nj::LIR_ldp, iter, offsetof(NativeIterator, props_cursor),
-                                 ACCSET_ITER),
-                    "cursor");
-    }
-
-    nj::LIns *ldpIterEnd(nj::LIns *iter) const {
-        return name(lir->insLoad(nj::LIR_ldp, iter, offsetof(NativeIterator, props_end),
-                                 ACCSET_ITER),
-                    "end");
-    }
-
-    nj::LIns *stpIterCursor(nj::LIns *cursor, nj::LIns *iter) const {
-        return lir->insStore(nj::LIR_stp, cursor, iter, offsetof(NativeIterator, props_cursor),
-                             ACCSET_ITER);
-    }
+    inline nj::LIns *ldpIterCursor(nj::LIns *iter) const;
+    inline nj::LIns *ldpIterEnd(nj::LIns *iter) const;
+    inline nj::LIns *stpIterCursor(nj::LIns *cursor, nj::LIns *iter) const;
 
     nj::LIns *ldpStringLengthAndFlags(nj::LIns *str) const {
         return name(lir->insLoad(nj::LIR_ldp, str, JSString::offsetOfLengthAndFlags(),
@@ -1177,18 +1181,15 @@ class Writer
     /*
      * Nb: this "Privatized" refers to the Private API in jsvalue.h.  It
      * doesn't refer to the JSObj::privateData slot!  Confusing.
+     * This should only be used for slots which are known to always be fixed.
      */
     nj::LIns *getObjPrivatizedSlot(nj::LIns *obj, uint32 slot) const {
+        uint32 offset = JSObject::getFixedSlotOffset(slot) + sPayloadOffset;
 #if JS_BITS_PER_WORD == 32
-        nj::LIns *vaddr_ins = ldpObjSlots(obj);
-        return lir->insLoad(nj::LIR_ldi, vaddr_ins,
-                            slot * sizeof(Value) + sPayloadOffset, ACCSET_SLOTS, nj::LOAD_CONST);
-
+        return lir->insLoad(nj::LIR_ldi, obj, offset, ACCSET_SLOTS, nj::LOAD_CONST);
 #elif JS_BITS_PER_WORD == 64
         /* N.B. On 64-bit, privatized value are encoded differently from other pointers. */
-        nj::LIns *vaddr_ins = ldpObjSlots(obj);
-        nj::LIns *v_ins = lir->insLoad(nj::LIR_ldq, vaddr_ins,
-                                       slot * sizeof(Value) + sPayloadOffset,
+        nj::LIns *v_ins = lir->insLoad(nj::LIR_ldq, obj, offset,
                                        ACCSET_SLOTS, nj::LOAD_CONST);
         return lshqN(v_ins, 1);
 #endif
@@ -1213,13 +1214,7 @@ class Writer
                     "strChar");
     }
 
-    nj::LIns *getArgsLength(nj::LIns *args) const {
-        uint32 slot = JSObject::JSSLOT_ARGS_LENGTH;
-        nj::LIns *vaddr_ins = ldpObjSlots(args);
-        return name(lir->insLoad(nj::LIR_ldi, vaddr_ins, slot * sizeof(Value) + sPayloadOffset,
-                                 ACCSET_SLOTS),
-                    "argsLength");
-    }
+    inline nj::LIns *getArgsLength(nj::LIns *args) const;
 };
 
 }   /* namespace tjit */
