@@ -213,10 +213,10 @@ nsContainerFrame::RemoveFrame(ChildListID aListID,
     // If the frame we are removing is a brFrame, we need a reflow so
     // the line the brFrame was on can attempt to pull up any frames
     // that can fit from lines below it.
-    PRBool generateReflowCommand = PR_TRUE;
+    bool generateReflowCommand = true;
 #ifdef IBMBIDI
     if (kNoReflowPrincipalList == aListID) {
-      generateReflowCommand = PR_FALSE;
+      generateReflowCommand = false;
     }
 #endif
     nsContainerFrame* parent = static_cast<nsContainerFrame*>(aOldFrame->GetParent());
@@ -233,7 +233,7 @@ nsContainerFrame::RemoveFrame(ChildListID aListID,
         if (!parent->mFrames.DestroyFrameIfPresent(aOldFrame)) {
           // Try to remove it from our overflow list, if we have one.
           // The simplest way is to reuse StealFrame.
-          StealFrame(PresContext(), aOldFrame, PR_TRUE);
+          StealFrame(PresContext(), aOldFrame, true);
           aOldFrame->Destroy();
         }
       } else {
@@ -345,6 +345,7 @@ nsContainerFrame::GetChildLists(nsTArray<ChildList>* aLists) const
     ::AppendIfNonempty(this, propTable, ExcessOverflowContainersProperty(),
                        aLists, kExcessOverflowContainersList);
   }
+  nsSplittableFrame::GetChildLists(aLists);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -385,27 +386,27 @@ nsContainerFrame::ChildIsDirty(nsIFrame* aChild)
   AddStateBits(NS_FRAME_HAS_DIRTY_CHILDREN);
 }
 
-PRBool
+bool
 nsContainerFrame::IsLeaf() const
 {
-  return PR_FALSE;
+  return false;
 }
 
-PRBool
-nsContainerFrame::PeekOffsetNoAmount(PRBool aForward, PRInt32* aOffset)
+bool
+nsContainerFrame::PeekOffsetNoAmount(bool aForward, PRInt32* aOffset)
 {
   NS_ASSERTION (aOffset && *aOffset <= 1, "aOffset out of range");
   // Don't allow the caret to stay in an empty (leaf) container frame.
-  return PR_FALSE;
+  return false;
 }
 
-PRBool
-nsContainerFrame::PeekOffsetCharacter(PRBool aForward, PRInt32* aOffset,
-                                      PRBool aRespectClusters)
+bool
+nsContainerFrame::PeekOffsetCharacter(bool aForward, PRInt32* aOffset,
+                                      bool aRespectClusters)
 {
   NS_ASSERTION (aOffset && *aOffset <= 1, "aOffset out of range");
   // Don't allow the caret to stay in an empty (leaf) container frame.
-  return PR_FALSE;
+  return false;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -457,7 +458,7 @@ ReparentFrameViewTo(nsIFrame*       aFrame,
 
 nsresult
 nsContainerFrame::CreateViewForFrame(nsIFrame* aFrame,
-                                     PRBool aForce)
+                                     bool aForce)
 {
   if (aFrame->HasView()) {
     return NS_OK;
@@ -484,7 +485,7 @@ nsContainerFrame::CreateViewForFrame(nsIFrame* aFrame,
 
   nsIView* insertBefore = nsLayoutUtils::FindSiblingViewFor(parentView, aFrame);
   // we insert this view 'above' the insertBefore view, unless insertBefore is null,
-  // in which case we want to call with aAbove == PR_FALSE to insert at the beginning
+  // in which case we want to call with aAbove == false to insert at the beginning
   // in document order
   viewManager->InsertChild(parentView, view, insertBefore, insertBefore != nsnull);
 
@@ -671,7 +672,7 @@ GetPresContextContainerWidget(nsPresContext* aPresContext)
   return mainWidget;
 }
 
-static PRBool
+static bool
 IsTopLevelWidget(nsIWidget* aWidget)
 {
   nsWindowType windowType;
@@ -751,7 +752,7 @@ nsContainerFrame::SyncFrameViewAfterReflow(nsPresContext* aPresContext,
   if (0 == (aFlags & NS_FRAME_NO_SIZE_VIEW)) {
     nsIViewManager* vm = aView->GetViewManager();
 
-    vm->ResizeView(aView, aVisualOverflowArea, PR_TRUE);
+    vm->ResizeView(aView, aVisualOverflowArea, true);
   }
 }
 
@@ -786,13 +787,13 @@ nsContainerFrame::SyncFrameViewProperties(nsPresContext*  aPresContext,
 
   // See if the frame is being relatively positioned or absolutely
   // positioned
-  PRBool isPositioned = aStyleContext->GetStyleDisplay()->IsPositioned();
+  bool isPositioned = aStyleContext->GetStyleDisplay()->IsPositioned();
 
   PRInt32 zIndex = 0;
-  PRBool  autoZIndex = PR_FALSE;
+  bool    autoZIndex = false;
 
   if (!isPositioned) {
-    autoZIndex = PR_TRUE;
+    autoZIndex = true;
   } else {
     // Make sure z-index is correct
     const nsStylePosition* position = aStyleContext->GetStylePosition();
@@ -800,7 +801,7 @@ nsContainerFrame::SyncFrameViewProperties(nsPresContext*  aPresContext,
     if (position->mZIndex.GetUnit() == eStyleUnit_Integer) {
       zIndex = position->mZIndex.GetIntValue();
     } else if (position->mZIndex.GetUnit() == eStyleUnit_Auto) {
-      autoZIndex = PR_TRUE;
+      autoZIndex = true;
     }
   }
 
@@ -901,7 +902,7 @@ nsContainerFrame::DoInlineIntrinsicWidth(nsRenderingContext *aRenderingContext,
 nsContainerFrame::ComputeAutoSize(nsRenderingContext *aRenderingContext,
                                   nsSize aCBSize, nscoord aAvailableWidth,
                                   nsSize aMargin, nsSize aBorder,
-                                  nsSize aPadding, PRBool aShrinkWrap)
+                                  nsSize aPadding, bool aShrinkWrap)
 {
   nsSize result(0xdeadbeef, NS_UNCONSTRAINEDSIZE);
   nscoord availBased = aAvailableWidth - aMargin.width - aBorder.width -
@@ -969,7 +970,7 @@ nsContainerFrame::ReflowChild(nsIFrame*                aKidFrame,
       // parent is not this because we are executing pullup code)
       if (aTracker) aTracker->Finish(aKidFrame);
       static_cast<nsContainerFrame*>(kidNextInFlow->GetParent())
-        ->DeleteNextInFlowChild(aPresContext, kidNextInFlow, PR_TRUE);
+        ->DeleteNextInFlowChild(aPresContext, kidNextInFlow, true);
     }
   }
   return result;
@@ -1114,8 +1115,8 @@ nsContainerFrame::ReflowOverflowContainerChildren(nsPresContext*           aPres
   if (!overflowContainers)
     return NS_OK; // nothing to reflow
 
-  nsOverflowContinuationTracker tracker(aPresContext, this, PR_FALSE, PR_FALSE);
-  PRBool shouldReflowAllKids = aReflowState.ShouldReflowAllKids();
+  nsOverflowContinuationTracker tracker(aPresContext, this, false, false);
+  bool shouldReflowAllKids = aReflowState.ShouldReflowAllKids();
 
   for (nsIFrame* frame = overflowContainers->FirstChild(); frame;
        frame = frame->GetNextSibling()) {
@@ -1232,9 +1233,9 @@ nsContainerFrame::DisplayOverflowContainers(nsDisplayListBuilder*   aBuilder,
 nsresult
 nsContainerFrame::StealFrame(nsPresContext* aPresContext,
                              nsIFrame*      aChild,
-                             PRBool         aForceNormal)
+                             bool           aForceNormal)
 {
-  PRBool removed = PR_TRUE;
+  bool removed = true;
   if ((aChild->GetStateBits() & NS_FRAME_IS_OVERFLOW_CONTAINER)
       && !aForceNormal) {
     // Try removing from the overflow container list
@@ -1247,7 +1248,7 @@ nsContainerFrame::StealFrame(nsPresContext* aPresContext,
   }
   else {
     if (!mFrames.RemoveFrameIfPresent(aChild)) {
-      removed = PR_FALSE;
+      removed = false;
       // We didn't find the child in the parent's principal child list.
       // Maybe it's on the overflow list?
       nsFrameList* frameList = GetOverflowFrames();
@@ -1322,7 +1323,7 @@ nsContainerFrame::DestroyOverflowList(nsPresContext* aPresContext,
 void
 nsContainerFrame::DeleteNextInFlowChild(nsPresContext* aPresContext,
                                         nsIFrame*      aNextInFlow,
-                                        PRBool         aDeletingEmptyFrames)
+                                        bool           aDeletingEmptyFrames)
 {
 #ifdef DEBUG
   nsIFrame* prevInFlow = aNextInFlow->GetPrevInFlow();
@@ -1397,7 +1398,7 @@ nsContainerFrame::RemovePropTableFrames(nsPresContext*                 aPresCont
   return static_cast<nsFrameList*>(propTable->Remove(this, aProperty));
 }
 
-PRBool
+bool
 nsContainerFrame::RemovePropTableFrame(nsPresContext*                 aPresContext,
                                        nsIFrame*                      aFrame,
                                        const FramePropertyDescriptor* aProperty)
@@ -1405,12 +1406,12 @@ nsContainerFrame::RemovePropTableFrame(nsPresContext*                 aPresConte
   nsFrameList* frameList = RemovePropTableFrames(aPresContext, aProperty);
   if (!frameList) {
     // No such list
-    return PR_FALSE;
+    return false;
   }
   if (!frameList->RemoveFrameIfPresent(aFrame)) {
     // Found list, but it doesn't have the frame. Put list back.
     SetPropTableFrames(aPresContext, frameList, aProperty);
-    return PR_FALSE;
+    return false;
   }
 
   if (frameList->IsEmpty()) {
@@ -1421,7 +1422,7 @@ nsContainerFrame::RemovePropTableFrame(nsPresContext*                 aPresConte
     // Removed frame, but list not empty. Put it back.
     SetPropTableFrames(aPresContext, frameList, aProperty);
   }
-  return PR_TRUE;
+  return true;
 }
 
 nsresult
@@ -1490,12 +1491,12 @@ nsContainerFrame::PushChildren(nsPresContext* aPresContext,
  *
  * Updates this frame's child count and content mapping.
  *
- * @return  PR_TRUE if any frames were moved and PR_FALSE otherwise
+ * @return  true if any frames were moved and false otherwise
  */
-PRBool
+bool
 nsContainerFrame::MoveOverflowToChildList(nsPresContext* aPresContext)
 {
-  PRBool result = PR_FALSE;
+  bool result = false;
 
   // Check for an overflow list with our prev-in-flow
   nsContainerFrame* prevInFlow = (nsContainerFrame*)GetPrevInFlow();
@@ -1512,7 +1513,7 @@ nsContainerFrame::MoveOverflowToChildList(nsPresContext* aPresContext)
                                               *prevOverflowFrames,
                                               prevInFlow, this);
       mFrames.AppendFrames(this, *prevOverflowFrames);
-      result = PR_TRUE;
+      result = true;
     }
   }
 
@@ -1521,15 +1522,15 @@ nsContainerFrame::MoveOverflowToChildList(nsPresContext* aPresContext)
   if (overflowFrames) {
     NS_ASSERTION(mFrames.NotEmpty(), "overflow list w/o frames");
     mFrames.AppendFrames(nsnull, *overflowFrames);
-    result = PR_TRUE;
+    result = true;
   }
   return result;
 }
 
 nsOverflowContinuationTracker::nsOverflowContinuationTracker(nsPresContext*    aPresContext,
                                                              nsContainerFrame* aFrame,
-                                                             PRBool            aWalkOOFFrames,
-                                                             PRBool            aSkipOverflowContainerChildren)
+                                                             bool              aWalkOOFFrames,
+                                                             bool              aSkipOverflowContainerChildren)
   : mOverflowContList(nsnull),
     mPrevOverflowCont(nsnull),
     mSentry(nsnull),
@@ -1632,7 +1633,7 @@ nsOverflowContinuationTracker::Insert(nsIFrame*       aOverflowCont,
   NS_PRECONDITION(aOverflowCont->GetPrevInFlow(),
                   "overflow containers must have a prev-in-flow");
   nsresult rv = NS_OK;
-  PRBool convertedToOverflowContainer = PR_FALSE;
+  bool convertedToOverflowContainer = false;
   nsPresContext* presContext = aOverflowCont->PresContext();
   if (!mSentry || aOverflowCont != mSentry->GetNextInFlow()) {
     // Not in our list, so we need to add it
@@ -1648,7 +1649,7 @@ nsOverflowContinuationTracker::Insert(nsIFrame*       aOverflowCont,
     }
     else {
       aOverflowCont->AddStateBits(NS_FRAME_IS_OVERFLOW_CONTAINER);
-      convertedToOverflowContainer = PR_TRUE;
+      convertedToOverflowContainer = true;
     }
     if (!mOverflowContList) {
       mOverflowContList = new nsFrameList();
@@ -1782,13 +1783,13 @@ nsContainerFrame::List(FILE* out, PRInt32 aIndent) const
   }
 
   // Output the children
-  PRBool outputOneList = PR_FALSE;
+  bool outputOneList = false;
   ChildListIterator lists(this);
   for (; !lists.IsDone(); lists.Next()) {
     if (outputOneList) {
       IndentBy(out, aIndent);
     }
-    outputOneList = PR_TRUE;
+    outputOneList = true;
     fputs(mozilla::layout::ChildListName(lists.CurrentID()), out);
     fputs("<\n", out);
     nsFrameList::Enumerator childFrames(lists.CurrentList());
