@@ -170,7 +170,7 @@ public:
     : frame(aFrame)
     , rendContext(aRenderingContext)
   {
-    InitOffsets(aContainingBlockWidth);
+    InitOffsets(aContainingBlockWidth, frame->GetType());
   }
 
 #ifdef DEBUG
@@ -190,20 +190,21 @@ private:
   /**
    * Computes margin values from the specified margin style information, and
    * fills in the mComputedMargin member.
-   * @return PR_TRUE if the margin is dependent on the containing block width
+   * @return true if the margin is dependent on the containing block width
    */
-  PRBool ComputeMargin(nscoord aContainingBlockWidth);
+  bool ComputeMargin(nscoord aContainingBlockWidth);
   
   /**
    * Computes padding values from the specified padding style information, and
    * fills in the mComputedPadding member.
-   * @return PR_TRUE if the padding is dependent on the containing block width
+   * @return true if the padding is dependent on the containing block width
    */
-   PRBool ComputePadding(nscoord aContainingBlockWidth);
+   bool ComputePadding(nscoord aContainingBlockWidth, nsIAtom* aFrameType);
 
 protected:
 
   void InitOffsets(nscoord aContainingBlockWidth,
+                   nsIAtom* aFrameType,
                    const nsMargin *aBorder = nsnull,
                    const nsMargin *aPadding = nsnull);
 
@@ -390,7 +391,7 @@ public:
                     // to override default containing block w & h:
                     nscoord                  aContainingBlockWidth = -1,
                     nscoord                  aContainingBlockHeight = -1,
-                    PRBool                   aInit = PR_TRUE);
+                    bool                     aInit = true);
 
   // This method initializes various data members. It is automatically
   // called by the various constructors
@@ -405,13 +406,6 @@ public:
   static nscoord
     GetContainingBlockContentWidth(const nsHTMLReflowState* aReflowState);
 
-  /**
-   * Find the containing block of aFrame.  This may return null if
-   * there isn't one (but that should really only happen for root
-   * frames).
-   */
-  static nsIFrame* GetContainingBlockFor(const nsIFrame* aFrame);
-
   /**
    * Calculate the used line-height property. The return value will be >= 0.
    */
@@ -442,7 +436,7 @@ public:
    */
   void ApplyMinMaxConstraints(nscoord* aContentWidth, nscoord* aContentHeight) const;
 
-  PRBool ShouldReflowAllKids() const {
+  bool ShouldReflowAllKids() const {
     // Note that we could make a stronger optimization for mVResize if
     // we use it in a ShouldReflowChild test that replaces the current
     // checks of NS_FRAME_IS_DIRTY | NS_FRAME_HAS_DIRTY_CHILDREN, if it
@@ -473,7 +467,7 @@ public:
 
   void SetTruncated(const nsHTMLReflowMetrics& aMetrics, nsReflowStatus* aStatus) const;
 
-  PRBool WillReflowAgainForClearance() const {
+  bool WillReflowAgainForClearance() const {
     return mDiscoveredClearance && *mDiscoveredClearance;
   }
 
@@ -497,15 +491,16 @@ public:
 #endif
 
 protected:
-  void InitFrameType();
+  void InitFrameType(nsIAtom* aFrameType);
   void InitCBReflowState();
-  void InitResizeFlags(nsPresContext* aPresContext);
+  void InitResizeFlags(nsPresContext* aPresContext, nsIAtom* aFrameType);
 
   void InitConstraints(nsPresContext* aPresContext,
                        nscoord         aContainingBlockWidth,
                        nscoord         aContainingBlockHeight,
                        const nsMargin* aBorder,
-                       const nsMargin* aPadding);
+                       const nsMargin* aPadding,
+                       nsIAtom*        aFrameType);
 
   // Returns the nearest containing block or block frame (whether or not
   // it is a containing block) for the specified frame.  Also returns
@@ -521,12 +516,14 @@ protected:
                                 nscoord           aBlockLeftContentEdge,
                                 nscoord           aBlockContentWidth,
                                 const nsHTMLReflowState* cbrs,
-                                nsHypotheticalBox& aHypotheticalBox);
+                                nsHypotheticalBox& aHypotheticalBox,
+                                nsIAtom*          aFrameType);
 
   void InitAbsoluteConstraints(nsPresContext* aPresContext,
                                const nsHTMLReflowState* cbrs,
                                nscoord aContainingBlockWidth,
-                               nscoord aContainingBlockHeight);
+                               nscoord aContainingBlockHeight,
+                               nsIAtom* aFrameType);
 
   void ComputeRelativeOffsets(const nsHTMLReflowState* cbrs,
                               nscoord aContainingBlockWidth,
@@ -545,7 +542,8 @@ protected:
                                          nscoord* aOutsideBoxSizing);
 
   void CalculateBlockSideMargins(nscoord aAvailWidth,
-                                 nscoord aComputedWidth);
+                                 nscoord aComputedWidth,
+                                 nsIAtom* aFrameType);
 };
 
 #endif /* nsHTMLReflowState_h___ */
