@@ -85,9 +85,9 @@ public:
    * @param aDest       The value to add to.
    * @param aValueToAdd The value to add.
    * @param aCount      The number of times to add aValueToAdd.
-   * @return PR_TRUE on success, PR_FALSE on failure.
+   * @return true on success, false on failure.
    */
-  static PRBool Add(nsCSSProperty aProperty, Value& aDest,
+  static bool Add(nsCSSProperty aProperty, Value& aDest,
                     const Value& aValueToAdd, PRUint32 aCount) {
     return AddWeighted(aProperty, 1.0, aDest, aCount, aValueToAdd, aDest);
   }
@@ -108,9 +108,9 @@ public:
    * @param aEndValue   The end of the interval for which the distance
    *                    should be calculated.
    * @param aDistance   The result of the calculation.
-   * @return PR_TRUE on success, PR_FALSE on failure.
+   * @return true on success, false on failure.
    */
-  static PRBool ComputeDistance(nsCSSProperty aProperty,
+  static bool ComputeDistance(nsCSSProperty aProperty,
                                 const Value& aStartValue,
                                 const Value& aEndValue,
                                 double& aDistance);
@@ -129,9 +129,9 @@ public:
    * @param aPortion    A number in the range [0.0, 1.0] defining the
    *                    distance of the interpolated value in the interval.
    * @param [out] aResultValue The resulting interpolated value.
-   * @return PR_TRUE on success, PR_FALSE on failure.
+   * @return true on success, false on failure.
    */
-  static PRBool Interpolate(nsCSSProperty aProperty,
+  static bool Interpolate(nsCSSProperty aProperty,
                             const Value& aStartValue,
                             const Value& aEndValue,
                             double aPortion,
@@ -146,7 +146,7 @@ public:
    *
    * @param [out] aResultValue The resulting interpolated value.  May be
    *                           the same as aValue1 or aValue2.
-   * @return PR_TRUE on success, PR_FALSE on failure.
+   * @return true on success, false on failure.
    *
    * NOTE: Current callers always pass aCoeff1 and aCoeff2 >= 0.  They
    * are currently permitted to be negative; however, if, as we add
@@ -154,7 +154,7 @@ public:
    * difficulty, we might change this to restrict them to being
    * positive.
    */
-  static PRBool AddWeighted(nsCSSProperty aProperty,
+  static bool AddWeighted(nsCSSProperty aProperty,
                             double aCoeff1, const Value& aValue1,
                             double aCoeff2, const Value& aValue2,
                             Value& aResultValue);
@@ -176,21 +176,21 @@ public:
    *                        |aSpecifiedValue| in SVG mode.
    * @param [out] aComputedValue The resulting computed value.
    * @param [out] aIsContextSensitive
-   *                        Set to PR_TRUE if |aSpecifiedValue| may produce
+   *                        Set to true if |aSpecifiedValue| may produce
    *                        a different |aComputedValue| depending on other CSS
    *                        properties on |aTargetElement| or its ancestors.
-   *                        PR_FALSE otherwise.
+   *                        false otherwise.
    *                        Note that the operation of this method is
    *                        significantly faster when |aIsContextSensitive| is
    *                        nsnull.
-   * @return PR_TRUE on success, PR_FALSE on failure.
+   * @return true on success, false on failure.
    */
-  static PRBool ComputeValue(nsCSSProperty aProperty,
+  static bool ComputeValue(nsCSSProperty aProperty,
                              mozilla::dom::Element* aTargetElement,
                              const nsAString& aSpecifiedValue,
-                             PRBool aUseSVGMode,
+                             bool aUseSVGMode,
                              Value& aComputedValue,
-                             PRBool* aIsContextSensitive = nsnull);
+                             bool* aIsContextSensitive = nsnull);
 
   /**
    * Creates a specified value for the given computed value.
@@ -205,13 +205,13 @@ public:
    *                       which we're working.
    * @param aComputedValue The computed value to be converted.
    * @param [out] aSpecifiedValue The resulting specified value.
-   * @return PR_TRUE on success, PR_FALSE on failure.
+   * @return true on success, false on failure.
    */
-  static PRBool UncomputeValue(nsCSSProperty aProperty,
+  static bool UncomputeValue(nsCSSProperty aProperty,
                                nsPresContext* aPresContext,
                                const Value& aComputedValue,
                                nsCSSValue& aSpecifiedValue);
-  static PRBool UncomputeValue(nsCSSProperty aProperty,
+  static bool UncomputeValue(nsCSSProperty aProperty,
                                nsPresContext* aPresContext,
                                const Value& aComputedValue,
                                nsAString& aSpecifiedValue);
@@ -223,9 +223,9 @@ public:
    * @param aProperty     The property whose value we're looking up.
    * @param aStyleContext The style context to check for the computed value.
    * @param [out] aComputedValue The resulting computed value.
-   * @return PR_TRUE on success, PR_FALSE on failure.
+   * @return true on success, false on failure.
    */
-  static PRBool ExtractComputedValue(nsCSSProperty aProperty,
+  static bool ExtractComputedValue(nsCSSProperty aProperty,
                                      nsStyleContext* aStyleContext,
                                      Value& aComputedValue);
 
@@ -292,7 +292,7 @@ public:
 
     // Accessor to let us verify assumptions about presence of null unit,
     // without tripping the assertion in GetUnit().
-    PRBool IsNull() const {
+    bool IsNull() const {
       return mUnit == eUnit_Null;
     }
 
@@ -392,8 +392,8 @@ public:
 
     Value& operator=(const Value& aOther);
 
-    PRBool operator==(const Value& aOther) const;
-    PRBool operator!=(const Value& aOther) const
+    bool operator==(const Value& aOther) const;
+    bool operator!=(const Value& aOther) const
       { return !(*this == aOther); }
 
   private:
@@ -403,30 +403,30 @@ public:
       return static_cast<PRUnichar*>(aBuffer->Data());
     }
 
-    static PRBool IsIntUnit(Unit aUnit) {
+    static bool IsIntUnit(Unit aUnit) {
       return aUnit == eUnit_Enumerated || aUnit == eUnit_Visibility ||
              aUnit == eUnit_Integer;
     }
-    static PRBool IsCSSValueUnit(Unit aUnit) {
+    static bool IsCSSValueUnit(Unit aUnit) {
       return aUnit == eUnit_Calc;
     }
-    static PRBool IsCSSValuePairUnit(Unit aUnit) {
+    static bool IsCSSValuePairUnit(Unit aUnit) {
       return aUnit == eUnit_CSSValuePair;
     }
-    static PRBool IsCSSValueTripletUnit(Unit aUnit) {
+    static bool IsCSSValueTripletUnit(Unit aUnit) {
       return aUnit == eUnit_CSSValueTriplet;
     }
-    static PRBool IsCSSRectUnit(Unit aUnit) {
+    static bool IsCSSRectUnit(Unit aUnit) {
       return aUnit == eUnit_CSSRect;
     }
-    static PRBool IsCSSValueListUnit(Unit aUnit) {
+    static bool IsCSSValueListUnit(Unit aUnit) {
       return aUnit == eUnit_Dasharray || aUnit == eUnit_Shadow ||
              aUnit == eUnit_Transform;
     }
-    static PRBool IsCSSValuePairListUnit(Unit aUnit) {
+    static bool IsCSSValuePairListUnit(Unit aUnit) {
       return aUnit == eUnit_CSSValuePairList;
     }
-    static PRBool IsStringUnit(Unit aUnit) {
+    static bool IsStringUnit(Unit aUnit) {
       return aUnit == eUnit_UnparsedString;
     }
   };
