@@ -37,7 +37,7 @@
  * ***** END LICENSE BLOCK ***** */
 
 #include "nsSVGTextFrame.h"
-#include "nsILookAndFeel.h"
+#include "mozilla/LookAndFeel.h"
 #include "nsTextFragment.h"
 #include "nsBidiPresUtils.h"
 #include "nsSVGUtils.h"
@@ -60,7 +60,7 @@ using namespace mozilla;
 struct CharacterPosition {
   gfxPoint pos;
   gfxFloat angle;
-  PRBool draw;
+  bool draw;
 };
 
 static gfxContext* MakeTmpCtx() {
@@ -102,7 +102,7 @@ public:
    * cluster.
    * @param aForceGlobalTransform passed on to EnsureTextRun (see below)
    */
-  CharacterIterator(nsSVGGlyphFrame *aSource, PRBool aForceGlobalTransform);
+  CharacterIterator(nsSVGGlyphFrame *aSource, bool aForceGlobalTransform);
   /**
    * This matrix will be applied to aContext in the SetupFor methods below,
    * before any glyph translation/rotation.
@@ -110,7 +110,7 @@ public:
   void SetInitialMatrix(gfxContext *aContext) {
     mInitialMatrix = aContext->CurrentMatrix();
     if (mInitialMatrix.IsSingular()) {
-      mInError = PR_TRUE;
+      mInError = true;
     }
   }
   /**
@@ -120,7 +120,7 @@ public:
    * the whole textrun at once is impossible due to individual positioning
    * and/or rotation of glyphs.
    */
-  PRBool SetupForDirectTextRunDrawing(gfxContext *aContext) {
+  bool SetupForDirectTextRunDrawing(gfxContext *aContext) {
     return SetupForDirectTextRun(aContext, mDrawScale);
   }
   /**
@@ -131,7 +131,7 @@ public:
    * Returns false if drawing the whole textrun at once is impossible due
    * to individual positioning and/or rotation of glyphs.
    */
-  PRBool SetupForDirectTextRunMetrics(gfxContext *aContext) {
+  bool SetupForDirectTextRunMetrics(gfxContext *aContext) {
     return SetupForDirectTextRun(aContext, mMetricsScale);
   }
   /**
@@ -143,16 +143,16 @@ public:
   }
 
   /**
-   * Returns the index of the next cluster in the string that should be
-   * drawn, or -1 if there is no such cluster.
+   * Returns the index of the next cluster in the string that should be drawn,
+   * or InvalidCluster() (i.e. PRUint32(-1)) if there is no such cluster.
    */
-  PRInt32 NextCluster();
+  PRUint32 NextCluster();
 
   /**
    * Returns the length of the current cluster (usually 1, unless there
    * are combining marks)
    */
-  PRInt32 ClusterLength();
+  PRUint32 ClusterLength();
 
   /**
    * Repeated calls NextCluster until it returns aIndex (i.e. aIndex is the
@@ -160,7 +160,7 @@ public:
    * (because aIndex is before or equal to the current character, or
    * out of bounds, or not drawable).
    */
-  PRBool AdvanceToCharacter(PRInt32 aIndex);
+  bool AdvanceToCharacter(PRUint32 aIndex);
 
   /**
    * Resets the iterator to the beginning of the string.
@@ -170,9 +170,9 @@ public:
     // a) If there was a problem creating the iterator (mCurrentChar == -1)
     // b) If we ran off the end of the string (mCurrentChar != -1)
     // We can only reset the mInError flag in case b)
-    if (mCurrentChar != -1) {
-      mCurrentChar = -1;
-      mInError = PR_FALSE;
+    if (mCurrentChar != InvalidCluster()) {
+      mCurrentChar = InvalidCluster();
+      mInError = false;
     }
   }
 
@@ -198,8 +198,15 @@ public:
    */
   CharacterPosition GetPositionData();
 
+  /**
+   * "Invalid" cluster index returned to indicate error state
+   */
+  PRUint32 InvalidCluster() {
+    return PRUint32(-1);
+  }
+
 private:
-  PRBool SetupForDirectTextRun(gfxContext *aContext, float aScale);
+  bool SetupForDirectTextRun(gfxContext *aContext, float aScale);
   void SetupFor(gfxContext *aContext, float aScale);
 
   nsSVGGlyphFrame *mSource;
@@ -207,10 +214,10 @@ private:
   gfxMatrix mInitialMatrix;
   // Textrun advance width from start to mCurrentChar, in appunits
   gfxFloat mCurrentAdvance;
-  PRInt32 mCurrentChar;
+  PRUint32 mCurrentChar;
   float mDrawScale;
   float mMetricsScale;
-  PRPackedBool mInError;
+  bool mInError;
 };
 
 //----------------------------------------------------------------------
@@ -228,7 +235,6 @@ NS_IMPL_FRAMEARENA_HELPERS(nsSVGGlyphFrame)
 // nsQueryFrame methods
 
 NS_QUERYFRAME_HEAD(nsSVGGlyphFrame)
-  NS_QUERYFRAME_ENTRY(nsISVGGlyphFragmentLeaf)
   NS_QUERYFRAME_ENTRY(nsISVGGlyphFragmentNode)
   NS_QUERYFRAME_ENTRY(nsISVGChildFrame)
 NS_QUERYFRAME_TAIL_INHERITING(nsSVGGlyphFrameBase)
@@ -241,6 +247,10 @@ nsSVGGlyphFrame::CharacterDataChanged(CharacterDataChangeInfo* aInfo)
 {
   ClearTextRun();
   NotifyGlyphMetricsChange();
+  if (IsTextEmpty()) {
+    // That's it for this frame. Leave no trace we were here
+    nsSVGUtils::UpdateGraphic(this);
+  }
 
   return NS_OK;
 }
@@ -262,7 +272,7 @@ nsSVGGlyphFrame::DidSetStyleContext(nsStyleContext* aOldStyleContext)
 }
 
 void
-nsSVGGlyphFrame::SetSelected(PRBool        aSelected,
+nsSVGGlyphFrame::SetSelected(bool          aSelected,
                              SelectionType aType)
 {
 #if defined(DEBUG) && defined(SVG_DEBUG_SELECTION)
@@ -273,7 +283,7 @@ nsSVGGlyphFrame::SetSelected(PRBool        aSelected,
     return;
 
   // check whether style allows selection
-  PRBool selectable;
+  bool selectable;
   IsSelectable(&selectable, nsnull);
   if (!selectable)
     return;
@@ -288,7 +298,7 @@ nsSVGGlyphFrame::SetSelected(PRBool        aSelected,
 }
 
 NS_IMETHODIMP
-nsSVGGlyphFrame::GetSelected(PRBool *aSelected) const
+nsSVGGlyphFrame::GetSelected(bool *aSelected) const
 {
   nsresult rv = nsSVGGlyphFrameBase::GetSelected(aSelected);
 #if defined(DEBUG) && defined(SVG_DEBUG_SELECTION)
@@ -298,7 +308,7 @@ nsSVGGlyphFrame::GetSelected(PRBool *aSelected) const
 }
 
 NS_IMETHODIMP
-nsSVGGlyphFrame::IsSelectable(PRBool* aIsSelectable,
+nsSVGGlyphFrame::IsSelectable(bool* aIsSelectable,
                               PRUint8* aSelectStyle) const
 {
   nsresult rv = nsSVGGlyphFrameBase::IsSelectable(aIsSelectable, aSelectStyle);
@@ -363,7 +373,7 @@ nsSVGGlyphFrame::PaintSVG(nsSVGRenderState *aContext,
     gfxMatrix matrix = gfx->CurrentMatrix();
     SetupGlobalTransform(gfx);
 
-    CharacterIterator iter(this, PR_TRUE);
+    CharacterIterator iter(this, true);
     iter.SetInitialMatrix(gfx);
 
     if (GetClipRule() == NS_STYLE_FILL_RULE_EVENODD)
@@ -387,7 +397,7 @@ nsSVGGlyphFrame::PaintSVG(nsSVGRenderState *aContext,
   gfx->Save();
   SetupGlobalTransform(gfx);
 
-  CharacterIterator iter(this, PR_TRUE);
+  CharacterIterator iter(this, true);
   iter.SetInitialMatrix(gfx);
 
   if (SetupCairoFill(gfx)) {
@@ -416,14 +426,14 @@ nsSVGGlyphFrame::PaintSVG(nsSVGRenderState *aContext,
 NS_IMETHODIMP_(nsIFrame*)
 nsSVGGlyphFrame::GetFrameForPoint(const nsPoint &aPoint)
 {
-  PRUint16 mask = GetHittestMask();
-  if (!mask) {
+  PRUint16 hitTestFlags = GetHitTestFlags();
+  if (!hitTestFlags) {
     return nsnull;
   }
 
   nsRefPtr<gfxContext> context = MakeTmpCtx();
   SetupGlobalTransform(context);
-  CharacterIterator iter(this, PR_TRUE);
+  CharacterIterator iter(this, true);
   iter.SetInitialMatrix(context);
 
   // The SVG 1.1 spec says that text is hit tested against the character cells
@@ -432,11 +442,11 @@ nsSVGGlyphFrame::GetFrameForPoint(const nsPoint &aPoint)
   //
   //   http://www.w3.org/TR/SVG11/interact.html#PointerEventsProperty
   //
-  // Currently we just test the character cells if GetHittestMask says we're
+  // Currently we just test the character cells if GetHitTestFlags says we're
   // supposed to be testing either the fill OR the stroke:
 
-  PRInt32 i;
-  while ((i = iter.NextCluster()) >= 0) {
+  PRUint32 i;
+  while ((i = iter.NextCluster()) != iter.InvalidCluster()) {
     gfxTextRun::Metrics metrics =
     mTextRun->MeasureText(i, iter.ClusterLength(),
                           gfxFont::LOOSE_INK_EXTENTS, nsnull, nsnull);
@@ -448,8 +458,8 @@ nsSVGGlyphFrame::GetFrameForPoint(const nsPoint &aPoint)
     context->DeviceToUser(gfxPoint(PresContext()->AppUnitsToGfxUnits(aPoint.x),
                                    PresContext()->AppUnitsToGfxUnits(aPoint.y)));
 
-  PRBool isHit = PR_FALSE;
-  if (mask & HITTEST_MASK_FILL || mask & HITTEST_MASK_STROKE) {
+  bool isHit = false;
+  if (hitTestFlags & SVG_HIT_TEST_FILL || hitTestFlags & SVG_HIT_TEST_STROKE) {
     isHit = context->PointInFill(userSpacePoint);
   }
 
@@ -474,7 +484,7 @@ nsSVGGlyphFrame::GetCoveredRegion()
 NS_IMETHODIMP
 nsSVGGlyphFrame::UpdateCoveredRegion()
 {
-  mRect.Empty();
+  mRect.SetEmpty();
 
   gfxMatrix matrix = GetCanvasTM();
   if (matrix.IsSingular()) {
@@ -484,18 +494,18 @@ nsSVGGlyphFrame::UpdateCoveredRegion()
   nsRefPtr<gfxContext> tmpCtx = MakeTmpCtx();
   tmpCtx->Multiply(matrix);
 
-  PRBool hasStroke = HasStroke();
+  bool hasStroke = HasStroke();
   if (hasStroke) {
     SetupCairoStrokeGeometry(tmpCtx);
   } else if (GetStyleSVG()->mFill.mType == eStyleSVGPaintType_None) {
     return NS_OK;
   }
 
-  SetMatrixPropagation(PR_FALSE);
-  CharacterIterator iter(this, PR_TRUE);
+  mPropagateTransform = false;
+  CharacterIterator iter(this, true);
   iter.SetInitialMatrix(tmpCtx);
   AddBoundingBoxesToPath(&iter, tmpCtx);
-  SetMatrixPropagation(PR_TRUE);
+  mPropagateTransform = true;
   tmpCtx->IdentityMatrix();
 
   // Be careful when replacing the following logic to get the fill and stroke
@@ -582,8 +592,8 @@ nsSVGGlyphFrame::AddCharactersToPath(CharacterIterator *aIter,
     return;
   }
 
-  PRInt32 i;
-  while ((i = aIter->NextCluster()) >= 0) {
+  PRUint32 i;
+  while ((i = aIter->NextCluster()) != aIter->InvalidCluster()) {
     aIter->SetupForDrawing(aContext);
     mTextRun->DrawToPath(aContext, gfxPoint(0, 0), i, aIter->ClusterLength(),
                          nsnull, nsnull);
@@ -602,8 +612,8 @@ nsSVGGlyphFrame::AddBoundingBoxesToPath(CharacterIterator *aIter,
     return;
   }
 
-  PRInt32 i;
-  while ((i = aIter->NextCluster()) >= 0) {
+  PRUint32 i;
+  while ((i = aIter->NextCluster()) != aIter->InvalidCluster()) {
     aIter->SetupForMetrics(aContext);
     gfxTextRun::Metrics metrics =
       mTextRun->MeasureText(i, aIter->ClusterLength(),
@@ -622,8 +632,8 @@ nsSVGGlyphFrame::FillCharacters(CharacterIterator *aIter,
     return;
   }
 
-  PRInt32 i;
-  while ((i = aIter->NextCluster()) >= 0) {
+  PRUint32 i;
+  while ((i = aIter->NextCluster()) != aIter->InvalidCluster()) {
     aIter->SetupForDrawing(aContext);
     mTextRun->Draw(aContext, gfxPoint(0, 0), i, aIter->ClusterLength(),
                    nsnull, nsnull);
@@ -631,20 +641,43 @@ nsSVGGlyphFrame::FillCharacters(CharacterIterator *aIter,
 }
 
 gfxRect
-nsSVGGlyphFrame::GetBBoxContribution(const gfxMatrix &aToBBoxUserspace)
+nsSVGGlyphFrame::GetBBoxContribution(const gfxMatrix &aToBBoxUserspace,
+                                     PRUint32 aFlags)
 {
-  mOverrideCanvasTM = NS_NewSVGMatrix(aToBBoxUserspace);
+  if (mOverrideCanvasTM) {
+    *mOverrideCanvasTM = aToBBoxUserspace;
+  } else {
+    mOverrideCanvasTM = new gfxMatrix(aToBBoxUserspace);
+  }
 
   nsRefPtr<gfxContext> tmpCtx = MakeTmpCtx();
   SetupGlobalTransform(tmpCtx);
-  CharacterIterator iter(this, PR_TRUE);
+  CharacterIterator iter(this, true);
   iter.SetInitialMatrix(tmpCtx);
   AddBoundingBoxesToPath(&iter, tmpCtx);
   tmpCtx->IdentityMatrix();
 
   mOverrideCanvasTM = nsnull;
 
-  return tmpCtx->GetUserPathExtent();
+  gfxRect bbox;
+
+  gfxRect pathExtents = tmpCtx->GetUserPathExtent();
+
+  // Account for fill:
+  if ((aFlags & nsSVGUtils::eBBoxIncludeFill) != 0 &&
+      ((aFlags & nsSVGUtils::eBBoxIgnoreFillIfNone) == 0 ||
+       GetStyleSVG()->mFill.mType != eStyleSVGPaintType_None)) {
+    bbox = pathExtents;
+  }
+
+  // Account for stroke:
+  if ((aFlags & nsSVGUtils::eBBoxIncludeStroke) != 0 &&
+      ((aFlags & nsSVGUtils::eBBoxIgnoreStrokeIfNone) == 0 || HasStroke())) {
+    bbox =
+      bbox.Union(nsSVGUtils::PathExtentsToMaxStrokeExtents(pathExtents, this));
+  }
+
+  return bbox;
 }
 
 //----------------------------------------------------------------------
@@ -654,7 +687,7 @@ gfxMatrix
 nsSVGGlyphFrame::GetCanvasTM()
 {
   if (mOverrideCanvasTM) {
-    return nsSVGUtils::ConvertSVGMatrixToThebes(mOverrideCanvasTM);
+    return *mOverrideCanvasTM;
   }
   NS_ASSERTION(mParent, "null parent");
   return static_cast<nsSVGContainerFrame*>(mParent)->GetCanvasTM();
@@ -663,18 +696,15 @@ nsSVGGlyphFrame::GetCanvasTM()
 //----------------------------------------------------------------------
 // nsSVGGlyphFrame methods:
 
-PRBool
+bool
 nsSVGGlyphFrame::GetCharacterData(nsAString & aCharacterData)
 {
   nsAutoString characterData;
   mContent->AppendTextTo(characterData);
 
-  if (mWhitespaceHandling & COMPRESS_WHITESPACE) {
-    PRBool trimLeadingWhitespace, trimTrailingWhitespace;
-    trimLeadingWhitespace = ((mWhitespaceHandling & TRIM_LEADING_WHITESPACE) != 0);
-    trimTrailingWhitespace = ((mWhitespaceHandling & TRIM_TRAILING_WHITESPACE) != 0);
-    characterData.CompressWhitespace(trimLeadingWhitespace, 
-                                     trimTrailingWhitespace);
+  if (mCompressWhitespace) {
+    characterData.CompressWhitespace(mTrimLeadingWhitespace,
+                                     mTrimTrailingWhitespace);
   } else {
     nsAString::iterator start, end;
     characterData.BeginWriting(start);
@@ -690,12 +720,12 @@ nsSVGGlyphFrame::GetCharacterData(nsAString & aCharacterData)
   return !characterData.IsEmpty();
 }
 
-PRBool
+bool
 nsSVGGlyphFrame::GetCharacterPositions(nsTArray<CharacterPosition>* aCharacterPositions,
                                        float aMetricsScale)
 {
   PRUint32 strLength = mTextRun->GetLength();
-  NS_ASSERTION(strLength > 0, "no text");
+  NS_ABORT_IF_FALSE(strLength > 0, "no text");
 
   const gfxFloat radPerDeg = M_PI / 180.0;
 
@@ -716,10 +746,10 @@ nsSVGGlyphFrame::GetCharacterPositions(nsTArray<CharacterPosition>* aCharacterPo
 
     // textPath frame, but invalid target
     if (!data)
-      return PR_FALSE;
+      return false;
 
     if (!aCharacterPositions->SetLength(strLength))
-      return PR_FALSE;
+      return false;
 
     gfxFloat pathScale = textPath->GetPathScale();
 
@@ -758,7 +788,7 @@ nsSVGGlyphFrame::GetCharacterPositions(nsTArray<CharacterPosition>* aCharacterPo
       }
       pos.x += 2 * halfAdvance;
     }
-    return PR_TRUE;
+    return true;
   }
 
   if (xList.Length() <= 1 &&
@@ -767,18 +797,18 @@ nsSVGGlyphFrame::GetCharacterPositions(nsTArray<CharacterPosition>* aCharacterPo
       dyList.Length() <= 1 &&
       rotateList.IsEmpty()) {
     // simple text without individual positioning
-    return PR_TRUE;
+    return true;
   }
 
   if (!aCharacterPositions->SetLength(strLength))
-    return PR_FALSE;
+    return false;
 
   CharacterPosition *cp = aCharacterPositions->Elements();
 
   PRUint16 anchor = GetTextAnchor();
 
   for (PRUint32 i = 0; i < strLength; i++) {
-    cp[i].draw = PR_TRUE;
+    cp[i].draw = true;
 
     gfxFloat advance = mTextRun->GetAdvanceWidth(i, 1, nsnull)*aMetricsScale;
     if (xList.Length() > 1 && i < xList.Length()) {
@@ -802,7 +832,7 @@ nsSVGGlyphFrame::GetCharacterPositions(nsTArray<CharacterPosition>* aCharacterPo
     }
     cp[i].angle = angle;
   }
-  return PR_TRUE;
+  return true;
 }
 
 PRUint32
@@ -954,7 +984,7 @@ nsSVGGlyphFrame::GetHighlight(PRUint32 *charnum, PRUint32 *nchars,
   *charnum=0;
   *nchars=0;
 
-  PRBool hasHighlight =
+  bool hasHighlight =
     (mState & NS_FRAME_SELECTED_CONTENT) == NS_FRAME_SELECTED_CONTENT;
 
   if (!hasHighlight) {
@@ -972,27 +1002,14 @@ nsSVGGlyphFrame::GetHighlight(PRUint32 *charnum, PRUint32 *nchars,
   // get the selection details 
   SelectionDetails *details = nsnull;
   {
-    nsCOMPtr<nsFrameSelection> frameSelection;
-    {
-      nsCOMPtr<nsISelectionController> controller;
-      GetSelectionController(presContext, getter_AddRefs(controller));
-      
-      if (!controller) {
-        NS_ERROR("no selection controller");
-        return NS_ERROR_FAILURE;
-      }
-      frameSelection = do_QueryInterface(controller);
-    }
-    if (!frameSelection) {
-      frameSelection = presContext->PresShell()->FrameSelection();
-    }
+    nsRefPtr<nsFrameSelection> frameSelection = presContext->PresShell()->FrameSelection();
     if (!frameSelection) {
       NS_ERROR("no frameselection interface");
       return NS_ERROR_FAILURE;
     }
 
     details = frameSelection->LookUpSelection(
-      mContent, 0, fragment->GetLength(), PR_FALSE
+      mContent, 0, fragment->GetLength(), false
       );
   }
 
@@ -1017,11 +1034,11 @@ nsSVGGlyphFrame::GetHighlight(PRUint32 *charnum, PRUint32 *nchars,
 
     *charnum=CompressIndex(details->mStart, fragment);
     *nchars=CompressIndex(details->mEnd, fragment)-*charnum;  
-    
-    nsILookAndFeel *look = presContext->LookAndFeel();
 
-    look->GetColor(nsILookAndFeel::eColor_TextSelectBackground, *background);
-    look->GetColor(nsILookAndFeel::eColor_TextSelectForeground, *foreground);
+    LookAndFeel::GetColor(LookAndFeel::eColorID_TextSelectBackground,
+                          background);
+    LookAndFeel::GetColor(LookAndFeel::eColorID_TextSelectForeground,
+                          foreground);
 
     SelectionDetails *dp = details;
     while ((dp=details->mNext) != nsnull) {
@@ -1036,17 +1053,17 @@ nsSVGGlyphFrame::GetHighlight(PRUint32 *charnum, PRUint32 *nchars,
 
 
 //----------------------------------------------------------------------
-// nsISVGGlyphFragmentLeaf interface:
+// Internal methods
 
-NS_IMETHODIMP_(void)
-nsSVGGlyphFrame::SetGlyphPosition(gfxPoint *aPosition, PRBool aForceGlobalTransform)
+void
+nsSVGGlyphFrame::SetGlyphPosition(gfxPoint *aPosition, bool aForceGlobalTransform)
 {
   float drawScale, metricsScale;
 
   nsSVGTextPathFrame *textPath = FindTextPathParent();
   // In a textPath, the 'y' attribute has no effect, so we reset 'y' here
   // to use aPosition.y for dy only
-  if (textPath && textPath->GetFirstChild(nsnull) == this) {
+  if (textPath && textPath->GetFirstPrincipalChild() == this) {
     aPosition->y = 0.0;
   }
 
@@ -1080,7 +1097,7 @@ nsSVGGlyphFrame::SetGlyphPosition(gfxPoint *aPosition, PRBool aForceGlobalTransf
   }
 
   gfxFloat y = (textPath || yCount <= 1) ? aPosition->y : yList[yCount - 1];
-  aPosition->MoveTo(x, y - GetBaselineOffset(metricsScale));
+  aPosition->MoveTo(x, y);
 
   gfxFloat pathScale = 1.0;
   if (textPath)
@@ -1105,13 +1122,13 @@ nsSVGGlyphFrame::SetGlyphPosition(gfxPoint *aPosition, PRBool aForceGlobalTransf
   }
 }
 
-NS_IMETHODIMP
+nsresult
 nsSVGGlyphFrame::GetStartPositionOfChar(PRUint32 charnum,
                                         nsIDOMSVGPoint **_retval)
 {
   *_retval = nsnull;
 
-  CharacterIterator iter(this, PR_FALSE);
+  CharacterIterator iter(this, false);
   if (!iter.AdvanceToCharacter(charnum))
     return NS_ERROR_DOM_INDEX_SIZE_ERR;
 
@@ -1119,13 +1136,13 @@ nsSVGGlyphFrame::GetStartPositionOfChar(PRUint32 charnum,
   return NS_OK;
 }
 
-NS_IMETHODIMP
+nsresult
 nsSVGGlyphFrame::GetEndPositionOfChar(PRUint32 charnum,
                                       nsIDOMSVGPoint **_retval)
 {
   *_retval = nsnull;
 
-  CharacterIterator iter(this, PR_FALSE);
+  CharacterIterator iter(this, false);
   if (!iter.AdvanceToCharacter(charnum))
     return NS_ERROR_DOM_INDEX_SIZE_ERR;
 
@@ -1137,12 +1154,12 @@ nsSVGGlyphFrame::GetEndPositionOfChar(PRUint32 charnum,
   return NS_OK;
 }
 
-NS_IMETHODIMP
+nsresult
 nsSVGGlyphFrame::GetExtentOfChar(PRUint32 charnum, nsIDOMSVGRect **_retval)
 {
   *_retval = nsnull;
 
-  CharacterIterator iter(this, PR_FALSE);
+  CharacterIterator iter(this, false);
   if (!iter.AdvanceToCharacter(0))
     return NS_ERROR_DOM_INDEX_SIZE_ERR;
 
@@ -1170,10 +1187,10 @@ nsSVGGlyphFrame::GetExtentOfChar(PRUint32 charnum, nsIDOMSVGRect **_retval)
   return NS_NewSVGRect(_retval, tmpCtx->GetUserPathExtent());
 }
 
-NS_IMETHODIMP
+nsresult
 nsSVGGlyphFrame::GetRotationOfChar(PRUint32 charnum, float *_retval)
 {
-  CharacterIterator iter(this, PR_FALSE);
+  CharacterIterator iter(this, false);
   if (!iter.AdvanceToCharacter(charnum))
     return NS_ERROR_DOM_INDEX_SIZE_ERR;
 
@@ -1186,8 +1203,8 @@ nsSVGGlyphFrame::GetRotationOfChar(PRUint32 charnum, float *_retval)
   return NS_OK;
 }
 
-NS_IMETHODIMP_(float)
-nsSVGGlyphFrame::GetAdvance(PRBool aForceGlobalTransform)
+float
+nsSVGGlyphFrame::GetAdvance(bool aForceGlobalTransform)
 {
   float drawScale, metricsScale;
   if (!EnsureTextRun(&drawScale, &metricsScale, aForceGlobalTransform))
@@ -1196,7 +1213,7 @@ nsSVGGlyphFrame::GetAdvance(PRBool aForceGlobalTransform)
   return GetSubStringAdvance(0, mTextRun->GetLength(), metricsScale);
 }
 
-NS_IMETHODIMP_(nsSVGTextPathFrame*) 
+nsSVGTextPathFrame*
 nsSVGGlyphFrame::FindTextPathParent()
 {
   /* check if we're the child of a textPath */
@@ -1212,29 +1229,29 @@ nsSVGGlyphFrame::FindTextPathParent()
   return nsnull;
 }
 
-NS_IMETHODIMP_(PRBool)
+bool
 nsSVGGlyphFrame::IsStartOfChunk()
 {
   // this fragment is a chunk if it has a corresponding absolute
   // position adjustment in an ancestors' x or y array. (At the moment
   // we don't map the full arrays, but only the first elements.)
 
-  return PR_FALSE;
+  return false;
 }
 
-NS_IMETHODIMP_(void)
+void
 nsSVGGlyphFrame::GetXY(SVGUserUnitList *aX, SVGUserUnitList *aY)
 {
   static_cast<nsSVGTextContainerFrame *>(mParent)->GetXY(aX, aY);
 }
 
-NS_IMETHODIMP_(void)
+void
 nsSVGGlyphFrame::SetStartIndex(PRUint32 aStartIndex)
 {
   mStartIndex = aStartIndex;
 }
 
-NS_IMETHODIMP_(void)
+void
 nsSVGGlyphFrame::GetEffectiveXY(PRInt32 strLength, nsTArray<float> &aX, nsTArray<float> &aY)
 {
   nsTArray<float> x, y;
@@ -1296,16 +1313,16 @@ nsSVGGlyphFrame::GetEffectiveRotate(PRInt32 strLength, nsTArray<float> &aRotate)
   }
 }
 
-NS_IMETHODIMP_(PRUint16)
+PRUint16
 nsSVGGlyphFrame::GetTextAnchor()
 {
   return GetStyleSVG()->mTextAnchor;
 }
 
-NS_IMETHODIMP_(PRBool)
+bool
 nsSVGGlyphFrame::IsAbsolutelyPositioned()
 {
-  PRBool hasTextPathAncestor = PR_FALSE;
+  bool hasTextPathAncestor = false;
   for (nsIFrame *frame = GetParent();
        frame != nsnull;
        frame = frame->GetParent()) {
@@ -1313,12 +1330,12 @@ nsSVGGlyphFrame::IsAbsolutelyPositioned()
     // at the start of a 'text' element
     // at the start of each 'textPath' element
     if (frame->GetType() == nsGkAtoms::svgTextPathFrame) {
-      hasTextPathAncestor = PR_TRUE;
+      hasTextPathAncestor = true;
     }
     if ((frame->GetType() == nsGkAtoms::svgTextFrame ||
          frame->GetType() == nsGkAtoms::svgTextPathFrame) &&
-        frame->GetFirstChild(nsnull) == this) {
-        return PR_TRUE;
+        frame->GetFirstPrincipalChild() == this) {
+        return true;
     }
 
     if (frame->GetType() == nsGkAtoms::svgTextFrame)
@@ -1340,25 +1357,26 @@ nsSVGGlyphFrame::IsAbsolutelyPositioned()
 PRUint32
 nsSVGGlyphFrame::GetNumberOfChars()
 {
-  if (mWhitespaceHandling == PRESERVE_WHITESPACE)
-    return mContent->TextLength();
+  if (mCompressWhitespace) {
+    nsAutoString text;
+    GetCharacterData(text);
+    return text.Length();
+  }
 
-  nsAutoString text;
-  GetCharacterData(text);
-  return text.Length();
+  return mContent->TextLength();
 }
 
 float
 nsSVGGlyphFrame::GetComputedTextLength()
 {
-  return GetAdvance(PR_FALSE);
+  return GetAdvance(false);
 }
 
 float
 nsSVGGlyphFrame::GetSubStringLength(PRUint32 charnum, PRUint32 fragmentChars)
 {
   float drawScale, metricsScale;
-  if (!EnsureTextRun(&drawScale, &metricsScale, PR_FALSE))
+  if (!EnsureTextRun(&drawScale, &metricsScale, false))
     return 0.0f;
 
   return GetSubStringAdvance(charnum, fragmentChars, metricsScale);
@@ -1372,13 +1390,13 @@ nsSVGGlyphFrame::GetCharNumAtPosition(nsIDOMSVGPoint *point)
   point->GetY(&yPos);
 
   nsRefPtr<gfxContext> tmpCtx = MakeTmpCtx();
-  CharacterIterator iter(this, PR_FALSE);
+  CharacterIterator iter(this, false);
 
-  PRInt32 i;
+  PRUint32 i;
   PRInt32 last = -1;
   gfxPoint pt(xPos, yPos);
-  while ((i = iter.NextCluster()) >= 0) {
-    PRInt32 limit = i + iter.ClusterLength();
+  while ((i = iter.NextCluster()) != iter.InvalidCluster()) {
+    PRUint32 limit = i + iter.ClusterLength();
     gfxTextRun::Metrics metrics =
       mTextRun->MeasureText(i, limit - i, gfxFont::LOOSE_INK_EXTENTS,
                             nsnull, nsnull);
@@ -1418,20 +1436,24 @@ nsSVGGlyphFrame::GetCharNumAtPosition(nsIDOMSVGPoint *point)
   return last;
 }
 
-NS_IMETHODIMP_(nsISVGGlyphFragmentLeaf *)
-nsSVGGlyphFrame::GetFirstGlyphFragment()
+NS_IMETHODIMP_(nsSVGGlyphFrame *)
+nsSVGGlyphFrame::GetFirstGlyphFrame()
 {
-  return this;
+  nsSVGGlyphFrame *frame = this;
+  while (frame && frame->IsTextEmpty()) {
+    frame = frame->GetNextGlyphFrame();
+  }
+  return frame;
 }
 
-NS_IMETHODIMP_(nsISVGGlyphFragmentLeaf *)
-nsSVGGlyphFrame::GetNextGlyphFragment()
+NS_IMETHODIMP_(nsSVGGlyphFrame *)
+nsSVGGlyphFrame::GetNextGlyphFrame()
 {
   nsIFrame* sibling = GetNextSibling();
   while (sibling) {
     nsISVGGlyphFragmentNode *node = do_QueryFrame(sibling);
     if (node)
-      return node->GetFirstGlyphFragment();
+      return node->GetFirstGlyphFrame();
     sibling = sibling->GetNextSibling();
   }
 
@@ -1439,29 +1461,32 @@ nsSVGGlyphFrame::GetNextGlyphFragment()
   
   NS_ASSERTION(GetParent(), "null parent");
   nsISVGGlyphFragmentNode *node = do_QueryFrame(GetParent());
-  return node ? node->GetNextGlyphFragment() : nsnull;
+  return node ? node->GetNextGlyphFrame() : nsnull;
 }
 
-NS_IMETHODIMP_(void)
-nsSVGGlyphFrame::SetWhitespaceHandling(PRUint8 aWhitespaceHandling)
+bool
+nsSVGGlyphFrame::EndsWithWhitespace() const
 {
-  mWhitespaceHandling = aWhitespaceHandling;
+  const nsTextFragment* text = mContent->GetText();
+  NS_ABORT_IF_FALSE(text->GetLength() > 0, "text expected");
+
+  return NS_IsAsciiWhitespace(text->CharAt(text->GetLength() - 1));
 }
 
-NS_IMETHODIMP_(PRBool)
-nsSVGGlyphFrame::IsAllWhitespace()
+bool
+nsSVGGlyphFrame::IsAllWhitespace() const
 {
   const nsTextFragment* text = mContent->GetText();
 
   if (text->Is2b())
-    return PR_FALSE;
+    return false;
   PRInt32 len = text->GetLength();
   const char* str = text->Get1b();
   for (PRInt32 i = 0; i < len; ++i) {
     if (!NS_IsAsciiWhitespace(str[i]))
-      return PR_FALSE;
+      return false;
   }
-  return PR_TRUE;
+  return true;
 }
 
 //----------------------------------------------------------------------
@@ -1476,12 +1501,12 @@ nsSVGGlyphFrame::NotifyGlyphMetricsChange()
     containerFrame->NotifyGlyphMetricsChange();
 }
 
-PRBool
+bool
 nsSVGGlyphFrame::GetGlobalTransform(gfxMatrix *aMatrix)
 {
-  if (!GetMatrixPropagation()) {
+  if (!mPropagateTransform) {
     aMatrix->Reset();
-    return PR_TRUE;
+    return true;
   }
 
   *aMatrix = GetCanvasTM();
@@ -1508,9 +1533,9 @@ nsSVGGlyphFrame::ClearTextRun()
   mTextRun = nsnull;
 }
 
-PRBool
+bool
 nsSVGGlyphFrame::EnsureTextRun(float *aDrawScale, float *aMetricsScale,
-                               PRBool aForceGlobalTransform)
+                               bool aForceGlobalTransform)
 {
   // Compute the size at which the text should render (excluding the CTM)
   const nsStyleFont* fontData = GetStyleFont();
@@ -1528,57 +1553,54 @@ nsSVGGlyphFrame::EnsureTextRun(float *aDrawScale, float *aMetricsScale,
   } else {
     nsAutoString text;
     if (!GetCharacterData(text))
-      return PR_FALSE;
+      return false;
 
-    nsBidiPresUtils* bidiUtils = presContext->GetBidiUtils();
-    if (bidiUtils) {
-      nsAutoString visualText;
-
-      /*
-       * XXXsmontagu: The SVG spec says:
-       *
-       * http://www.w3.org/TR/SVG11/text.html#DirectionProperty
-       *  "For the 'direction' property to have any effect, the 'unicode-bidi'
-       *   property's value must be embed or bidi-override."
-       *
-       * The SVGTiny spec, on the other hand, says 
-       *
-       * http://www.w3.org/TR/SVGTiny12/text.html#DirectionProperty
-       *  "For the 'direction' property to have any effect on an element that 
-       *   does not by itself establish a new text chunk (such as the 'tspan'
-       *   element in SVG 1.2 Tiny), the 'unicode-bidi' property's value must
-       *   be embed or bidi-override."
-       *
-       * Note that this is different from HTML/CSS, where setting the 'dir'
-       *  attribute on an inline element automatically sets unicode-bidi: embed
-       *
-       * Our current implementation of bidi in SVG does not distinguish between
-       * different text elements, but treats every text container frame as a
-       * new text chunk, so we always set the base direction according to the
-       * direction property
-       *
-       * See also XXXsmontagu comments in nsSVGTextFrame::UpdateGlyphPositioning
-       */
-        
-      // Get the unicodeBidi property from the parent, because it doesn't
-      // inherit
-      PRBool bidiOverride = (mParent->GetStyleTextReset()->mUnicodeBidi ==
-                             NS_STYLE_UNICODE_BIDI_OVERRIDE);
-      nsBidiLevel baseDirection =
-        GetStyleVisibility()->mDirection == NS_STYLE_DIRECTION_RTL ?
-          NSBIDI_RTL : NSBIDI_LTR;
-      bidiUtils->CopyLogicalToVisual(text, visualText,
-                                     baseDirection, bidiOverride);
-      if (!visualText.IsEmpty()) {
-        text = visualText;
-      }
+    nsAutoString visualText;
+      
+    /*
+     * XXXsmontagu: The SVG spec says:
+     *
+     * http://www.w3.org/TR/SVG11/text.html#DirectionProperty
+     *  "For the 'direction' property to have any effect, the 'unicode-bidi'
+     *   property's value must be embed or bidi-override."
+     *
+     * The SVGTiny spec, on the other hand, says 
+     *
+     * http://www.w3.org/TR/SVGTiny12/text.html#DirectionProperty
+     *  "For the 'direction' property to have any effect on an element that 
+     *   does not by itself establish a new text chunk (such as the 'tspan'
+     *   element in SVG 1.2 Tiny), the 'unicode-bidi' property's value must
+     *   be embed or bidi-override."
+     *
+     * Note that this is different from HTML/CSS, where setting the 'dir'
+     *  attribute on an inline element automatically sets unicode-bidi: embed
+     *
+     * Our current implementation of bidi in SVG does not distinguish between
+     * different text elements, but treats every text container frame as a
+     * new text chunk, so we always set the base direction according to the
+     * direction property
+     *
+     * See also XXXsmontagu comments in nsSVGTextFrame::UpdateGlyphPositioning
+     */
+    
+    // Get the unicodeBidi property from the parent, because it doesn't
+    // inherit
+    bool bidiOverride = !!(mParent->GetStyleTextReset()->mUnicodeBidi &
+                           NS_STYLE_UNICODE_BIDI_OVERRIDE);
+    nsBidiLevel baseDirection =
+      GetStyleVisibility()->mDirection == NS_STYLE_DIRECTION_RTL ?
+        NSBIDI_RTL : NSBIDI_LTR;
+    nsBidiPresUtils::CopyLogicalToVisual(text, visualText,
+                                         baseDirection, bidiOverride);
+    if (!visualText.IsEmpty()) {
+      text = visualText;
     }
 
     gfxMatrix m;
     if (aForceGlobalTransform ||
         !(GetStateBits() & NS_STATE_SVG_NONDISPLAY_CHILD)) {
       if (!GetGlobalTransform(&m))
-        return PR_FALSE;
+        return false;
     }
 
     // The context scale is the ratio of the length of the transformed
@@ -1597,7 +1619,7 @@ nsSVGGlyphFrame::EnsureTextRun(float *aDrawScale, float *aMetricsScale,
     }
 
     const nsFont& font = fontData->mFont;
-    PRBool printerFont = (presContext->Type() == nsPresContext::eContext_PrintPreview ||
+    bool printerFont = (presContext->Type() == nsPresContext::eContext_PrintPreview ||
                           presContext->Type() == nsPresContext::eContext_Print);
     gfxFontStyle fontStyle(font.style, font.weight, font.stretch, textRunSize,
                            mStyleContext->GetStyleVisibility()->mLanguage,
@@ -1630,81 +1652,66 @@ nsSVGGlyphFrame::EnsureTextRun(float *aDrawScale, float *aMetricsScale,
     mTextRun = gfxTextRunWordCache::MakeTextRun(text.get(), text.Length(),
       fontGroup, &params, flags);
     if (!mTextRun)
-      return PR_FALSE;
+      return false;
   }
 
   *aDrawScale = float(size/textRunSize);
   *aMetricsScale = (*aDrawScale)/GetTextRunUnitsFactor();
-  return PR_TRUE;
-}
-
-NS_IMETHODIMP
-nsSVGGlyphFrame::SetMatrixPropagation(PRBool aPropagate)
-{
-  if (aPropagate) {
-    AddStateBits(NS_STATE_SVG_PROPAGATE_TRANSFORM);
-  } else {
-    RemoveStateBits(NS_STATE_SVG_PROPAGATE_TRANSFORM);
-  }
-  return NS_OK;
-}
-
-PRBool
-nsSVGGlyphFrame::GetMatrixPropagation()
-{
-  return (GetStateBits() & NS_STATE_SVG_PROPAGATE_TRANSFORM) != 0;
+  return true;
 }
 
 //----------------------------------------------------------------------
 // helper class
 
 CharacterIterator::CharacterIterator(nsSVGGlyphFrame *aSource,
-        PRBool aForceGlobalTransform)
-  : mSource(aSource), mCurrentAdvance(0), mCurrentChar(-1),
-    mInError(PR_FALSE)
+        bool aForceGlobalTransform)
+  : mSource(aSource)
+  , mCurrentAdvance(0)
+  , mCurrentChar(PRUint32(-1))
+  , mInError(false)
 {
   if (!aSource->EnsureTextRun(&mDrawScale, &mMetricsScale,
                               aForceGlobalTransform) ||
       !aSource->GetCharacterPositions(&mPositions, mMetricsScale)) {
-    mInError = PR_TRUE;
+    mInError = true;
   }
 }
 
-PRBool
+bool
 CharacterIterator::SetupForDirectTextRun(gfxContext *aContext, float aScale)
 {
   if (!mPositions.IsEmpty() || mInError)
-    return PR_FALSE;
+    return false;
   aContext->SetMatrix(mInitialMatrix);
   aContext->Translate(mSource->mPosition);
   aContext->Scale(aScale, aScale);
-  return PR_TRUE;
+  return true;
 }
 
-PRInt32
+PRUint32
 CharacterIterator::NextCluster()
 {
   if (mInError) {
 #ifdef DEBUG
-    if (mCurrentChar != -1) {
-      PRBool pastEnd = (mCurrentChar >= PRInt32(mSource->mTextRun->GetLength()));
+    if (mCurrentChar != InvalidCluster()) {
+      bool pastEnd = (mCurrentChar >= mSource->mTextRun->GetLength());
       NS_ABORT_IF_FALSE(pastEnd, "Past the end of CharacterIterator. Missing Reset?");
     }
 #endif
-    return -1;
+    return InvalidCluster();
   }
 
-  while (PR_TRUE) {
-    if (mCurrentChar >= 0 &&
+  while (true) {
+    if (mCurrentChar != InvalidCluster() &&
         (mPositions.IsEmpty() || mPositions[mCurrentChar].draw)) {
       mCurrentAdvance +=
         mSource->mTextRun->GetAdvanceWidth(mCurrentChar, 1, nsnull);
     }
     ++mCurrentChar;
 
-    if (mCurrentChar >= PRInt32(mSource->mTextRun->GetLength())) {
-      mInError = PR_TRUE;
-      return -1;
+    if (mCurrentChar >= mSource->mTextRun->GetLength()) {
+      mInError = true;
+      return InvalidCluster();
     }
 
     if (mSource->mTextRun->IsClusterStart(mCurrentChar) &&
@@ -1714,14 +1721,14 @@ CharacterIterator::NextCluster()
   }
 }
 
-PRInt32
+PRUint32
 CharacterIterator::ClusterLength()
 {
   if (mInError) {
     return 0;
   }
 
-  PRInt32 i = mCurrentChar;
+  PRUint32 i = mCurrentChar;
   while (++i < mSource->mTextRun->GetLength()) {
     if (mSource->mTextRun->IsClusterStart(i)) {
       break;
@@ -1730,14 +1737,14 @@ CharacterIterator::ClusterLength()
   return i - mCurrentChar;
 }
 
-PRBool
-CharacterIterator::AdvanceToCharacter(PRInt32 aIndex)
+bool
+CharacterIterator::AdvanceToCharacter(PRUint32 aIndex)
 {
-  while (NextCluster() != -1) {
+  while (NextCluster() != InvalidCluster()) {
     if (mCurrentChar == aIndex)
-      return PR_TRUE;
+      return true;
   }
-  return PR_FALSE;
+  return false;
 }
 
 void
@@ -1765,6 +1772,6 @@ CharacterIterator::GetPositionData()
 
   gfxFloat advance = mCurrentAdvance * mMetricsScale;
   CharacterPosition cp =
-    { mSource->mPosition + gfxPoint(advance, 0), 0, PR_TRUE };
+    { mSource->mPosition + gfxPoint(advance, 0), 0, true };
   return cp;
 }
