@@ -142,11 +142,11 @@ nsSVGOuterSVGFrame::nsSVGOuterSVGFrame(nsStyleContext* aContext)
     : nsSVGOuterSVGFrameBase(aContext)
     ,  mRedrawSuspendCount(0)
     , mFullZoom(0)
-    , mViewportInitialized(PR_FALSE)
+    , mViewportInitialized(false)
 #ifdef XP_MACOSX
-    , mEnableBitmapFallback(PR_FALSE)
+    , mEnableBitmapFallback(false)
 #endif
-    , mIsRootContent(PR_FALSE)
+    , mIsRootContent(false)
 {
 }
 
@@ -175,7 +175,7 @@ nsSVGOuterSVGFrame::Init(nsIContent* aContent,
   if (doc) {
     // we only care about our content's zoom and pan values if it's the root element
     if (doc->GetRootElement() == mContent) {
-      mIsRootContent = PR_TRUE;
+      mIsRootContent = true;
     }
     // sSVGMutationObserver has the same lifetime as the document so does
     // not need to be removed
@@ -315,7 +315,7 @@ nsSVGOuterSVGFrame::GetIntrinsicRatio()
 nsSVGOuterSVGFrame::ComputeSize(nsRenderingContext *aRenderingContext,
                                 nsSize aCBSize, nscoord aAvailableWidth,
                                 nsSize aMargin, nsSize aBorder, nsSize aPadding,
-                                PRBool aShrinkWrap)
+                                bool aShrinkWrap)
 {
   nsSVGSVGElement* content = static_cast<nsSVGSVGElement*>(mContent);
 
@@ -372,7 +372,7 @@ nsSVGOuterSVGFrame::Reflow(nsPresContext*           aPresContext,
   if (newViewportSize != svgElem->GetViewportSize() ||
       mFullZoom != PresContext()->GetFullZoom()) {
     svgElem->SetViewportSize(newViewportSize);
-    mViewportInitialized = PR_TRUE;
+    mViewportInitialized = true;
     mFullZoom = PresContext()->GetFullZoom();
     NotifyViewportChange();
   }
@@ -397,7 +397,7 @@ nsSVGOuterSVGFrame::DidReflow(nsPresContext*   aPresContext,
                               const nsHTMLReflowState*  aReflowState,
                               nsDidReflowStatus aStatus)
 {
-  PRBool firstReflow = (GetStateBits() & NS_FRAME_FIRST_REFLOW) != 0;
+  bool firstReflow = (GetStateBits() & NS_FRAME_FIRST_REFLOW) != 0;
 
   nsresult rv = nsSVGOuterSVGFrameBase::DidReflow(aPresContext,aReflowState,aStatus);
 
@@ -482,7 +482,7 @@ nsDisplaySVG::Paint(nsDisplayListBuilder* aBuilder,
 }
 
 // helper
-static inline PRBool
+static inline bool
 DependsOnIntrinsicSize(const nsIFrame* aEmbeddingFrame)
 {
   const nsStylePosition *pos = aEmbeddingFrame->GetStylePosition();
@@ -502,22 +502,36 @@ nsSVGOuterSVGFrame::AttributeChanged(PRInt32  aNameSpaceID,
                                      PRInt32  aModType)
 {
   if (aNameSpaceID == kNameSpaceID_None &&
-      !(GetStateBits() & NS_FRAME_FIRST_REFLOW) &&
-      (aAttribute == nsGkAtoms::width || aAttribute == nsGkAtoms::height)) {
-    nsIFrame* embeddingFrame;
-    if (IsRootOfReplacedElementSubDoc(&embeddingFrame) && embeddingFrame) {
-      if (DependsOnIntrinsicSize(embeddingFrame)) {
-        // Tell embeddingFrame's presShell it needs to be reflowed (which takes
-        // care of reflowing us too).
-        embeddingFrame->PresContext()->PresShell()->
-          FrameNeedsReflow(embeddingFrame, nsIPresShell::eStyleChange, NS_FRAME_IS_DIRTY);
-      }
-      // else our width and height is overridden - don't reflow anything
-    } else {
-      // We are not embedded by reference, so our 'width' and 'height'
-      // attributes are not overridden - we need to reflow.
-      PresContext()->PresShell()->
-        FrameNeedsReflow(this, nsIPresShell::eStyleChange, NS_FRAME_IS_DIRTY);
+      !(GetStateBits() & NS_FRAME_FIRST_REFLOW)) {
+    if (aAttribute == nsGkAtoms::viewBox ||
+        aAttribute == nsGkAtoms::preserveAspectRatio ||
+        aAttribute == nsGkAtoms::transform) {
+
+      // make sure our cached transform matrix gets (lazily) updated
+      mCanvasTM = nsnull;
+
+      nsSVGUtils::NotifyChildrenOfSVGChange(
+          this, aAttribute == nsGkAtoms::viewBox ?
+                  TRANSFORM_CHANGED | COORD_CONTEXT_CHANGED : TRANSFORM_CHANGED);
+
+    } else if (aAttribute == nsGkAtoms::width ||
+               aAttribute == nsGkAtoms::height) {
+
+        nsIFrame* embeddingFrame;
+        if (IsRootOfReplacedElementSubDoc(&embeddingFrame) && embeddingFrame) {
+          if (DependsOnIntrinsicSize(embeddingFrame)) {
+            // Tell embeddingFrame's presShell it needs to be reflowed (which takes
+            // care of reflowing us too).
+            embeddingFrame->PresContext()->PresShell()->
+              FrameNeedsReflow(embeddingFrame, nsIPresShell::eStyleChange, NS_FRAME_IS_DIRTY);
+          }
+          // else our width and height is overridden - don't reflow anything
+        } else {
+          // We are not embedded by reference, so our 'width' and 'height'
+          // attributes are not overridden - we need to reflow.
+          PresContext()->PresShell()->
+            FrameNeedsReflow(this, nsIPresShell::eStyleChange, NS_FRAME_IS_DIRTY);
+        }
     }
   }
 
@@ -566,7 +580,7 @@ nsSVGOuterSVGFrame::Paint(const nsDisplayListBuilder* aBuilder,
   nsSVGRenderState ctx(&aRenderingContext);
 
   if (aBuilder->IsPaintingToWindow()) {
-    ctx.SetPaintingToWindow(PR_TRUE);
+    ctx.SetPaintingToWindow(true);
   }
 
 #ifdef XP_MACOSX
@@ -587,7 +601,7 @@ nsSVGOuterSVGFrame::Paint(const nsDisplayListBuilder* aBuilder,
   }
   
   if (ctx.GetGfxContext()->HasError() && !mEnableBitmapFallback) {
-    mEnableBitmapFallback = PR_TRUE;
+    mEnableBitmapFallback = true;
     // It's not really clear what area to invalidate here. We might have
     // stuffed up rendering for the entire window in this paint pass,
     // so we can't just invalidate our own rect. Invalidate everything
@@ -597,7 +611,7 @@ nsSVGOuterSVGFrame::Paint(const nsDisplayListBuilder* aBuilder,
     // documents. Better to fix things so we don't need fallback.
     nsIFrame* frame = this;
     PRUint32 flags = 0;
-    while (PR_TRUE) {
+    while (true) {
       nsIFrame* next = nsLayoutUtils::GetCrossDocParentFrame(frame);
       if (!next)
         break;
@@ -648,25 +662,25 @@ nsSVGOuterSVGFrame::InvalidateCoveredRegion(nsIFrame *aFrame)
   Invalidate(rect);
 }
 
-PRBool
+bool
 nsSVGOuterSVGFrame::UpdateAndInvalidateCoveredRegion(nsIFrame *aFrame)
 {
   nsISVGChildFrame *svgFrame = do_QueryFrame(aFrame);
   if (!svgFrame)
-    return PR_FALSE;
+    return false;
 
   nsRect oldRegion = svgFrame->GetCoveredRegion();
   Invalidate(nsSVGUtils::FindFilterInvalidation(aFrame, oldRegion));
   svgFrame->UpdateCoveredRegion();
   nsRect newRegion = svgFrame->GetCoveredRegion();
   if (oldRegion.IsEqualInterior(newRegion))
-    return PR_FALSE;
+    return false;
 
   Invalidate(nsSVGUtils::FindFilterInvalidation(aFrame, newRegion));
-  return PR_TRUE;
+  return true;
 }
 
-PRBool
+bool
 nsSVGOuterSVGFrame::IsRedrawSuspended()
 {
   return (mRedrawSuspendCount>0) || !mViewportInitialized;
@@ -802,7 +816,7 @@ nsSVGOuterSVGFrame::UnregisterForeignObject(nsSVGForeignObjectFrame* aFrame)
   return mForeignObjectHash.RemoveEntry(aFrame);
 }
 
-PRBool
+bool
 nsSVGOuterSVGFrame::IsRootOfReplacedElementSubDoc(nsIFrame **aEmbeddingFrame)
 {
   if (!mContent->GetParent()) {
@@ -821,17 +835,17 @@ nsSVGOuterSVGFrame::IsRootOfReplacedElementSubDoc(nsIFrame **aEmbeddingFrame)
             static_cast<nsGenericElement*>(element.get())->GetPrimaryFrame();
           NS_ASSERTION(*aEmbeddingFrame, "Yikes, no embedding frame!");
         }
-        return PR_TRUE;
+        return true;
       }
     }
   }
   if (aEmbeddingFrame) {
     *aEmbeddingFrame = nsnull;
   }
-  return PR_FALSE;
+  return false;
 }
 
-PRBool
+bool
 nsSVGOuterSVGFrame::IsRootOfImage()
 {
   if (!mContent->GetParent()) {
@@ -839,9 +853,9 @@ nsSVGOuterSVGFrame::IsRootOfImage()
     nsIDocument* doc = mContent->GetCurrentDoc();
     if (doc && doc->IsBeingUsedAsImage()) {
       // Our document is being used as an image
-      return PR_TRUE;
+      return true;
     }
   }
 
-  return PR_FALSE;
+  return false;
 }
