@@ -51,7 +51,6 @@
 #include "nsIDragSession.h"
 #include "nsITimer.h"
 #include "nsIReflowCallback.h"
-#include "nsILookAndFeel.h"
 #include "nsTArray.h"
 #include "nsTreeStyleCache.h"
 #include "nsTreeColumns.h"
@@ -60,8 +59,9 @@
 #include "nsDataHashtable.h"
 #include "imgIRequest.h"
 #include "imgIDecoderObserver.h"
-#include "nsIScrollbarFrame.h"
+#include "nsScrollbarFrame.h"
 #include "nsThreadUtils.h"
+#include "mozilla/LookAndFeel.h"
 
 class nsOverflowChecker;
 
@@ -95,8 +95,8 @@ public:
   nsresult GetColumns(nsITreeColumns **aColumns);
   nsresult GetView(nsITreeView **aView);
   nsresult SetView(nsITreeView *aView);
-  nsresult GetFocused(PRBool *aFocused);
-  nsresult SetFocused(PRBool aFocused);
+  nsresult GetFocused(bool *aFocused);
+  nsresult SetFocused(bool aFocused);
   nsresult GetTreeBody(nsIDOMElement **aElement);
   nsresult GetRowHeight(PRInt32 *aValue);
   nsresult GetRowWidth(PRInt32 *aValue);
@@ -127,7 +127,7 @@ public:
                                 const nsACString &aElt,
                                 PRInt32 *aX, PRInt32 *aY,
                                 PRInt32 *aWidth, PRInt32 *aHeight);
-  nsresult IsCellCropped(PRInt32 aRow, nsITreeColumn *aCol, PRBool *aResult);
+  nsresult IsCellCropped(PRInt32 aRow, nsITreeColumn *aCol, bool *aResult);
   nsresult RowCountChanged(PRInt32 aIndex, PRInt32 aCount);
   nsresult BeginUpdateBatch();
   nsresult EndUpdateBatch();
@@ -136,25 +136,25 @@ public:
   // nsIBox
   virtual nsSize GetMinSize(nsBoxLayoutState& aBoxLayoutState);
   virtual void SetBounds(nsBoxLayoutState& aBoxLayoutState, const nsRect& aRect,
-                         PRBool aRemoveOverflowArea = PR_FALSE);
+                         bool aRemoveOverflowArea = false);
 
   // nsIReflowCallback
-  virtual PRBool ReflowFinished();
+  virtual bool ReflowFinished();
   virtual void ReflowCallbackCanceled();
 
   // nsICSSPseudoComparator
-  NS_IMETHOD PseudoMatches(nsIAtom* aTag, nsCSSSelector* aSelector, PRBool* aResult);
+  virtual bool PseudoMatches(nsCSSSelector* aSelector);
 
   // nsIScrollbarMediator
-  NS_IMETHOD PositionChanged(nsIScrollbarFrame* aScrollbar, PRInt32 aOldIndex, PRInt32& aNewIndex);
-  NS_IMETHOD ScrollbarButtonPressed(nsIScrollbarFrame* aScrollbar, PRInt32 aOldIndex, PRInt32 aNewIndex);
-  NS_IMETHOD VisibilityChanged(PRBool aVisible) { Invalidate(); return NS_OK; }
+  NS_IMETHOD PositionChanged(nsScrollbarFrame* aScrollbar, PRInt32 aOldIndex, PRInt32& aNewIndex);
+  NS_IMETHOD ScrollbarButtonPressed(nsScrollbarFrame* aScrollbar, PRInt32 aOldIndex, PRInt32 aNewIndex);
+  NS_IMETHOD VisibilityChanged(bool aVisible) { Invalidate(); return NS_OK; }
 
   // Overridden from nsIFrame to cache our pres context.
   NS_IMETHOD Init(nsIContent*     aContent,
                   nsIFrame*       aParent,
                   nsIFrame*       aPrevInFlow);
-  virtual void Destroy();
+  virtual void DestroyFrom(nsIFrame* aDestructRoot);
 
   NS_IMETHOD GetCursor(const nsPoint& aPoint,
                        nsIFrame::Cursor& aCursor);
@@ -173,21 +173,21 @@ public:
   friend class nsTreeColumn;
 
   struct ScrollParts {
-    nsIScrollbarFrame*   mVScrollbar;
+    nsScrollbarFrame*    mVScrollbar;
     nsCOMPtr<nsIContent> mVScrollbarContent;
-    nsIScrollbarFrame*   mHScrollbar;
+    nsScrollbarFrame*    mHScrollbar;
     nsCOMPtr<nsIContent> mHScrollbarContent;
     nsIFrame*            mColumnsFrame;
-    nsIScrollableView*   mColumnsScrollableView;
+    nsIScrollableFrame*  mColumnsScrollFrame;
   };
 
-  void PaintTreeBody(nsIRenderingContext& aRenderingContext,
+  void PaintTreeBody(nsRenderingContext& aRenderingContext,
                      const nsRect& aDirtyRect, nsPoint aPt);
 
   nsITreeBoxObject* GetTreeBoxObject() const { return mTreeBoxObject; }
 
-  PRBool GetVerticalOverflow() const { return mVerticalOverflow; }
-  PRBool GetHorizontalOverflow() const {return mHorizontalOverflow; }
+  bool GetVerticalOverflow() const { return mVerticalOverflow; }
+  bool GetHorizontalOverflow() const {return mHorizontalOverflow; }
 
 protected:
   friend class nsOverflowChecker;
@@ -196,14 +196,14 @@ protected:
   void PaintColumn(nsTreeColumn*        aColumn,
                    const nsRect&        aColumnRect,
                    nsPresContext*      aPresContext,
-                   nsIRenderingContext& aRenderingContext,
+                   nsRenderingContext& aRenderingContext,
                    const nsRect&        aDirtyRect);
 
   // This method paints a single row in the tree.
   void PaintRow(PRInt32              aRowIndex,
                 const nsRect&        aRowRect,
                 nsPresContext*       aPresContext,
-                nsIRenderingContext& aRenderingContext,
+                nsRenderingContext& aRenderingContext,
                 const nsRect&        aDirtyRect,
                 nsPoint              aPt);
 
@@ -211,7 +211,7 @@ protected:
   void PaintSeparator(PRInt32              aRowIndex,
                       const nsRect&        aSeparatorRect,
                       nsPresContext*      aPresContext,
-                      nsIRenderingContext& aRenderingContext,
+                      nsRenderingContext& aRenderingContext,
                       const nsRect&        aDirtyRect);
 
   // This method paints a specific cell in a given row of the tree.
@@ -219,7 +219,7 @@ protected:
                  nsTreeColumn*        aColumn,
                  const nsRect&        aCellRect,
                  nsPresContext*       aPresContext,
-                 nsIRenderingContext& aRenderingContext,
+                 nsRenderingContext& aRenderingContext,
                  const nsRect&        aDirtyRect,
                  nscoord&             aCurrX,
                  nsPoint              aPt);
@@ -229,7 +229,7 @@ protected:
                    nsTreeColumn*        aColumn,
                    const nsRect&        aTwistyRect,
                    nsPresContext*      aPresContext,
-                   nsIRenderingContext& aRenderingContext,
+                   nsRenderingContext& aRenderingContext,
                    const nsRect&        aDirtyRect,
                    nscoord&             aRemainingWidth,
                    nscoord&             aCurrX);
@@ -239,7 +239,7 @@ protected:
                   nsTreeColumn*        aColumn,
                   const nsRect&        aImageRect,
                   nsPresContext*      aPresContext,
-                  nsIRenderingContext& aRenderingContext,
+                  nsRenderingContext& aRenderingContext,
                   const nsRect&        aDirtyRect,
                   nscoord&             aRemainingWidth,
                   nscoord&             aCurrX);
@@ -249,17 +249,17 @@ protected:
                  nsTreeColumn*        aColumn,
                  const nsRect&        aTextRect,
                  nsPresContext*      aPresContext,
-                 nsIRenderingContext& aRenderingContext,
+                 nsRenderingContext& aRenderingContext,
                  const nsRect&        aDirtyRect,
                  nscoord&             aCurrX,
-                 PRBool               aTextRTL);
+                 bool                 aTextRTL);
 
   // This method paints the checkbox inside a particular cell of the tree.
   void PaintCheckbox(PRInt32              aRowIndex, 
                      nsTreeColumn*        aColumn,
                      const nsRect&        aCheckboxRect,
                      nsPresContext*      aPresContext,
-                     nsIRenderingContext& aRenderingContext,
+                     nsRenderingContext& aRenderingContext,
                      const nsRect&        aDirtyRect);
 
   // This method paints the progress meter inside a particular cell of the tree.
@@ -267,13 +267,13 @@ protected:
                           nsTreeColumn*        aColumn,
                           const nsRect&        aProgressMeterRect,
                           nsPresContext*      aPresContext,
-                          nsIRenderingContext& aRenderingContext,
+                          nsRenderingContext& aRenderingContext,
                           const nsRect&        aDirtyRect);
 
   // This method paints a drop feedback of the tree.
   void PaintDropFeedback(const nsRect&        aDropFeedbackRect, 
                          nsPresContext*      aPresContext,
-                         nsIRenderingContext& aRenderingContext,
+                         nsRenderingContext& aRenderingContext,
                          const nsRect&        aDirtyRect,
                          nsPoint              aPt);
 
@@ -281,7 +281,7 @@ protected:
   // paint the background rect as if it were a full-blown frame.
   void PaintBackgroundLayer(nsStyleContext*      aStyleContext,
                             nsPresContext*      aPresContext, 
-                            nsIRenderingContext& aRenderingContext, 
+                            nsRenderingContext& aRenderingContext, 
                             const nsRect&        aRect,
                             const nsRect&        aDirtyRect);
 
@@ -300,7 +300,7 @@ protected:
 
   void AdjustForCellText(nsAutoString& aText,
                          PRInt32 aRowIndex,  nsTreeColumn* aColumn,
-                         nsIRenderingContext& aRenderingContext,
+                         nsRenderingContext& aRenderingContext,
                          nsRect& aTextRect);
 
   // A helper used when hit testing.
@@ -318,22 +318,22 @@ protected:
                           nsRect& aImageRect,
                           nsRect& aTwistyRect,
                           nsPresContext* aPresContext,
-                          nsIRenderingContext& aRenderingContext,
+                          nsRenderingContext& aRenderingContext,
                           nsStyleContext* aTwistyContext);
 
   // Fetch an image from the image cache.
-  nsresult GetImage(PRInt32 aRowIndex, nsTreeColumn* aCol, PRBool aUseContext,
-                    nsStyleContext* aStyleContext, PRBool& aAllowImageRegions, imgIContainer** aResult);
+  nsresult GetImage(PRInt32 aRowIndex, nsTreeColumn* aCol, bool aUseContext,
+                    nsStyleContext* aStyleContext, bool& aAllowImageRegions, imgIContainer** aResult);
 
   // Returns the size of a given image.   This size *includes* border and
   // padding.  It does not include margins.
-  nsRect GetImageSize(PRInt32 aRowIndex, nsTreeColumn* aCol, PRBool aUseContext, nsStyleContext* aStyleContext);
+  nsRect GetImageSize(PRInt32 aRowIndex, nsTreeColumn* aCol, bool aUseContext, nsStyleContext* aStyleContext);
 
   // Returns the destination size of the image, not including borders and padding.
-  nsSize GetImageDestSize(nsStyleContext* aStyleContext, PRBool useImageRegion, imgIContainer* image);
+  nsSize GetImageDestSize(nsStyleContext* aStyleContext, bool useImageRegion, imgIContainer* image);
 
   // Returns the source rectangle of the image to be displayed.
-  nsRect GetImageSourceRect(nsStyleContext* aStyleContext, PRBool useImageRegion, imgIContainer* image);
+  nsRect GetImageSourceRect(nsStyleContext* aStyleContext, bool useImageRegion, imgIContainer* image);
 
   // Returns the height of rows in the tree.
   PRInt32 GetRowHeight();
@@ -367,10 +367,10 @@ protected:
   // Check overflow and generate events.
   void CheckOverflow(const ScrollParts& aParts);
 
-  // Calls UpdateScrollbars, Invalidate aNeedsFullInvalidation if PR_TRUE,
+  // Calls UpdateScrollbars, Invalidate aNeedsFullInvalidation if true,
   // InvalidateScrollbars and finally CheckOverflow.
-  // returns PR_TRUE if the frame is still alive after the method call.
-  PRBool FullScrollbarsUpdate(PRBool aNeedsFullInvalidation);
+  // returns true if the frame is still alive after the method call.
+  bool FullScrollbarsUpdate(bool aNeedsFullInvalidation);
 
   // Use to auto-fill some of the common properties without the view having to do it.
   // Examples include container, open, selected, and focus.
@@ -382,13 +382,9 @@ protected:
   nsresult ScrollToColumnInternal(const ScrollParts& aParts, nsITreeColumn* aCol);
   nsresult ScrollHorzInternal(const ScrollParts& aParts, PRInt32 aPosition);
   nsresult EnsureRowIsVisibleInternal(const ScrollParts& aParts, PRInt32 aRow);
-  
-  // Convert client pixels into twips in our coordinate space.
-  void AdjustClientCoordsToBoxCoordSpace(PRInt32 aX, PRInt32 aY,
-                                         nscoord* aResultX, nscoord* aResultY);
 
-  // Convert a border style into line style.
-  nsLineStyle ConvertBorderStyleToLineStyle(PRUint8 aBorderStyle);
+  // Convert client pixels into appunits in our coordinate space.
+  nsPoint AdjustClientCoordsToBoxCoordSpace(PRInt32 aX, PRInt32 aY);
 
   // Cache the box object
   void EnsureBoxObject();
@@ -399,7 +395,7 @@ protected:
   nsIContent* GetBaseElement();
 
   nsresult GetCellWidth(PRInt32 aRow, nsTreeColumn* aCol,
-                        nsIRenderingContext* aRenderingContext,
+                        nsRenderingContext* aRenderingContext,
                         nscoord& aDesiredSize, nscoord& aCurrentSize);
   nscoord CalcMaxRowWidth();
 
@@ -408,9 +404,9 @@ protected:
   // rect to its intersection with mInnerBox in the horizontal direction.
   // Return whether the result has a nonempty intersection with mInnerBox
   // after projecting both onto the horizontal coordinate axis.
-  PRBool OffsetForHorzScroll(nsRect& rect, PRBool clip);
+  bool OffsetForHorzScroll(nsRect& rect, bool clip);
 
-  PRBool CanAutoScroll(PRInt32 aRowIndex);
+  bool CanAutoScroll(PRInt32 aRowIndex);
 
   // Calc the row and above/below/on status given where the mouse currently is hovering.
   // Also calc if we're in the region in which we want to auto-scroll the tree.
@@ -428,6 +424,8 @@ protected:
       InvalidateRow(aRow + aOrientation);
   }
 
+public:
+  static
   already_AddRefed<nsTreeColumn> GetColumnImpl(nsITreeColumn* aUnknownCol) {
     if (!aUnknownCol)
       return nsnull;
@@ -437,11 +435,13 @@ protected:
     return col;
   }
 
+protected:
+
   // Create a new timer. This method is used to delay various actions like
   // opening/closing folders or tree scrolling.
   // aID is type of the action, aFunc is the function to be called when
   // the timer fires and aType is type of timer - one shot or repeating.
-  nsresult CreateTimer(const nsILookAndFeel::nsMetricID aID,
+  nsresult CreateTimer(const mozilla::LookAndFeel::IntID aID,
                        nsTimerCallbackFunc aFunc, PRInt32 aType,
                        nsITimer** aTimer);
 
@@ -511,7 +511,7 @@ protected: // Data Members
 
     protected:
       // If the drop is actually allowed here or not.
-      PRBool                   mDropAllowed;
+      bool                     mDropAllowed;
 
       // The row the mouse is hovering over during a drop.
       PRInt32                  mDropRow;
@@ -593,15 +593,15 @@ protected: // Data Members
   PRInt32 mMouseOverRow;
 
   // Whether or not we're currently focused.
-  PRPackedBool mFocused;
+  bool mFocused;
 
   // Do we have a fixed number of onscreen rows?
-  PRPackedBool mHasFixedRowCount;
+  bool mHasFixedRowCount;
 
-  PRPackedBool mVerticalOverflow;
-  PRPackedBool mHorizontalOverflow;
+  bool mVerticalOverflow;
+  bool mHorizontalOverflow;
 
-  PRPackedBool mReflowCallbackPosted;
+  bool mReflowCallbackPosted;
 }; // class nsTreeBodyFrame
 
 #endif
