@@ -62,9 +62,9 @@
 // static functions declared below are moved from mailnews/mime/src/comi18n.cpp
   
 static char *DecodeQ(const char *, PRUint32);
-static PRBool Is7bitNonAsciiString(const char *, PRUint32);
+static bool Is7bitNonAsciiString(const char *, PRUint32);
 static void CopyRawHeader(const char *, PRUint32, const char *, nsACString &);
-static nsresult DecodeRFC2047Str(const char *, const char *, PRBool, nsACString&);
+static nsresult DecodeRFC2047Str(const char *, const char *, bool, nsACString&);
 
 // XXX The chance of UTF-7 being used in the message header is really
 // low, but in theory it's possible. 
@@ -75,23 +75,47 @@ static nsresult DecodeRFC2047Str(const char *, const char *, PRBool, nsACString&
 
 NS_IMPL_ISUPPORTS1(nsMIMEHeaderParamImpl, nsIMIMEHeaderParam)
 
-// XXX : aTryLocaleCharset is not yet effective.
 NS_IMETHODIMP 
 nsMIMEHeaderParamImpl::GetParameter(const nsACString& aHeaderVal, 
                                     const char *aParamName,
                                     const nsACString& aFallbackCharset, 
-                                    PRBool aTryLocaleCharset, 
+                                    bool aTryLocaleCharset, 
                                     char **aLang, nsAString& aResult)
+{
+  return DoGetParameter(aHeaderVal, aParamName, RFC_2231_DECODING,
+                        aFallbackCharset, aTryLocaleCharset, aLang, aResult);
+}
+
+NS_IMETHODIMP 
+nsMIMEHeaderParamImpl::GetParameter5987(const nsACString& aHeaderVal, 
+                                        const char *aParamName,
+                                        const nsACString& aFallbackCharset, 
+                                        bool aTryLocaleCharset, 
+                                        char **aLang, nsAString& aResult)
+{
+  return DoGetParameter(aHeaderVal, aParamName, RFC_5987_DECODING,
+                        aFallbackCharset, aTryLocaleCharset, aLang, aResult);
+}
+
+// XXX : aTryLocaleCharset is not yet effective.
+nsresult 
+nsMIMEHeaderParamImpl::DoGetParameter(const nsACString& aHeaderVal, 
+                                      const char *aParamName,
+                                      ParamDecoding aDecoding,
+                                      const nsACString& aFallbackCharset, 
+                                      bool aTryLocaleCharset, 
+                                      char **aLang, nsAString& aResult)
 {
     aResult.Truncate();
     nsresult rv;
 
-    // get parameter (decode RFC 2231 if it's RFC 2231-encoded and 
-    // return charset.)
+    // get parameter (decode RFC 2231/5987 when applicable, as specified by
+    // aDecoding (5987 being a subset of 2231) and return charset.)
     nsXPIDLCString med;
     nsXPIDLCString charset;
-    rv = GetParameterInternal(PromiseFlatCString(aHeaderVal).get(), aParamName, 
-                              getter_Copies(charset), aLang, getter_Copies(med));
+    rv = DoParameterInternal(PromiseFlatCString(aHeaderVal).get(), aParamName, 
+                             aDecoding, getter_Copies(charset), aLang, 
+                             getter_Copies(med));
     if (NS_FAILED(rv))
         return rv; 
 
@@ -99,7 +123,7 @@ nsMIMEHeaderParamImpl::GetParameter(const nsACString& aHeaderVal,
     // if necessary.
     
     nsCAutoString str1;
-    rv = DecodeParameter(med, charset.get(), nsnull, PR_FALSE, str1);
+    rv = DecodeParameter(med, charset.get(), nsnull, false, str1);
     NS_ENSURE_SUCCESS(rv, rv);
 
     if (!aFallbackCharset.IsEmpty())
@@ -109,7 +133,7 @@ nsMIMEHeaderParamImpl::GetParameter(const nsACString& aHeaderVal,
           cvtUTF8(do_GetService(NS_UTF8CONVERTERSERVICE_CONTRACTID));
         if (cvtUTF8 &&
             NS_SUCCEEDED(cvtUTF8->ConvertStringToUTF8(str1, 
-                PromiseFlatCString(aFallbackCharset).get(), PR_FALSE, str2))) {
+                PromiseFlatCString(aFallbackCharset).get(), false, str2))) {
           CopyUTF8toUTF16(str2, aResult);
           return NS_OK;
         }
@@ -159,6 +183,20 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
                                             char **aLang,
                                             char **aResult)
 {
+  return DoParameterInternal(aHeaderValue, aParamName, RFC_2231_DECODING,
+                             aCharset, aLang, aResult);
+}
+
+
+nsresult 
+nsMIMEHeaderParamImpl::DoParameterInternal(const char *aHeaderValue, 
+                                           const char *aParamName,
+                                           ParamDecoding aDecoding,
+                                           char **aCharset,
+                                           char **aLang,
+                                           char **aResult)
+{
+
   if (!aHeaderValue ||  !*aHeaderValue || !aResult)
     return NS_ERROR_INVALID_ARG;
 
@@ -215,15 +253,19 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
   //    title*2="Else..."
   // D. title*0="Hey, what you think you are doing?"
   //    title*1="There is no charset and lang info."
-
+  // RFC5987: only A and B
+  
   PRInt32 paramLen = strlen(aParamName);
 
+  bool haveCaseAValue = false;
+  PRInt32 nextContinuation = 0; // next value in series, or -1 if error
+
   while (*str) {
     const char *tokenStart = str;
     const char *tokenEnd = 0;
     const char *valueStart = str;
     const char *valueEnd = 0;
-    PRBool seenEquals = PR_FALSE;
+    bool seenEquals = false;
 
     NS_ASSERTION(!nsCRT::IsAsciiSpace(*str), "should be after whitespace.");
 
@@ -236,11 +278,11 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
     while (nsCRT::IsAsciiSpace(*str)) ++str;
     if (*str == '=') {
       ++str;
-      seenEquals = PR_TRUE;
+      seenEquals = true;
     }
     while (nsCRT::IsAsciiSpace(*str)) ++str;
 
-    PRBool needUnquote = PR_FALSE;
+    bool needUnquote = false;
     
     if (*str != '"')
     {
@@ -255,7 +297,7 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
     else
     {
       // The value is a quoted string.
-      needUnquote = PR_TRUE;
+      needUnquote = true;
       
       ++str;
       valueStart = str;
@@ -276,6 +318,12 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
         seenEquals &&
         !nsCRT::strncasecmp(tokenStart, aParamName, paramLen))
     {
+      if (*aResult)
+      {
+        // either seen earlier caseA value already--we prefer first--or caseA
+        // came after a continuation: either way, prefer other value
+        goto increment_str;
+      }
       // if the parameter spans across multiple lines we have to strip out the
       //     line continuation -- jht 4/29/98 
       nsCAutoString tempStr(valueStart, valueEnd - valueStart);
@@ -288,7 +336,8 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
             
       *aResult = res;
       
-      // keep going, we may find a RFC 2231 encoded alternative
+      haveCaseAValue = true;
+      // keep going, we may find a RFC 2231/5987 encoded alternative
     }
     // case B, C, and D
     else if (tokenEnd - tokenStart > paramLen &&
@@ -296,12 +345,26 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
              seenEquals &&
              *(tokenStart + paramLen) == '*')
     {
-      const char *cp = tokenStart + paramLen + 1; // 1st char pass '*'
-      PRBool needUnescape = *(tokenEnd - 1) == '*';
-      // the 1st line of a multi-line parameter or a single line  that needs 
-      // unescaping. ( title*0*=  or  title*= )
-      if ((*cp == '0' && needUnescape) || (tokenEnd - tokenStart == paramLen + 1))
+      const char *cp = tokenStart + paramLen + 1; // 1st char past '*'
+      bool needUnescape = *(tokenEnd - 1) == '*';
+
+      bool caseB = (tokenEnd - tokenStart) == paramLen + 1;
+      bool caseCorDStart = (*cp == '0') && needUnescape;
+      bool acceptContinuations = (aDecoding != RFC_5987_DECODING);
+ 
+      // CaseB and start of CaseC: requires charset and optional language
+      // in quotes (quotes required even if lang is blank)
+      if (caseB || (caseCorDStart && acceptContinuations))
       {
+        if (caseCorDStart) {
+          if (nextContinuation++ != 0)
+          {
+            // error: already started a continuation.  Skip future
+            // continuations and return whatever initial parts were in order.
+            nextContinuation = -1;
+            goto increment_str;
+          }
+        }
         // look for single quotation mark(')
         const char *sQuote1 = PL_strchr(valueStart, 0x27);
         const char *sQuote2 = (char *) (sQuote1 ? PL_strchr(sQuote1 + 1, 0x27) : nsnull);
@@ -338,9 +401,10 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
         {
           if (*aResult)
           {
-            // drop non-2231-encoded value, instead prefer the one using
-            // the RFC2231 encoding
+            // caseA value already read, or caseC/D value already read
+            // but we're now reading caseB: either way, drop old value
             nsMemory::Free(*aResult);
+            haveCaseAValue = false;
           }
           *aResult = (char *) nsMemory::Alloc(valueEnd - (sQuote2 + 1) + 1);
           if (*aResult)
@@ -350,17 +414,35 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
             if (needUnescape)
             {
               nsUnescape(*aResult);
-              if (tokenEnd - tokenStart == paramLen + 1)
-                // we're done; this is case B 
-                return NS_OK; 
+              if (caseB)
+                return NS_OK; // caseB wins over everything else
             }
           }
         }
       }  // end of if-block :  title*0*=  or  title*= 
-      // a line of multiline param with no need for unescaping : title*[0-9]=
-      // or 2nd or later lines of a multiline param : title*[1-9]*= 
-      else if (nsCRT::IsAsciiDigit(PRUnichar(*cp)))
+      // caseD: a line of multiline param with no need for unescaping : title*[0-9]=
+      // or 2nd or later lines of a caseC param : title*[1-9]*= 
+      else if (acceptContinuations && nsCRT::IsAsciiDigit(PRUnichar(*cp)))
       {
+        PRInt32 nextSegment = atoi(cp);
+        // no leading zeros allowed except for ... position 0
+        bool broken = nextSegment > 0 && *cp == '0';
+          
+        if (broken || nextSegment != nextContinuation++)
+        {
+          // error: gap in continuation or unneccessary leading 0.
+          // Skip future continuations and return whatever initial parts were
+          // in order.
+          nextContinuation = -1;
+          goto increment_str;
+        }
+        if (haveCaseAValue && *aResult) 
+        {
+          // drop caseA value
+          nsMemory::Free(*aResult);
+          *aResult = 0;
+          haveCaseAValue = false;
+        }
         PRInt32 len = 0;
         if (*aResult) // 2nd or later lines of multiline parameter
         {
@@ -372,11 +454,11 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
           }
           *aResult = ns;
         }
-        else if (*cp == '0') // must be; 1st line :  title*0=
+        else 
         {
+          NS_ASSERTION(*cp == '0', "Not first value in continuation"); // must be; 1st line :  title*0=
           *aResult = (char *) nsMemory::Alloc(valueEnd - valueStart + 1);
         }
-        // else {} something is really wrong; out of memory
         if (*aResult)
         {
           // append a partial value
@@ -392,7 +474,7 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
 
     // str now points after the end of the value.
     //   skip over whitespace, ';', whitespace.
-      
+increment_str:      
     while (nsCRT::IsAsciiSpace(*str)) ++str;
     if (*str == ';') ++str;
     while (nsCRT::IsAsciiSpace(*str)) ++str;
@@ -408,8 +490,8 @@ nsMIMEHeaderParamImpl::GetParameterInternal(const char *aHeaderValue,
 NS_IMETHODIMP
 nsMIMEHeaderParamImpl::DecodeRFC2047Header(const char* aHeaderVal, 
                                            const char* aDefaultCharset, 
-                                           PRBool aOverrideCharset, 
-                                           PRBool aEatContinuations,
+                                           bool aOverrideCharset, 
+                                           bool aEatContinuations,
                                            nsACString& aResult)
 {
   aResult.Truncate();
@@ -423,14 +505,14 @@ nsMIMEHeaderParamImpl::DecodeRFC2047Header(const char* aHeaderVal,
   // aDefaultCharset is specified, decodes RFC 2047 encoding and converts
   // to UTF-8. Otherwise, just strips away CRLF. 
   if (PL_strstr(aHeaderVal, "=?") || 
-      aDefaultCharset && (!IsUTF8(nsDependentCString(aHeaderVal)) || 
-      Is7bitNonAsciiString(aHeaderVal, PL_strlen(aHeaderVal)))) {
+      (aDefaultCharset && (!IsUTF8(nsDependentCString(aHeaderVal)) || 
+      Is7bitNonAsciiString(aHeaderVal, PL_strlen(aHeaderVal))))) {
     DecodeRFC2047Str(aHeaderVal, aDefaultCharset, aOverrideCharset, aResult);
   } else if (aEatContinuations && 
              (PL_strchr(aHeaderVal, '\n') || PL_strchr(aHeaderVal, '\r'))) {
     aResult = aHeaderVal;
   } else {
-    aEatContinuations = PR_FALSE;
+    aEatContinuations = false;
     aResult = aHeaderVal;
   }
 
@@ -449,11 +531,11 @@ NS_IMETHODIMP
 nsMIMEHeaderParamImpl::DecodeParameter(const nsACString& aParamValue,
                                        const char* aCharset,
                                        const char* aDefaultCharset,
-                                       PRBool aOverrideCharset, 
+                                       bool aOverrideCharset, 
                                        nsACString& aResult)
 {
   aResult.Truncate();
-  // If aCharset is given, aParamValue was obtained from RFC2231 
+  // If aCharset is given, aParamValue was obtained from RFC2231/5987 
   // encoding and we're pretty sure that it's in aCharset.
   if (aCharset && *aCharset)
   {
@@ -490,7 +572,7 @@ nsMIMEHeaderParamImpl::DecodeParameter(const nsACString& aParamValue,
 
   // Try RFC 2047 encoding, instead.
   nsresult rv = DecodeRFC2047Header(unQuoted.get(), aDefaultCharset, 
-                                    aOverrideCharset, PR_TRUE, decoded);
+                                    aOverrideCharset, true, decoded);
   
   if (NS_SUCCEEDED(rv) && !decoded.IsEmpty())
     aResult = decoded;
@@ -499,9 +581,9 @@ nsMIMEHeaderParamImpl::DecodeParameter(const nsACString& aParamValue,
 }
 
 #define ISHEXCHAR(c) \
-        (0x30 <= PRUint8(c) && PRUint8(c) <= 0x39  ||  \
-         0x41 <= PRUint8(c) && PRUint8(c) <= 0x46  ||  \
-         0x61 <= PRUint8(c) && PRUint8(c) <= 0x66)
+        ((0x30 <= PRUint8(c) && PRUint8(c) <= 0x39)  ||  \
+         (0x41 <= PRUint8(c) && PRUint8(c) <= 0x46)  ||  \
+         (0x61 <= PRUint8(c) && PRUint8(c) <= 0x66))
 
 // Decode Q encoding (RFC 2047).
 // static
@@ -555,7 +637,7 @@ char *DecodeQ(const char *in, PRUint32 length)
 // or has  ESC which may be an  indication that  it's in one of many ISO 
 // 2022 7bit  encodings (e.g. ISO-2022-JP(-2)/CN : see RFC 1468, 1922, 1554).
 // static
-PRBool Is7bitNonAsciiString(const char *input, PRUint32 len)
+bool Is7bitNonAsciiString(const char *input, PRUint32 len)
 {
   PRInt32 c;
 
@@ -569,8 +651,8 @@ PRBool Is7bitNonAsciiString(const char *input, PRUint32 len)
   while (len) {
     c = PRUint8(*input++);
     len--;
-    if (c & 0x80) return PR_FALSE;
-    if (c == 0x1B) return PR_TRUE;
+    if (c & 0x80) return false;
+    if (c == 0x1B) return true;
     if (c == '~') {
       switch (hz_state) {
       case hz_initial:
@@ -631,7 +713,7 @@ void CopyRawHeader(const char *aInput, PRUint32 aLen,
 
   // skip ASCIIness/UTF8ness test if aInput is supected to be a 7bit non-ascii
   // string and aDefaultCharset is a 7bit non-ascii charset.
-  PRBool skipCheck = (c == 0x1B || c == '~') && 
+  bool skipCheck = (c == 0x1B || c == '~') && 
                      IS_7BIT_NON_ASCII_CHARSET(aDefaultCharset);
 
   // If not UTF-8, treat as default charset
@@ -663,7 +745,7 @@ static const char especials[] = "()<>@,;:\\\"/[]?.=";
 // is also used to convert raw octets (without RFC 2047 encoding) to UTF-8.
 //static
 nsresult DecodeRFC2047Str(const char *aHeader, const char *aDefaultCharset, 
-                          PRBool aOverrideCharset, nsACString &aResult)
+                          bool aOverrideCharset, nsACString &aResult)
 {
   const char *p, *q, *r;
   char *decodedText;
