@@ -115,7 +115,7 @@ nsViewSourceChannel::GetName(nsACString &result)
 }
 
 NS_IMETHODIMP
-nsViewSourceChannel::IsPending(PRBool *result)
+nsViewSourceChannel::IsPending(bool *result)
 {
     NS_ENSURE_TRUE(mChannel, NS_ERROR_FAILURE);
 
@@ -205,7 +205,7 @@ nsViewSourceChannel::Open(nsIInputStream **_retval)
 
     nsresult rv = mChannel->Open(_retval);
     if (NS_SUCCEEDED(rv)) {
-        mOpened = PR_TRUE;
+        mOpened = true;
     }
     
     return rv;
@@ -238,7 +238,7 @@ nsViewSourceChannel::AsyncOpen(nsIStreamListener *aListener, nsISupports *ctxt)
                                  nsnull, rv);
 
     if (NS_SUCCEEDED(rv)) {
-        mOpened = PR_TRUE;
+        mOpened = true;
     }
     
     return rv;
@@ -288,7 +288,7 @@ nsViewSourceChannel::SetLoadFlags(PRUint32 aLoadFlags)
     // the win32 compiler fails to deal due to amiguous inheritance.
     // nsIChannel::LOAD_DOCUMENT_URI/nsIRequest::LOAD_FROM_CACHE also fails; the
     // Win32 compiler thinks that's supposed to be a method.
-    mIsDocument = (aLoadFlags & ::nsIChannel::LOAD_DOCUMENT_URI) ? PR_TRUE : PR_FALSE;
+    mIsDocument = (aLoadFlags & ::nsIChannel::LOAD_DOCUMENT_URI) ? true : false;
 
     return mChannel->SetLoadFlags((aLoadFlags |
                                    ::nsIRequest::LOAD_FROM_CACHE) &
@@ -371,6 +371,30 @@ nsViewSourceChannel::SetContentCharset(const nsACString &aContentCharset)
     return mChannel->SetContentCharset(aContentCharset);
 }
 
+NS_IMETHODIMP
+nsViewSourceChannel::GetContentDisposition(PRUint32 *aContentDisposition)
+{
+    NS_ENSURE_TRUE(mChannel, NS_ERROR_FAILURE);
+
+    return mChannel->GetContentDisposition(aContentDisposition);
+}
+
+NS_IMETHODIMP
+nsViewSourceChannel::GetContentDispositionFilename(nsAString &aContentDispositionFilename)
+{
+    NS_ENSURE_TRUE(mChannel, NS_ERROR_FAILURE);
+
+    return mChannel->GetContentDispositionFilename(aContentDispositionFilename);
+}
+
+NS_IMETHODIMP
+nsViewSourceChannel::GetContentDispositionHeader(nsACString &aContentDispositionHeader)
+{
+    NS_ENSURE_TRUE(mChannel, NS_ERROR_FAILURE);
+
+    return mChannel->GetContentDispositionHeader(aContentDispositionHeader);
+}
+
 NS_IMETHODIMP
 nsViewSourceChannel::GetContentLength(PRInt32 *aContentLength)
 {
@@ -560,7 +584,7 @@ nsViewSourceChannel::GetRequestHeader(const nsACString & aHeader,
 NS_IMETHODIMP
 nsViewSourceChannel::SetRequestHeader(const nsACString & aHeader,
                                       const nsACString & aValue,
-                                      PRBool aMerge)
+                                      bool aMerge)
 {
     return !mHttpChannel ? NS_ERROR_NULL_POINTER :
         mHttpChannel->SetRequestHeader(aHeader, aValue, aMerge);
@@ -574,14 +598,14 @@ nsViewSourceChannel::VisitRequestHeaders(nsIHttpHeaderVisitor *aVisitor)
 }
 
 NS_IMETHODIMP
-nsViewSourceChannel::GetAllowPipelining(PRBool *aAllowPipelining)
+nsViewSourceChannel::GetAllowPipelining(bool *aAllowPipelining)
 {
     return !mHttpChannel ? NS_ERROR_NULL_POINTER :
         mHttpChannel->GetAllowPipelining(aAllowPipelining);
 }
 
 NS_IMETHODIMP
-nsViewSourceChannel::SetAllowPipelining(PRBool aAllowPipelining)
+nsViewSourceChannel::SetAllowPipelining(bool aAllowPipelining)
 {
     return !mHttpChannel ? NS_ERROR_NULL_POINTER :
         mHttpChannel->SetAllowPipelining(aAllowPipelining);
@@ -616,7 +640,7 @@ nsViewSourceChannel::GetResponseStatusText(nsACString & aResponseStatusText)
 }
 
 NS_IMETHODIMP
-nsViewSourceChannel::GetRequestSucceeded(PRBool *aRequestSucceeded)
+nsViewSourceChannel::GetRequestSucceeded(bool *aRequestSucceeded)
 {
     return !mHttpChannel ? NS_ERROR_NULL_POINTER :
         mHttpChannel->GetRequestSucceeded(aRequestSucceeded);
@@ -646,7 +670,7 @@ nsViewSourceChannel::GetResponseHeader(const nsACString & aHeader,
 
 NS_IMETHODIMP
 nsViewSourceChannel::SetResponseHeader(const nsACString & header,
-                                       const nsACString & value, PRBool merge)
+                                       const nsACString & value, bool merge)
 {
     return !mHttpChannel ? NS_ERROR_NULL_POINTER :
         mHttpChannel->SetResponseHeader(header, value, merge);
@@ -668,14 +692,14 @@ nsViewSourceChannel::VisitResponseHeaders(nsIHttpHeaderVisitor *aVisitor)
 }
 
 NS_IMETHODIMP
-nsViewSourceChannel::IsNoStoreResponse(PRBool *_retval)
+nsViewSourceChannel::IsNoStoreResponse(bool *_retval)
 {
     return !mHttpChannel ? NS_ERROR_NULL_POINTER :
         mHttpChannel->IsNoStoreResponse(_retval);
 }
 
 NS_IMETHODIMP
-nsViewSourceChannel::IsNoCacheResponse(PRBool *_retval)
+nsViewSourceChannel::IsNoCacheResponse(bool *_retval)
 {
     return !mHttpChannel ? NS_ERROR_NULL_POINTER :
         mHttpChannel->IsNoCacheResponse(_retval);
