@@ -57,7 +57,7 @@ const PRFloat64 growthRate = 1.2;
 // 0xA0's and a single ending space, so need to treat 0xA0's as spaces.
 // 0xA0 is the Latin1/Unicode character for "non-breaking space (nbsp)"
 // Also recognize the Japanese ideographic space 0x3000 as a space.
-static inline PRBool IsSpace(const PRUnichar aChar)
+static inline bool IsSpace(const PRUnichar aChar)
 {
   return (nsCRT::IsAsciiSpace(aChar) || aChar == 0xA0 || aChar == 0x3000);
 }
@@ -66,7 +66,7 @@ static inline PRBool IsSpace(const PRUnichar aChar)
 // aStringToAppendTo
 void
 mozTXTToHTMLConv::EscapeChar(const PRUnichar ch, nsString& aStringToAppendTo,
-                             PRBool inAttribute)
+                             bool inAttribute)
 {
     switch (ch)
     {
@@ -96,7 +96,7 @@ mozTXTToHTMLConv::EscapeChar(const PRUnichar ch, nsString& aStringToAppendTo,
 // EscapeStr takes the passed in string and
 // escapes it IN PLACE.
 void
-mozTXTToHTMLConv::EscapeStr(nsString& aInString, PRBool inAttribute)
+mozTXTToHTMLConv::EscapeStr(nsString& aInString, bool inAttribute)
 {
   // the replace substring routines
   // don't seem to work if you have a character
@@ -218,7 +218,7 @@ mozTXTToHTMLConv::CompleteAbbreviatedURL(const PRUnichar * aInString, PRInt32 aI
   }
 }
 
-PRBool
+bool
 mozTXTToHTMLConv::FindURLStart(const PRUnichar * aInString, PRInt32 aInLength,
                                const PRUint32 pos, const modetype check,
                                PRUint32& start)
@@ -230,10 +230,10 @@ mozTXTToHTMLConv::FindURLStart(const PRUnichar * aInString, PRInt32 aInLength,
     if (!nsCRT::strncmp(&aInString[MaxInt(pos - 4, 0)], NS_LITERAL_STRING("<URL:").get(), 5))
     {
       start = pos + 1;
-      return PR_TRUE;
+      return true;
     }
     else
-      return PR_FALSE;
+      return false;
   }
   case RFC2396E:
   {
@@ -246,7 +246,7 @@ mozTXTToHTMLConv::FindURLStart(const PRUnichar * aInString, PRInt32 aInLength,
       return start < pos;
     }
     else
-      return PR_FALSE;
+      return false;
   }
   case freetext:
   {
@@ -262,17 +262,17 @@ mozTXTToHTMLConv::FindURLStart(const PRUnichar * aInString, PRInt32 aInLength,
     if (++i >= 0 && PRUint32(i) < pos && nsCRT::IsAsciiAlpha(aInString[PRUint32(i)]))
     {
       start = PRUint32(i);
-      return PR_TRUE;
+      return true;
     }
     else
-      return PR_FALSE;
+      return false;
   }
   case abbreviated:
   {
     PRInt32 i = pos - 1;
     // This disallows non-ascii-characters for email.
     // Currently correct, but revisit later after standards changed.
-    PRBool isEmail = aInString[pos] == (PRUnichar)'@';
+    bool isEmail = aInString[pos] == (PRUnichar)'@';
     // These chars mark the start of the URL
     for (; i >= 0
              && aInString[PRUint32(i)] != '>' && aInString[PRUint32(i)] != '<'
@@ -296,17 +296,17 @@ mozTXTToHTMLConv::FindURLStart(const PRUnichar * aInString, PRInt32 aInLength,
       )
     {
       start = PRUint32(i);
-      return PR_TRUE;
+      return true;
     }
     else
-      return PR_FALSE;
+      return false;
   }
   default:
-    return PR_FALSE;
+    return false;
   } //switch
 }
 
-PRBool
+bool
 mozTXTToHTMLConv::FindURLEnd(const PRUnichar * aInString, PRInt32 aInStringLength, const PRUint32 pos,
            const modetype check, const PRUint32 start, PRUint32& end)
 {
@@ -325,14 +325,14 @@ mozTXTToHTMLConv::FindURLEnd(const PRUnichar * aInString, PRInt32 aInStringLengt
       return end > pos;
     }
     else
-      return PR_FALSE;
+      return false;
   }
   case freetext:
   case abbreviated:
   {
     PRUint32 i = pos + 1;
-    PRBool isEmail = aInString[pos] == (PRUnichar)'@';
-    PRBool haveOpeningBracket = PR_FALSE;
+    bool isEmail = aInString[pos] == (PRUnichar)'@';
+    bool haveOpeningBracket = false;
     for (; PRInt32(i) < aInStringLength; i++)
     {
       // These chars mark the end of the URL
@@ -351,7 +351,7 @@ mozTXTToHTMLConv::FindURLEnd(const PRUnichar * aInString, PRInt32 aInStringLengt
             !nsCRT::IsAscii(aInString[i])       ))
           break;
       if (aInString[i] == '(')
-        haveOpeningBracket = PR_TRUE;
+        haveOpeningBracket = true;
     }
     // These chars are allowed in the middle of the URL, but not at end.
     // Technically they are, but are used in normal text after the URL.
@@ -364,13 +364,13 @@ mozTXTToHTMLConv::FindURLEnd(const PRUnichar * aInString, PRInt32 aInStringLengt
     if (i > pos)
     {
       end = i;
-      return PR_TRUE;
+      return true;
     }
     else
-      return PR_FALSE;
+      return false;
   }
   default:
-    return PR_FALSE;
+    return false;
   } //switch
 }
 
@@ -406,7 +406,7 @@ mozTXTToHTMLConv::CalculateURLBoundaries(const PRUnichar * aInString, PRInt32 aI
   default: break;
   } //switch
 
-  EscapeStr(desc, PR_FALSE);
+  EscapeStr(desc, false);
 
   txtURL.Append(&aInString[start], end - start + 1);
   txtURL.StripWhitespace();
@@ -418,34 +418,34 @@ mozTXTToHTMLConv::CalculateURLBoundaries(const PRUnichar * aInString, PRInt32 aI
   return;
 }
 
-PRBool mozTXTToHTMLConv::ShouldLinkify(const nsCString& aURL)
+bool mozTXTToHTMLConv::ShouldLinkify(const nsCString& aURL)
 {
   if (!mIOService)
-    return PR_FALSE;
+    return false;
 
   nsCAutoString scheme;
   nsresult rv = mIOService->ExtractScheme(aURL, scheme);
   if(NS_FAILED(rv))
-    return PR_FALSE;
+    return false;
 
   // Get the handler for this scheme.
   nsCOMPtr<nsIProtocolHandler> handler;    
   rv = mIOService->GetProtocolHandler(scheme.get(), getter_AddRefs(handler));
   if(NS_FAILED(rv))
-    return PR_FALSE;
+    return false;
 
   // Is it an external protocol handler? If not, linkify it.
   nsCOMPtr<nsIExternalProtocolHandler> externalHandler = do_QueryInterface(handler);
   if (!externalHandler)
-   return PR_TRUE; // handler is built-in, linkify it!
+   return true; // handler is built-in, linkify it!
 
   // If external app exists for the scheme then linkify it.
-  PRBool exists;
+  bool exists;
   rv = externalHandler->ExternalAppExistsForScheme(scheme, &exists);
   return(NS_SUCCEEDED(rv) && exists);
 }
 
-PRBool
+bool
 mozTXTToHTMLConv::CheckURLAndCreateHTML(
      const nsString& txtURL, const nsString& desc, const modetype mode,
      nsString& outputHTML)
@@ -459,13 +459,13 @@ mozTXTToHTMLConv::CheckURLAndCreateHTML(
     mIOService = do_GetIOService();
 
     if (!mIOService)
-      return PR_FALSE;
+      return false;
   }
 
   // See if the url should be linkified.
   NS_ConvertUTF16toUTF8 utf8URL(txtURL);
   if (!ShouldLinkify(utf8URL))
-    return PR_FALSE;
+    return false;
 
   // it would be faster if we could just check to see if there is a protocol
   // handler for the url and return instead of actually trying to create a url...
@@ -492,17 +492,17 @@ mozTXTToHTMLConv::CheckURLAndCreateHTML(
     default: break;
     }
     nsAutoString escapedURL(txtURL);
-    EscapeStr(escapedURL, PR_TRUE);
+    EscapeStr(escapedURL, true);
 
     outputHTML.AppendLiteral("\" href=\"");
     outputHTML += escapedURL;
     outputHTML.AppendLiteral("\">");
     outputHTML += desc;
     outputHTML.AppendLiteral("</a>");
-    return PR_TRUE;
+    return true;
   }
   else
-    return PR_FALSE;
+    return false;
 }
 
 NS_IMETHODIMP mozTXTToHTMLConv::FindURLInPlaintext(const PRUnichar * aInString, PRInt32 aInLength, PRInt32 aPos, PRInt32 * aStartPos, PRInt32 * aEndPos)
@@ -518,7 +518,7 @@ NS_IMETHODIMP mozTXTToHTMLConv::FindURLInPlaintext(const PRUnichar * aInString,
   return NS_OK;
 }
 
-PRBool
+bool
 mozTXTToHTMLConv::FindURL(const PRUnichar * aInString, PRInt32 aInLength, const PRUint32 pos,
      const PRUint32 whathasbeendone,
      nsString& outputHTML, PRInt32& replaceBefore, PRInt32& replaceAfter)
@@ -599,7 +599,7 @@ mozTXTToHTMLConv::FindURL(const PRUnichar * aInString, PRInt32 aInLength, const
   return state[check] == success;
 }
 
-PRBool
+bool
 mozTXTToHTMLConv::ItMatchesDelimited(const PRUnichar * aInString,
     PRInt32 aInLength, const PRUnichar* rep, PRInt32 aRepLen,
     LIMTYPE before, LIMTYPE after)
@@ -620,7 +620,7 @@ mozTXTToHTMLConv::ItMatchesDelimited(const PRUnichar * aInString,
       before != LT_IGNORE && after != LT_IGNORE && after != LT_DELIMITER
         && textLen < aRepLen + 2
     )
-    return PR_FALSE;
+    return false;
 
   PRUnichar text0 = aInString[0];
   PRUnichar textAfterPos = aInString[aRepLen + (before == LT_IGNORE ? 0 : 1)];
@@ -654,9 +654,9 @@ mozTXTToHTMLConv::ItMatchesDelimited(const PRUnichar * aInString,
                    aRepLen).Equals(Substring(rep, rep+aRepLen),
                                    nsCaseInsensitiveStringComparator())
     )
-    return PR_FALSE;
+    return false;
 
-  return PR_TRUE;
+  return true;
 }
 
 PRUint32
@@ -677,8 +677,8 @@ mozTXTToHTMLConv::NumberOfMatches(const PRUnichar * aInString, PRInt32 aInString
 
 // NOTE: the converted html for the phrase is appended to aOutString
 // tagHTML and attributeHTML are plain ASCII (literal strings, in fact)
-PRBool
-mozTXTToHTMLConv::StructPhraseHit(const PRUnichar * aInString, PRInt32 aInStringLength, PRBool col0,
+bool
+mozTXTToHTMLConv::StructPhraseHit(const PRUnichar * aInString, PRInt32 aInStringLength, bool col0,
      const PRUnichar* tagTXT, PRInt32 aTagTXTLen, 
      const char* tagHTML, const char* attributeHTML,
      nsString& aOutString, PRUint32& openTags)
@@ -715,7 +715,7 @@ mozTXTToHTMLConv::StructPhraseHit(const PRUnichar * aInString, PRInt32 aInString
     aOutString.AppendLiteral("><span class=\"moz-txt-tag\">");
     aOutString.Append(tagTXT);
     aOutString.AppendLiteral("</span>");
-    return PR_TRUE;
+    return true;
   }
 
   // closing tag
@@ -728,20 +728,20 @@ mozTXTToHTMLConv::StructPhraseHit(const PRUnichar * aInString, PRInt32 aInString
     aOutString.AppendLiteral("</span></");
     aOutString.AppendASCII(tagHTML);
     aOutString.Append(PRUnichar('>'));
-    return PR_TRUE;
+    return true;
   }
 
-  return PR_FALSE;
+  return false;
 }
 
 
-PRBool
-mozTXTToHTMLConv::SmilyHit(const PRUnichar * aInString, PRInt32 aLength, PRBool col0,
+bool
+mozTXTToHTMLConv::SmilyHit(const PRUnichar * aInString, PRInt32 aLength, bool col0,
          const char* tagTXT, const char* imageName,
          nsString& outputHTML, PRInt32& glyphTextLen)
 {
   if ( !aInString || !tagTXT || !imageName )
-      return PR_FALSE;
+      return false;
 
   PRInt32  tagLen = nsCRT::strlen(tagTXT);
  
@@ -786,15 +786,15 @@ mozTXTToHTMLConv::SmilyHit(const PRUnichar * aInString, PRInt32 aLength, PRBool
     AppendASCIItoUTF16(tagTXT, outputHTML);     // original text 
     outputHTML.AppendLiteral("</span></span>"); // </span></span>
     glyphTextLen = (col0 ? 0 : 1) + tagLen;
-    return PR_TRUE;
+    return true;
   }
 
-  return PR_FALSE;
+  return false;
 }
 
 // the glyph is appended to aOutputString instead of the original string...
-PRBool
-mozTXTToHTMLConv::GlyphHit(const PRUnichar * aInString, PRInt32 aInLength, PRBool col0,
+bool
+mozTXTToHTMLConv::GlyphHit(const PRUnichar * aInString, PRInt32 aInLength, bool col0,
          nsString& aOutputString, PRInt32& glyphTextLen)
 {
   PRUnichar text0 = aInString[0]; 
@@ -803,8 +803,8 @@ mozTXTToHTMLConv::GlyphHit(const PRUnichar * aInString, PRInt32 aInLength, PRBoo
 
   // temporary variable used to store the glyph html text
   nsAutoString outputHTML;
-  PRBool bTestSmilie;
-  PRBool bArg;
+  bool bTestSmilie;
+  bool bArg;
   int i;
 
   // refactor some of this mess to avoid code duplication and speed execution a bit
@@ -814,20 +814,20 @@ mozTXTToHTMLConv::GlyphHit(const PRUnichar * aInString, PRInt32 aInLength, PRBoo
   i = 0;
   while ( i < 2 )
   {
-    bTestSmilie = PR_FALSE;
+    bTestSmilie = false;
     if ( !i && (firstChar == ':' || firstChar == ';' || firstChar == '=' || firstChar == '>' || firstChar == '8' || firstChar == 'O'))
     {
         // first test passed
 
-        bTestSmilie = PR_TRUE;
+        bTestSmilie = true;
         bArg = col0;
     }
     if ( i && col0 && ( text1 == ':' || text1 == ';' || text1 == '=' || text1 == '>' || text1 == '8' || text1 == 'O' ) )
     {
         // second test passed
 
-        bTestSmilie = PR_TRUE;
-        bArg = PR_FALSE;
+        bTestSmilie = true;
+        bArg = false;
     }
     if ( bTestSmilie && (
           SmilyHit(aInString, aInLength, bArg,
@@ -938,7 +938,7 @@ mozTXTToHTMLConv::GlyphHit(const PRUnichar * aInString, PRInt32 aInLength, PRBoo
     )
     {
         aOutputString.Append(outputHTML);
-        return PR_TRUE;
+        return true;
     }
     i++;
   }
@@ -946,7 +946,7 @@ mozTXTToHTMLConv::GlyphHit(const PRUnichar * aInString, PRInt32 aInLength, PRBoo
   {
       aOutputString.AppendLiteral("<span class='moz-txt-formfeed'></span>");
       glyphTextLen = 1;
-      return PR_TRUE;
+      return true;
   }
   if (text0 == '+' || text1 == '+')
   {
@@ -956,7 +956,7 @@ mozTXTToHTMLConv::GlyphHit(const PRUnichar * aInString, PRInt32 aInLength, PRBoo
     {
       aOutputString.AppendLiteral(" &plusmn;");
       glyphTextLen = 4;
-      return PR_TRUE;
+      return true;
     }
     if (col0 && ItMatchesDelimited(aInString, aInLength,
                                    NS_LITERAL_STRING("+/-").get(), 3,
@@ -964,7 +964,7 @@ mozTXTToHTMLConv::GlyphHit(const PRUnichar * aInString, PRInt32 aInLength, PRBoo
     {
       aOutputString.AppendLiteral("&plusmn;");
       glyphTextLen = 3;
-      return PR_TRUE;
+      return true;
     }
   }
 
@@ -999,7 +999,7 @@ mozTXTToHTMLConv::GlyphHit(const PRUnichar * aInString, PRInt32 aInLength, PRBoo
 
     if (delimPos < aInLength && nsCRT::IsAsciiAlpha(aInString[delimPos]))
     {
-      return PR_FALSE;
+      return false;
     }
 
     outputHTML.Truncate();
@@ -1014,7 +1014,7 @@ mozTXTToHTMLConv::GlyphHit(const PRUnichar * aInString, PRInt32 aInLength, PRBoo
     aOutputString.AppendLiteral("</sup>");
 
     glyphTextLen = delimPos /* - 1 + 1 */ ;
-    return PR_TRUE;
+    return true;
   }
   /*
    The following strings are not substituted:
@@ -1029,7 +1029,7 @@ mozTXTToHTMLConv::GlyphHit(const PRUnichar * aInString, PRInt32 aInLength, PRBoo
     3/4    &frac34;  dito
     1/2    &frac12;  similar
   */
-  return PR_FALSE;
+  return false;
 }
 
 /***************************************************************************
@@ -1057,7 +1057,7 @@ mozTXTToHTMLConv::CiteLevelTXT(const PRUnichar *line,
   PRInt32 result = 0;
   PRInt32 lineLength = nsCRT::strlen(line);
 
-  PRBool moreCites = PR_TRUE;
+  bool moreCites = true;
   while (moreCites)
   {
     /* E.g. the following lines count as quote:
@@ -1099,7 +1099,7 @@ mozTXTToHTMLConv::CiteLevelTXT(const PRUnichar *line,
                     indexString+minlength).Equals(Substring(NS_LITERAL_STRING(">From "), 0, minlength),
                                                   nsCaseInsensitiveStringComparator()))
         //XXX RFC2646
-        moreCites = PR_FALSE;
+        moreCites = false;
       else
       {
         result++;
@@ -1107,7 +1107,7 @@ mozTXTToHTMLConv::CiteLevelTXT(const PRUnichar *line,
       }
     }
     else
-      moreCites = PR_FALSE;
+      moreCites = false;
   }
 
   return result;
@@ -1116,9 +1116,9 @@ mozTXTToHTMLConv::CiteLevelTXT(const PRUnichar *line,
 void
 mozTXTToHTMLConv::ScanTXT(const PRUnichar * aInString, PRInt32 aInStringLength, PRUint32 whattodo, nsString& aOutString)
 {
-  PRBool doURLs = 0 != (whattodo & kURLs);
-  PRBool doGlyphSubstitution = 0 != (whattodo & kGlyphSubstitution);
-  PRBool doStructPhrase = 0 != (whattodo & kStructPhrase);
+  bool doURLs = 0 != (whattodo & kURLs);
+  bool doGlyphSubstitution = 0 != (whattodo & kGlyphSubstitution);
+  bool doStructPhrase = 0 != (whattodo & kStructPhrase);
 
   PRUint32 structPhrase_strong = 0;  // Number of currently open tags
   PRUint32 structPhrase_underline = 0;
@@ -1228,7 +1228,7 @@ mozTXTToHTMLConv::ScanTXT(const PRUnichar * aInString, PRInt32 aInStringLength,
     case '<':
     case '>':
     case '&':
-      EscapeChar(aInString[i], aOutString, PR_FALSE);
+      EscapeChar(aInString[i], aOutString, false);
       i++;
       break;
     // Normal characters
@@ -1264,7 +1264,7 @@ mozTXTToHTMLConv::ScanHTML(nsString& aInString, PRUint32 whattodo, nsString &aOu
       if (nsCRT::ToLower((char)aInString[PRUint32(i) + 1]) == 'a')
            // if a tag, skip until </a>
       {
-        i = aInString.Find("</a>", PR_TRUE, i);
+        i = aInString.Find("</a>", true, i);
         if (i == kNotFound)
           i = lengthOfInString;
         else
@@ -1274,7 +1274,7 @@ mozTXTToHTMLConv::ScanHTML(nsString& aInString, PRUint32 whattodo, nsString &aOu
         aInString[PRUint32(i) + 3] == '-')
           //if out-commended code, skip until -->
       {
-        i = aInString.Find("-->", PR_FALSE, i);
+        i = aInString.Find("-->", false, i);
         if (i == kNotFound)
           i = lengthOfInString;
         else
