@@ -57,14 +57,14 @@ nsQtNetworkLinkService::~nsQtNetworkLinkService()
 }
 
 NS_IMETHODIMP
-nsQtNetworkLinkService::GetIsLinkUp(PRBool* aIsUp)
+nsQtNetworkLinkService::GetIsLinkUp(bool* aIsUp)
 {
   *aIsUp = nsQtNetworkManager::get()->isOnline();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsQtNetworkLinkService::GetLinkStatusKnown(PRBool* aIsKnown)
+nsQtNetworkLinkService::GetLinkStatusKnown(bool* aIsKnown)
 {
   *aIsKnown = nsQtNetworkManager::get()->isOnline();
   return NS_OK;
@@ -109,12 +109,12 @@ nsQtNetworkLinkService::Init(void)
   nsQtNetworkManager::create();
   nsresult rv;
 
-  rv = observerService->AddObserver(this, "xpcom-shutdown", PR_FALSE);
+  rv = observerService->AddObserver(this, "xpcom-shutdown", false);
   if (NS_FAILED(rv)) {
     return NS_ERROR_FAILURE;
   }
 
-  rv = observerService->AddObserver(this, "browser-lastwindow-close-granted", PR_FALSE);
+  rv = observerService->AddObserver(this, "browser-lastwindow-close-granted", false);
   if (NS_FAILED(rv)) {
     return NS_ERROR_FAILURE;
   }
