@@ -46,6 +46,7 @@
 #endif
 
 #include "primpl.h"
+#include "prbit.h"
 
 #define MULTIPLE_THREADS
 #define ACQUIRE_DTOA_LOCK(n)	PR_Lock(dtoa_lock[n])
@@ -83,6 +84,8 @@ void _PR_CleanupDtoa(void)
 #define ULong PRUint32
 #define NO_LONG_LONG
 
+#define No_Hex_NaN
+
 /****************************************************************
  *
  * The author of this software is David M. Gay.
@@ -742,6 +745,9 @@ hi0bits
 	(register ULong x)
 #endif
 {
+#ifdef PR_HAVE_BUILTIN_BITSCAN32
+	return( (!x) ? 32 : pr_bitscan_clz32(x) );
+#else
 	register int k = 0;
 
 	if (!(x & 0xffff0000)) {
@@ -766,6 +772,7 @@ hi0bits
 			return 32;
 		}
 	return k;
+#endif /* PR_HAVE_BUILTIN_BITSCAN32 */
 	}
 
  static int
@@ -776,6 +783,15 @@ lo0bits
 	(ULong *y)
 #endif
 {
+#ifdef PR_HAVE_BUILTIN_BITSCAN32
+	int k;
+	ULong x = *y;
+
+	if (x>1)
+		*y = ( x >> (k = pr_bitscan_ctz32(x)) );
+	else
+		k = ((x ^ 1) << 5);
+#else
 	register int k;
 	register ULong x = *y;
 
@@ -813,6 +829,7 @@ lo0bits
 			return 32;
 		}
 	*y = x;
+#endif /* PR_HAVE_BUILTIN_BITSCAN32 */
 	return k;
 	}
 
@@ -1728,6 +1745,8 @@ PR_strtod
 			}
 		}
  dig_done:
+	if (nd > 64 * 1024)
+		goto ret0;
 	e = 0;
 	if (c == 'e' || c == 'E') {
 		if (!nd && !nz && !nz0) {
@@ -2671,7 +2690,7 @@ nrv_alloc(char *s, char **rve, int n)
  * when MULTIPLE_THREADS is not defined.
  */
 
- void
+ static void
 #ifdef KR_headers
 freedtoa(s) char *s;
 #else
