@@ -51,7 +51,7 @@ CParserContext::CParserContext(CParserContext* aPrevContext,
                                eParserCommands aCommand,
                                nsIRequestObserver* aListener, 
                                eAutoDetectResult aStatus, 
-                               PRBool aCopyUnused)
+                               bool aCopyUnused)
   : mListener(aListener),
     mKey(aKey),
     mPrevContext(aPrevContext),
@@ -61,7 +61,7 @@ CParserContext::CParserContext(CParserContext* aPrevContext,
     mContextType(eCTNone),
     mAutoDetectStatus(aStatus),
     mParserCommand(aCommand),
-    mMultipart(PR_TRUE),
+    mMultipart(true),
     mCopyUnused(aCopyUnused),
     mNumConsumed(0)
 { 
@@ -87,12 +87,8 @@ CParserContext::SetMimeType(const nsACString& aMimeType)
            mMimeType.EqualsLiteral(APPLICATION_XML)       ||
            mMimeType.EqualsLiteral(APPLICATION_XHTML_XML) ||
            mMimeType.EqualsLiteral(TEXT_XUL)              ||
-#ifdef MOZ_SVG
            mMimeType.EqualsLiteral(IMAGE_SVG_XML)         ||
-#endif
-#ifdef MOZ_MATHML
            mMimeType.EqualsLiteral(APPLICATION_MATHML_XML) ||
-#endif
            mMimeType.EqualsLiteral(APPLICATION_RDF_XML)   ||
            mMimeType.EqualsLiteral(TEXT_RDF))
     mDocType = eXML;
