@@ -515,22 +515,11 @@ class Mochitest(object):
     """
     return self.getFullPath(logFile)
 
-  def installSpecialPowersExtension(self, options):
-    """ install the Special Powers extension for special testing capabilities """
-    extensionSource = os.path.normpath(os.path.join(self.SCRIPT_DIRECTORY, "specialpowers"))
-    self.automation.log.info("INFO | runtests.py | Installing extension at %s to %s." % 
-                             (extensionSource, options.profilePath))
-
-    self.automation.installExtension(extensionSource, options.profilePath, "special-powers@mozilla.org")
-    self.automation.log.info("INFO | runtests.py | Done installing extension.")
-
   def buildProfile(self, options):
     """ create the profile and add optional chrome bits and files if requested """
     self.automation.initializeProfile(options.profilePath, options.extraPrefs, useServerLocations = True)
     manifest = self.addChromeToProfile(options)
     self.copyExtraFilesToProfile(options)
-
-    self.installSpecialPowersExtension(options)
     self.installExtensionsToProfile(options)
     return manifest
 
@@ -562,7 +551,7 @@ class Mochitest(object):
         URL parameters to test URL:
 
         autorun -- kick off tests automatically
-        closeWhenDone -- runs quit.js after tests
+        closeWhenDone -- closes the browser after the tests
         hideResultsTable -- hides the table of individual test results
         logFile -- logs test run to an absolute path
         totalChunks -- how many chunks to split tests into
@@ -813,17 +802,9 @@ toolbar#nav-bar {
       chrome += """
 overlay chrome://browser/content/browser.xul chrome://mochikit/content/browser-test-overlay.xul
 overlay chrome://navigator/content/navigator.xul chrome://mochikit/content/browser-test-overlay.xul
-"""
-    else:
-      #only do the ipc-overlay.xul for mochitest-plain.  
-      #Currently there are focus issues in chrome tests and issues with new windows and dialogs when using ipc
-      chrome += """
-overlay chrome://browser/content/browser.xul chrome://mochikit/content/ipc-overlay.xul
-overlay chrome://navigator/content/navigator.xul chrome://mochikit/content/ipc-overlay.xul
 """
 
     self.installChromeJar(jarDir, chrome, options)
-
     return manifest
 
   def installChromeJar(self, jarDirName, chrome, options):
@@ -859,17 +840,33 @@ overlay chrome://navigator/content/navigator.xul chrome://mochikit/content/ipc-o
         self.automation.log.warning("WARNING | runtests.py | Failed to copy %s to profile", abspath)
         continue
 
-  def installExtensionsToProfile(self, options):
-    "Install application distributed extensions and specified on the command line ones to testing profile."
-    # Install distributed extensions, if application has any.
-    distExtDir = os.path.join(options.app[ : options.app.rfind(os.sep)], "distribution", "extensions")
-    if os.path.isdir(distExtDir):
-      for f in os.listdir(distExtDir):
-        self.automation.installExtension(os.path.join(distExtDir, f), options.profilePath)
+  def installExtensionFromPath(self, options, path, extensionID = None):
+    extensionPath = self.getFullPath(path)
 
-    # Install custom extensions.
-    for f in options.extensionsToInstall:
-      self.automation.installExtension(self.getFullPath(f), options.profilePath)
+    self.automation.log.info("INFO | runtests.py | Installing extension at %s to %s." %
+                            (extensionPath, options.profilePath))
+    self.automation.installExtension(extensionPath, options.profilePath,
+                                     extensionID)
+
+  def installExtensionsToProfile(self, options):
+    "Install special testing extensions, application distributed extensions, and specified on the command line ones to testing profile."
+    extensionDirs = [
+      # Extensions distributed with the test harness.
+      os.path.normpath(os.path.join(self.SCRIPT_DIRECTORY, "extensions")),
+      # Extensions distributed with the application.
+      os.path.join(options.app[ : options.app.rfind(os.sep)], "distribution", "extensions")
+    ]
+
+    for extensionDir in extensionDirs:
+      if os.path.isdir(extensionDir):
+        for dirEntry in os.listdir(extensionDir):
+          path = os.path.join(extensionDir, dirEntry)
+          if os.path.isdir(path) or (os.path.isfile(path) and path.endswith(".xpi")):
+            self.installExtensionFromPath(options, path)
+
+    # Install custom extensions passed on the command line.
+    for path in options.extensionsToInstall:
+      self.installExtensionFromPath(options, path)
 
 def main():
   automation = Automation()
