@@ -76,16 +76,16 @@ NS_INTERFACE_TABLE_HEAD(nsAutoCompleteController)
 NS_INTERFACE_MAP_END
 
 nsAutoCompleteController::nsAutoCompleteController() :
-  mDefaultIndexCompleted(PR_FALSE),
-  mBackspaced(PR_FALSE),
-  mPopupClosedByCompositionStart(PR_FALSE),
-  mIsIMEComposing(PR_FALSE),
-  mIgnoreHandleText(PR_FALSE),
-  mIsOpen(PR_FALSE),
+  mDefaultIndexCompleted(false),
+  mBackspaced(false),
+  mPopupClosedByCompositionStart(false),
+  mIsIMEComposing(false),
+  mIgnoreHandleText(false),
+  mIsOpen(false),
   mSearchStatus(nsAutoCompleteController::STATUS_NONE),
   mRowCount(0),
   mSearchesOngoing(0),
-  mFirstSearchResult(PR_FALSE)
+  mFirstSearchResult(false)
 {
 }
 
@@ -150,8 +150,8 @@ nsAutoCompleteController::SetInput(nsIAutoCompleteInput *aInput)
 
   // Reset all search state members to default values
   mSearchString = newValue;
-  mDefaultIndexCompleted = PR_FALSE;
-  mBackspaced = PR_FALSE;
+  mDefaultIndexCompleted = false;
+  mBackspaced = false;
   mSearchStatus = nsIAutoCompleteController::STATUS_NONE;
   mRowCount = 0;
   mSearchesOngoing = 0;
@@ -216,7 +216,7 @@ nsAutoCompleteController::HandleText()
   // (E.g., calling StopSearch() and ClosePopup().)
   // If it is not, popup is always closed after composition end.
   if (mIgnoreHandleText) {
-    mIgnoreHandleText = PR_FALSE;
+    mIgnoreHandleText = false;
     if (newValue.Equals(mSearchString))
       return NS_OK;
     NS_ERROR("Now is after composition end event. But the value was changed.");
@@ -232,7 +232,7 @@ nsAutoCompleteController::HandleText()
     return NS_OK;
   }
 
-  PRBool disabled;
+  bool disabled;
   input->GetDisableAutoComplete(&disabled);
   NS_ENSURE_TRUE(!disabled, NS_OK);
 
@@ -246,9 +246,9 @@ nsAutoCompleteController::HandleText()
   {
     // We need to throw away previous results so we don't try to search through them again
     ClearResults();
-    mBackspaced = PR_TRUE;
+    mBackspaced = true;
   } else
-    mBackspaced = PR_FALSE;
+    mBackspaced = false;
 
   mSearchString = newValue;
 
@@ -264,9 +264,9 @@ nsAutoCompleteController::HandleText()
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::HandleEnter(PRBool aIsPopupSelection, PRBool *_retval)
+nsAutoCompleteController::HandleEnter(bool aIsPopupSelection, bool *_retval)
 {
-  *_retval = PR_FALSE;
+  *_retval = false;
   if (!mInput)
     return NS_OK;
 
@@ -291,9 +291,9 @@ nsAutoCompleteController::HandleEnter(PRBool aIsPopupSelection, PRBool *_retval)
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::HandleEscape(PRBool *_retval)
+nsAutoCompleteController::HandleEscape(bool *_retval)
 {
-  *_retval = PR_FALSE;
+  *_retval = false;
   if (!mInput)
     return NS_OK;
 
@@ -314,14 +314,14 @@ nsAutoCompleteController::HandleStartComposition()
 {
   NS_ENSURE_TRUE(!mIsIMEComposing, NS_OK);
 
-  mPopupClosedByCompositionStart = PR_FALSE;
-  mIsIMEComposing = PR_TRUE;
+  mPopupClosedByCompositionStart = false;
+  mIsIMEComposing = true;
 
   if (!mInput)
     return NS_OK;
 
   nsCOMPtr<nsIAutoCompleteInput> input(mInput);
-  PRBool disabled;
+  bool disabled;
   input->GetDisableAutoComplete(&disabled);
   if (disabled)
     return NS_OK;
@@ -329,12 +329,12 @@ nsAutoCompleteController::HandleStartComposition()
   // Stop all searches in case they are async.
   StopSearch();
 
-  PRBool isOpen = PR_FALSE;
+  bool isOpen = false;
   input->GetPopupOpen(&isOpen);
   if (isOpen) {
     ClosePopup();
 
-    PRBool stillOpen = PR_FALSE;
+    bool stillOpen = false;
     input->GetPopupOpen(&stillOpen);
     mPopupClosedByCompositionStart = !stillOpen;
   }
@@ -346,9 +346,9 @@ nsAutoCompleteController::HandleEndComposition()
 {
   NS_ENSURE_TRUE(mIsIMEComposing, NS_OK);
 
-  mIsIMEComposing = PR_FALSE;
-  PRBool forceOpenPopup = mPopupClosedByCompositionStart;
-  mPopupClosedByCompositionStart = PR_FALSE;
+  mIsIMEComposing = false;
+  bool forceOpenPopup = mPopupClosedByCompositionStart;
+  mPopupClosedByCompositionStart = false;
 
   if (!mInput)
     return NS_OK;
@@ -360,12 +360,12 @@ nsAutoCompleteController::HandleEndComposition()
     // Show the popup with a filtered result set
     HandleText();
   } else if (forceOpenPopup) {
-    PRBool cancel;
+    bool cancel;
     HandleKeyNavigation(nsIDOMKeyEvent::DOM_VK_DOWN, &cancel);
   }
   // On here, |value| and |mSearchString| are same. Therefore, next HandleText should be
   // ignored. Because there are no reason to research.
-  mIgnoreHandleText = PR_TRUE;
+  mIgnoreHandleText = true;
 
   return NS_OK;
 }
@@ -373,15 +373,15 @@ nsAutoCompleteController::HandleEndComposition()
 NS_IMETHODIMP
 nsAutoCompleteController::HandleTab()
 {
-  PRBool cancel;
-  return HandleEnter(PR_FALSE, &cancel);
+  bool cancel;
+  return HandleEnter(false, &cancel);
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::HandleKeyNavigation(PRUint32 aKey, PRBool *_retval)
+nsAutoCompleteController::HandleKeyNavigation(PRUint32 aKey, bool *_retval)
 {
   // By default, don't cancel the event
-  *_retval = PR_FALSE;
+  *_retval = false;
 
   if (!mInput) {
     // Stop all searches in case they are async.
@@ -398,7 +398,7 @@ nsAutoCompleteController::HandleKeyNavigation(PRUint32 aKey, PRBool *_retval)
   input->GetPopup(getter_AddRefs(popup));
   NS_ENSURE_TRUE(popup != nsnull, NS_ERROR_FAILURE);
 
-  PRBool disabled;
+  bool disabled;
   input->GetDisableAutoComplete(&disabled);
   NS_ENSURE_TRUE(!disabled, NS_OK);
 
@@ -409,20 +409,20 @@ nsAutoCompleteController::HandleKeyNavigation(PRUint32 aKey, PRBool *_retval)
   {
     // Prevent the input from handling up/down events, as it may move
     // the cursor to home/end on some systems
-    *_retval = PR_TRUE;
+    *_retval = true;
 
-    PRBool isOpen = PR_FALSE;
+    bool isOpen = false;
     input->GetPopupOpen(&isOpen);
     if (isOpen) {
-      PRBool reverse = aKey == nsIDOMKeyEvent::DOM_VK_UP ||
-                      aKey == nsIDOMKeyEvent::DOM_VK_PAGE_UP ? PR_TRUE : PR_FALSE;
-      PRBool page = aKey == nsIDOMKeyEvent::DOM_VK_PAGE_UP ||
-                    aKey == nsIDOMKeyEvent::DOM_VK_PAGE_DOWN ? PR_TRUE : PR_FALSE;
+      bool reverse = aKey == nsIDOMKeyEvent::DOM_VK_UP ||
+                      aKey == nsIDOMKeyEvent::DOM_VK_PAGE_UP ? true : false;
+      bool page = aKey == nsIDOMKeyEvent::DOM_VK_PAGE_UP ||
+                    aKey == nsIDOMKeyEvent::DOM_VK_PAGE_DOWN ? true : false;
 
       // Fill in the value of the textbox with whatever is selected in the popup
       // if the completeSelectedIndex attribute is set.  We check this before
       // calling SelectBy of an earlier attempt to avoid crashing.
-      PRBool completeSelection;
+      bool completeSelection;
       input->GetCompleteSelectedIndex(&completeSelection);
 
       // Instruct the result view to scroll by the given amount and direction
@@ -435,7 +435,7 @@ nsAutoCompleteController::HandleKeyNavigation(PRUint32 aKey, PRBool *_retval)
         if (selectedIndex >= 0) {
           //  A result is selected, so fill in its value
           nsAutoString value;
-          if (NS_SUCCEEDED(GetResultValueAt(selectedIndex, PR_TRUE, value))) {
+          if (NS_SUCCEEDED(GetResultValueAt(selectedIndex, true, value))) {
             input->SetTextValue(value);
             input->SelectTextRange(value.Length(), value.Length());
           }
@@ -456,7 +456,7 @@ nsAutoCompleteController::HandleKeyNavigation(PRUint32 aKey, PRBool *_retval)
         input->GetSelectionStart(&start);
         input->GetSelectionEnd(&end);
         if (start > 0 || start != end)
-          *_retval = PR_FALSE;
+          *_retval = false;
       }
       else if (aKey == nsIDOMKeyEvent::DOM_VK_DOWN) {
         nsAutoString text;
@@ -464,7 +464,7 @@ nsAutoCompleteController::HandleKeyNavigation(PRUint32 aKey, PRBool *_retval)
         input->GetSelectionStart(&start);
         input->GetSelectionEnd(&end);
         if (start != end || end < (PRInt32)text.Length())
-          *_retval = PR_FALSE;
+          *_retval = false;
       }
 #endif
       if (*_retval) {
@@ -496,17 +496,17 @@ nsAutoCompleteController::HandleKeyNavigation(PRUint32 aKey, PRBool *_retval)
             )
   {
     // The user hit a text-navigation key.
-    PRBool isOpen = PR_FALSE;
+    bool isOpen = false;
     input->GetPopupOpen(&isOpen);
     if (isOpen) {
       PRInt32 selectedIndex;
       popup->GetSelectedIndex(&selectedIndex);
-      PRBool shouldComplete;
+      bool shouldComplete;
       input->GetCompleteDefaultIndex(&shouldComplete);
       if (selectedIndex >= 0) {
         // The pop-up is open and has a selection, take its value
         nsAutoString value;
-        if (NS_SUCCEEDED(GetResultValueAt(selectedIndex, PR_TRUE, value))) {
+        if (NS_SUCCEEDED(GetResultValueAt(selectedIndex, true, value))) {
           input->SetTextValue(value);
           input->SelectTextRange(value.Length(), value.Length());
         }
@@ -520,7 +520,7 @@ nsAutoCompleteController::HandleKeyNavigation(PRUint32 aKey, PRBool *_retval)
         nsAutoString value;
         nsAutoString inputValue;
         input->GetTextValue(inputValue);
-        if (NS_SUCCEEDED(GetDefaultCompleteValue(selectedIndex, PR_FALSE, value)) &&
+        if (NS_SUCCEEDED(GetDefaultCompleteValue(selectedIndex, false, value)) &&
             value.Equals(inputValue, nsCaseInsensitiveStringComparator())) {
           input->SetTextValue(value);
           input->SelectTextRange(value.Length(), value.Length());
@@ -542,14 +542,14 @@ nsAutoCompleteController::HandleKeyNavigation(PRUint32 aKey, PRBool *_retval)
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::HandleDelete(PRBool *_retval)
+nsAutoCompleteController::HandleDelete(bool *_retval)
 {
-  *_retval = PR_FALSE;
+  *_retval = false;
   if (!mInput)
     return NS_OK;
 
   nsCOMPtr<nsIAutoCompleteInput> input(mInput);
-  PRBool isOpen = PR_FALSE;
+  bool isOpen = false;
   input->GetPopupOpen(&isOpen);
   if (!isOpen || mRowCount <= 0) {
     // Nothing left to delete, proceed as normal
@@ -572,11 +572,11 @@ nsAutoCompleteController::HandleDelete(PRBool *_retval)
   input->GetSearchParam(search);
 
   // Clear the row in our result and in the DB.
-  result->RemoveValueAt(rowIndex, PR_TRUE);
+  result->RemoveValueAt(rowIndex, true);
   --mRowCount;
 
   // We removed it, so make sure we cancel the event that triggered this call.
-  *_retval = PR_TRUE;
+  *_retval = true;
 
   // Unselect the current item.
   popup->SetSelectedIndex(-1);
@@ -594,11 +594,11 @@ nsAutoCompleteController::HandleDelete(PRBool *_retval)
     popup->SetSelectedIndex(index);
 
     // Complete to the new current value.
-    PRBool shouldComplete = PR_FALSE;
+    bool shouldComplete = false;
     mInput->GetCompleteDefaultIndex(&shouldComplete);
     if (shouldComplete) {
       nsAutoString value;
-      if (NS_SUCCEEDED(GetResultValueAt(index, PR_TRUE, value))) {
+      if (NS_SUCCEEDED(GetResultValueAt(index, true, value))) {
         CompleteValue(value);
       }
     }
@@ -631,7 +631,7 @@ nsAutoCompleteController::GetResultAt(PRInt32 aIndex, nsIAutoCompleteResult** aR
 NS_IMETHODIMP
 nsAutoCompleteController::GetValueAt(PRInt32 aIndex, nsAString & _retval)
 {
-  GetResultLabelAt(aIndex, PR_FALSE, _retval);
+  GetResultLabelAt(aIndex, false, _retval);
 
   return NS_OK;
 }
@@ -639,7 +639,7 @@ nsAutoCompleteController::GetValueAt(PRInt32 aIndex, nsAString & _retval)
 NS_IMETHODIMP
 nsAutoCompleteController::GetLabelAt(PRInt32 aIndex, nsAString & _retval)
 {
-  GetResultLabelAt(aIndex, PR_FALSE, _retval);
+  GetResultLabelAt(aIndex, false, _retval);
 
   return NS_OK;
 }
@@ -805,21 +805,21 @@ nsAutoCompleteController::GetCellText(PRInt32 row, nsITreeColumn* col, nsAString
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::IsContainer(PRInt32 index, PRBool *_retval)
+nsAutoCompleteController::IsContainer(PRInt32 index, bool *_retval)
 {
-  *_retval = PR_FALSE;
+  *_retval = false;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::IsContainerOpen(PRInt32 index, PRBool *_retval)
+nsAutoCompleteController::IsContainerOpen(PRInt32 index, bool *_retval)
 {
   NS_NOTREACHED("no container cells");
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::IsContainerEmpty(PRInt32 index, PRBool *_retval)
+nsAutoCompleteController::IsContainerEmpty(PRInt32 index, bool *_retval)
 {
   NS_NOTREACHED("no container cells");
   return NS_OK;
@@ -840,9 +840,9 @@ nsAutoCompleteController::GetParentIndex(PRInt32 rowIndex, PRInt32 *_retval)
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::HasNextSibling(PRInt32 rowIndex, PRInt32 afterIndex, PRBool *_retval)
+nsAutoCompleteController::HasNextSibling(PRInt32 rowIndex, PRInt32 afterIndex, bool *_retval)
 {
-  *_retval = PR_FALSE;
+  *_retval = false;
   return NS_OK;
 }
 
@@ -904,36 +904,36 @@ nsAutoCompleteController::CycleCell(PRInt32 row, nsITreeColumn* col)
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::IsEditable(PRInt32 row, nsITreeColumn* col, PRBool *_retval)
+nsAutoCompleteController::IsEditable(PRInt32 row, nsITreeColumn* col, bool *_retval)
 {
-  *_retval = PR_FALSE;
+  *_retval = false;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::IsSelectable(PRInt32 row, nsITreeColumn* col, PRBool *_retval)
+nsAutoCompleteController::IsSelectable(PRInt32 row, nsITreeColumn* col, bool *_retval)
 {
-  *_retval = PR_FALSE;
+  *_retval = false;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::IsSeparator(PRInt32 index, PRBool *_retval)
+nsAutoCompleteController::IsSeparator(PRInt32 index, bool *_retval)
 {
-  *_retval = PR_FALSE;
+  *_retval = false;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsAutoCompleteController::IsSorted(PRBool *_retval)
+nsAutoCompleteController::IsSorted(bool *_retval)
 {
-  *_retval = PR_FALSE;
+  *_retval = false;
   return NS_OK;
 }
 
 NS_IMETHODIMP
 nsAutoCompleteController::CanDrop(PRInt32 index, PRInt32 orientation,
-                                  nsIDOMDataTransfer* dataTransfer, PRBool *_retval)
+                                  nsIDOMDataTransfer* dataTransfer, bool *_retval)
 {
   return NS_OK;
 }
@@ -972,8 +972,8 @@ nsAutoCompleteController::OpenPopup()
   mInput->GetMinResultsForPopup(&minResults);
 
   if (mRowCount >= minResults) {
-    mIsOpen = PR_TRUE;
-    return mInput->SetPopupOpen(PR_TRUE);
+    mIsOpen = true;
+    return mInput->SetPopupOpen(true);
   }
 
   return NS_OK;
@@ -986,7 +986,7 @@ nsAutoCompleteController::ClosePopup()
     return NS_OK;
   }
 
-  PRBool isOpen = PR_FALSE;
+  bool isOpen = false;
   mInput->GetPopupOpen(&isOpen);
   if (!isOpen)
     return NS_OK;
@@ -995,8 +995,8 @@ nsAutoCompleteController::ClosePopup()
   mInput->GetPopup(getter_AddRefs(popup));
   NS_ENSURE_TRUE(popup != nsnull, NS_ERROR_FAILURE);
   popup->SetSelectedIndex(-1);
-  mIsOpen = PR_FALSE;
-  return mInput->SetPopupOpen(PR_FALSE);
+  mIsOpen = false;
+  return mInput->SetPopupOpen(false);
 }
 
 nsresult
@@ -1005,7 +1005,7 @@ nsAutoCompleteController::StartSearch()
   NS_ENSURE_STATE(mInput);
   nsCOMPtr<nsIAutoCompleteInput> input(mInput);
   mSearchStatus = nsIAutoCompleteController::STATUS_SEARCHING;
-  mDefaultIndexCompleted = PR_FALSE;
+  mDefaultIndexCompleted = false;
 
   // Cache the current results so that we can pass these through to all the
   // searches without losing them
@@ -1016,7 +1016,7 @@ nsAutoCompleteController::StartSearch()
 
   PRUint32 count = mSearches.Count();
   mSearchesOngoing = count;
-  mFirstSearchResult = PR_TRUE;
+  mFirstSearchResult = true;
 
   // notify the input that the search is beginning
   input->OnSearchBegin();
@@ -1118,23 +1118,23 @@ nsAutoCompleteController::ClearSearchTimer()
 }
 
 nsresult
-nsAutoCompleteController::EnterMatch(PRBool aIsPopupSelection)
+nsAutoCompleteController::EnterMatch(bool aIsPopupSelection)
 {
   nsCOMPtr<nsIAutoCompleteInput> input(mInput);
   nsCOMPtr<nsIAutoCompletePopup> popup;
   input->GetPopup(getter_AddRefs(popup));
   NS_ENSURE_TRUE(popup != nsnull, NS_ERROR_FAILURE);
 
-  PRBool forceComplete;
+  bool forceComplete;
   input->GetForceComplete(&forceComplete);
 
   // Ask the popup if it wants to enter a special value into the textbox
   nsAutoString value;
   popup->GetOverrideValue(value);
   if (value.IsEmpty()) {
-    PRBool shouldComplete;
+    bool shouldComplete;
     mInput->GetCompleteDefaultIndex(&shouldComplete);
-    PRBool completeSelection;
+    bool completeSelection;
     input->GetCompleteSelectedIndex(&completeSelection);
 
     // If completeselectedindex is false or a row was selected from the popup,
@@ -1144,7 +1144,7 @@ nsAutoCompleteController::EnterMatch(PRBool aIsPopupSelection)
     PRInt32 selectedIndex;
     popup->GetSelectedIndex(&selectedIndex);
     if (selectedIndex >= 0 && (!completeSelection || aIsPopupSelection))
-      GetResultValueAt(selectedIndex, PR_TRUE, value);
+      GetResultValueAt(selectedIndex, true, value);
     else if (shouldComplete) {
       // We usually try to preserve the casing of what user has typed, but
       // if he wants to autocomplete, we will replace the value with the
@@ -1154,7 +1154,7 @@ nsAutoCompleteController::EnterMatch(PRBool aIsPopupSelection)
       nsAutoString defaultIndexValue;
       nsAutoString inputValue;
       input->GetTextValue(inputValue);
-      if (NS_SUCCEEDED(GetDefaultCompleteValue(selectedIndex, PR_FALSE, defaultIndexValue)) &&
+      if (NS_SUCCEEDED(GetDefaultCompleteValue(selectedIndex, false, defaultIndexValue)) &&
           defaultIndexValue.Equals(inputValue, nsCaseInsensitiveStringComparator()))
         value = defaultIndexValue;
     }
@@ -1192,7 +1192,7 @@ nsAutoCompleteController::EnterMatch(PRBool aIsPopupSelection)
   obsSvc->NotifyObservers(input, "autocomplete-did-enter-text", nsnull);
   ClosePopup();
 
-  PRBool cancel;
+  bool cancel;
   input->OnTextEntered(&cancel);
 
   return NS_OK;
@@ -1210,7 +1210,7 @@ nsAutoCompleteController::RevertTextValue()
   nsAutoString oldValue(mSearchString);
   nsCOMPtr<nsIAutoCompleteInput> input(mInput);
 
-  PRBool cancel = PR_FALSE;
+  bool cancel = false;
   input->OnTextReverted(&cancel);
 
   if (!cancel) {
@@ -1219,7 +1219,13 @@ nsAutoCompleteController::RevertTextValue()
     NS_ENSURE_STATE(obsSvc);
     obsSvc->NotifyObservers(input, "autocomplete-will-revert-text", nsnull);
 
-    input->SetTextValue(oldValue);
+    nsAutoString inputValue;
+    input->GetTextValue(inputValue);
+    // Don't change the value if it is the same to prevent sending useless events.
+    // NOTE: how can |RevertTextValue| be called with inputValue != oldValue?
+    if (!oldValue.Equals(inputValue)) {
+      input->SetTextValue(oldValue);
+    }
 
     obsSvc->NotifyObservers(input, "autocomplete-did-revert-text", nsnull);
   }
@@ -1237,7 +1243,7 @@ nsAutoCompleteController::ProcessResult(PRInt32 aSearchIndex, nsIAutoCompleteRes
   // we should clear out the previously cached results
   if (mFirstSearchResult) {
     ClearResults();
-    mFirstSearchResult = PR_FALSE;
+    mFirstSearchResult = false;
   }
 
   PRUint16 result = 0;
@@ -1379,23 +1385,23 @@ nsAutoCompleteController::CompleteDefaultIndex(PRInt32 aSearchIndex)
       selectionEnd != (PRInt32)mSearchString.Length())
     return NS_OK;
 
-  PRBool shouldComplete;
+  bool shouldComplete;
   mInput->GetCompleteDefaultIndex(&shouldComplete);
   if (!shouldComplete)
     return NS_OK;
 
   nsAutoString resultValue;
-  if (NS_SUCCEEDED(GetDefaultCompleteValue(aSearchIndex, PR_TRUE, resultValue)))
+  if (NS_SUCCEEDED(GetDefaultCompleteValue(aSearchIndex, true, resultValue)))
     CompleteValue(resultValue);
 
-  mDefaultIndexCompleted = PR_TRUE;
+  mDefaultIndexCompleted = true;
 
   return NS_OK;
 }
 
 nsresult
 nsAutoCompleteController::GetDefaultCompleteValue(PRInt32 aSearchIndex,
-                                                  PRBool aPreserveCasing,
+                                                  bool aPreserveCasing,
                                                   nsAString &_retval)
 {
   PRInt32 defaultIndex = -1;
@@ -1505,20 +1511,20 @@ nsAutoCompleteController::CompleteValue(nsString &aValue)
 }
 
 nsresult
-nsAutoCompleteController::GetResultLabelAt(PRInt32 aIndex, PRBool aValueOnly, nsAString & _retval)
+nsAutoCompleteController::GetResultLabelAt(PRInt32 aIndex, bool aValueOnly, nsAString & _retval)
 {
-  return GetResultValueLabelAt(aIndex, aValueOnly, PR_FALSE, _retval);
+  return GetResultValueLabelAt(aIndex, aValueOnly, false, _retval);
 }
 
 nsresult
-nsAutoCompleteController::GetResultValueAt(PRInt32 aIndex, PRBool aValueOnly, nsAString & _retval)
+nsAutoCompleteController::GetResultValueAt(PRInt32 aIndex, bool aValueOnly, nsAString & _retval)
 {
-  return GetResultValueLabelAt(aIndex, aValueOnly, PR_TRUE, _retval);
+  return GetResultValueLabelAt(aIndex, aValueOnly, true, _retval);
 }
 
 nsresult
-nsAutoCompleteController::GetResultValueLabelAt(PRInt32 aIndex, PRBool aValueOnly,
-                                               PRBool aGetValue, nsAString & _retval)
+nsAutoCompleteController::GetResultValueLabelAt(PRInt32 aIndex, bool aValueOnly,
+                                               bool aGetValue, nsAString & _retval)
 {
   NS_ENSURE_TRUE(aIndex >= 0 && (PRUint32) aIndex < mRowCount, NS_ERROR_ILLEGAL_VALUE);
 
