@@ -60,7 +60,7 @@ const kBookTagSQLFragment =
 + "( "
 +   "SELECT GROUP_CONCAT(t.title, ',') "
 +   "FROM moz_bookmarks b "
-+   "JOIN moz_bookmarks t ON t.id = b.parent AND t.parent = :parent "
++   "JOIN moz_bookmarks t ON t.id = +b.parent AND t.parent = :parent "
 +   "WHERE b.fk = h.id "
 + ") AS tags";
 
@@ -113,9 +113,6 @@ const kBrowserUrlbarBranch = "browser.urlbar.";
  */
 function initTempTable(aDatabase)
 {
-  // Keep our temporary table in memory.
-  aDatabase.executeSimpleSQL("PRAGMA temp_store = MEMORY");
-
   // Note: this should be kept up-to-date with the definition in
   //       nsPlacesTables.h.
   let stmt = aDatabase.createAsyncStatement(
@@ -254,6 +251,22 @@ function nsPlacesAutoComplete()
     // Create our in-memory tables for tab tracking.
     initTempTable(db);
 
+    // Populate the table with current open pages cache contents.
+    if (this._openPagesCache.length > 0) {
+      // Avoid getter re-entrance from the _registerOpenPageQuery lazy getter.
+      let stmt = this._registerOpenPageQuery =
+        db.createAsyncStatement(this._registerOpenPageQuerySQL);
+      let params = stmt.newBindingParamsArray();
+      for (let i = 0; i < this._openPagesCache.length; i++) {
+        let bp = params.newBindingParams();
+        bp.bindByName("page_url", this._openPagesCache[i]);
+        params.addParams(bp);
+      }
+      stmt.bindParameters(params);
+      stmt.executeAsync();
+      delete this._openPagesCache;
+    }
+
     return db;
   });
 
@@ -379,20 +392,20 @@ function nsPlacesAutoComplete()
     );
   });
 
+  this._registerOpenPageQuerySQL = "INSERT OR REPLACE INTO moz_openpages_temp "
+                                 +   "(url, open_count) "
+                                 + "VALUES (:page_url, "
+                                 +   "IFNULL("
+                                 +     "("
+                                 +        "SELECT open_count + 1 "
+                                 +        "FROM moz_openpages_temp "
+                                 +        "WHERE url = :page_url "
+                                 +      "), "
+                                 +     "1"
+                                 +   ")"
+                                 + ")";
   XPCOMUtils.defineLazyGetter(this, "_registerOpenPageQuery", function() {
-    return this._db.createAsyncStatement(
-      "INSERT OR REPLACE INTO moz_openpages_temp (url, open_count) "
-    + "VALUES (:page_url, "
-    +   "IFNULL("
-    +     "("
-    +        "SELECT open_count + 1 "
-    +        "FROM moz_openpages_temp "
-    +        "WHERE url = :page_url "
-    +      "), "
-    +     "1"
-    +   ")"
-    + ")"
-    );
+    return this._db.createAsyncStatement(this._registerOpenPageQuerySQL);
   });
 
   XPCOMUtils.defineLazyGetter(this, "_unregisterOpenPageQuery", function() {
@@ -509,19 +522,33 @@ nsPlacesAutoComplete.prototype = {
   //////////////////////////////////////////////////////////////////////////////
   //// mozIPlacesAutoComplete
 
+  // If the connection has not yet been started, use this local cache.  This
+  // prevents autocomplete from initing the database till the first search.
+  _openPagesCache: [],
   registerOpenPage: function PAC_registerOpenPage(aURI)
   {
+    if (!this._databaseInitialized) {
+      this._openPagesCache.push(aURI.spec);
+      return;
+    }
+
     let stmt = this._registerOpenPageQuery;
     stmt.params.page_url = aURI.spec;
-
     stmt.executeAsync();
   },
 
   unregisterOpenPage: function PAC_unregisterOpenPage(aURI)
   {
+    if (!this._databaseInitialized) {
+      let index = this._openPagesCache.indexOf(aURI.spec);
+      if (index != -1) {
+        this._openPagesCache.splice(index, 1);
+      }
+      return;
+    }
+
     let stmt = this._unregisterOpenPageQuery;
     stmt.params.page_url = aURI.spec;
-
     stmt.executeAsync();
   },
 
@@ -613,7 +640,7 @@ nsPlacesAutoComplete.prototype = {
         }
       }
 
-      if (Object.getOwnPropertyDescriptor(this, "_db").value !== undefined) {
+      if (this._databaseInitialized) {
         this._db.asyncClose();
       }
     }
@@ -625,6 +652,9 @@ nsPlacesAutoComplete.prototype = {
   //////////////////////////////////////////////////////////////////////////////
   //// nsPlacesAutoComplete
 
+  get _databaseInitialized()
+    Object.getOwnPropertyDescriptor(this, "_db").value !== undefined,
+
   /**
    * Used to unescape encoded URI strings, and drop information that we do not
    * care about for searching.
