@@ -1,42 +1,10 @@
-/* -*- Mode: Java; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* vim:set ts=2 sw=2 sts=2 et: */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Mozilla Corporation.
- * Portions created by the Initial Developer are Copyright (C) 2007
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Shawn Wilsher <me@shawnwilsher.com> (Original Author)
- *   Marco Bonardo <mak77@bonardo.net>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* Any copyright is dedicated to the Public Domain.
+   http://creativecommons.org/publicdomain/zero/1.0/ */
+
+/**
+ * The first part of this file runs a series of tests for the synchronous
+ * behavior of the nsIDownloadHistory::AddDownload function.
+ */
 
 // Get services
 var histsvc = Cc["@mozilla.org/browser/nav-history-service;1"].
@@ -159,4 +127,93 @@ function run_test() {
   }
 
   os.removeObserver(observer, NS_LINK_VISITED_EVENT_TOPIC);
+
+  // Asynchronous part of the test.
+  test_dh_details();
+}
+
+/**
+ * The second part of this file tests that nsIDownloadHistory::AddDownload saves
+ * the additional download details if the optional destination URL is specified.
+ */
+
+function test_dh_details()
+{
+  do_test_pending();
+
+  const SOURCE_URI = uri("http://example.com/test_download_history_details");
+  const DEST_FILE_NAME = "dest.txt";
+
+  // We must build a real, valid file URI for the destination.
+  let destFileUri = NetUtil.newURI(FileUtils.getFile("TmpD", [DEST_FILE_NAME]));
+
+  let titleSet = false;
+  let destinationFileUriSet = false;
+  let destinationFileNameSet = false;
+
+  function checkFinished()
+  {
+    if (titleSet && destinationFileUriSet && destinationFileNameSet) {
+      PlacesUtils.annotations.removeObserver(annoObserver);
+      PlacesUtils.history.removeObserver(historyObserver);
+
+      // Cleanup.
+      bh.removeAllPages();
+      do_test_finished();
+    }
+  };
+
+  let annoObserver = {
+    onPageAnnotationSet: function AO_onPageAnnotationSet(aPage, aName)
+    {
+      if (aPage.equals(SOURCE_URI)) {
+        let value = PlacesUtils.annotations.getPageAnnotation(aPage, aName);
+        switch (aName)
+        {
+          case "downloads/destinationFileURI":
+            destinationFileUriSet = true;
+            do_check_eq(value, destFileUri.spec);
+            break;
+          case "downloads/destinationFileName":
+            destinationFileNameSet = true;
+            do_check_eq(value, DEST_FILE_NAME);
+            break;
+        }
+        checkFinished();
+      }
+    },
+    onItemAnnotationSet: function() {},
+    onPageAnnotationRemoved: function() {},
+    onItemAnnotationRemoved: function() {}
+  }
+
+  let historyObserver = {
+    onBeginUpdateBatch: function() {},
+    onEndUpdateBatch: function() {},
+    onVisit: function() {},
+    onTitleChanged: function HO_onTitleChanged(aURI, aPageTitle)
+    {
+      if (aURI.equals(SOURCE_URI)) {
+        titleSet = true;
+        do_check_eq(aPageTitle, DEST_FILE_NAME);
+        checkFinished();
+      }
+    },
+    onBeforeDeleteURI: function() {},
+    onDeleteURI: function() {},
+    onClearHistory: function() {},
+    onPageChanged: function() {},
+    onDeleteVisits: function() {}   
+  };
+
+  PlacesUtils.annotations.addObserver(annoObserver, false);
+  PlacesUtils.history.addObserver(historyObserver, false);
+
+  // Both null values and remote URIs should not cause errors.
+  dh.addDownload(SOURCE_URI, null, Date.now() * 1000);
+  dh.addDownload(SOURCE_URI, null, Date.now() * 1000, null);
+  dh.addDownload(SOURCE_URI, null, Date.now() * 1000, uri("http://localhost/"));
+
+  // Valid local file URIs should cause the download details to be saved.
+  dh.addDownload(SOURCE_URI, null, Date.now() * 1000, destFileUri);
 }
