@@ -9,7 +9,8 @@ do_load_httpd_js();
 var testserver;
 
 // The test extension uses an insecure update url.
-Services.prefs.setBoolPref("extensions.checkUpdateSecurity", false);
+Services.prefs.setBoolPref(PREF_EM_CHECK_UPDATE_SECURITY, false);
+Services.prefs.setBoolPref(PREF_EM_STRICT_COMPATIBILITY, false);
 
 // Will be enabled
 var addon1 = {
@@ -35,7 +36,7 @@ var addon2 = {
   }]
 };
 
-// Will get a compatibility update and be enabled
+// Will get a compatibility update and stay enabled
 var addon3 = {
   id: "addon3@tests.mozilla.org",
   version: "1.0",
@@ -48,7 +49,7 @@ var addon3 = {
   }]
 };
 
-// Will get a compatibility update and be disabled
+// Will get a compatibility update and be enabled
 var addon4 = {
   id: "addon4@tests.mozilla.org",
   version: "1.0",
@@ -61,7 +62,7 @@ var addon4 = {
   }]
 };
 
-// Stays incompatible
+// Would stay incompatible with strict compat
 var addon5 = {
   id: "addon5@tests.mozilla.org",
   version: "1.0",
@@ -217,9 +218,9 @@ function run_test_1() {
     do_check_eq(a4.pendingOperations, AddonManager.PENDING_NONE);
 
     do_check_neq(a5, null);
-    do_check_false(a5.isActive);
+    do_check_true(a5.isActive);
     do_check_false(a5.userDisabled);
-    do_check_true(a5.appDisabled);
+    do_check_false(a5.appDisabled);
     do_check_eq(a5.pendingOperations, AddonManager.PENDING_NONE);
 
     do_check_neq(a6, null);
@@ -285,21 +286,23 @@ function run_test_1() {
       do_check_neq(a3, null);
       do_check_true(a3.isActive);
       do_check_false(a3.userDisabled);
-      do_check_true(a3.appDisabled);
-      do_check_eq(a3.pendingOperations, AddonManager.PENDING_DISABLE);
+      do_check_false(a3.appDisabled);
+      do_check_eq(a3.pendingOperations, AddonManager.PENDING_NONE);
 
-      // The compatibility update won't be recovered and it will not have been
-      // able to tell that it was previously userDisabled
+      // The compatibility update won't be recovered and with strict
+      // compatibility it would not have been able to tell that it was
+      // previously userDisabled. However, without strict compat, it wasn't
+      // appDisabled, so it knows it must have been userDisabled.
       do_check_neq(a4, null);
       do_check_false(a4.isActive);
-      do_check_false(a4.userDisabled);
-      do_check_true(a4.appDisabled);
+      do_check_true(a4.userDisabled);
+      do_check_false(a4.appDisabled);
       do_check_eq(a4.pendingOperations, AddonManager.PENDING_NONE);
 
       do_check_neq(a5, null);
-      do_check_false(a5.isActive);
+      do_check_true(a5.isActive);
       do_check_false(a5.userDisabled);
-      do_check_true(a5.appDisabled);
+      do_check_false(a5.appDisabled);
       do_check_eq(a5.pendingOperations, AddonManager.PENDING_NONE);
 
       do_check_neq(a6, null);
@@ -354,21 +357,21 @@ function run_test_1() {
         do_check_eq(a2.pendingOperations, AddonManager.PENDING_NONE);
 
         do_check_neq(a3, null);
-        do_check_false(a3.isActive);
+        do_check_true(a3.isActive);
         do_check_false(a3.userDisabled);
-        do_check_true(a3.appDisabled);
+        do_check_false(a3.appDisabled);
         do_check_eq(a3.pendingOperations, AddonManager.PENDING_NONE);
 
         do_check_neq(a4, null);
         do_check_false(a4.isActive);
-        do_check_false(a4.userDisabled);
-        do_check_true(a4.appDisabled);
+        do_check_true(a4.userDisabled);
+        do_check_false(a4.appDisabled);
         do_check_eq(a4.pendingOperations, AddonManager.PENDING_NONE);
 
         do_check_neq(a5, null);
-        do_check_false(a5.isActive);
+        do_check_true(a5.isActive);
         do_check_false(a5.userDisabled);
-        do_check_true(a5.appDisabled);
+        do_check_false(a5.appDisabled);
         do_check_eq(a5.pendingOperations, AddonManager.PENDING_NONE);
 
         do_check_neq(a6, null);
