@@ -66,7 +66,6 @@
 #include "nsXPIDLString.h"
 #include "nsString.h"
 #include "nsNetUtil.h"
-#include "nsIDOMWindowInternal.h"
 #include "nsReadableUtils.h"
 #include "nsDOMError.h"
 
@@ -80,6 +79,19 @@
 
 #include "nsDocLoader.h"
 
+#include "mozilla/FunctionTimer.h"
+#ifdef NS_FUNCTION_TIMER
+#define TIME_URILOADER_FUNCTION(req)                         \
+    nsCAutoString name__("N/A");                             \
+    (req)->GetName(name__);                                  \
+    NS_TIME_FUNCTION_FMT("%s (line %d) (request: %s)",       \
+                         MOZ_FUNCTION_NAME,                  \
+                         __LINE__,                           \
+                         name__.get())
+#else
+#define TIME_URILOADER_FUNCTION(req) do {} while(0)
+#endif
+
 #ifdef PR_LOGGING
 PRLogModuleInfo* nsURILoader::mLog = nsnull;
 #endif
@@ -129,11 +141,11 @@ public:
 
   /**
    * Function to attempt to use aListener to handle the load.  If
-   * PR_TRUE is returned, nothing else needs to be done; if PR_FALSE
+   * true is returned, nothing else needs to be done; if false
    * is returned, then a different way of handling the load should be
    * tried.
    */
-  PRBool TryContentListener(nsIURIContentListener* aListener,
+  bool TryContentListener(nsIURIContentListener* aListener,
                             nsIChannel* aChannel);
 
   // nsIRequestObserver methods:
@@ -224,6 +236,8 @@ nsresult nsDocumentOpenInfo::Prepare()
 
 NS_IMETHODIMP nsDocumentOpenInfo::OnStartRequest(nsIRequest *request, nsISupports * aCtxt)
 {
+  TIME_URILOADER_FUNCTION(request);
+
   LOG(("[0x%p] nsDocumentOpenInfo::OnStartRequest", this));
   
   nsresult rv = NS_OK;
@@ -297,6 +311,8 @@ NS_IMETHODIMP nsDocumentOpenInfo::OnStartRequest(nsIRequest *request, nsISupport
 NS_IMETHODIMP nsDocumentOpenInfo::OnDataAvailable(nsIRequest *request, nsISupports * aCtxt,
                                                   nsIInputStream * inStr, PRUint32 sourceOffset, PRUint32 count)
 {
+  TIME_URILOADER_FUNCTION(request);
+
   // if we have retarged to the end stream listener, then forward the call....
   // otherwise, don't do anything
 
@@ -310,6 +326,8 @@ NS_IMETHODIMP nsDocumentOpenInfo::OnDataAvailable(nsIRequest *request, nsISuppor
 NS_IMETHODIMP nsDocumentOpenInfo::OnStopRequest(nsIRequest *request, nsISupports *aCtxt, 
                                                 nsresult aStatus)
 {
+  TIME_URILOADER_FUNCTION(request);
+
   LOG(("[0x%p] nsDocumentOpenInfo::OnStopRequest", this));
   
   if ( m_targetStreamListener)
@@ -332,6 +350,8 @@ NS_IMETHODIMP nsDocumentOpenInfo::OnStopRequest(nsIRequest *request, nsISupports
 
 nsresult nsDocumentOpenInfo::DispatchContent(nsIRequest *request, nsISupports * aCtxt)
 {
+  TIME_URILOADER_FUNCTION(request);
+
   LOG(("[0x%p] nsDocumentOpenInfo::DispatchContent for type '%s'", this, mContentType.get()));
 
   NS_PRECONDITION(!m_targetStreamListener,
@@ -351,7 +371,7 @@ nsresult nsDocumentOpenInfo::DispatchContent(nsIRequest *request, nsISupports *
     LOG(("  Got type from channel: '%s'", mContentType.get()));
   }
 
-  PRBool isGuessFromExt =
+  bool isGuessFromExt =
     mContentType.LowerCaseEqualsASCII(APPLICATION_GUESS_FROM_EXT);
   if (isGuessFromExt) {
     // Reset to application/octet-stream for now; no one other than the
@@ -364,59 +384,11 @@ nsresult nsDocumentOpenInfo::DispatchContent(nsIRequest *request, nsISupports *
   // could happen because the Content-Disposition header is set so, or, in the
   // future, because the user has specified external handling for the MIME
   // type.
-  PRBool forceExternalHandling = PR_FALSE;
-  nsCAutoString disposition;
-  nsCOMPtr<nsIHttpChannel> httpChannel(do_QueryInterface(request));
-  nsCOMPtr<nsIURI> uri;
-  if (httpChannel)
-  {
-    rv = httpChannel->GetResponseHeader(NS_LITERAL_CSTRING("content-disposition"),
-                                        disposition);
-    httpChannel->GetURI(getter_AddRefs(uri));
-  }
-  else
-  {
-    nsCOMPtr<nsIMultiPartChannel> multipartChannel(do_QueryInterface(request));
-    if (multipartChannel)
-    {
-      rv = multipartChannel->GetContentDisposition(disposition);
-    } else {
-      // Soon-to-be common way to get Disposition: right now only JARChannel
-      rv = NS_GetContentDisposition(request, disposition);
-    }
-  }
-
-  LOG(("  Disposition header: '%s'", disposition.get()));
-
-  if (NS_SUCCEEDED(rv) && !disposition.IsEmpty())
-  {
-    nsCOMPtr<nsIMIMEHeaderParam> mimehdrpar = do_GetService(NS_MIMEHEADERPARAM_CONTRACTID, &rv);
-    if (NS_SUCCEEDED(rv))
-    {
-      nsCAutoString fallbackCharset;
-      if (uri)
-        uri->GetOriginCharset(fallbackCharset);
-      nsAutoString dispToken;
-      // Get the disposition type
-      rv = mimehdrpar->GetParameter(disposition, "", fallbackCharset,
-                                    PR_TRUE, nsnull, dispToken);
-      // RFC 2183, section 2.8 says that an unknown disposition
-      // value should be treated as "attachment"
-      // XXXbz this code is duplicated in GetFilenameAndExtensionFromChannel in
-      // nsExternalHelperAppService.  Factor it out!
-      if (NS_FAILED(rv) || 
-          (!dispToken.IsEmpty() &&
-           !dispToken.LowerCaseEqualsLiteral("inline") &&
-           // Broken sites just send
-           // Content-Disposition: filename="file"
-           // without a disposition token... screen those out.
-           !dispToken.EqualsIgnoreCase("filename", 8) &&
-           // Also in use is Content-Disposition: name="file"
-           !dispToken.EqualsIgnoreCase("name", 4)))
-        // We have a content-disposition of "attachment" or unknown
-        forceExternalHandling = PR_TRUE;
-    }
-  }
+  bool forceExternalHandling = false;
+  PRUint32 disposition;
+  rv = aChannel->GetContentDisposition(&disposition);
+  if (NS_SUCCEEDED(rv) && disposition == nsIChannel::DISPOSITION_ATTACHMENT)
+    forceExternalHandling = true;
 
   LOG(("  forceExternalHandling: %s", forceExternalHandling ? "yes" : "no"));
     
@@ -556,8 +528,9 @@ nsresult nsDocumentOpenInfo::DispatchContent(nsIRequest *request, nsISupports *
   // Before dispatching to the external helper app service, check for an HTTP
   // error page.  If we got one, we don't want to handle it with a helper app,
   // really.
+  nsCOMPtr<nsIHttpChannel> httpChannel(do_QueryInterface(request));
   if (httpChannel) {
-    PRBool requestSucceeded;
+    bool requestSucceeded;
     httpChannel->GetRequestSucceeded(&requestSucceeded);
     if (!requestSucceeded) {
       // returning error from OnStartRequest will cancel the channel
@@ -590,7 +563,7 @@ nsresult nsDocumentOpenInfo::DispatchContent(nsIRequest *request, nsISupports *
     rv = helperAppService->DoContent(mContentType,
                                      request,
                                      m_originalContext,
-                                     PR_FALSE,
+                                     false,
                                      getter_AddRefs(m_targetStreamListener));
     if (NS_FAILED(rv)) {
       request->SetLoadFlags(loadFlags);
@@ -609,6 +582,8 @@ nsDocumentOpenInfo::ConvertData(nsIRequest *request,
                                 const nsACString& aSrcContentType,
                                 const nsACString& aOutContentType)
 {
+  TIME_URILOADER_FUNCTION(request);
+
   LOG(("[0x%p] nsDocumentOpenInfo::ConvertData from '%s' to '%s'", this,
        PromiseFlatCString(aSrcContentType).get(),
        PromiseFlatCString(aOutContentType).get()));
@@ -661,17 +636,19 @@ nsDocumentOpenInfo::ConvertData(nsIRequest *request,
                                              getter_AddRefs(m_targetStreamListener));
 }
 
-PRBool
+bool
 nsDocumentOpenInfo::TryContentListener(nsIURIContentListener* aListener,
                                        nsIChannel* aChannel)
 {
+  TIME_URILOADER_FUNCTION(aChannel);
+
   LOG(("[0x%p] nsDocumentOpenInfo::TryContentListener; mFlags = 0x%x",
        this, mFlags));
 
   NS_PRECONDITION(aListener, "Must have a non-null listener");
   NS_PRECONDITION(aChannel, "Must have a channel");
   
-  PRBool listenerWantsContent = PR_FALSE;
+  bool listenerWantsContent = false;
   nsXPIDLCString typeToUse;
   
   if (mFlags & nsIURILoader::IS_CONTENT_PREFERRED) {
@@ -679,13 +656,13 @@ nsDocumentOpenInfo::TryContentListener(nsIURIContentListener* aListener,
                            getter_Copies(typeToUse),
                            &listenerWantsContent);
   } else {
-    aListener->CanHandleContent(mContentType.get(), PR_FALSE,
+    aListener->CanHandleContent(mContentType.get(), false,
                                 getter_Copies(typeToUse),
                                 &listenerWantsContent);
   }
   if (!listenerWantsContent) {
     LOG(("  Listener is not interested"));
-    return PR_FALSE;
+    return false;
   }
 
   if (!typeToUse.IsEmpty() && typeToUse != mContentType) {
@@ -723,8 +700,8 @@ nsDocumentOpenInfo::TryContentListener(nsIURIContentListener* aListener,
   }
   aChannel->SetLoadFlags(loadFlags | newLoadFlags);
   
-  PRBool abort = PR_FALSE;
-  PRBool isPreferred = (mFlags & nsIURILoader::IS_CONTENT_PREFERRED) != 0;
+  bool abort = false;
+  bool isPreferred = (mFlags & nsIURILoader::IS_CONTENT_PREFERRED) != 0;
   nsresult rv = aListener->DoContent(mContentType.get(),
                                      isPreferred,
                                      aChannel,
@@ -737,7 +714,7 @@ nsDocumentOpenInfo::TryContentListener(nsIURIContentListener* aListener,
     // Unset the RETARGETED_DOCUMENT_URI flag if we set it...
     aChannel->SetLoadFlags(loadFlags);
     m_targetStreamListener = nsnull;
-    return PR_FALSE;
+    return false;
   }
 
   if (abort) {
@@ -751,7 +728,7 @@ nsDocumentOpenInfo::TryContentListener(nsIURIContentListener* aListener,
   NS_ASSERTION(abort || m_targetStreamListener, "DoContent returned no listener?");
 
   // aListener is handling the load from this point on.  
-  return PR_TRUE;
+  return true;
 }
 
 
@@ -804,11 +781,13 @@ NS_IMETHODIMP nsURILoader::UnRegisterContentListener(nsIURIContentListener * aCo
 }
 
 NS_IMETHODIMP nsURILoader::OpenURI(nsIChannel *channel, 
-                                   PRBool aIsContentPreferred,
+                                   bool aIsContentPreferred,
                                    nsIInterfaceRequestor *aWindowContext)
 {
   NS_ENSURE_ARG_POINTER(channel);
 
+  TIME_URILOADER_FUNCTION(channel);
+
 #ifdef PR_LOGGING
   if (LOG_ENABLED()) {
     nsCOMPtr<nsIURI> uri;
@@ -823,7 +802,7 @@ NS_IMETHODIMP nsURILoader::OpenURI(nsIChannel *channel,
   nsresult rv = OpenChannel(channel,
                             aIsContentPreferred ? IS_CONTENT_PREFERRED : 0,
                             aWindowContext,
-                            PR_FALSE,
+                            false,
                             getter_AddRefs(loader));
 
   if (NS_SUCCEEDED(rv)) {
@@ -850,12 +829,14 @@ NS_IMETHODIMP nsURILoader::OpenURI(nsIChannel *channel,
 nsresult nsURILoader::OpenChannel(nsIChannel* channel,
                                   PRUint32 aFlags,
                                   nsIInterfaceRequestor* aWindowContext,
-                                  PRBool aChannelIsOpen,
+                                  bool aChannelIsOpen,
                                   nsIStreamListener** aListener)
 {
   NS_ASSERTION(channel, "Trying to open a null channel!");
   NS_ASSERTION(aWindowContext, "Window context must not be null");
 
+  TIME_URILOADER_FUNCTION(channel);
+
 #ifdef PR_LOGGING
   if (LOG_ENABLED()) {
     nsCOMPtr<nsIURI> uri;
@@ -873,7 +854,7 @@ nsresult nsURILoader::OpenChannel(nsIChannel* channel,
     nsCOMPtr<nsIURI> uri;
     channel->GetURI(getter_AddRefs(uri));
     if (uri) {
-      PRBool doAbort = PR_FALSE;
+      bool doAbort = false;
       winContextListener->OnStartURIOpen(uri, &doAbort);
 
       if (doAbort) {
@@ -947,9 +928,9 @@ NS_IMETHODIMP nsURILoader::OpenChannel(nsIChannel* channel,
                                        nsIInterfaceRequestor* aWindowContext,
                                        nsIStreamListener** aListener)
 {
-  PRBool pending;
+  bool pending;
   if (NS_FAILED(channel->IsPending(&pending))) {
-    pending = PR_FALSE;
+    pending = false;
   }
 
   return OpenChannel(channel, aFlags, aWindowContext, pending, aListener);
