@@ -56,15 +56,6 @@
 #include "nsOSHelperAppService.h"
 #include "nsUnicharUtils.h"
 
-#ifdef WINCE 
-#ifdef UNICODE
-#define SHELLEXECUTEINFOW SHELLEXECUTEINFO
-#define ShellExecuteExW ShellExecuteEx
-#else
-#error "we don't support narrow char wince"
-#endif
-#endif
-
 #define RUNDLL32_EXE L"\\rundll32.exe"
 
 
@@ -82,7 +73,7 @@ nsMIMEInfoWin::LaunchDefaultWithFile(nsIFile* aFile)
   if (!local)
     return NS_ERROR_FAILURE;
 
-  PRBool executable = PR_TRUE;
+  bool executable = true;
   local->IsExecutable(&executable);
   if (executable)
     return NS_ERROR_FAILURE;
@@ -116,8 +107,8 @@ nsMIMEInfoWin::LaunchWithFile(nsIFile* aFile)
     rv = localHandler->GetExecutable(getter_AddRefs(executable));
     NS_ENSURE_SUCCESS(rv, rv);
 
-    nsCAutoString path;
-    aFile->GetNativePath(path);
+    nsAutoString path;
+    aFile->GetPath(path);
 
     // Deal with local dll based handlers
     nsCString filename;
@@ -132,7 +123,7 @@ nsMIMEInfoWin::LaunchWithFile(nsIFile* aFile)
         // including the dll handler.
         nsCOMPtr<nsILocalFile> locFile(do_QueryInterface(aFile));
 
-        if (!GetDllLaunchInfo(executable, locFile, args, PR_FALSE))
+        if (!GetDllLaunchInfo(executable, locFile, args, false))
           return NS_ERROR_INVALID_ARG;
 
         WCHAR rundll32Path[MAX_PATH + sizeof(RUNDLL32_EXE) / sizeof(WCHAR) + 1] = {L'\0'};
@@ -192,7 +183,7 @@ nsMIMEInfoWin::LaunchWithFile(nsIFile* aFile)
 }
 
 NS_IMETHODIMP
-nsMIMEInfoWin::GetHasDefaultHandler(PRBool * _retval)
+nsMIMEInfoWin::GetHasDefaultHandler(bool * _retval)
 {
   // We have a default application if we have a description
   // We can ShellExecute anything; however, callers are probably interested if
@@ -256,14 +247,12 @@ nsMIMEInfoWin::GetProperty(const nsAString& aName, nsIVariant* *_retval)
   return NS_OK;
 }
 
-#ifndef WINCE
 typedef HRESULT (STDMETHODCALLTYPE *MySHParseDisplayName)
                  (PCWSTR pszName,
                   IBindCtx *pbc,
                   LPITEMIDLIST *ppidl,
                   SFGAOF sfgaoIn,
                   SFGAOF *psfgaoOut);
-#endif
 
 // this implementation was pretty much copied verbatime from 
 // Tony Robinson's code in nsExternalProtocolWin.cpp
@@ -298,17 +287,12 @@ nsMIMEInfoWin::LoadUriInternal(nsIURI * aURL)
     SHELLEXECUTEINFOW sinfo;
     memset(&sinfo, 0, sizeof(sinfo));
     sinfo.cbSize   = sizeof(sinfo);
-#ifdef WINCE
-    sinfo.fMask    = SEE_MASK_FLAG_NO_UI;
-#else
     sinfo.fMask    = SEE_MASK_FLAG_DDEWAIT |
       SEE_MASK_FLAG_NO_UI;
-#endif
     sinfo.hwnd     = NULL;
     sinfo.lpVerb   = (LPWSTR)&cmdVerb;
     sinfo.nShow    = SW_SHOWNORMAL;
     
-#ifndef WINCE
     LPITEMIDLIST pidl = NULL;
     SFGAOF sfgao;
     
@@ -327,9 +311,7 @@ nsMIMEInfoWin::LoadUriInternal(nsIURI * aURL)
         // Microsoft Security Bulletin MS07-061
         rv = NS_ERROR_FAILURE;
       }
-    } else 
-#endif
-    {
+    } else {
       sinfo.lpFile =  NS_ConvertUTF8toUTF16(urlSpec).get();
     }
     if (NS_SUCCEEDED(rv)) {
@@ -337,10 +319,8 @@ nsMIMEInfoWin::LoadUriInternal(nsIURI * aURL)
       if (!result || ((LONG_PTR)sinfo.hInstApp) < 32)
         rv = NS_ERROR_FAILURE;
     }
-#ifndef WINCE
     if (pidl)
       CoTaskMemFree(pidl);
-#endif
     if (hDll) 
       ::FreeLibrary(hDll);
   }
@@ -349,33 +329,33 @@ nsMIMEInfoWin::LoadUriInternal(nsIURI * aURL)
 }
 
 // Given a path to a local file, return its nsILocalHandlerApp instance.
-PRBool nsMIMEInfoWin::GetLocalHandlerApp(const nsAString& aCommandHandler,
+bool nsMIMEInfoWin::GetLocalHandlerApp(const nsAString& aCommandHandler,
                                          nsCOMPtr<nsILocalHandlerApp>& aApp)
 {
   nsCOMPtr<nsILocalFile> locfile;
   nsresult rv = 
-    NS_NewLocalFile(aCommandHandler, PR_TRUE, getter_AddRefs(locfile));
+    NS_NewLocalFile(aCommandHandler, true, getter_AddRefs(locfile));
   if (NS_FAILED(rv))
-    return PR_FALSE;
+    return false;
 
   aApp = do_CreateInstance("@mozilla.org/uriloader/local-handler-app;1");
   if (!aApp) 
-    return PR_FALSE;
+    return false;
 
   aApp->SetExecutable(locfile);
-  return PR_TRUE;
+  return true;
 }
 
 // Return the cleaned up file path associated with a command verb 
 // located in root/Applications.
-PRBool nsMIMEInfoWin::GetAppsVerbCommandHandler(const nsAString& appExeName,
+bool nsMIMEInfoWin::GetAppsVerbCommandHandler(const nsAString& appExeName,
                                                 nsAString& applicationPath,
-                                                PRBool edit)
+                                                bool edit)
 {
   nsCOMPtr<nsIWindowsRegKey> appKey = 
     do_CreateInstance("@mozilla.org/windows-registry-key;1");
   if (!appKey) 
-    return PR_FALSE; 
+    return false; 
 
   // HKEY_CLASSES_ROOT\Applications\iexplore.exe
   nsAutoString applicationsPath;
@@ -386,19 +366,19 @@ PRBool nsMIMEInfoWin::GetAppsVerbCommandHandler(const nsAString& appExeName,
                              applicationsPath,
                              nsIWindowsRegKey::ACCESS_QUERY_VALUE);
   if (NS_FAILED(rv)) 
-    return PR_FALSE;
+    return false;
 
   // Check for the NoOpenWith flag, if it exists
   PRUint32 value;
   if (NS_SUCCEEDED(appKey->ReadIntValue(
       NS_LITERAL_STRING("NoOpenWith"), &value)) &&
       value == 1)
-    return PR_FALSE;
+    return false;
 
   nsAutoString dummy;
   if (NS_SUCCEEDED(appKey->ReadStringValue(
         NS_LITERAL_STRING("NoOpenWith"), dummy)))
-    return PR_FALSE;
+    return false;
 
   appKey->Close();
 
@@ -415,7 +395,7 @@ PRBool nsMIMEInfoWin::GetAppsVerbCommandHandler(const nsAString& appExeName,
                     applicationsPath,
                     nsIWindowsRegKey::ACCESS_QUERY_VALUE);
   if (NS_FAILED(rv)) 
-    return PR_FALSE;
+    return false;
 
   nsAutoString appFilesystemCommand;
   if (NS_SUCCEEDED(appKey->ReadStringValue(EmptyString(), 
@@ -423,29 +403,29 @@ PRBool nsMIMEInfoWin::GetAppsVerbCommandHandler(const nsAString& appExeName,
     
     // Expand environment vars, clean up any misc.
     if (!nsOSHelperAppService::CleanupCmdHandlerPath(appFilesystemCommand))
-      return PR_FALSE;
+      return false;
     
     applicationPath = appFilesystemCommand;
-    return PR_TRUE;
+    return true;
   }
-  return PR_FALSE;
+  return false;
 }
 
 // Return a fully populated command string based on
 // passing information. Used in launchWithFile to trace
 // back to the full handler path based on the dll.
 // (dll, targetfile, return args, open/edit)
-PRBool nsMIMEInfoWin::GetDllLaunchInfo(nsIFile * aDll,
+bool nsMIMEInfoWin::GetDllLaunchInfo(nsIFile * aDll,
                                        nsILocalFile * aFile,
                                        nsAString& args,
-                                       PRBool edit)
+                                       bool edit)
 {
   if (!aDll || !aFile) 
-    return PR_FALSE;
+    return false;
 
   nsCOMPtr<nsILocalFile> localDll(do_QueryInterface(aDll));
   if (!localDll)
-    return PR_FALSE;
+    return false;
 
   nsString appExeName;
   localDll->GetLeafName(appExeName);
@@ -453,7 +433,7 @@ PRBool nsMIMEInfoWin::GetDllLaunchInfo(nsIFile * aDll,
   nsCOMPtr<nsIWindowsRegKey> appKey = 
     do_CreateInstance("@mozilla.org/windows-registry-key;1");
   if (!appKey) 
-    return PR_FALSE; 
+    return false; 
 
   // HKEY_CLASSES_ROOT\Applications\iexplore.exe
   nsAutoString applicationsPath;
@@ -464,18 +444,18 @@ PRBool nsMIMEInfoWin::GetDllLaunchInfo(nsIFile * aDll,
                              applicationsPath,
                              nsIWindowsRegKey::ACCESS_QUERY_VALUE);
   if (NS_FAILED(rv))
-    return PR_FALSE;
+    return false;
 
   // Check for the NoOpenWith flag, if it exists
   PRUint32 value;
   rv = appKey->ReadIntValue(NS_LITERAL_STRING("NoOpenWith"), &value);
   if (NS_SUCCEEDED(rv) && value == 1)
-    return PR_FALSE;
+    return false;
 
   nsAutoString dummy;
   if (NS_SUCCEEDED(appKey->ReadStringValue(NS_LITERAL_STRING("NoOpenWith"), 
                                            dummy)))
-    return PR_FALSE;
+    return false;
 
   appKey->Close();
 
@@ -491,7 +471,7 @@ PRBool nsMIMEInfoWin::GetDllLaunchInfo(nsIFile * aDll,
                     applicationsPath,
                     nsIWindowsRegKey::ACCESS_QUERY_VALUE);
   if (NS_FAILED(rv))
-    return PR_FALSE;
+    return false;
 
   nsAutoString appFilesystemCommand;
   if (NS_SUCCEEDED(appKey->ReadStringValue(EmptyString(),
@@ -501,15 +481,15 @@ PRBool nsMIMEInfoWin::GetDllLaunchInfo(nsIFile * aDll,
       ::ExpandEnvironmentStringsW(appFilesystemCommand.get(),
                                   L"", 0);
     if (bufLength == 0) // Error
-      return PR_FALSE;
+      return false;
 
     nsAutoArrayPtr<PRUnichar> destination(new PRUnichar[bufLength]);
     if (!destination)
-      return PR_FALSE;
+      return false;
     if (!::ExpandEnvironmentStringsW(appFilesystemCommand.get(),
                                      destination,
                                      bufLength))
-      return PR_FALSE;
+      return false;
 
     appFilesystemCommand = destination;
 
@@ -529,7 +509,7 @@ PRBool nsMIMEInfoWin::GetDllLaunchInfo(nsIFile * aDll,
     NS_NAMED_LITERAL_STRING(percentOneParam, "%1");
     index = params.Find(percentOneParam);
     if (index == kNotFound) // no parameter
-      return PR_FALSE;
+      return false;
 
     nsString target;
     aFile->GetTarget(target);
@@ -537,21 +517,21 @@ PRBool nsMIMEInfoWin::GetDllLaunchInfo(nsIFile * aDll,
 
     args = params;
 
-    return PR_TRUE;
+    return true;
   }
-  return PR_FALSE;
+  return false;
 }
 
 // Return the cleaned up file path associated with a progid command 
 // verb located in root.
-PRBool nsMIMEInfoWin::GetProgIDVerbCommandHandler(const nsAString& appProgIDName,
+bool nsMIMEInfoWin::GetProgIDVerbCommandHandler(const nsAString& appProgIDName,
                                                   nsAString& applicationPath,
-                                                  PRBool edit)
+                                                  bool edit)
 {
   nsCOMPtr<nsIWindowsRegKey> appKey =
     do_CreateInstance("@mozilla.org/windows-registry-key;1");
   if (!appKey) 
-    return PR_FALSE; 
+    return false; 
 
   nsAutoString appProgId(appProgIDName);
 
@@ -565,19 +545,19 @@ PRBool nsMIMEInfoWin::GetProgIDVerbCommandHandler(const nsAString& appProgIDName
                              appProgId,
                              nsIWindowsRegKey::ACCESS_QUERY_VALUE);
   if (NS_FAILED(rv))
-    return PR_FALSE;
+    return false;
 
   nsAutoString appFilesystemCommand;
   if (NS_SUCCEEDED(appKey->ReadStringValue(EmptyString(), appFilesystemCommand))) {
     
     // Expand environment vars, clean up any misc.
     if (!nsOSHelperAppService::CleanupCmdHandlerPath(appFilesystemCommand))
-      return PR_FALSE;
+      return false;
     
     applicationPath = appFilesystemCommand;
-    return PR_TRUE;
+    return true;
   }
-  return PR_FALSE;
+  return false;
 }
 
 // Helper routine used in tracking app lists. Converts path
@@ -603,13 +583,13 @@ void nsMIMEInfoWin::ProcessPath(nsCOMPtr<nsIMutableArray>& appList,
     return;
 
   // Save in our main tracking arrays
-  appList->AppendElement(aApp, PR_FALSE);
+  appList->AppendElement(aApp, false);
   trackList.AppendElement(lower);
 }
 
 // Helper routine that handles a compare between a path
 // and an array of paths.
-static PRBool IsPathInList(nsAString& appPath,
+static bool IsPathInList(nsAString& appPath,
                            nsTArray<nsString>& trackList)
 {
   // trackList data is always lowercase, see ProcessPath
@@ -619,9 +599,9 @@ static PRBool IsPathInList(nsAString& appPath,
 
   for (PRUint32 i = 0; i < trackList.Length(); i++) {
     if (tmp.Equals(trackList[i]))
-      return PR_TRUE;
+      return true;
   }
-  return PR_FALSE;
+  return false;
 }
 
 /** 
@@ -662,9 +642,9 @@ nsMIMEInfoWin::GetPossibleLocalHandlers(nsIArray **_retval)
 
   nsAutoString workingRegistryPath;
 
-  PRBool extKnown = PR_FALSE;
+  bool extKnown = false;
   if (fileExt.IsEmpty()) {
-    extKnown = PR_TRUE;
+    extKnown = true;
     // Mime type discovery is possible in some cases, through 
     // HKEY_CLASSES_ROOT\MIME\Database\Content Type, however, a number
     // of file extensions related to mime type are simply not defined,
@@ -683,7 +663,7 @@ nsMIMEInfoWin::GetPossibleLocalHandlers(nsIArray **_retval)
         nsAutoString mimeFileExt;
         if (NS_SUCCEEDED(regKey->ReadStringValue(EmptyString(), mimeFileExt))) {
           CopyUTF16toUTF8(mimeFileExt, fileExt);
-          extKnown = PR_FALSE;
+          extKnown = false;
         }
       }
     }
@@ -712,7 +692,7 @@ nsMIMEInfoWin::GetPossibleLocalHandlers(nsIArray **_retval)
           nsAutoString appFilesystemCommand;
           if (GetProgIDVerbCommandHandler(appProgId,
                                           appFilesystemCommand,
-                                          PR_FALSE) &&
+                                          false) &&
               !IsPathInList(appFilesystemCommand, trackList)) {
             ProcessPath(appList, trackList, appFilesystemCommand);
           }
@@ -742,7 +722,7 @@ nsMIMEInfoWin::GetPossibleLocalHandlers(nsIArray **_retval)
           nsAutoString appFilesystemCommand;
           if (!GetAppsVerbCommandHandler(appName,
                                          appFilesystemCommand,
-                                         PR_FALSE) ||
+                                         false) ||
               IsPathInList(appFilesystemCommand, trackList))
             continue;
           ProcessPath(appList, trackList, appFilesystemCommand);
@@ -773,7 +753,7 @@ nsMIMEInfoWin::GetPossibleLocalHandlers(nsIArray **_retval)
           nsAutoString appFilesystemCommand;
           if (!GetProgIDVerbCommandHandler(appProgId,
                                            appFilesystemCommand,
-                                           PR_FALSE) ||
+                                           false) ||
               IsPathInList(appFilesystemCommand, trackList))
             continue;
           ProcessPath(appList, trackList, appFilesystemCommand);
@@ -811,7 +791,7 @@ nsMIMEInfoWin::GetPossibleLocalHandlers(nsIArray **_retval)
           nsAutoString appFilesystemCommand;
           if (!GetAppsVerbCommandHandler(appValue,
                                          appFilesystemCommand,
-                                         PR_FALSE) ||
+                                         false) ||
               IsPathInList(appFilesystemCommand, trackList))
             continue;
           ProcessPath(appList, trackList, appFilesystemCommand);
@@ -844,7 +824,7 @@ nsMIMEInfoWin::GetPossibleLocalHandlers(nsIArray **_retval)
           nsAutoString appFilesystemCommand;
           if (!GetProgIDVerbCommandHandler(appProgId,
                                            appFilesystemCommand,
-                                           PR_FALSE) ||
+                                           false) ||
               IsPathInList(appFilesystemCommand, trackList))
             continue;
           ProcessPath(appList, trackList, appFilesystemCommand);
@@ -886,7 +866,7 @@ nsMIMEInfoWin::GetPossibleLocalHandlers(nsIArray **_retval)
               // HKEY_CLASSES_ROOT\Applications\firefox.exe = "path params"
               nsAutoString appFilesystemCommand;
               if (!GetAppsVerbCommandHandler(appName, appFilesystemCommand, 
-                                             PR_FALSE) ||
+                                             false) ||
                   IsPathInList(appFilesystemCommand, trackList))
                 continue;
               ProcessPath(appList, trackList, appFilesystemCommand);
@@ -895,7 +875,7 @@ nsMIMEInfoWin::GetPossibleLocalHandlers(nsIArray **_retval)
         }
       }
     }
-  } // extKnown == PR_FALSE
+  } // extKnown == false
 
 
   // 7) list global HKEY_CLASSES_ROOT\*\OpenWithList\
@@ -917,7 +897,7 @@ nsMIMEInfoWin::GetPossibleLocalHandlers(nsIArray **_retval)
         // HKEY_CLASSES_ROOT\Applications\firefox.exe = "path params"
         nsAutoString appFilesystemCommand;
         if (!GetAppsVerbCommandHandler(appName, appFilesystemCommand,
-                                       PR_FALSE) ||
+                                       false) ||
             IsPathInList(appFilesystemCommand, trackList))
           continue;
         ProcessPath(appList, trackList, appFilesystemCommand);
@@ -945,7 +925,7 @@ nsMIMEInfoWin::GetPossibleLocalHandlers(nsIArray **_retval)
         // HKEY_CLASSES_ROOT\Applications\firefox.exe = "path params"
         nsAutoString appFilesystemCommand;
         if (!GetAppsVerbCommandHandler(appName, appFilesystemCommand,
-                                       PR_FALSE) ||
+                                       false) ||
             IsPathInList(appFilesystemCommand, trackList))
           continue;
         ProcessPath(appList, trackList, appFilesystemCommand);
