@@ -41,27 +41,16 @@
 #include "nscore.h"
 #include "nsIView.h"
 #include "nsEvent.h"
-#include "nsIRenderingContext.h"
 
-class nsIScrollableView;
 class nsIWidget;
 struct nsRect;
 class nsRegion;
-class nsIDeviceContext;
+class nsDeviceContext;
 class nsIViewObserver;
 
-enum nsRectVisibility { 
-  nsRectVisibility_kVisible, 
-  nsRectVisibility_kAboveViewport, 
-  nsRectVisibility_kBelowViewport, 
-  nsRectVisibility_kLeftOfViewport, 
-  nsRectVisibility_kRightOfViewport, 
-  nsRectVisibility_kZeroAreaRect
-}; 
-
-#define NS_IVIEWMANAGER_IID   \
-  { 0x739bbc2b, 0x5c45, 0x40bb, \
-    { 0xb0, 0xbc, 0xe3, 0x1c, 0xe0, 0xf2, 0x19, 0xc2 } }
+#define NS_IVIEWMANAGER_IID \
+{ 0x144ef328, 0xbece, 0x43d6, \
+  { 0xac, 0xac, 0x1a, 0x90, 0x4b, 0x5c, 0xc1, 0x11 } }
 
 class nsIViewManager : public nsISupports
 {
@@ -74,7 +63,7 @@ public:
    * because it holds a reference to this instance.
    * @result The result of the initialization, NS_OK if no errors
    */
-  NS_IMETHOD  Init(nsIDeviceContext* aContext) = 0;
+  NS_IMETHOD  Init(nsDeviceContext* aContext) = 0;
 
   /**
    * Create an ordinary view
@@ -92,24 +81,11 @@ public:
                                    const nsIView* aParent,
                                    nsViewVisibility aVisibilityFlag = nsViewVisibility_kShow) = 0;
 
-  /**
-   * Create an scrollable view
-   * @param aBounds initial bounds for view
-   *        XXX We should eliminate this parameter; you can set the bounds after CreateScrollableView
-   * @param aParent intended parent for view. this is not actually set in the
-   *        nsIView through this method. it is only used by the initialization
-   *        code to walk up the view tree, if necessary, to find resources.
-   *        XXX We should eliminate this parameter!
-   * @result The new view
-   */
-  NS_IMETHOD_(nsIScrollableView*) CreateScrollableView(const nsRect& aBounds,
-                                                       const nsIView* aParent) = 0;
-
   /**
    * Get the root of the view tree.
    * @result the root view
    */
-  NS_IMETHOD  GetRootView(nsIView *&aView) = 0;
+  NS_IMETHOD_(nsIView*) GetRootView() = 0;
 
   /**
    * Set the root of the view tree. Does not destroy the current root view.
@@ -139,7 +115,7 @@ public:
   /**
    * Do any resizes that are pending.
    */
-  NS_IMETHOD  FlushDelayedResize() = 0;
+  NS_IMETHOD  FlushDelayedResize(bool aDoReflow) = 0;
 
   /**
    * Called to force a redrawing of any dirty areas.
@@ -160,14 +136,15 @@ public:
   NS_IMETHOD  UpdateView(nsIView *aView, PRUint32 aUpdateFlags) = 0;
 
   /**
-   * Called to inform the view manager that some portion of a view
-   * is dirty and needs to be redrawn. The rect passed in
-   * should be in the view's coordinate space.
+   * Called to inform the view manager that some portion of a view is dirty and
+   * needs to be redrawn. The rect passed in should be in the view's coordinate
+   * space. Does not check for paint suppression.
    * @param aView view to paint. should be root view
    * @param rect rect to mark as damaged
    * @param aUpdateFlags see bottom of nsIViewManager.h for description
    */
-  NS_IMETHOD  UpdateView(nsIView *aView, const nsRect &aRect, PRUint32 aUpdateFlags) = 0;
+  NS_IMETHOD  UpdateViewNoSuppression(nsIView *aView, const nsRect &aRect,
+                                      PRUint32 aUpdateFlags) = 0;
 
   /**
    * Called to inform the view manager that it should redraw all views.
@@ -187,30 +164,15 @@ public:
   NS_IMETHOD  DispatchEvent(nsGUIEvent *aEvent,
       nsIView* aViewTarget, nsEventStatus* aStatus) = 0;
 
-  /**
-   * Used to grab/capture all mouse events for a specific view,
-   * irrespective of the cursor position at which the
-   * event occurred.
-   * @param aView view to capture mouse events
-   * @result event handling status
-   */
-  NS_IMETHOD  GrabMouseEvents(nsIView *aView, PRBool& aResult) = 0;
-
-  /**
-   * Get the current view, if any, that's capturing mouse events.
-   * @result view that is capturing mouse events or nsnull
-   */
-  NS_IMETHOD  GetMouseEventGrabber(nsIView *&aView) = 0;
-
   /**
    * Given a parent view, insert another view as its child.
    * aSibling and aAbove control the "document order" for the insertion.
    * If aSibling is null, the view is inserted at the end of the document order
-   * if aAfter is PR_TRUE, otherwise it is inserted at the beginning.
-   * If aSibling is non-null, then if aAfter is PR_TRUE, the view is inserted
+   * if aAfter is true, otherwise it is inserted at the beginning.
+   * If aSibling is non-null, then if aAfter is true, the view is inserted
    * after the sibling in document order (appearing above the sibling unless
    * overriden by z-order).
-   * If it is PR_FALSE, the view is inserted before the sibling.
+   * If it is false, the view is inserted before the sibling.
    * The view manager generates the appopriate dirty regions.
    * @param aParent parent view
    * @param aChild child view
@@ -218,7 +180,7 @@ public:
    * @param aAfter after or before in the document order
    */
   NS_IMETHOD  InsertChild(nsIView *aParent, nsIView *aChild, nsIView *aSibling,
-                          PRBool aAfter) = 0;
+                          bool aAfter) = 0;
 
   /**
    * Remove a specific child view from its parent. This will NOT remove its placeholder
@@ -249,11 +211,11 @@ public:
    * @param aView view to move
    * @param the new bounds relative to the current position
    * @param RepaintExposedAreaOnly
-   *     if PR_TRUE Repaint only the expanded or contracted region,
-   *     if PR_FALSE Repaint the union of the old and new rectangles.
+   *     if true Repaint only the expanded or contracted region,
+   *     if false Repaint the union of the old and new rectangles.
    */
   NS_IMETHOD  ResizeView(nsIView *aView, const nsRect &aRect,
-                         PRBool aRepaintExposedAreaOnly = PR_FALSE) = 0;
+                         bool aRepaintExposedAreaOnly = false) = 0;
 
   /**
    * Set the visibility of a view. Hidden views have the effect of hiding
@@ -281,10 +243,10 @@ public:
    * @param aZindex explicit z depth
    * @param aTopMost used when this view is z-index:auto to compare against 
    *        other z-index:auto views.
-   *        PR_TRUE if the view should be topmost when compared with 
+   *        true if the view should be topmost when compared with 
    *        other z-index:auto views.
    */
-  NS_IMETHOD  SetViewZIndex(nsIView *aView, PRBool aAutoZIndex, PRInt32 aZindex, PRBool aTopMost = PR_FALSE) = 0;
+  NS_IMETHOD  SetViewZIndex(nsIView *aView, bool aAutoZIndex, PRInt32 aZindex, bool aTopMost = false) = 0;
 
   /**
    * Set whether the view "floats" above all other views,
@@ -293,46 +255,26 @@ public:
    * this view. This is a hack, but it fixes some problems with
    * views that need to be drawn in front of all other views.
    */
-  NS_IMETHOD  SetViewFloating(nsIView *aView, PRBool aFloatingView) = 0;
+  NS_IMETHOD  SetViewFloating(nsIView *aView, bool aFloatingView) = 0;
 
   /**
    * Set the view observer associated with this manager
    * @param aObserver - new observer
-   * @result error status
    */
-  NS_IMETHOD SetViewObserver(nsIViewObserver *aObserver) = 0;
+  virtual void SetViewObserver(nsIViewObserver *aObserver) = 0;
 
   /**
    * Get the view observer associated with this manager
-   * @param aObserver - out parameter for observer
-   * @result error status
    */
-  NS_IMETHOD GetViewObserver(nsIViewObserver *&aObserver) = 0;
+  virtual nsIViewObserver* GetViewObserver() = 0;
 
   /**
    * Get the device context associated with this manager
    * @result device context
    */
-  NS_IMETHOD  GetDeviceContext(nsIDeviceContext *&aContext) = 0;
+  NS_IMETHOD  GetDeviceContext(nsDeviceContext *&aContext) = 0;
 
-  /**
-   * prevent the view manager from refreshing.
-   * @return error status
-   */
-  // XXXbz callers of this function don't seem to realize that it disables
-  // refresh for the entire view manager hierarchy.... Maybe it shouldn't do
-  // that?
-  NS_IMETHOD DisableRefresh(void) = 0;
-
-  /**
-   * allow the view manager to refresh. this may cause a synchronous
-   * paint to occur inside the call.
-   * @param aUpdateFlags see bottom of nsIViewManager.h for description
-   * @return error status
-   */
-  NS_IMETHOD EnableRefresh(PRUint32 aUpdateFlags) = 0;
-
-  class NS_STACK_CLASS UpdateViewBatch {
+  class UpdateViewBatch {
   public:
     UpdateViewBatch() {}
   /**
@@ -404,23 +346,6 @@ private:
   NS_IMETHOD EndUpdateViewBatch(PRUint32 aUpdateFlags) = 0;
 
 public:
-
-  /**
-   * set the view that is is considered to be the root scrollable
-   * view for the document.
-   * @param aScrollable root scrollable view
-   * @return error status
-   */
-  NS_IMETHOD SetRootScrollableView(nsIScrollableView *aScrollable) = 0;
-
-  /**
-   * get the view that is is considered to be the root scrollable
-   * view for the document.
-   * @param aScrollable out parameter for root scrollable view
-   * @return error status
-   */
-  NS_IMETHOD GetRootScrollableView(nsIScrollableView **aScrollable) = 0;
-
   /**
    * Retrieve the widget at the root of the nearest enclosing
    * view manager whose root view has a widget.
@@ -440,10 +365,10 @@ public:
   /**
    * Indicate whether the viewmanager is currently painting
    *
-   * @param aPainting PR_TRUE if the viewmanager is painting
-   *                  PR_FALSE otherwise
+   * @param aPainting true if the viewmanager is painting
+   *                  false otherwise
    */
-  NS_IMETHOD IsPainting(PRBool& aIsPainting)=0;
+  NS_IMETHOD IsPainting(bool& aIsPainting)=0;
 
   /**
    * Retrieve the time of the last user event. User events
@@ -455,26 +380,10 @@ public:
   NS_IMETHOD GetLastUserEventTime(PRUint32& aTime)=0;
 
   /**
-   * Determine if a rectangle specified in the view's coordinate system 
-   * is completely, or partially visible.
-   * @param aView view that aRect coordinates are specified relative to
-   * @param aRect rectangle in twips to test for visibility 
-   * @param aMinTwips is the min. pixel rows or cols at edge of screen 
-   *                  needed for object to be counted visible
-   * @param aRectVisibility returns eVisible if the rect is visible, 
-   *                        otherwise it returns an enum indicating why not
+   * Find the nearest display root view for the view aView. This is the view for
+   * the nearest enclosing popup or the root view for the root document.
    */
-  NS_IMETHOD GetRectVisibility(nsIView *aView, const nsRect &aRect, 
-                               nscoord aMinTwips,
-                               nsRectVisibility *aRectVisibility)=0;
-
-  /**
-   * Dispatch a mouse move event based on the most recent mouse
-   * position.  This is used when the contents of the page moved
-   * (aFromScroll is false) or scrolled (aFromScroll is true).
-   */
-  NS_IMETHOD SynthesizeMouseMove(PRBool aFromScroll)=0;
-
+  static nsIView* GetDisplayRootFor(nsIView* aView);
 };
 
 NS_DEFINE_STATIC_IID_ACCESSOR(nsIViewManager, NS_IVIEWMANAGER_IID)
@@ -496,7 +405,4 @@ NS_DEFINE_STATIC_IID_ACCESSOR(nsIViewManager, NS_IVIEWMANAGER_IID)
 // synchronously updates the window(s) right away before returning
 #define NS_VMREFRESH_IMMEDIATE          0x0002
 
-//animate scroll operation
-#define NS_VMREFRESH_SMOOTHSCROLL       0x0008
-
 #endif  // nsIViewManager_h___
