@@ -61,18 +61,20 @@
 #include "nsCocoaUtils.h"
 #include "nsChildView.h"
 #include "nsToolkit.h"
+#include "TextInputHandler.h"
 
 #include "npapi.h"
 
+using namespace mozilla::widget;
+
 // defined in nsChildView.mm
 extern nsIRollupListener * gRollupListener;
 extern nsIWidget         * gRollupWidget;
-extern PRUint32          gLastModifierState;
 
 // defined in nsCocoaWindow.mm
 extern PRInt32             gXULModalLevel;
 
-static PRBool gAppShellMethodsSwizzled = PR_FALSE;
+static bool gAppShellMethodsSwizzled = false;
 // List of current Cocoa app-modal windows (nested if more than one).
 nsCocoaAppModalWindowList *gCocoaAppModalWindowList = NULL;
 
@@ -161,10 +163,10 @@ NSModalSession nsCocoaAppModalWindowList::CurrentSession()
 }
 
 // Has a Gecko modal dialog popped up over a Cocoa app-modal dialog?
-PRBool nsCocoaAppModalWindowList::GeckoModalAboveCocoaModal()
+bool nsCocoaAppModalWindowList::GeckoModalAboveCocoaModal()
 {
   if (mList.IsEmpty())
-    return PR_FALSE;
+    return false;
 
   nsCocoaAppModalWindowListItem &topItem = mList.ElementAt(mList.Length() - 1);
 
@@ -217,7 +219,7 @@ nsAppShell::ResumeNative(void)
   if (NS_SUCCEEDED(retval) && (mSuspendNativeCount == 0) &&
       mSkippedNativeCallback)
   {
-    mSkippedNativeCallback = PR_FALSE;
+    mSkippedNativeCallback = false;
     ScheduleNativeEventCallback();
   }
   return retval;
@@ -228,10 +230,10 @@ nsAppShell::nsAppShell()
 , mDelegate(nsnull)
 , mCFRunLoop(NULL)
 , mCFRunLoopSource(NULL)
-, mRunningEventLoop(PR_FALSE)
-, mStarted(PR_FALSE)
-, mTerminated(PR_FALSE)
-, mSkippedNativeCallback(PR_FALSE)
+, mRunningEventLoop(false)
+, mStarted(false)
+, mTerminated(false)
+, mSkippedNativeCallback(false)
 , mHadMoreEventsCount(0)
 , mRecursionDepth(0)
 , mNativeEventCallbackDepth(0)
@@ -239,7 +241,7 @@ nsAppShell::nsAppShell()
 {
   // A Cocoa event loop is running here if (and only if) we've been embedded
   // by a Cocoa app (like Camino).
-  mRunningCocoaEmbedded = [NSApp isRunning] ? PR_TRUE : PR_FALSE;
+  mRunningCocoaEmbedded = [NSApp isRunning] ? true : false;
 }
 
 nsAppShell::~nsAppShell()
@@ -337,7 +339,7 @@ nsAppShell::Init()
   rv = nsBaseAppShell::Init();
 
 #ifndef NP_NO_CARBON
-  NS_InstallPluginKeyEventsHandler();
+  TextInputHandler::InstallPluginKeyEventsHandler();
 #endif
 
   gCocoaAppModalWindowList = new nsCocoaAppModalWindowList;
@@ -363,7 +365,7 @@ nsAppShell::Init()
                                   @selector(nsAppShell_PDEPluginCallback_dealloc));
       }
     }
-    gAppShellMethodsSwizzled = PR_TRUE;
+    gAppShellMethodsSwizzled = true;
   }
 
   [localPool release];
@@ -391,7 +393,7 @@ nsAppShell::ProcessGeckoEvents(void* aInfo)
   nsAppShell* self = static_cast<nsAppShell*> (aInfo);
 
   if (self->mRunningEventLoop) {
-    self->mRunningEventLoop = PR_FALSE;
+    self->mRunningEventLoop = false;
 
     // The run loop may be sleeping -- [NSRunLoop runMode:...]
     // won't return until it's given a reason to wake up.  Awaken it by
@@ -422,7 +424,7 @@ nsAppShell::ProcessGeckoEvents(void* aInfo)
     self->NativeEventCallback();
     --self->mNativeEventCallbackDepth;
   } else {
-    self->mSkippedNativeCallback = PR_TRUE;
+    self->mSkippedNativeCallback = true;
   }
 
   // Still needed to fix bug 343033 ("5-10 second delay or hang or crash
@@ -445,7 +447,7 @@ nsAppShell::ProcessGeckoEvents(void* aInfo)
   // corresponding call to ProcessGeckoEvents() will never happen.  We check
   // for this possibility in two different places -- here and in Exit()
   // itself.  If we find here that Exit() has been called (that mTerminated
-  // is PR_TRUE), it's because we've been called recursively, that Exit() was
+  // is true), it's because we've been called recursively, that Exit() was
   // called from self->NativeEventCallback() above, and that we're unwinding
   // the recursion.  In this case we'll never be called again, and we balance
   // here any extra calls to ScheduleNativeEventCallback().
@@ -500,7 +502,7 @@ nsAppShell::WillTerminate()
   // from [MacApplicationDelegate applicationShouldTerminate:]) gets run.
   NS_ProcessPendingEvents(NS_GetCurrentThread());
 
-  mTerminated = PR_TRUE;
+  mTerminated = true;
 }
 
 // ScheduleNativeEventCallback
@@ -557,18 +559,18 @@ nsAppShell::ScheduleNativeEventCallback()
 // times in a row.  This doesn't seem to cause native event starvation.
 //
 // protected virtual
-PRBool
-nsAppShell::ProcessNextNativeEvent(PRBool aMayWait)
+bool
+nsAppShell::ProcessNextNativeEvent(bool aMayWait)
 {
-  PRBool moreEvents = PR_FALSE;
+  bool moreEvents = false;
 
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK;
 
-  PRBool eventProcessed = PR_FALSE;
+  bool eventProcessed = false;
   NSString* currentMode = nil;
 
   if (mTerminated)
-    return PR_FALSE;
+    return false;
 
   // We don't want any native events to be processed here (via Gecko) while
   // Cocoa is displaying an app-modal dialog (as opposed to a window-modal
@@ -581,9 +583,9 @@ nsAppShell::ProcessNextNativeEvent(PRBool aMayWait)
   // which see below.
   if ([NSApp _isRunningAppModal] &&
       (!gCocoaAppModalWindowList || !gCocoaAppModalWindowList->GeckoModalAboveCocoaModal()))
-    return PR_FALSE;
+    return false;
 
-  PRBool wasRunningEventLoop = mRunningEventLoop;
+  bool wasRunningEventLoop = mRunningEventLoop;
   mRunningEventLoop = aMayWait;
   NSDate* waitUntil = nil;
   if (aMayWait)
@@ -626,8 +628,8 @@ nsAppShell::ProcessNextNativeEvent(PRBool aMayWait)
     // that it is called from [NSRunLoop runMode:beforeDate:], and that
     // [NSRunLoop runMode:beforeDate:], though it does process timer events,
     // doesn't return after doing so.  To get around this, when aWait is
-    // PR_FALSE we check for timer events and process them using [NSApp
-    // sendEvent:].  When aWait is PR_TRUE [NSRunLoop runMode:beforeDate:]
+    // false we check for timer events and process them using [NSApp
+    // sendEvent:].  When aWait is true [NSRunLoop runMode:beforeDate:]
     // will only return on a "real" event.  But there's code in
     // ProcessGeckoEvents() that should (when need be) wake us up by sending
     // a "fake" "real" event.  (See Apple's current doc on [NSRunLoop
@@ -669,7 +671,7 @@ nsAppShell::ProcessNextNativeEvent(PRBool aMayWait)
         } else {
           [NSApp sendEvent:nextEvent];
         }
-        eventProcessed = PR_TRUE;
+        eventProcessed = true;
       }
     } else {
       if (aMayWait ||
@@ -686,7 +688,7 @@ nsAppShell::ProcessNextNativeEvent(PRBool aMayWait)
         } else {
           [currentRunLoop runMode:currentMode beforeDate:waitUntil];
         }
-        eventProcessed = PR_TRUE;
+        eventProcessed = true;
       }
     }
   } while (mRunningEventLoop);
@@ -717,8 +719,8 @@ nsAppShell::ProcessNextNativeEvent(PRBool aMayWait)
   return moreEvents;
 }
 
-// Returns PR_TRUE if Gecko events are currently being processed in its "main"
-// event loop (or one of its "main" event loops).  Returns PR_FALSE if Gecko
+// Returns true if Gecko events are currently being processed in its "main"
+// event loop (or one of its "main" event loops).  Returns false if Gecko
 // events are being processed in a "nested" event loop, or if we're not
 // running in any sort of Gecko event loop.  How we process native events in
 // ProcessNextNativeEvent() turns on our decision (and if we make the wrong
@@ -736,14 +738,14 @@ nsAppShell::ProcessNextNativeEvent(PRBool aMayWait)
 // nsAppShell implementation, what counts as the "main" event loop is what
 // nsBaseAppShell::NativeEventCallback() does to process Gecko events.  We
 // don't currently use nsBaseAppShell::Run().)
-PRBool
+bool
 nsAppShell::InGeckoMainEventLoop()
 {
   if ((gXULModalLevel > 0) || (mRecursionDepth > 0))
-    return PR_FALSE;
+    return false;
   if (mNativeEventCallbackDepth <= 0)
-    return PR_FALSE;
-  return PR_TRUE;
+    return false;
+  return true;
 }
 
 // Run
@@ -765,7 +767,7 @@ nsAppShell::Run(void)
   if (mStarted)
     return NS_OK;
 
-  mStarted = PR_TRUE;
+  mStarted = true;
   NS_OBJC_TRY_ABORT([NSApp run]);
 
   return NS_OK;
@@ -786,13 +788,13 @@ nsAppShell::Exit(void)
     return NS_OK;
   }
 
-  mTerminated = PR_TRUE;
+  mTerminated = true;
 
   delete gCocoaAppModalWindowList;
   gCocoaAppModalWindowList = NULL;
 
 #ifndef NP_NO_CARBON
-  NS_RemovePluginKeyEventsHandler();
+  TextInputHandler::RemovePluginKeyEventsHandler();
 #endif
 
   // Quoting from Apple's doc on the [NSApplication stop:] method (from their
@@ -840,7 +842,7 @@ nsAppShell::Exit(void)
 //
 // public
 NS_IMETHODIMP
-nsAppShell::OnProcessNextEvent(nsIThreadInternal *aThread, PRBool aMayWait,
+nsAppShell::OnProcessNextEvent(nsIThreadInternal *aThread, bool aMayWait,
                                PRUint32 aRecursionDepth)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
@@ -947,8 +949,9 @@ nsAppShell::AfterProcessNextEvent(nsIThreadInternal *aThread,
 
 // applicationDidBecomeActive
 //
-// Make sure gLastModifierState is updated when we become active (since we
-// won't have received [ChildView flagsChanged:] messages while inactive).
+// Make sure TextInputHandler::sLastModifierState is updated when we become
+// active (since we won't have received [ChildView flagsChanged:] messages
+// while inactive).
 - (void)applicationDidBecomeActive:(NSNotification*)aNotification
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK;
@@ -957,7 +960,8 @@ nsAppShell::AfterProcessNextEvent(nsIThreadInternal *aThread,
   // to worry about getting an NSInternalInconsistencyException here.
   NSEvent* currentEvent = [NSApp currentEvent];
   if (currentEvent) {
-    gLastModifierState = [currentEvent modifierFlags] & NSDeviceIndependentModifierFlagsMask;
+    TextInputHandler::sLastModifierState =
+      [currentEvent modifierFlags] & NSDeviceIndependentModifierFlagsMask;
   }
 
   NS_OBJC_END_TRY_ABORT_BLOCK;
