@@ -47,7 +47,6 @@
 #include "nsChildView.h"
 #include "nsWindowMap.h"
 #include "nsAppShell.h"
-#include "nsIAppShell.h"
 #include "nsIAppShellService.h"
 #include "nsIBaseWindow.h"
 #include "nsIInterfaceRequestorUtils.h"
@@ -89,7 +88,7 @@ PRInt32 gXULModalLevel = 0;
 // also made app-modal.)  See nsCocoaWindow::SetModal().
 nsCocoaWindowList *gGeckoAppModalWindowList = NULL;
 
-PRBool gConsumeRollupEvent;
+bool gConsumeRollupEvent;
 
 // defined in nsMenuBarX.mm
 extern NSMenu* sApplicationMenu; // Application menu shared by all menubars
@@ -138,10 +137,10 @@ nsCocoaWindow::nsCocoaWindow()
 , mPopupContentView(nil)
 , mShadowStyle(NS_STYLE_WINDOW_SHADOW_DEFAULT)
 , mWindowFilter(0)
-, mWindowMadeHere(PR_FALSE)
-, mSheetNeedsShow(PR_FALSE)
-, mFullScreen(PR_FALSE)
-, mModal(PR_FALSE)
+, mWindowMadeHere(false)
+, mSheetNeedsShow(false)
+, mFullScreen(false)
+, mModal(false)
 , mNumModalDescendents(0)
 {
 
@@ -233,12 +232,12 @@ static void FitRectToVisibleAreaForScreen(nsIntRect &aRect, NSScreen *screen)
 
 // Some applications like Camino use native popup windows
 // (native context menus, native tooltips)
-static PRBool UseNativePopupWindows()
+static bool UseNativePopupWindows()
 {
 #ifdef MOZ_USE_NATIVE_POPUP_WINDOWS
-  return PR_TRUE;
+  return true;
 #else
-  return PR_FALSE;
+  return false;
 #endif /* MOZ_USE_NATIVE_POPUP_WINDOWS */
 }
 
@@ -247,8 +246,6 @@ nsresult nsCocoaWindow::Create(nsIWidget *aParent,
                                const nsIntRect &aRect,
                                EVENT_CALLBACK aHandleEventFunction,
                                nsDeviceContext *aContext,
-                               nsIAppShell *aAppShell,
-                               nsIToolkit *aToolkit,
                                nsWidgetInitData *aInitData)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
@@ -285,8 +282,11 @@ nsresult nsCocoaWindow::Create(nsIWidget *aParent,
   mWindowType = eWindowType_toplevel;
   mBorderStyle = eBorderStyle_default;
 
-  Inherited::BaseCreate(aParent, newBounds, aHandleEventFunction, aContext, aAppShell,
-                        aToolkit, aInitData);
+  // Ensure that the toolkit is created.
+  nsToolkit::GetToolkit();
+
+  Inherited::BaseCreate(aParent, newBounds, aHandleEventFunction, aContext,
+                        aInitData);
 
   mParent = aParent;
 
@@ -295,14 +295,14 @@ nsresult nsCocoaWindow::Create(nsIWidget *aParent,
     return NS_OK;
 
   nsresult rv = CreateNativeWindow(nsCocoaUtils::GeckoRectToCocoaRect(newBounds),
-                                   mBorderStyle, PR_FALSE);
+                                   mBorderStyle, false);
   NS_ENSURE_SUCCESS(rv, rv);
 
   if (mWindowType == eWindowType_popup) {
     if (aInitData->mIsDragPopup) {
       [mWindow setIgnoresMouseEvents:YES];
     }
-    return CreatePopupContentView(newBounds, aHandleEventFunction, aContext, aAppShell, aToolkit);
+    return CreatePopupContentView(newBounds, aHandleEventFunction, aContext);
   }
 
   return NS_OK;
@@ -312,7 +312,7 @@ nsresult nsCocoaWindow::Create(nsIWidget *aParent,
 
 static unsigned int WindowMaskForBorderStyle(nsBorderStyle aBorderStyle)
 {
-  PRBool allOrDefault = (aBorderStyle == eBorderStyle_all ||
+  bool allOrDefault = (aBorderStyle == eBorderStyle_all ||
                          aBorderStyle == eBorderStyle_default);
 
   /* Apple's docs on NSWindow styles say that "a window's style mask should
@@ -345,7 +345,7 @@ NS_IMETHODIMP nsCocoaWindow::ReparentNativeWidget(nsIWidget* aNewParent)
 // content rect.
 nsresult nsCocoaWindow::CreateNativeWindow(const NSRect &aRect,
                                            nsBorderStyle aBorderStyle,
-                                           PRBool aRectIsFrameRect)
+                                           bool aRectIsFrameRect)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
 
@@ -470,7 +470,7 @@ nsresult nsCocoaWindow::CreateNativeWindow(const NSRect &aRect,
   [mWindow setDelegate:mDelegate];
 
   [[WindowDataMap sharedWindowDataMap] ensureDataForWindow:mWindow];
-  mWindowMadeHere = PR_TRUE;
+  mWindowMadeHere = true;
 
   return NS_OK;
 
@@ -479,9 +479,7 @@ nsresult nsCocoaWindow::CreateNativeWindow(const NSRect &aRect,
 
 NS_IMETHODIMP nsCocoaWindow::CreatePopupContentView(const nsIntRect &aRect,
                              EVENT_CALLBACK aHandleEventFunction,
-                             nsDeviceContext *aContext,
-                             nsIAppShell *aAppShell,
-                             nsIToolkit *aToolkit)
+                             nsDeviceContext *aContext)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
 
@@ -494,7 +492,7 @@ NS_IMETHODIMP nsCocoaWindow::CreatePopupContentView(const nsIntRect &aRect,
 
   nsIWidget* thisAsWidget = static_cast<nsIWidget*>(this);
   mPopupContentView->Create(thisAsWidget, nsnull, aRect, aHandleEventFunction,
-                            aContext, aAppShell, aToolkit, nsnull);
+                            aContext, nsnull);
 
   ChildView* newContentView = (ChildView*)mPopupContentView->GetNativeData(NS_NATIVE_WIDGET);
   [mWindow setContentView:newContentView];
@@ -513,7 +511,7 @@ NS_IMETHODIMP nsCocoaWindow::Destroy()
   nsBaseWidget::OnDestroy();
 
   if (mFullScreen) {
-    nsCocoaUtils::HideOSChromeOnScreen(PR_FALSE, [mWindow screen]);
+    nsCocoaUtils::HideOSChromeOnScreen(false, [mWindow screen]);
   }
 
   return NS_OK;
@@ -559,7 +557,7 @@ void* nsCocoaWindow::GetNativeData(PRUint32 aDataType)
   NS_OBJC_END_TRY_ABORT_BLOCK_NSNULL;
 }
 
-NS_IMETHODIMP nsCocoaWindow::IsVisible(PRBool & aState)
+NS_IMETHODIMP nsCocoaWindow::IsVisible(bool & aState)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
 
@@ -569,7 +567,7 @@ NS_IMETHODIMP nsCocoaWindow::IsVisible(PRBool & aState)
   NS_OBJC_END_TRY_ABORT_BLOCK_NSRESULT;
 }
 
-NS_IMETHODIMP nsCocoaWindow::SetModal(PRBool aState)
+NS_IMETHODIMP nsCocoaWindow::SetModal(bool aState)
 {
   // This is used during startup (outside the event loop) when creating
   // the add-ons compatibility checking dialog and the profile manager UI;
@@ -613,7 +611,7 @@ NS_IMETHODIMP nsCocoaWindow::SetModal(PRBool aState)
   }
   else {
     --gXULModalLevel;
-    NS_ASSERTION(gXULModalLevel >= 0, "Mismatched call to nsCocoaWindow::SetModal(PR_FALSE)!");
+    NS_ASSERTION(gXULModalLevel >= 0, "Mismatched call to nsCocoaWindow::SetModal(false)!");
     if (gCocoaAppModalWindowList)
       gCocoaAppModalWindowList->PopGecko(mWindow, this);
     if (mWindowType != eWindowType_sheet) {
@@ -645,7 +643,7 @@ NS_IMETHODIMP nsCocoaWindow::SetModal(PRBool aState)
 }
 
 // Hide or show this window
-NS_IMETHODIMP nsCocoaWindow::Show(PRBool bState)
+NS_IMETHODIMP nsCocoaWindow::Show(bool bState)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
 
@@ -671,7 +669,7 @@ NS_IMETHODIMP nsCocoaWindow::Show(PRBool bState)
       // this sheet can be displayed. Leave the parent mSheetNeedsShow alone,
       // that is only used to handle sibling sheet contention. The parent will
       // return once there are no more child sheets.
-      PRBool parentIsSheet = PR_FALSE;
+      bool parentIsSheet = false;
       if (NS_SUCCEEDED(piParentWidget->GetIsSheet(&parentIsSheet)) &&
           parentIsSheet) {
         piParentWidget->GetSheetWindowParent(&topNonSheetWindow);
@@ -679,13 +677,13 @@ NS_IMETHODIMP nsCocoaWindow::Show(PRBool bState)
       }
 
       nsCocoaWindow* sheetShown = nsnull;
-      if (NS_SUCCEEDED(piParentWidget->GetChildSheet(PR_TRUE, &sheetShown)) &&
+      if (NS_SUCCEEDED(piParentWidget->GetChildSheet(true, &sheetShown)) &&
           (!sheetShown || sheetShown == this)) {
         // If this sheet is already the sheet actually being shown, don't
         // tell it to show again. Otherwise the number of calls to
         // [NSApp beginSheet...] won't match up with [NSApp endSheet...].
         if (![mWindow isVisible]) {
-          mSheetNeedsShow = PR_FALSE;
+          mSheetNeedsShow = false;
           mSheetWindowParent = topNonSheetWindow;
           // Only set contextInfo if our parent isn't a sheet.
           NSWindow* contextInfo = parentIsSheet ? nil : mSheetWindowParent;
@@ -703,7 +701,7 @@ NS_IMETHODIMP nsCocoaWindow::Show(PRBool bState)
         // A sibling of this sheet is active, don't show this sheet yet.
         // When the active sheet hides, its brothers and sisters that have
         // mSheetNeedsShow set will have their opportunities to display.
-        mSheetNeedsShow = PR_TRUE;
+        mSheetNeedsShow = true;
       }
     }
     else if (mWindowType == eWindowType_popup) {
@@ -764,7 +762,7 @@ NS_IMETHODIMP nsCocoaWindow::Show(PRBool bState)
         // This is an attempt to hide a sheet that never had a chance to
         // be shown. There's nothing to do other than make sure that it
         // won't show.
-        mSheetNeedsShow = PR_FALSE;
+        mSheetNeedsShow = false;
       }
       else {
         // get sheet's parent *before* hiding the sheet (which breaks the linkage)
@@ -776,13 +774,13 @@ NS_IMETHODIMP nsCocoaWindow::Show(PRBool bState)
         [TopLevelWindowData deactivateInWindow:mWindow];
 
         nsCocoaWindow* siblingSheetToShow = nsnull;
-        PRBool parentIsSheet = PR_FALSE;
+        bool parentIsSheet = false;
 
         if (nativeParentWindow && piParentWidget &&
-            NS_SUCCEEDED(piParentWidget->GetChildSheet(PR_FALSE, &siblingSheetToShow)) &&
+            NS_SUCCEEDED(piParentWidget->GetChildSheet(false, &siblingSheetToShow)) &&
             siblingSheetToShow) {
           // First, give sibling sheets an opportunity to show.
-          siblingSheetToShow->Show(PR_TRUE);
+          siblingSheetToShow->Show(true);
         }
         else if (nativeParentWindow && piParentWidget &&
                  NS_SUCCEEDED(piParentWidget->GetIsSheet(&parentIsSheet)) &&
@@ -793,7 +791,7 @@ NS_IMETHODIMP nsCocoaWindow::Show(PRBool bState)
           nsIWidget* grandparentWidget = nil;
           if (NS_SUCCEEDED(piParentWidget->GetRealParent(&grandparentWidget)) && grandparentWidget) {
             nsCOMPtr<nsPIWidgetCocoa> piGrandparentWidget(do_QueryInterface(grandparentWidget));
-            PRBool grandparentIsSheet = PR_FALSE;
+            bool grandparentIsSheet = false;
             if (piGrandparentWidget && NS_SUCCEEDED(piGrandparentWidget->GetIsSheet(&grandparentIsSheet)) &&
                 grandparentIsSheet) {
                 contextInfo = nil;
@@ -992,19 +990,19 @@ void nsCocoaWindow::SetTransparencyMode(nsTransparencyMode aMode)
   NS_OBJC_END_TRY_ABORT_BLOCK;
 }
 
-NS_IMETHODIMP nsCocoaWindow::Enable(PRBool aState)
+NS_IMETHODIMP nsCocoaWindow::Enable(bool aState)
 {
   return NS_OK;
 }
 
-NS_IMETHODIMP nsCocoaWindow::IsEnabled(PRBool *aState)
+NS_IMETHODIMP nsCocoaWindow::IsEnabled(bool *aState)
 {
   if (aState)
-    *aState = PR_TRUE;
+    *aState = true;
   return NS_OK;
 }
 
-NS_IMETHODIMP nsCocoaWindow::ConstrainPosition(PRBool aAllowSlop,
+NS_IMETHODIMP nsCocoaWindow::ConstrainPosition(bool aAllowSlop,
                                                PRInt32 *aX, PRInt32 *aY)
 {
   return NS_OK;
@@ -1025,7 +1023,7 @@ NS_IMETHODIMP nsCocoaWindow::Move(PRInt32 aX, PRInt32 aY)
 
 // Position the window behind the given window
 NS_METHOD nsCocoaWindow::PlaceBehind(nsTopLevelWidgetZPlacement aPlacement,
-                                     nsIWidget *aWidget, PRBool aActivate)
+                                     nsIWidget *aWidget, bool aActivate)
 {
   return NS_OK;
 }
@@ -1067,7 +1065,7 @@ NS_METHOD nsCocoaWindow::SetSizeMode(PRInt32 aMode)
 // This has to preserve the window's frame bounds.
 // This method requires (as does the Windows impl.) that you call Resize shortly
 // after calling HideWindowChrome. See bug 498835 for fixing this.
-NS_IMETHODIMP nsCocoaWindow::HideWindowChrome(PRBool aShouldHide)
+NS_IMETHODIMP nsCocoaWindow::HideWindowChrome(bool aShouldHide)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
 
@@ -1096,7 +1094,7 @@ NS_IMETHODIMP nsCocoaWindow::HideWindowChrome(PRBool aShouldHide)
   // Recreate the window with the right border style.
   NSRect frameRect = [mWindow frame];
   DestroyNativeWindow();
-  nsresult rv = CreateNativeWindow(frameRect, aShouldHide ? eBorderStyle_none : mBorderStyle, PR_TRUE);
+  nsresult rv = CreateNativeWindow(frameRect, aShouldHide ? eBorderStyle_none : mBorderStyle, true);
   NS_ENSURE_SUCCESS(rv, rv);
 
   // Re-import state.
@@ -1114,7 +1112,7 @@ NS_IMETHODIMP nsCocoaWindow::HideWindowChrome(PRBool aShouldHide)
 
   // Show the new window.
   if (isVisible) {
-    rv = Show(PR_TRUE);
+    rv = Show(true);
     NS_ENSURE_SUCCESS(rv, rv);
   }
 
@@ -1124,7 +1122,7 @@ NS_IMETHODIMP nsCocoaWindow::HideWindowChrome(PRBool aShouldHide)
 }
 
 
-NS_METHOD nsCocoaWindow::MakeFullScreen(PRBool aFullScreen)
+NS_METHOD nsCocoaWindow::MakeFullScreen(bool aFullScreen)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
 
@@ -1147,7 +1145,7 @@ NS_METHOD nsCocoaWindow::MakeFullScreen(PRBool aFullScreen)
 }
 
 
-NS_IMETHODIMP nsCocoaWindow::Resize(PRInt32 aX, PRInt32 aY, PRInt32 aWidth, PRInt32 aHeight, PRBool aRepaint)
+NS_IMETHODIMP nsCocoaWindow::Resize(PRInt32 aX, PRInt32 aY, PRInt32 aWidth, PRInt32 aHeight, bool aRepaint)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
 
@@ -1172,7 +1170,7 @@ NS_IMETHODIMP nsCocoaWindow::Resize(PRInt32 aX, PRInt32 aY, PRInt32 aWidth, PRIn
   NS_OBJC_END_TRY_ABORT_BLOCK_NSRESULT;
 }
 
-NS_IMETHODIMP nsCocoaWindow::Resize(PRInt32 aWidth, PRInt32 aHeight, PRBool aRepaint)
+NS_IMETHODIMP nsCocoaWindow::Resize(PRInt32 aWidth, PRInt32 aHeight, bool aRepaint)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
   
@@ -1247,7 +1245,7 @@ NS_IMETHODIMP nsCocoaWindow::SetTitle(const nsAString& aTitle)
   NS_OBJC_END_TRY_ABORT_BLOCK_NSRESULT;
 }
 
-NS_IMETHODIMP nsCocoaWindow::Invalidate(const nsIntRect & aRect, PRBool aIsSynchronous)
+NS_IMETHODIMP nsCocoaWindow::Invalidate(const nsIntRect & aRect, bool aIsSynchronous)
 {
   if (mPopupContentView)
     return mPopupContentView->Invalidate(aRect, aIsSynchronous);
@@ -1270,20 +1268,20 @@ NS_IMETHODIMP nsCocoaWindow::Update()
 // a drop, to a drag enter/leave, or a drag over event. The actual event
 // is passed in |aMessage| and is passed along to our event hanlder so Gecko
 // knows about it.
-PRBool nsCocoaWindow::DragEvent(unsigned int aMessage, Point aMouseGlobal, UInt16 aKeyModifiers)
+bool nsCocoaWindow::DragEvent(unsigned int aMessage, Point aMouseGlobal, UInt16 aKeyModifiers)
 {
-  return PR_FALSE;
+  return false;
 }
 
 NS_IMETHODIMP nsCocoaWindow::SendSetZLevelEvent()
 {
-  nsZLevelEvent event(PR_TRUE, NS_SETZLEVEL, this);
+  nsZLevelEvent event(true, NS_SETZLEVEL, this);
 
   event.refPoint.x = mBounds.x;
   event.refPoint.y = mBounds.y;
   event.time = PR_IntervalNow();
 
-  event.mImmediate = PR_TRUE;
+  event.mImmediate = true;
 
   nsEventStatus status = nsEventStatus_eIgnore;
   DispatchEvent(&event, status);
@@ -1291,7 +1289,7 @@ NS_IMETHODIMP nsCocoaWindow::SendSetZLevelEvent()
   return NS_OK;
 }
 
-NS_IMETHODIMP nsCocoaWindow::GetChildSheet(PRBool aShown, nsCocoaWindow** _retval)
+NS_IMETHODIMP nsCocoaWindow::GetChildSheet(bool aShown, nsCocoaWindow** _retval)
 {
   nsIWidget* child = GetFirstChild();
 
@@ -1320,9 +1318,9 @@ NS_IMETHODIMP nsCocoaWindow::GetRealParent(nsIWidget** parent)
   return NS_OK;
 }
 
-NS_IMETHODIMP nsCocoaWindow::GetIsSheet(PRBool* isSheet)
+NS_IMETHODIMP nsCocoaWindow::GetIsSheet(bool* isSheet)
 {
-  mWindowType == eWindowType_sheet ? *isSheet = PR_TRUE : *isSheet = PR_FALSE;
+  mWindowType == eWindowType_sheet ? *isSheet = true : *isSheet = false;
   return NS_OK;
 }
 
@@ -1371,7 +1369,7 @@ nsCocoaWindow::ReportMoveEvent()
   UpdateBounds();
 
   // Dispatch the move event to Gecko
-  nsGUIEvent guiEvent(PR_TRUE, NS_MOVE, this);
+  nsGUIEvent guiEvent(true, NS_MOVE, this);
   guiEvent.refPoint.x = mBounds.x;
   guiEvent.refPoint.y = mBounds.y;
   guiEvent.time = PR_IntervalNow();
@@ -1384,7 +1382,7 @@ nsCocoaWindow::ReportMoveEvent()
 void
 nsCocoaWindow::DispatchSizeModeEvent()
 {
-  nsSizeModeEvent event(PR_TRUE, NS_SIZEMODE, this);
+  nsSizeModeEvent event(true, NS_SIZEMODE, this);
   event.mSizeMode = GetWindowSizeMode(mWindow);
   event.time = PR_IntervalNow();
 
@@ -1399,7 +1397,7 @@ nsCocoaWindow::ReportSizeEvent()
 
   UpdateBounds();
 
-  nsSizeEvent sizeEvent(PR_TRUE, NS_SIZE, this);
+  nsSizeEvent sizeEvent(true, NS_SIZE, this);
   sizeEvent.time = PR_IntervalNow();
 
   nsIntRect innerBounds;
@@ -1430,7 +1428,7 @@ void nsCocoaWindow::SetMenuBar(nsMenuBarX *aMenuBar)
     mMenuBar->Paint();
 }
 
-NS_IMETHODIMP nsCocoaWindow::SetFocus(PRBool aState)
+NS_IMETHODIMP nsCocoaWindow::SetFocus(bool aState)
 {
   if (mPopupContentView) {
     mPopupContentView->SetFocus(aState);
@@ -1490,8 +1488,8 @@ nsMenuBarX* nsCocoaWindow::GetMenuBar()
 
 NS_IMETHODIMP nsCocoaWindow::CaptureRollupEvents(nsIRollupListener * aListener, 
                                                  nsIMenuRollup * aMenuRollup,
-                                                 PRBool aDoCapture, 
-                                                 PRBool aConsumeRollupEvent)
+                                                 bool aDoCapture, 
+                                                 bool aConsumeRollupEvent)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
 
@@ -1546,7 +1544,7 @@ NS_IMETHODIMP nsCocoaWindow::GetAttention(PRInt32 aCycleCount)
   NS_OBJC_END_TRY_ABORT_BLOCK_NSRESULT;
 }
 
-PRBool
+bool
 nsCocoaWindow::HasPendingInputEvent()
 {
   return nsChildView::DoHasPendingInputEvent();
@@ -1566,7 +1564,7 @@ NS_IMETHODIMP nsCocoaWindow::SetWindowShadowStyle(PRInt32 aStyle)
   NS_OBJC_END_TRY_ABORT_BLOCK_NSRESULT;
 }
 
-void nsCocoaWindow::SetShowsToolbarButton(PRBool aShow)
+void nsCocoaWindow::SetShowsToolbarButton(bool aShow)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK;
 
@@ -1575,7 +1573,7 @@ void nsCocoaWindow::SetShowsToolbarButton(PRBool aShow)
   NS_OBJC_END_TRY_ABORT_BLOCK;
 }
 
-NS_IMETHODIMP nsCocoaWindow::SetWindowTitlebarColor(nscolor aColor, PRBool aActive)
+NS_IMETHODIMP nsCocoaWindow::SetWindowTitlebarColor(nscolor aColor, bool aActive)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NSRESULT;
 
@@ -1610,7 +1608,7 @@ NS_IMETHODIMP nsCocoaWindow::SetWindowTitlebarColor(nscolor aColor, PRBool aActi
   NS_OBJC_END_TRY_ABORT_BLOCK_NSRESULT;
 }
 
-void nsCocoaWindow::SetDrawsInTitlebar(PRBool aState)
+void nsCocoaWindow::SetDrawsInTitlebar(bool aState)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK;
 
@@ -1683,12 +1681,12 @@ void nsCocoaWindow::SetPopupWindowLevel()
   }
 }
 
-PRBool nsCocoaWindow::IsChildInFailingLeftClickThrough(NSView *aChild)
+bool nsCocoaWindow::IsChildInFailingLeftClickThrough(NSView *aChild)
 {
   if ([aChild isKindOfClass:[ChildView class]]) {
     ChildView* childView = (ChildView*) aChild;
     if ([childView isInFailingLeftClickThrough])
-      return PR_TRUE;
+      return true;
   }
   NSArray* subviews = [aChild subviews];
   if (subviews) {
@@ -1696,21 +1694,21 @@ PRBool nsCocoaWindow::IsChildInFailingLeftClickThrough(NSView *aChild)
     for (NSUInteger i = 0; i < count; ++i) {
       NSView* aView = (NSView*) [subviews objectAtIndex:i];
       if (IsChildInFailingLeftClickThrough(aView))
-        return PR_TRUE;
+        return true;
     }
   }
-  return PR_FALSE;
+  return false;
 }
 
 // Don't focus a plugin if we're in a left click-through that will
 // fail (see [ChildView isInFailingLeftClickThrough]).  Called from
 // [ChildView shouldFocusPlugin].
-PRBool nsCocoaWindow::ShouldFocusPlugin()
+bool nsCocoaWindow::ShouldFocusPlugin()
 {
   if (IsChildInFailingLeftClickThrough([mWindow contentView]))
-    return PR_FALSE;
+    return false;
 
-  return PR_TRUE;
+  return true;
 }
 
 @implementation WindowDelegate
@@ -1768,8 +1766,8 @@ PRBool nsCocoaWindow::ShouldFocusPlugin()
 
   [super init];
   mGeckoWindow = geckoWind;
-  mToplevelActiveState = PR_FALSE;
-  mHasEverBeenZoomed = PR_FALSE;
+  mToplevelActiveState = false;
+  mHasEverBeenZoomed = false;
   return self;
 
   NS_OBJC_END_TRY_ABORT_BLOCK_NIL;
@@ -1873,7 +1871,7 @@ PRBool nsCocoaWindow::ShouldFocusPlugin()
 - (BOOL)windowShouldClose:(id)sender
 {
   // We only want to send NS_XUL_CLOSE and let gecko close the window
-  nsGUIEvent guiEvent(PR_TRUE, NS_XUL_CLOSE, mGeckoWindow);
+  nsGUIEvent guiEvent(true, NS_XUL_CLOSE, mGeckoWindow);
   guiEvent.time = PR_IntervalNow();
   nsEventStatus status = nsEventStatus_eIgnore;
   mGeckoWindow->DispatchEvent(&guiEvent, status);
@@ -1917,7 +1915,7 @@ PRBool nsCocoaWindow::ShouldFocusPlugin()
     return;
 
   nsEventStatus status = nsEventStatus_eIgnore;
-  nsGUIEvent focusGuiEvent(PR_TRUE, eventType, mGeckoWindow);
+  nsGUIEvent focusGuiEvent(true, eventType, mGeckoWindow);
   focusGuiEvent.time = PR_IntervalNow();
   mGeckoWindow->DispatchEvent(&focusGuiEvent, status);
 }
@@ -1946,7 +1944,7 @@ PRBool nsCocoaWindow::ShouldFocusPlugin()
   return mGeckoWindow;
 }
 
-- (PRBool)toplevelActiveState
+- (bool)toplevelActiveState
 {
   return mToplevelActiveState;
 }
@@ -1955,7 +1953,7 @@ PRBool nsCocoaWindow::ShouldFocusPlugin()
 {
   if (!mToplevelActiveState) {
     [self sendFocusEvent:NS_ACTIVATE];
-    mToplevelActiveState = PR_TRUE;
+    mToplevelActiveState = true;
   }
 }
 
@@ -1963,7 +1961,7 @@ PRBool nsCocoaWindow::ShouldFocusPlugin()
 {
   if (mToplevelActiveState) {
     [self sendFocusEvent:NS_DEACTIVATE];
-    mToplevelActiveState = PR_FALSE;
+    mToplevelActiveState = false;
   }
 }
 
@@ -2175,6 +2173,53 @@ static const NSString* kStateShowsToolbarButton = @"showsToolbarButton";
   [self tryToPerform:aSelector with:nil];
 }
 
+- (id)accessibilityAttributeValue:(NSString *)attribute
+{
+  id retval = [super accessibilityAttributeValue:attribute];
+
+  // The following works around a problem with Text-to-Speech on OS X 10.7.
+  // See bug 674612 for more info.
+  //
+  // When accessibility is off, AXUIElementCopyAttributeValue(), when called
+  // on an AXApplication object to get its AXFocusedUIElement attribute,
+  // always returns an AXWindow object (the actual browser window -- never a
+  // mozAccessible object).  This also happens with accessibility turned on,
+  // if no other object in the browser window has yet been focused.  But if
+  // the browser window has a title bar (as it currently always does), the
+  // AXWindow object will always have four "accessible" children, one of which
+  // is an AXStaticText object (the title bar's "title"; the other three are
+  // the close, minimize and zoom buttons).  This means that (for complicated
+  // reasons, for which see bug 674612) Text-to-Speech on OS X 10.7 will often
+  // "speak" the window title, no matter what text is selected, or even if no
+  // text at all is selected.  (This always happens when accessibility is off.
+  // It doesn't happen in Firefox releases because Apple has (on OS X 10.7)
+  // special-cased the handling of apps whose CFBundleIdentifier is
+  // org.mozilla.firefox.)
+  //
+  // We work around this problem by only returning AXChildren that are
+  // mozAccessible object or are one of the titlebar's buttons (which
+  // instantiate subclasses of NSButtonCell).
+  if (nsToolkit::OnLionOrLater() && [retval isKindOfClass:[NSArray class]] &&
+      [attribute isEqualToString:@"AXChildren"]) {
+    NSMutableArray *holder = [NSMutableArray arrayWithCapacity:10];
+    [holder addObjectsFromArray:(NSArray *)retval];
+    NSUInteger count = [holder count];
+    for (NSInteger i = count - 1; i >= 0; --i) {
+      id item = [holder objectAtIndex:i];
+      // Remove anything from holder that isn't one of the titlebar's buttons
+      // (which instantiate subclasses of NSButtonCell) or a mozAccessible
+      // object (or one of its subclasses).
+      if (![item isKindOfClass:[NSButtonCell class]] &&
+          ![item respondsToSelector:@selector(hasRepresentedView)]) {
+        [holder removeObjectAtIndex:i];
+      }
+    }
+    retval = [NSArray arrayWithArray:holder];
+  }
+
+  return retval;
+}
+
 @end
 
 // This class allows us to have a "unified toolbar" style window. It works like this:
@@ -2367,7 +2412,7 @@ static const NSString* kStateShowsToolbarButton = @"showsToolbarButton";
     if (!geckoWindow)
       return;
     nsEventStatus status = nsEventStatus_eIgnore;
-    nsGUIEvent guiEvent(PR_TRUE, NS_OS_TOOLBAR, geckoWindow);
+    nsGUIEvent guiEvent(true, NS_OS_TOOLBAR, geckoWindow);
     guiEvent.time = PR_IntervalNow();
     geckoWindow->DispatchEvent(&guiEvent, status);
   }
