@@ -53,17 +53,33 @@
 #include "nsIURL.h"
 #include "nsArrayEnumerator.h"
 #include "nsIStringBundle.h"
-#include "nsIPrefService.h"
-#include "nsIPrefBranch.h"
 #include "nsCocoaUtils.h"
+#include "nsToolkit.h"
+#include "mozilla/Preferences.h"
+
+using namespace mozilla;
 
 const float kAccessoryViewPadding = 5;
 const int   kSaveTypeControlTag = 1;
-const char  kLastTypeIndexPref[] = "filepicker.lastTypeIndex";
 
-static PRBool gCallSecretHiddenFileAPI = PR_FALSE;
+static bool gCallSecretHiddenFileAPI = false;
 const char kShowHiddenFilesPref[] = "filepicker.showHiddenFiles";
 
+/**
+ * This class is an observer of NSPopUpButton selection change.
+ */
+@interface NSPopUpButtonObserver : NSObject
+{
+  NSPopUpButton* mPopUpButton;
+  NSOpenPanel*   mOpenPanel;
+  nsFilePicker*  mFilePicker;
+}
+- (void) setPopUpButton:(NSPopUpButton*)aPopUpButton;
+- (void) setOpenPanel:(NSOpenPanel*)aOpenPanel;
+- (void) setFilePicker:(nsFilePicker*)aFilePicker;
+- (void) menuChangedItem:(NSNotification*)aSender;
+@end
+
 NS_IMPL_ISUPPORTS1(nsFilePicker, nsIFilePicker)
 
 // We never want to call the secret show hidden files API unless the pref
@@ -75,12 +91,9 @@ static void SetShowHiddenFileState(NSSavePanel* panel)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK;
 
-  PRBool show = PR_FALSE;
-  nsCOMPtr<nsIPrefBranch> prefs = do_GetService(NS_PREFSERVICE_CONTRACTID);
-  if (prefs) {
-    nsresult rv = prefs->GetBoolPref(kShowHiddenFilesPref, &show);
-    if (NS_SUCCEEDED(rv))
-      gCallSecretHiddenFileAPI = PR_TRUE;
+  bool show = false;
+  if (NS_SUCCEEDED(Preferences::GetBool(kShowHiddenFilesPref, &show))) {
+    gCallSecretHiddenFileAPI = true;
   }
 
   if (gCallSecretHiddenFileAPI) {
@@ -129,14 +142,6 @@ nsFilePicker::InitNative(nsIWidget *aParent, const nsAString& aTitle,
 {
   mTitle = aTitle;
   mMode = aMode;
-
-  // read in initial type index from prefs
-  nsCOMPtr<nsIPrefBranch> prefs = do_GetService(NS_PREFSERVICE_CONTRACTID);
-  if (prefs) {
-    int prefIndex;
-    if (NS_SUCCEEDED(prefs->GetIntPref(kLastTypeIndexPref, &prefIndex)))
-      mSelectedTypeIndex = prefIndex;
-  }
 }
 
 NSView* nsFilePicker::GetAccessoryView()
@@ -145,16 +150,20 @@ NSView* nsFilePicker::GetAccessoryView()
 
   NSView* accessoryView = [[[NSView alloc] initWithFrame:NSMakeRect(0, 0, 0, 0)] autorelease];
 
-  // get the localized string for "Save As:"
-  NSString* saveAsLabel = @"Save As:"; // backup in case we can't get a localized string
+  // Set a label's default value.
+  NSString* label = @"Format:";
+
+  // Try to get the localized string.
   nsCOMPtr<nsIStringBundleService> sbs = do_GetService(NS_STRINGBUNDLE_CONTRACTID);
   nsCOMPtr<nsIStringBundle> bundle;
   nsresult rv = sbs->CreateBundle("chrome://global/locale/filepicker.properties", getter_AddRefs(bundle));
   if (NS_SUCCEEDED(rv)) {
-    nsXPIDLString label;
-    bundle->GetStringFromName(NS_LITERAL_STRING("saveAsLabel").get(), getter_Copies(label));
-    if (label)
-      saveAsLabel = [NSString stringWithCharacters:label.get() length:label.Length()];
+    nsXPIDLString locaLabel;
+    bundle->GetStringFromName(NS_LITERAL_STRING("formatLabel").get(),
+			      getter_Copies(locaLabel));
+    if (locaLabel) {
+      label = [NSString stringWithCharacters:locaLabel.get() length:locaLabel.Length()];
+    }
   }
 
   // set up label text field
@@ -165,7 +174,7 @@ NSView* nsFilePicker::GetAccessoryView()
   [textField setBezeled:NO];
   [textField setBordered:NO];
   [textField setFont:[NSFont labelFontOfSize:13.0]];
-  [textField setStringValue:saveAsLabel];
+  [textField setStringValue:label];
   [textField setTag:0];
   [textField sizeToFit];
 
@@ -243,11 +252,11 @@ NS_IMETHODIMP nsFilePicker::Show(PRInt16 *retval)
   switch (mMode)
   {
     case modeOpen:
-      userClicksOK = GetLocalFiles(mTitle, mDefault, PR_FALSE, mFiles);
+      userClicksOK = GetLocalFiles(mTitle, false, mFiles);
       break;
     
     case modeOpenMultiple:
-      userClicksOK = GetLocalFiles(mTitle, mDefault, PR_TRUE, mFiles);
+      userClicksOK = GetLocalFiles(mTitle, true, mFiles);
       break;
       
     case modeSave:
@@ -270,9 +279,49 @@ NS_IMETHODIMP nsFilePicker::Show(PRInt16 *retval)
   return NS_OK;
 }
 
+static
+void UpdatePanelFileTypes(NSOpenPanel* aPanel, NSArray* aFilters)
+{
+  // If we show all file types, also "expose" bundles' contents.
+  [aPanel setTreatsFilePackagesAsDirectories:!aFilters];
+
+  [aPanel setAllowedFileTypes:aFilters];
+}
+
+@implementation NSPopUpButtonObserver
+- (void) setPopUpButton:(NSPopUpButton*)aPopUpButton
+{
+  mPopUpButton = aPopUpButton;
+}
+
+- (void) setOpenPanel:(NSOpenPanel*)aOpenPanel
+{
+  mOpenPanel = aOpenPanel;
+}
+
+- (void) setFilePicker:(nsFilePicker*)aFilePicker
+{
+  mFilePicker = aFilePicker;
+}
+
+- (void) menuChangedItem:(NSNotification *)aSender
+{
+  NS_OBJC_BEGIN_TRY_ABORT_BLOCK_RETURN;
+  PRInt32 selectedItem = [mPopUpButton indexOfSelectedItem];
+  if (selectedItem < 0) {
+    return;
+  }
+
+  mFilePicker->SetFilterIndex(selectedItem);
+  UpdatePanelFileTypes(mOpenPanel, mFilePicker->GetFilterList());
+
+  NS_OBJC_END_TRY_ABORT_BLOCK_RETURN();
+}
+@end
+
 // Use OpenPanel to do a GetFile. Returns |returnOK| if the user presses OK in the dialog. 
 PRInt16
-nsFilePicker::GetLocalFiles(const nsString& inTitle, const nsString& inDefaultName, PRBool inAllowMultiple, nsCOMArray<nsILocalFile>& outFiles)
+nsFilePicker::GetLocalFiles(const nsString& inTitle, bool inAllowMultiple, nsCOMArray<nsILocalFile>& outFiles)
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_RETURN;
 
@@ -281,10 +330,6 @@ nsFilePicker::GetLocalFiles(const nsString& inTitle, const nsString& inDefaultNa
 
   SetShowHiddenFileState(thePanel);
 
-  // Get filters
-  // filters may be null, if we should allow all file types.
-  NSArray *filters = GenerateFilterList();
-
   // Set the options for how the get file dialog will appear
   SetDialogTitle(inTitle, thePanel);
   [thePanel setAllowsMultipleSelection:inAllowMultiple];
@@ -293,12 +338,9 @@ nsFilePicker::GetLocalFiles(const nsString& inTitle, const nsString& inDefaultNa
   [thePanel setCanChooseFiles:YES];
   [thePanel setResolvesAliases:YES];        //this is default - probably doesn't need to be set
   
-  // if we show all file types, also "expose" bundles' contents.
-  if (!filters)
-    [thePanel setTreatsFilePackagesAsDirectories:NO];       
-
-  // set up default file name
-  NSString* defaultFilename = [NSString stringWithCharacters:(const unichar*)inDefaultName.get() length:inDefaultName.Length()];
+  // Get filters
+  // filters may be null, if we should allow all file types.
+  NSArray *filters = GetFilterList();
 
   // set up default directory
   NSString *theDir = PanelDefaultDirectory();
@@ -310,23 +352,63 @@ nsFilePicker::GetLocalFiles(const nsString& inTitle, const nsString& inDefaultNa
     theDir = @"/Applications/";
   }
 
+  // On 10.6+, we let users change the filters. Unfortunately, some methods
+  // are not available on 10.5 and without using them it happens to be buggy.
+  int result;
   nsCocoaUtils::PrepareForNativeAppModalDialog();
-  int result = [thePanel runModalForDirectory:theDir file:defaultFilename
-                types:filters];
+  if (mFilters.Length() > 1 && nsToolkit::OnSnowLeopardOrLater()) {
+    // [NSURL initWithString:] (below) throws an exception if URLString is nil.
+    if (!theDir) {
+      theDir = @"";
+    }
+
+    NSPopUpButtonObserver* observer = [[NSPopUpButtonObserver alloc] init];
+
+    NSView* accessoryView = GetAccessoryView();
+    [thePanel setAccessoryView:accessoryView];
+
+    [observer setPopUpButton:[accessoryView viewWithTag:kSaveTypeControlTag]];
+    [observer setOpenPanel:thePanel];
+    [observer setFilePicker:this];
+
+    [[NSNotificationCenter defaultCenter]
+      addObserver:observer
+      selector:@selector(menuChangedItem:)
+      name:NSMenuWillSendActionNotification object:nil];
+
+    [thePanel setDirectoryURL:[[NSURL alloc] initWithString:theDir]];
+    UpdatePanelFileTypes(thePanel, filters);
+    result = [thePanel runModal];
+
+    [[NSNotificationCenter defaultCenter] removeObserver:observer];
+    [observer release];
+  } else {
+    // If we show all file types, also "expose" bundles' contents.
+    if (!filters) {
+      [thePanel setTreatsFilePackagesAsDirectories:YES];
+    }
+    result = [thePanel runModalForDirectory:theDir file:nil types:filters];
+  }
   nsCocoaUtils::CleanUpAfterNativeAppModalDialog();
   
   if (result == NSFileHandlingPanelCancelButton)
     return retVal;
-  
-  // append each chosen file to our list
-  for (unsigned int i = 0; i < [[thePanel URLs] count]; i++) {
-    NSURL *theURL = [[thePanel URLs] objectAtIndex:i];
-    if (theURL) {
-      nsCOMPtr<nsILocalFile> localFile;
-      NS_NewLocalFile(EmptyString(), PR_TRUE, getter_AddRefs(localFile));
-      nsCOMPtr<nsILocalFileMac> macLocalFile = do_QueryInterface(localFile);
-      if (macLocalFile && NS_SUCCEEDED(macLocalFile->InitWithCFURL((CFURLRef)theURL)))
-        outFiles.AppendObject(localFile);
+
+  // Converts data from a NSArray of NSURL to the returned format.
+  // We should be careful to not call [thePanel URLs] more than once given that
+  // it creates a new array each time.
+  // We are using Fast Enumeration, thus the NSURL array is created once then
+  // iterated.
+  for (NSURL* url in [thePanel URLs]) {
+    if (!url) {
+      continue;
+    }
+
+    nsCOMPtr<nsILocalFile> localFile;
+    NS_NewLocalFile(EmptyString(), true, getter_AddRefs(localFile));
+    nsCOMPtr<nsILocalFileMac> macLocalFile = do_QueryInterface(localFile);
+    if (macLocalFile && NS_SUCCEEDED(macLocalFile->InitWithCFURL((CFURLRef)url))) {
+      outFiles.AppendObject(localFile);
     }
   }
 
@@ -375,7 +457,7 @@ nsFilePicker::GetLocalFolder(const nsString& inTitle, nsILocalFile** outFile)
   NSURL *theURL = [[thePanel URLs] objectAtIndex:0];
   if (theURL) {
     nsCOMPtr<nsILocalFile> localFile;
-    NS_NewLocalFile(EmptyString(), PR_TRUE, getter_AddRefs(localFile));
+    NS_NewLocalFile(EmptyString(), true, getter_AddRefs(localFile));
     nsCOMPtr<nsILocalFileMac> macLocalFile = do_QueryInterface(localFile);
     if (macLocalFile && NS_SUCCEEDED(macLocalFile->InitWithCFURL((CFURLRef)theURL))) {
       *outFile = localFile;
@@ -424,16 +506,12 @@ nsFilePicker::PutLocalFile(const nsString& inTitle, const nsString& inDefaultNam
   NSPopUpButton* popupButton = [accessoryView viewWithTag:kSaveTypeControlTag];
   if (popupButton) {
     mSelectedTypeIndex = [popupButton indexOfSelectedItem];
-    // save out to prefs for initializing other file picker instances
-    nsCOMPtr<nsIPrefBranch> prefs = do_GetService(NS_PREFSERVICE_CONTRACTID);
-    if (prefs)
-      prefs->SetIntPref(kLastTypeIndexPref, mSelectedTypeIndex);
   }
 
   NSURL* fileURL = [thePanel URL];
   if (fileURL) { 
     nsCOMPtr<nsILocalFile> localFile;
-    NS_NewLocalFile(EmptyString(), PR_TRUE, getter_AddRefs(localFile));
+    NS_NewLocalFile(EmptyString(), true, getter_AddRefs(localFile));
     nsCOMPtr<nsILocalFileMac> macLocalFile = do_QueryInterface(localFile);
     if (macLocalFile && NS_SUCCEEDED(macLocalFile->InitWithCFURL((CFURLRef)fileURL))) {
       *outFile = localFile;
@@ -452,60 +530,44 @@ nsFilePicker::PutLocalFile(const nsString& inTitle, const nsString& inDefaultNam
   NS_OBJC_END_TRY_ABORT_BLOCK_RETURN(0);
 }
 
-// Take the list of file types (in a nice win32-specific format) and fills up
-// an NSArray of them for the Open Panel.  Note: Will return nil if we should allow
-// all file types.
 NSArray *
-nsFilePicker::GenerateFilterList()
+nsFilePicker::GetFilterList()
 {
   NS_OBJC_BEGIN_TRY_ABORT_BLOCK_NIL;
 
-  NSArray *filterArray = nil;
-  if (mFilters.Length() > 0) {
-    // Set up our filter string
-    NSMutableString *giantFilterString = [[[NSMutableString alloc] initWithString:@""] autorelease];
-
-    // Loop through each of the filter strings
-    for (PRUint32 loop = 0; loop < mFilters.Length(); loop++) {
-      const nsString& filterWide = mFilters[loop];
-
-      // separate individual filters
-      if ([giantFilterString length] > 0)
-        [giantFilterString appendString:[NSString stringWithString:@";"]];
-
-      // handle special case filters
-      if (filterWide.Equals(NS_LITERAL_STRING("*"))) {
-        // if we'll allow all files, we won't bother parsing all other
-        // file types. just return early.
-        return nil;
-      }
-      else if (filterWide.Equals(NS_LITERAL_STRING("..apps"))) {
-        // this magic filter means that we should enable app bundles.
-        // translate it into a usable filter, and continue looping through 
-        // other filters.
-        [giantFilterString appendString:@"*.app"];
-        continue;
-      }
-      
-      if (filterWide.Length() > 0)
-        [giantFilterString appendString:[NSString stringWithCharacters:filterWide.get() length:filterWide.Length()]];
-    }
-    
-    // Now we clean stuff up.  Get rid of white spaces, "*"'s, and the odd period or two.
-    NSCharacterSet *aSet = [NSCharacterSet characterSetWithCharactersInString:[NSString stringWithString:@". *"]];
-    NSRange aRange = [giantFilterString rangeOfCharacterFromSet:aSet];
-    while (aRange.length) {
-      [giantFilterString replaceCharactersInRange:aRange withString:@""];
-      aRange = [giantFilterString rangeOfCharacterFromSet:aSet];
-    }   
-    // OK, if string isn't empty we'll make a new filter list
-    if ([giantFilterString length] > 0) {
-      // every time we find a semicolon, we've found a new filter.
-      // components SeparatedByString should do that for us.
-      filterArray = [[[NSArray alloc] initWithArray:[giantFilterString componentsSeparatedByString:@";"]] autorelease];
-    }
+  if (!mFilters.Length()) {
+    return nil;
   }
-  return filterArray;
+
+  if (mFilters.Length() <= (PRUint32)mSelectedTypeIndex) {
+    NS_WARNING("An out of range index has been selected. Using the first index instead.");
+    mSelectedTypeIndex = 0;
+  }
+
+  const nsString& filterWide = mFilters[mSelectedTypeIndex];
+  if (!filterWide.Length()) {
+    return nil;
+  }
+
+  if (filterWide.Equals(NS_LITERAL_STRING("*"))) {
+    return nil;
+  }
+
+  // The extensions in filterWide are in the format "*.ext" but are expected
+  // in the format "ext" by NSOpenPanel. So we need to filter some characters.
+  NSMutableString* filterString = [[[NSMutableString alloc] initWithString:
+                                    [NSString stringWithCharacters:filterWide.get()
+				              length:filterWide.Length()]] autorelease];
+  NSCharacterSet *set = [NSCharacterSet characterSetWithCharactersInString:
+                          [NSString stringWithString:@". *"]];
+  NSRange range = [filterString rangeOfCharacterFromSet:set];
+  while (range.length) {
+    [filterString replaceCharactersInRange:range withString:@""];
+    range = [filterString rangeOfCharacterFromSet:set];
+  }
+
+  return [[[NSArray alloc] initWithArray:
+           [filterString componentsSeparatedByString:@";"]] autorelease];
 
   NS_OBJC_END_TRY_ABORT_BLOCK_NIL;
 }
@@ -597,7 +659,12 @@ NS_IMETHODIMP nsFilePicker::SetDefaultExtension(const nsAString& aExtension)
 NS_IMETHODIMP
 nsFilePicker::AppendFilter(const nsAString& aTitle, const nsAString& aFilter)
 {
-  mFilters.AppendElement(aFilter);
+  // "..apps" has to be translated with native executable extensions.
+  if (aFilter.EqualsLiteral("..apps")) {
+    mFilters.AppendElement(NS_LITERAL_STRING("*.app"));
+  } else {
+    mFilters.AppendElement(aFilter);
+  }
   mTitles.AppendElement(aTitle);
   
   return NS_OK;
