@@ -35,6 +35,8 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
+#include "mozilla/Util.h"
+
 #include <gtk/gtk.h>
 
 #include "nsIFileURL.h"
@@ -59,6 +61,8 @@
 #include <hildon-fm-2/hildon/hildon-file-chooser-dialog.h>
 #endif
 
+using namespace mozilla;
+
 #define MAX_PREVIEW_SIZE 180
 
 nsILocalFile *nsFilePicker::mPrevDisplayDirectory = nsnull;
@@ -205,7 +209,7 @@ NS_IMPL_ISUPPORTS1(nsFilePicker, nsIFilePicker)
 nsFilePicker::nsFilePicker()
   : mMode(nsIFilePicker::modeOpen),
     mSelectedType(0),
-    mAllowURLs(PR_FALSE)
+    mAllowURLs(false)
 {
 }
 
@@ -218,7 +222,7 @@ ReadMultipleFiles(gpointer filename, gpointer array)
 {
   nsCOMPtr<nsILocalFile> localfile;
   nsresult rv = NS_NewNativeLocalFile(nsDependentCString(static_cast<char*>(filename)),
-                                      PR_FALSE,
+                                      false,
                                       getter_AddRefs(localfile));
   if (NS_SUCCEEDED(rv)) {
     nsCOMArray<nsILocalFile>& files = *static_cast<nsCOMArray<nsILocalFile>*>(array);
@@ -386,7 +390,7 @@ nsFilePicker::GetFiles(nsISimpleEnumerator **aFiles)
   return NS_ERROR_FAILURE;
 }
 
-PRBool
+bool
 confirm_overwrite_file(GtkWidget *parent, nsILocalFile* file)
 {
   nsCOMPtr<nsIStringBundleService> sbs = do_GetService(NS_STRINGBUNDLE_CONTRACTID);
@@ -394,7 +398,7 @@ confirm_overwrite_file(GtkWidget *parent, nsILocalFile* file)
   nsresult rv = sbs->CreateBundle("chrome://global/locale/filepicker.properties",
                                   getter_AddRefs(bundle));
   if (NS_FAILED(rv)) {
-    return PR_FALSE;
+    return false;
   }
 
   nsAutoString leafName;
@@ -408,7 +412,7 @@ confirm_overwrite_file(GtkWidget *parent, nsILocalFile* file)
   bundle->GetStringFromName(NS_LITERAL_STRING("confirmTitle").get(),
                             getter_Copies(title));
   bundle->FormatStringFromName(NS_LITERAL_STRING("confirmFileReplacing").get(),
-                               formatStrings, NS_ARRAY_LENGTH(formatStrings),
+                               formatStrings, ArrayLength(formatStrings),
                                getter_Copies(message));
 
   GtkWindow *parent_window = GTK_WINDOW(parent);
@@ -424,7 +428,7 @@ confirm_overwrite_file(GtkWidget *parent, nsILocalFile* file)
     gtk_window_group_add_window(parent_window->group, GTK_WINDOW(dialog));
   }
 
-  PRBool result = (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_YES);
+  bool result = (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_YES);
 
   gtk_widget_destroy(dialog);
 
@@ -548,7 +552,7 @@ nsFilePicker::Show(PRInt16 *aReturn)
     }
   }
 
-  gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER(file_chooser), PR_TRUE);
+  gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER(file_chooser), TRUE);
   gint response = gtk_dialog_run(GTK_DIALOG(file_chooser));
 
   switch (response) {
@@ -560,7 +564,7 @@ nsFilePicker::Show(PRInt16 *aReturn)
       nsCOMPtr<nsILocalFile> file;
       GetFile(getter_AddRefs(file));
       if (file) {
-        PRBool exists = PR_FALSE;
+        bool exists = false;
         file->Exists(&exists);
         if (exists)
           *aReturn = nsIFilePicker::returnReplace;
