@@ -73,14 +73,14 @@ nsWinGesture::UnregisterTouchWindowPtr nsWinGesture::unregisterTouchWindow = nsn
 nsWinGesture::GetTouchInputInfoPtr nsWinGesture::getTouchInputInfo = nsnull;
 nsWinGesture::CloseTouchInputHandlePtr nsWinGesture::closeTouchInputHandle = nsnull;
 
-static PRBool gEnableSingleFingerPanEvents = PR_FALSE;
+static bool gEnableSingleFingerPanEvents = false;
 
 nsWinGesture::nsWinGesture() :
-  mPanActive(PR_FALSE),
-  mFeedbackActive(PR_FALSE),
-  mXAxisFeedback(PR_FALSE),
-  mYAxisFeedback(PR_FALSE),
-  mPanInertiaActive(PR_FALSE)
+  mPanActive(false),
+  mFeedbackActive(false),
+  mXAxisFeedback(false),
+  mYAxisFeedback(false),
+  mPanInertiaActive(false)
 {
   (void)InitLibrary();
   mPixelScrollOverflow = 0;
@@ -88,12 +88,12 @@ nsWinGesture::nsWinGesture() :
 
 /* Load and shutdown */
 
-PRBool nsWinGesture::InitLibrary()
+bool nsWinGesture::InitLibrary()
 {
   if (getGestureInfo) {
-    return PR_TRUE;
+    return true;
   } else if (sLibraryHandle) {
-    return PR_FALSE;
+    return false;
   }
 
   sLibraryHandle = ::LoadLibraryW(kGestureLibraryName);
@@ -119,7 +119,7 @@ PRBool nsWinGesture::InitLibrary()
     getGestureExtraArgs    = nsnull;
     setGestureConfig       = nsnull;
     getGestureConfig       = nsnull;
-    return PR_FALSE;
+    return false;
   }
   
   if (!registerTouchWindow || !unregisterTouchWindow || !getTouchInputInfo || !closeTouchInputHandle) {
@@ -145,17 +145,17 @@ PRBool nsWinGesture::InitLibrary()
   // Check to see if we want single finger gesture input. Only do this once
   // for the app so we don't have to look it up on every window create.
   gEnableSingleFingerPanEvents =
-    Preferences::GetBool("gestures.enable_single_finger_input", PR_FALSE);
+    Preferences::GetBool("gestures.enable_single_finger_input", false);
 
-  return PR_TRUE;
+  return true;
 }
 
 #define GCOUNT 5
 
-PRBool nsWinGesture::SetWinGestureSupport(HWND hWnd, nsGestureNotifyEvent::ePanDirection aDirection)
+bool nsWinGesture::SetWinGestureSupport(HWND hWnd, nsGestureNotifyEvent::ePanDirection aDirection)
 {
   if (!getGestureInfo)
-    return PR_FALSE;
+    return false;
 
   GESTURECONFIG config[GCOUNT];
 
@@ -206,47 +206,47 @@ PRBool nsWinGesture::SetWinGestureSupport(HWND hWnd, nsGestureNotifyEvent::ePanD
 
 /* Helpers */
 
-PRBool nsWinGesture::IsAvailable()
+bool nsWinGesture::IsAvailable()
 {
   return getGestureInfo != nsnull;
 }
 
-PRBool nsWinGesture::RegisterTouchWindow(HWND hWnd)
+bool nsWinGesture::RegisterTouchWindow(HWND hWnd)
 {
   if (!registerTouchWindow)
-    return PR_FALSE;
+    return false;
 
   return registerTouchWindow(hWnd, TWF_WANTPALM);
 }
 
-PRBool nsWinGesture::UnregisterTouchWindow(HWND hWnd)
+bool nsWinGesture::UnregisterTouchWindow(HWND hWnd)
 {
   if (!unregisterTouchWindow)
-    return PR_FALSE;
+    return false;
 
   return unregisterTouchWindow(hWnd);
 }
 
-PRBool nsWinGesture::GetTouchInputInfo(HTOUCHINPUT hTouchInput, PRUint32 cInputs, PTOUCHINPUT pInputs)
+bool nsWinGesture::GetTouchInputInfo(HTOUCHINPUT hTouchInput, PRUint32 cInputs, PTOUCHINPUT pInputs)
 {
   if (!getTouchInputInfo)
-    return PR_FALSE;
+    return false;
 
   return getTouchInputInfo(hTouchInput, cInputs, pInputs, sizeof(TOUCHINPUT));
 }
 
-PRBool nsWinGesture::CloseTouchInputHandle(HTOUCHINPUT hTouchInput)
+bool nsWinGesture::CloseTouchInputHandle(HTOUCHINPUT hTouchInput)
 {
   if (!closeTouchInputHandle)
-    return PR_FALSE;
+    return false;
 
   return closeTouchInputHandle(hTouchInput);
 }
 
-PRBool nsWinGesture::GetGestureInfo(HGESTUREINFO hGestureInfo, PGESTUREINFO pGestureInfo)
+bool nsWinGesture::GetGestureInfo(HGESTUREINFO hGestureInfo, PGESTUREINFO pGestureInfo)
 {
   if (!getGestureInfo || !hGestureInfo || !pGestureInfo)
-    return PR_FALSE;
+    return false;
 
   ZeroMemory(pGestureInfo, sizeof(GESTUREINFO));
   pGestureInfo->cbSize = sizeof(GESTUREINFO);
@@ -254,63 +254,63 @@ PRBool nsWinGesture::GetGestureInfo(HGESTUREINFO hGestureInfo, PGESTUREINFO pGes
   return getGestureInfo(hGestureInfo, pGestureInfo);
 }
 
-PRBool nsWinGesture::CloseGestureInfoHandle(HGESTUREINFO hGestureInfo)
+bool nsWinGesture::CloseGestureInfoHandle(HGESTUREINFO hGestureInfo)
 {
   if (!getGestureInfo || !hGestureInfo)
-    return PR_FALSE;
+    return false;
 
   return closeGestureInfoHandle(hGestureInfo);
 }
 
-PRBool nsWinGesture::GetGestureExtraArgs(HGESTUREINFO hGestureInfo, UINT cbExtraArgs, PBYTE pExtraArgs)
+bool nsWinGesture::GetGestureExtraArgs(HGESTUREINFO hGestureInfo, UINT cbExtraArgs, PBYTE pExtraArgs)
 {
   if (!getGestureInfo || !hGestureInfo || !pExtraArgs)
-    return PR_FALSE;
+    return false;
 
   return getGestureExtraArgs(hGestureInfo, cbExtraArgs, pExtraArgs);
 }
 
-PRBool nsWinGesture::SetGestureConfig(HWND hWnd, UINT cIDs, PGESTURECONFIG pGestureConfig)
+bool nsWinGesture::SetGestureConfig(HWND hWnd, UINT cIDs, PGESTURECONFIG pGestureConfig)
 {
   if (!getGestureInfo || !pGestureConfig)
-    return PR_FALSE;
+    return false;
 
   return setGestureConfig(hWnd, 0, cIDs, pGestureConfig, sizeof(GESTURECONFIG));
 }
 
-PRBool nsWinGesture::GetGestureConfig(HWND hWnd, DWORD dwFlags, PUINT pcIDs, PGESTURECONFIG pGestureConfig)
+bool nsWinGesture::GetGestureConfig(HWND hWnd, DWORD dwFlags, PUINT pcIDs, PGESTURECONFIG pGestureConfig)
 {
   if (!getGestureInfo || !pGestureConfig)
-    return PR_FALSE;
+    return false;
 
   return getGestureConfig(hWnd, 0, dwFlags, pcIDs, pGestureConfig, sizeof(GESTURECONFIG));
 }
 
-PRBool nsWinGesture::BeginPanningFeedback(HWND hWnd)
+bool nsWinGesture::BeginPanningFeedback(HWND hWnd)
 {
   if (!beginPanningFeedback)
-    return PR_FALSE;
+    return false;
 
   return beginPanningFeedback(hWnd);
 }
 
-PRBool nsWinGesture::EndPanningFeedback(HWND hWnd)
+bool nsWinGesture::EndPanningFeedback(HWND hWnd)
 {
   if (!beginPanningFeedback)
-    return PR_FALSE;
+    return false;
 
   return endPanningFeedback(hWnd, TRUE);
 }
 
-PRBool nsWinGesture::UpdatePanningFeedback(HWND hWnd, LONG offsetX, LONG offsetY, BOOL fInInertia)
+bool nsWinGesture::UpdatePanningFeedback(HWND hWnd, LONG offsetX, LONG offsetY, BOOL fInInertia)
 {
   if (!beginPanningFeedback)
-    return PR_FALSE;
+    return false;
 
   return updatePanningFeedback(hWnd, offsetX, offsetY, fInInertia);
 }
 
-PRBool nsWinGesture::IsPanEvent(LPARAM lParam)
+bool nsWinGesture::IsPanEvent(LPARAM lParam)
 {
   GESTUREINFO gi;
 
@@ -319,17 +319,17 @@ PRBool nsWinGesture::IsPanEvent(LPARAM lParam)
 
   BOOL result = GetGestureInfo((HGESTUREINFO)lParam, &gi);
   if (!result)
-    return PR_FALSE;
+    return false;
 
   if (gi.dwID == GID_PAN)
-    return PR_TRUE;
+    return true;
 
-  return PR_FALSE;
+  return false;
 }
 
 /* Gesture event processing */
 
-PRBool
+bool
 nsWinGesture::ProcessGestureMessage(HWND hWnd, WPARAM wParam, LPARAM lParam, nsSimpleGestureEvent& evt)
 {
   GESTUREINFO gi;
@@ -339,7 +339,7 @@ nsWinGesture::ProcessGestureMessage(HWND hWnd, WPARAM wParam, LPARAM lParam, nsS
 
   BOOL result = GetGestureInfo((HGESTUREINFO)lParam, &gi);
   if (!result)
-    return PR_FALSE;
+    return false;
 
   // The coordinates of this event
   nsPointWin coord;
@@ -356,7 +356,7 @@ nsWinGesture::ProcessGestureMessage(HWND hWnd, WPARAM wParam, LPARAM lParam, nsS
     case GID_BEGIN:
     case GID_END:
       // These should always fall through to DefWndProc
-      return PR_FALSE;
+      return false;
       break;
 
     case GID_ZOOM:
@@ -434,10 +434,10 @@ nsWinGesture::ProcessGestureMessage(HWND hWnd, WPARAM wParam, LPARAM lParam, nsS
     break;
   }
 
-  return PR_TRUE;
+  return true;
 }
 
-PRBool
+bool
 nsWinGesture::ProcessPanMessage(HWND hWnd, WPARAM wParam, LPARAM lParam)
 {
   GESTUREINFO gi;
@@ -447,7 +447,7 @@ nsWinGesture::ProcessPanMessage(HWND hWnd, WPARAM wParam, LPARAM lParam)
 
   BOOL result = GetGestureInfo((HGESTUREINFO)lParam, &gi);
   if (!result)
-    return PR_FALSE;
+    return false;
 
   // The coordinates of this event
   nsPointWin coord;
@@ -461,7 +461,7 @@ nsWinGesture::ProcessPanMessage(HWND hWnd, WPARAM wParam, LPARAM lParam)
     case GID_BEGIN:
     case GID_END:
       // These should always fall through to DefWndProc
-      return PR_FALSE;
+      return false;
       break;
 
     // Setup pixel scroll events for both axis
@@ -470,8 +470,8 @@ nsWinGesture::ProcessPanMessage(HWND hWnd, WPARAM wParam, LPARAM lParam)
       if (gi.dwFlags & GF_BEGIN) {
         mPanIntermediate = coord;
         mPixelScrollDelta = 0;
-        mPanActive = PR_TRUE;
-        mPanInertiaActive = PR_FALSE;
+        mPanActive = true;
+        mPanInertiaActive = false;
       }
       else {
 
@@ -488,41 +488,41 @@ nsWinGesture::ProcessPanMessage(HWND hWnd, WPARAM wParam, LPARAM lParam)
         mPanIntermediate = coord;
 
         if (gi.dwFlags & GF_INERTIA)
-          mPanInertiaActive = PR_TRUE;
+          mPanInertiaActive = true;
 
         if (gi.dwFlags & GF_END) {
-          mPanActive = PR_FALSE;
-          mPanInertiaActive = PR_FALSE;
-          PanFeedbackFinalize(hWnd, PR_TRUE);
+          mPanActive = false;
+          mPanInertiaActive = false;
+          PanFeedbackFinalize(hWnd, true);
         }
       }
     }
     break;
   }
-  return PR_TRUE;
+  return true;
 }
 
-inline PRBool TestTransition(PRInt32 a, PRInt32 b)
+inline bool TestTransition(PRInt32 a, PRInt32 b)
 {
   // If a is zero, overflow is zero, implying the cursor has moved back to the start position.
   // If b is zero, cached overscroll is zero, implying feedback just begun. 
-  if (a == 0 || b == 0) return PR_TRUE;
+  if (a == 0 || b == 0) return true;
   // Test for different signs.
   return (a < 0) == (b < 0);
 }
 
 void
-nsWinGesture::UpdatePanFeedbackX(HWND hWnd, PRInt32 scrollOverflow, PRBool& endFeedback)
+nsWinGesture::UpdatePanFeedbackX(HWND hWnd, PRInt32 scrollOverflow, bool& endFeedback)
 {
   // If scroll overflow was returned indicating we panned past the bounds of
   // the scrollable view port, start feeback.
   if (scrollOverflow != 0) {
     if (!mFeedbackActive) {
       BeginPanningFeedback(hWnd);
-      mFeedbackActive = PR_TRUE;
+      mFeedbackActive = true;
     }      
-    endFeedback = PR_FALSE;
-    mXAxisFeedback = PR_TRUE;
+    endFeedback = false;
+    mXAxisFeedback = true;
     return;
   }
   
@@ -536,22 +536,22 @@ nsWinGesture::UpdatePanFeedbackX(HWND hWnd, PRInt32 scrollOverflow, PRBool& endF
 
     // Cache the total over scroll in pixels.
     mPixelScrollOverflow.x = newOverflow;
-    endFeedback = PR_FALSE;
+    endFeedback = false;
   }
 }
 
 void
-nsWinGesture::UpdatePanFeedbackY(HWND hWnd, PRInt32 scrollOverflow, PRBool& endFeedback)
+nsWinGesture::UpdatePanFeedbackY(HWND hWnd, PRInt32 scrollOverflow, bool& endFeedback)
 {
   // If scroll overflow was returned indicating we panned past the bounds of
   // the scrollable view port, start feeback.
   if (scrollOverflow != 0) {
     if (!mFeedbackActive) {
       BeginPanningFeedback(hWnd);
-      mFeedbackActive = PR_TRUE;
+      mFeedbackActive = true;
     }
-    endFeedback = PR_FALSE;
-    mYAxisFeedback = PR_TRUE;
+    endFeedback = false;
+    mYAxisFeedback = true;
     return;
   }
   
@@ -565,20 +565,20 @@ nsWinGesture::UpdatePanFeedbackY(HWND hWnd, PRInt32 scrollOverflow, PRBool& endF
 
     // Cache the total over scroll in pixels.
     mPixelScrollOverflow.y = newOverflow;
-    endFeedback = PR_FALSE;
+    endFeedback = false;
   }
 }
 
 void
-nsWinGesture::PanFeedbackFinalize(HWND hWnd, PRBool endFeedback)
+nsWinGesture::PanFeedbackFinalize(HWND hWnd, bool endFeedback)
 {
   if (!mFeedbackActive)
     return;
 
   if (endFeedback) {
-    mFeedbackActive = PR_FALSE;
-    mXAxisFeedback = PR_FALSE;
-    mYAxisFeedback = PR_FALSE;
+    mFeedbackActive = false;
+    mXAxisFeedback = false;
+    mYAxisFeedback = false;
     mPixelScrollOverflow = 0;
     EndPanningFeedback(hWnd);
     return;
@@ -587,7 +587,7 @@ nsWinGesture::PanFeedbackFinalize(HWND hWnd, PRBool endFeedback)
   UpdatePanningFeedback(hWnd, mPixelScrollOverflow.x, mPixelScrollOverflow.y, mPanInertiaActive);
 }
 
-PRBool
+bool
 nsWinGesture::PanDeltaToPixelScrollX(nsMouseScrollEvent& evt)
 {
   evt.delta = 0;
@@ -597,7 +597,7 @@ nsWinGesture::PanDeltaToPixelScrollX(nsMouseScrollEvent& evt)
   // panning back from a max feedback position. This keeps the original drag point
   // constant.
   if (mXAxisFeedback)
-    return PR_FALSE;
+    return false;
 
   if (mPixelScrollDelta.x != 0)
   {
@@ -608,12 +608,12 @@ nsWinGesture::PanDeltaToPixelScrollX(nsMouseScrollEvent& evt)
     evt.delta = mPixelScrollDelta.x;
     evt.refPoint.x = mPanRefPoint.x;
     evt.refPoint.y = mPanRefPoint.y;
-    return PR_TRUE;
+    return true;
   }
-  return PR_FALSE;
+  return false;
 }
 
-PRBool
+bool
 nsWinGesture::PanDeltaToPixelScrollY(nsMouseScrollEvent& evt)
 {
   evt.delta = 0;
@@ -623,7 +623,7 @@ nsWinGesture::PanDeltaToPixelScrollY(nsMouseScrollEvent& evt)
   // panning back from a max feedback position. This keeps the original drag point
   // constant.
   if (mYAxisFeedback)
-    return PR_FALSE;
+    return false;
 
   if (mPixelScrollDelta.y != 0)
   {
@@ -634,7 +634,7 @@ nsWinGesture::PanDeltaToPixelScrollY(nsMouseScrollEvent& evt)
     evt.delta = mPixelScrollDelta.y;
     evt.refPoint.x = mPanRefPoint.x;
     evt.refPoint.y = mPanRefPoint.y;
-    return PR_TRUE;
+    return true;
   }
-  return PR_FALSE;
+  return false;
 }
