@@ -40,7 +40,7 @@
 #ifndef nsAutoRef_h_
 #define nsAutoRef_h_
 
-#include "nscore.h" // for nsnull, PRBool
+#include "nscore.h" // for nsnull, bool
 
 template <class T> class nsSimpleRef;
 template <class T> class nsAutoRefBase;
@@ -301,7 +301,7 @@ public:
     }
     ThisClass& operator=(RawRef aRefToCopy)
     {
-        own(aRefToCopy);
+        this->own(aRefToCopy);
         SafeAddRef();
         return *this;
     }
@@ -323,7 +323,7 @@ protected:
     void SafeAddRef()
     {
         if (this->HaveResource())
-            AddRef(this->get());
+            this->AddRef(this->get());
     }
 };
 
@@ -548,7 +548,7 @@ protected:
     // provide this.  The function is permitted to always return true if the
     // default constructor is not accessible, or if Release (and AddRef) can
     // deal with void handles.
-    PRBool HaveResource() const
+    bool HaveResource() const
     {
         return mRawRef != Traits::Void();
     }
@@ -690,7 +690,7 @@ protected:
     void SafeRelease()
     {
         if (this->HaveResource())
-            Release(this->get());
+            this->Release(this->get());
     }
 };
 
