@@ -41,13 +41,14 @@
 #include "nsIServiceManager.h"
 #include "nsCOMPtr.h"
 #include "prthread.h"
-#include "prlock.h"
 #include "mozilla/Services.h"
 
+using namespace mozilla;
+
 static const PRUintn BAD_TLS_INDEX = (PRUintn) -1;
 
-#define CHECK_SERVICE_USE_OK() if (!lock) return NS_ERROR_NOT_INITIALIZED
-#define CHECK_MANAGER_USE_OK() if (!mService || !nsExceptionService::lock) return NS_ERROR_NOT_INITIALIZED
+#define CHECK_SERVICE_USE_OK() if (!sLock) return NS_ERROR_NOT_INITIALIZED
+#define CHECK_MANAGER_USE_OK() if (!mService || !nsExceptionService::sLock) return NS_ERROR_NOT_INITIALIZED
 
 // A key for our registered module providers hashtable
 class nsProviderKey : public nsHashKey {
@@ -58,7 +59,7 @@ public:
   PRUint32 HashCode(void) const {
     return mKey;
   }
-  PRBool Equals(const nsHashKey *aKey) const {
+  bool Equals(const nsHashKey *aKey) const {
     return mKey == ((const nsProviderKey *) aKey)->mKey;
   }
   nsHashKey *Clone() const {
@@ -96,7 +97,7 @@ PRInt32 nsExceptionManager::totalInstances = 0;
 // one per thread.
 // An exception if the destructor, which may be called on
 // the thread shutting down xpcom
-NS_IMPL_ISUPPORTS1(nsExceptionManager, nsIExceptionManager)
+NS_IMPL_THREADSAFE_ISUPPORTS1(nsExceptionManager, nsIExceptionManager)
 
 nsExceptionManager::nsExceptionManager(nsExceptionService *svc) :
   mNextThread(nsnull),
@@ -104,7 +105,7 @@ nsExceptionManager::nsExceptionManager(nsExceptionService *svc) :
 {
   /* member initializers and constructor code */
 #ifdef NS_DEBUG
-  PR_AtomicIncrement(&totalInstances);
+  PR_ATOMIC_INCREMENT(&totalInstances);
 #endif
 }
 
@@ -112,7 +113,7 @@ nsExceptionManager::~nsExceptionManager()
 {
   /* destructor code */
 #ifdef NS_DEBUG
-  PR_AtomicDecrement(&totalInstances);
+  PR_ATOMIC_DECREMENT(&totalInstances);
 #endif // NS_DEBUG
 }
 
@@ -144,7 +145,7 @@ NS_IMETHODIMP nsExceptionManager::GetExceptionFromProvider(nsresult rc, nsIExcep
 /* The Exception Service */
 
 PRUintn nsExceptionService::tlsIndex = BAD_TLS_INDEX;
-PRLock *nsExceptionService::lock = nsnull;
+Mutex *nsExceptionService::sLock = nsnull;
 nsExceptionManager *nsExceptionService::firstThread = nsnull;
 
 #ifdef NS_DEBUG
@@ -157,10 +158,10 @@ NS_IMPL_THREADSAFE_ISUPPORTS3(nsExceptionService,
                               nsIObserver)
 
 nsExceptionService::nsExceptionService()
-  : mProviders(4, PR_TRUE) /* small, thread-safe hashtable */
+  : mProviders(4, true) /* small, thread-safe hashtable */
 {
 #ifdef NS_DEBUG
-  if (PR_AtomicIncrement(&totalInstances)!=1) {
+  if (PR_ATOMIC_INCREMENT(&totalInstances)!=1) {
     NS_ERROR("The nsExceptionService is a singleton!");
   }
 #endif
@@ -170,15 +171,14 @@ nsExceptionService::nsExceptionService()
     status = PR_NewThreadPrivateIndex( &tlsIndex, ThreadDestruct );
     NS_ASSERTION(status==0, "ScriptErrorService could not allocate TLS storage.");
   }
-  lock = PR_NewLock();
-  NS_ASSERTION(lock, "Error allocating ExceptionService lock");
+  sLock = new Mutex("nsExceptionService.sLock");
 
   // observe XPCOM shutdown.
   nsCOMPtr<nsIObserverService> observerService =
     mozilla::services::GetObserverService();
   NS_ASSERTION(observerService, "Could not get observer service!");
   if (observerService)
-    observerService->AddObserver(this, NS_XPCOM_SHUTDOWN_OBSERVER_ID, PR_FALSE);
+    observerService->AddObserver(this, NS_XPCOM_SHUTDOWN_OBSERVER_ID, false);
 }
 
 nsExceptionService::~nsExceptionService()
@@ -186,14 +186,14 @@ nsExceptionService::~nsExceptionService()
   Shutdown();
   /* destructor code */
 #ifdef NS_DEBUG
-  PR_AtomicDecrement(&totalInstances);
+  PR_ATOMIC_DECREMENT(&totalInstances);
 #endif
 }
 
 /*static*/
 void nsExceptionService::ThreadDestruct( void *data )
 {
-  if (!lock) {
+  if (!sLock) {
     NS_WARNING("nsExceptionService ignoring thread destruction after shutdown");
     return;
   }
@@ -204,10 +204,10 @@ void nsExceptionService::ThreadDestruct( void *data )
 void nsExceptionService::Shutdown()
 {
   mProviders.Reset();
-  if (lock) {
+  if (sLock) {
     DropAllThreads();
-    PR_DestroyLock(lock);
-    lock = nsnull;
+    delete sLock;
+    sLock = nsnull;
   }
   PR_SetThreadPrivate(tlsIndex, nsnull);
 }
@@ -250,8 +250,6 @@ NS_IMETHODIMP nsExceptionService::GetCurrentExceptionManager(nsIExceptionManager
     if (mgr == nsnull) {
         // Stick the new exception object in with no reference count.
         mgr = new nsExceptionManager(this);
-        if (mgr == nsnull)
-            return NS_ERROR_OUT_OF_MEMORY;
         PR_SetThreadPrivate(tlsIndex, mgr);
         // The reference count is held in the thread-list
         AddThread(mgr);
@@ -323,11 +321,10 @@ nsExceptionService::DoGetExceptionFromProvider(nsresult errCode,
 // thread management
 /*static*/ void nsExceptionService::AddThread(nsExceptionManager *thread)
 {
-    PR_Lock(lock);
+    MutexAutoLock lock(*sLock);
     thread->mNextThread = firstThread;
     firstThread = thread;
     NS_ADDREF(thread);
-    PR_Unlock(lock);
 }
 
 /*static*/ void nsExceptionService::DoDropThread(nsExceptionManager *thread)
@@ -343,15 +340,13 @@ nsExceptionService::DoGetExceptionFromProvider(nsresult errCode,
 
 /*static*/ void nsExceptionService::DropThread(nsExceptionManager *thread)
 {
-    PR_Lock(lock);
+    MutexAutoLock lock(*sLock);
     DoDropThread(thread);
-    PR_Unlock(lock);
 }
 
 /*static*/ void nsExceptionService::DropAllThreads()
 {
-    PR_Lock(lock);
+    MutexAutoLock lock(*sLock);
     while (firstThread)
         DoDropThread(firstThread);
-    PR_Unlock(lock);
 }
