@@ -40,6 +40,7 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
+#include "mozilla/Util.h"
 
 #include "nsCOMPtr.h"
 #include "nsMemory.h"
@@ -308,7 +309,7 @@ MyFileSeek64(HANDLE aHandle, __int64 aDistance, DWORD aMoveMethod)
     return li.QuadPart;
 }
 
-static PRBool
+static bool
 IsShortcutPath(const nsAString &path)
 {
     // Under Windows, the shortcuts are just files with a ".lnk" extension. 
@@ -344,13 +345,13 @@ struct _MDFileDesc {
 
 struct PRFilePrivate {
     PRInt32 state;
-    PRBool nonblocking;
+    bool nonblocking;
     _PRTriStateBool inheritable;
     PRFileDesc *next;
     PRIntn lockCount;   /*   0: not locked
                          *  -1: a native lockfile call is in progress
                          * > 0: # times the file is locked */
-    PRBool  appendMode; 
+    bool    appendMode; 
     _MDFileDesc md;
 };
 
@@ -398,6 +399,10 @@ OpenFile(const nsAFlatString &name, PRIntn osflags, PRIntn mode,
       flag6 |= FILE_FLAG_DELETE_ON_CLOSE;
     }
 
+    if (osflags && nsILocalFile::OS_READAHEAD) {
+      flag6 |= FILE_FLAG_SEQUENTIAL_SCAN;
+    }
+
     HANDLE file = ::CreateFileW(name.get(), access,
                                 FILE_SHARE_READ|FILE_SHARE_WRITE,
                                 NULL, flags, flag6, NULL);
@@ -411,7 +416,7 @@ OpenFile(const nsAFlatString &name, PRIntn osflags, PRIntn mode,
     if (*fd) {
         // On Windows, _PR_HAVE_O_APPEND is not defined so that we have to
         // add it manually. (see |PR_Open| in nsprpub/pr/src/io/prfile.c)
-        (*fd)->secret->appendMode = (PR_APPEND & osflags) ? PR_TRUE : PR_FALSE;
+        (*fd)->secret->appendMode = (PR_APPEND & osflags) ? true : false;
         return NS_OK;
     }
 
@@ -480,7 +485,7 @@ struct nsDir
 {
     HANDLE   handle; 
     WIN32_FIND_DATAW data;
-    PRBool   firstEntry;
+    bool     firstEntry;
 };
 
 static nsresult
@@ -514,7 +519,7 @@ OpenDir(const nsAFlatString &name, nsDir * *dir)
         PR_Free(d);
         return ConvertWinError(GetLastError());
     }
-    d->firstEntry = PR_TRUE;
+    d->firstEntry = true;
 
     *dir = d;
     return NS_OK;
@@ -530,7 +535,7 @@ ReadDir(nsDir *dir, PRDirFlags flags, nsString& name)
         BOOL rv;
         if (dir->firstEntry)
         {
-            dir->firstEntry = PR_FALSE;
+            dir->firstEntry = false;
             rv = 1;
         } else
             rv = ::FindNextFileW(dir->handle, &(dir->data));
@@ -566,11 +571,12 @@ ReadDir(nsDir *dir, PRDirFlags flags, nsString& name)
 }
 
 static nsresult
-CloseDir(nsDir *d)
+CloseDir(nsDir *&d)
 {
     NS_ENSURE_ARG(d);
 
     BOOL isOk = FindClose(d->handle);
+    // PR_DELETE also nulls out the passed in pointer.
     PR_DELETE(d);
     return isOk ? NS_OK : ConvertWinError(GetLastError());
 }
@@ -613,7 +619,7 @@ class nsDirEnumerator : public nsISimpleEnumerator,
             return NS_OK;
         }
 
-        NS_IMETHOD HasMoreElements(PRBool *result)
+        NS_IMETHOD HasMoreElements(bool *result)
         {
             nsresult rv;
             if (mNext == nsnull && mDir)
@@ -628,9 +634,7 @@ class nsDirEnumerator : public nsISimpleEnumerator,
                     if (NS_FAILED(CloseDir(mDir)))
                         return NS_ERROR_FAILURE;
 
-                    mDir = nsnull;
-
-                    *result = PR_FALSE;
+                    *result = false;
                     return NS_OK;
                 }
 
@@ -654,7 +658,7 @@ class nsDirEnumerator : public nsISimpleEnumerator,
         NS_IMETHOD GetNext(nsISupports **result)
         {
             nsresult rv;
-            PRBool hasMore;
+            bool hasMore;
             rv = HasMoreElements(&hasMore);
             if (NS_FAILED(rv)) return rv;
 
@@ -668,7 +672,7 @@ class nsDirEnumerator : public nsISimpleEnumerator,
         NS_IMETHOD GetNextFile(nsIFile **result)
         {
             *result = nsnull;
-            PRBool hasMore = PR_FALSE;
+            bool hasMore = false;
             nsresult rv = HasMoreElements(&hasMore);
             if (NS_FAILED(rv) || !hasMore)
                 return rv;
@@ -686,7 +690,6 @@ class nsDirEnumerator : public nsISimpleEnumerator,
                 NS_ASSERTION(NS_SUCCEEDED(rv), "close failed");
                 if (NS_FAILED(rv))
                     return NS_ERROR_FAILURE;
-                mDir = nsnull;
             }
             return NS_OK;
         }
@@ -712,8 +715,8 @@ NS_IMPL_ISUPPORTS2(nsDirEnumerator, nsISimpleEnumerator, nsIDirectoryEnumerator)
 //-----------------------------------------------------------------------------
 
 nsLocalFile::nsLocalFile()
-  : mDirty(PR_TRUE)
-  , mFollowSymlinks(PR_FALSE)
+  : mDirty(true)
+  , mFollowSymlinks(false)
 {
 }
 
@@ -753,7 +756,7 @@ NS_IMPL_THREADSAFE_ISUPPORTS4(nsLocalFile,
 //-----------------------------------------------------------------------------
 
 nsLocalFile::nsLocalFile(const nsLocalFile& other)
-  : mDirty(PR_TRUE)
+  : mDirty(true)
   , mFollowSymlinks(other.mFollowSymlinks)
   , mWorkingPath(other.mWorkingPath)
 {
@@ -815,7 +818,7 @@ nsLocalFile::ResolveAndStat()
         || mFileInfo64.type != PR_FILE_FILE 
         || !IsShortcutPath(mWorkingPath))
     {
-        mDirty = PR_FALSE;
+        mDirty = false;
         return NS_OK;
     }
 
@@ -835,7 +838,7 @@ nsLocalFile::ResolveAndStat()
     if (NS_FAILED(rv))
         return rv;
 
-    mDirty = PR_FALSE;
+    mDirty = false;
     return NS_OK;
 }
 
@@ -1012,7 +1015,7 @@ nsLocalFile::Create(PRUint32 type, PRUint32 attributes)
         if (rv == NS_ERROR_FILE_ACCESS_DENIED)
         {
             // need to return already-exists for directories (bug 452217)
-            PRBool isdir;
+            bool isdir;
             if (NS_SUCCEEDED(IsDirectory(&isdir)) && isdir)
                 rv = NS_ERROR_FILE_ALREADY_EXISTS;
         } else if (NS_ERROR_FILE_NOT_FOUND == rv && 
@@ -1047,19 +1050,19 @@ NS_IMETHODIMP
 nsLocalFile::Append(const nsAString &node)
 {
     // append this path, multiple components are not permitted
-    return AppendInternal(PromiseFlatString(node), PR_FALSE);
+    return AppendInternal(PromiseFlatString(node), false);
 }
 
 NS_IMETHODIMP
 nsLocalFile::AppendRelativePath(const nsAString &node)
 {
     // append this path, multiple components are permitted
-    return AppendInternal(PromiseFlatString(node), PR_TRUE);
+    return AppendInternal(PromiseFlatString(node), true);
 }
 
 
 nsresult
-nsLocalFile::AppendInternal(const nsAFlatString &node, PRBool multipleComponents)
+nsLocalFile::AppendInternal(const nsAFlatString &node, bool multipleComponents)
 {
     if (node.IsEmpty())
         return NS_OK;
@@ -1387,8 +1390,8 @@ nsLocalFile::GetVersionInfoField(const char* aField, nsAString& _retval)
 nsresult
 nsLocalFile::CopySingleFile(nsIFile *sourceFile, nsIFile *destParent,
                             const nsAString &newName, 
-                            PRBool followSymlinks, PRBool move,
-                            PRBool skipNtfsAclReset)
+                            bool followSymlinks, bool move,
+                            bool skipNtfsAclReset)
 {
     nsresult rv;
     nsAutoString filePath;
@@ -1496,7 +1499,7 @@ nsLocalFile::CopySingleFile(nsIFile *sourceFile, nsIFile *destParent,
 }
 
 nsresult
-nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, PRBool followSymlinks, PRBool move)
+nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, bool followSymlinks, bool move)
 {
     nsCOMPtr<nsIFile> newParentDir = aParentDir;
     // check to see if this exists, otherwise return an error.
@@ -1522,7 +1525,7 @@ nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, PRBool foll
         return NS_ERROR_FILE_DESTINATION_NOT_DIR;
 
     // make sure it exists and is a directory.  Create it if not there.
-    PRBool exists;
+    bool exists;
     newParentDir->Exists(&exists);
     if (!exists)
     {
@@ -1532,13 +1535,13 @@ nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, PRBool foll
     }
     else
     {
-        PRBool isDir;
+        bool isDir;
         newParentDir->IsDirectory(&isDir);
         if (!isDir)
         {
             if (followSymlinks)
             {
-                PRBool isLink;
+                bool isLink;
                 newParentDir->IsSymlink(&isLink);
                 if (isLink)
                 {
@@ -1565,10 +1568,10 @@ nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, PRBool foll
     }
 
     // Try different ways to move/copy files/directories
-    PRBool done = PR_FALSE;
-    PRBool isDir;
+    bool done = false;
+    bool isDir;
     IsDirectory(&isDir);
-    PRBool isSymlink;
+    bool isSymlink;
     IsSymlink(&isSymlink);
 
     // Try to move the file or directory, or try to copy a single file (or non-followed symlink)
@@ -1597,7 +1600,7 @@ nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, PRBool foll
         nsAutoString allocatedNewName;
         if (newName.IsEmpty())
         {
-            PRBool isLink;
+            bool isLink;
             IsSymlink(&isLink);
             if (isLink)
             {
@@ -1637,7 +1640,7 @@ nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, PRBool foll
         else
         {
             // check if the destination directory is writable and empty
-            PRBool isWritable;
+            bool isWritable;
 
             target->IsWritable(&isWritable);
             if (!isWritable)
@@ -1648,7 +1651,7 @@ nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, PRBool foll
             if (NS_FAILED(rv))
                 return rv;
 
-            PRBool more;
+            bool more;
             targetIterator->HasMoreElements(&more);
             // return error if target directory is not empty
             if (more)
@@ -1663,7 +1666,7 @@ nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, PRBool foll
             return rv;
         }
 
-        PRBool more;
+        bool more;
         while (NS_SUCCEEDED(dirEnum.HasMoreElements(&more)) && more)
         {
             nsCOMPtr<nsISupports> item;
@@ -1672,7 +1675,7 @@ nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, PRBool foll
             file = do_QueryInterface(item);
             if (file)
             {
-                PRBool isDir, isLink;
+                bool isDir, isLink;
 
                 file->IsDirectory(&isDir);
                 file->IsSymlink(&isLink);
@@ -1703,7 +1706,7 @@ nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, PRBool foll
         // to the new location.  nothing should be left in the folder.
         if (move)
         {
-          rv = Remove(PR_FALSE /* recursive */);
+          rv = Remove(false /* recursive */);
           NS_ENSURE_SUCCESS(rv,rv);
         }
     }
@@ -1741,19 +1744,19 @@ nsLocalFile::CopyMove(nsIFile *aParentDir, const nsAString &newName, PRBool foll
 NS_IMETHODIMP
 nsLocalFile::CopyTo(nsIFile *newParentDir, const nsAString &newName)
 {
-    return CopyMove(newParentDir, newName, PR_FALSE, PR_FALSE);
+    return CopyMove(newParentDir, newName, false, false);
 }
 
 NS_IMETHODIMP
 nsLocalFile::CopyToFollowingLinks(nsIFile *newParentDir, const nsAString &newName)
 {
-    return CopyMove(newParentDir, newName, PR_TRUE, PR_FALSE);
+    return CopyMove(newParentDir, newName, true, false);
 }
 
 NS_IMETHODIMP
 nsLocalFile::MoveTo(nsIFile *newParentDir, const nsAString &newName)
 {
-    return CopyMove(newParentDir, newName, PR_FALSE, PR_TRUE);
+    return CopyMove(newParentDir, newName, false, true);
 }
 
 
@@ -1763,7 +1766,7 @@ nsLocalFile::Load(PRLibrary * *_retval)
     // Check we are correctly initialized.
     CHECK_mWorkingPath();
 
-    PRBool isFile;
+    bool isFile;
     nsresult rv = IsFile(&isFile);
 
     if (NS_FAILED(rv))
@@ -1773,7 +1776,7 @@ nsLocalFile::Load(PRLibrary * *_retval)
         return NS_ERROR_FILE_IS_DIRECTORY;
 
 #ifdef NS_BUILD_REFCNT_LOGGING
-    nsTraceRefcntImpl::SetActivityIsLegal(PR_FALSE);
+    nsTraceRefcntImpl::SetActivityIsLegal(false);
 #endif
 
     PRLibSpec libSpec;
@@ -1782,7 +1785,7 @@ nsLocalFile::Load(PRLibrary * *_retval)
     *_retval =  PR_LoadLibraryWithFlags(libSpec, 0);
 
 #ifdef NS_BUILD_REFCNT_LOGGING
-    nsTraceRefcntImpl::SetActivityIsLegal(PR_TRUE);
+    nsTraceRefcntImpl::SetActivityIsLegal(true);
 #endif
 
     if (*_retval)
@@ -1791,7 +1794,7 @@ nsLocalFile::Load(PRLibrary * *_retval)
 }
 
 NS_IMETHODIMP
-nsLocalFile::Remove(PRBool recursive)
+nsLocalFile::Remove(bool recursive)
 {
     // NOTE:
     //
@@ -1814,10 +1817,10 @@ nsLocalFile::Remove(PRBool recursive)
     // Check we are correctly initialized.
     CHECK_mWorkingPath();
 
-    PRBool isDir, isLink;
+    bool isDir, isLink;
     nsresult rv;
     
-    isDir = PR_FALSE;
+    isDir = false;
     rv = IsSymlink(&isLink);
     if (NS_FAILED(rv))
         return rv;
@@ -1840,7 +1843,7 @@ nsLocalFile::Remove(PRBool recursive)
             if (NS_FAILED(rv))
                 return rv;
 
-            PRBool more;
+            bool more;
             while (NS_SUCCEEDED(dirEnum.HasMoreElements(&more)) && more)
             {
                 nsCOMPtr<nsISupports> item;
@@ -1872,7 +1875,7 @@ nsLocalFile::GetLastModifiedTime(PRInt64 *aLastModifiedTime)
     NS_ENSURE_ARG(aLastModifiedTime);
  
     // get the modified time of the target as determined by mFollowSymlinks
-    // If PR_TRUE, then this will be for the target of the shortcut file, 
+    // If true, then this will be for the target of the shortcut file, 
     // otherwise it will be for the shortcut file itself (i.e. the same 
     // results as GetLastModifiedTimeOfLink)
 
@@ -1923,7 +1926,7 @@ nsLocalFile::SetLastModifiedTime(PRInt64 aLastModifiedTime)
         return rv;
 
     // set the modified time of the target as determined by mFollowSymlinks
-    // If PR_TRUE, then this will be for the target of the shortcut file, 
+    // If true, then this will be for the target of the shortcut file, 
     // otherwise it will be for the shortcut file itself (i.e. the same 
     // results as SetLastModifiedTimeOfLink)
 
@@ -1999,14 +2002,14 @@ nsLocalFile::GetPermissions(PRUint32 *aPermissions)
     NS_ENSURE_ARG(aPermissions);
 
     // get the permissions of the target as determined by mFollowSymlinks
-    // If PR_TRUE, then this will be for the target of the shortcut file, 
+    // If true, then this will be for the target of the shortcut file, 
     // otherwise it will be for the shortcut file itself (i.e. the same 
     // results as GetPermissionsOfLink)
     nsresult rv = ResolveAndStat();
     if (NS_FAILED(rv))
         return rv;
 
-    PRBool isWritable, isExecutable;
+    bool isWritable, isExecutable;
     IsWritable(&isWritable);
     IsExecutable(&isExecutable);
 
@@ -2035,7 +2038,7 @@ nsLocalFile::GetPermissionsOfLink(PRUint32 *aPermissions)
     if (word == INVALID_FILE_ATTRIBUTES)
         return NS_ERROR_FILE_INVALID_PATH;
 
-    PRBool isWritable = !(word & FILE_ATTRIBUTE_READONLY);
+    bool isWritable = !(word & FILE_ATTRIBUTE_READONLY);
     *aPermissions = PR_IRUSR|PR_IRGRP|PR_IROTH;         // all read
     if (isWritable)
         *aPermissions |= PR_IWUSR|PR_IWGRP|PR_IWOTH;    // all write
@@ -2051,7 +2054,7 @@ nsLocalFile::SetPermissions(PRUint32 aPermissions)
     CHECK_mWorkingPath();
 
     // set the permissions of the target as determined by mFollowSymlinks
-    // If PR_TRUE, then this will be for the target of the shortcut file, 
+    // If true, then this will be for the target of the shortcut file, 
     // otherwise it will be for the shortcut file itself (i.e. the same 
     // results as SetPermissionsOfLink)
     nsresult rv = ResolveAndStat();
@@ -2235,13 +2238,13 @@ nsLocalFile::GetParent(nsIFile * *aParent)
 }
 
 NS_IMETHODIMP
-nsLocalFile::Exists(PRBool *_retval)
+nsLocalFile::Exists(bool *_retval)
 {
     // Check we are correctly initialized.
     CHECK_mWorkingPath();
 
     NS_ENSURE_ARG(_retval);
-    *_retval = PR_FALSE;
+    *_retval = false;
 
     MakeDirty();
     nsresult rv = ResolveAndStat();
@@ -2251,7 +2254,7 @@ nsLocalFile::Exists(PRBool *_retval)
 }
 
 NS_IMETHODIMP
-nsLocalFile::IsWritable(PRBool *aIsWritable)
+nsLocalFile::IsWritable(bool *aIsWritable)
 {
     // Check we are correctly initialized.
     CHECK_mWorkingPath();
@@ -2260,7 +2263,7 @@ nsLocalFile::IsWritable(PRBool *aIsWritable)
     // be deleted. It is still possible to modify the contents of the directory.
     nsresult rv = IsDirectory(aIsWritable);
     if (rv == NS_ERROR_FILE_ACCESS_DENIED) {
-      *aIsWritable = PR_TRUE;
+      *aIsWritable = true;
       return NS_OK;
     } else if (rv == NS_ERROR_FILE_IS_LOCKED) {
       // If the file is normally allowed write access
@@ -2274,7 +2277,7 @@ nsLocalFile::IsWritable(PRBool *aIsWritable)
     // writable if the file doesn't have the readonly attribute
     rv = HasFileAttribute(FILE_ATTRIBUTE_READONLY, aIsWritable);
     if (rv == NS_ERROR_FILE_ACCESS_DENIED) {
-        *aIsWritable = PR_FALSE;
+        *aIsWritable = false;
         return NS_OK;
     } else if (rv == NS_ERROR_FILE_IS_LOCKED) {
       // If the file is normally allowed write access
@@ -2305,36 +2308,36 @@ nsLocalFile::IsWritable(PRBool *aIsWritable)
 }
 
 NS_IMETHODIMP
-nsLocalFile::IsReadable(PRBool *_retval)
+nsLocalFile::IsReadable(bool *_retval)
 {
     // Check we are correctly initialized.
     CHECK_mWorkingPath();
 
     NS_ENSURE_ARG(_retval);
-    *_retval = PR_FALSE;
+    *_retval = false;
 
     nsresult rv = ResolveAndStat();
     if (NS_FAILED(rv))
         return rv;
 
-    *_retval = PR_TRUE;
+    *_retval = true;
     return NS_OK;
 }
 
 
 NS_IMETHODIMP
-nsLocalFile::IsExecutable(PRBool *_retval)
+nsLocalFile::IsExecutable(bool *_retval)
 {
     // Check we are correctly initialized.
     CHECK_mWorkingPath();
 
     NS_ENSURE_ARG(_retval);
-    *_retval = PR_FALSE;
+    *_retval = false;
     
     nsresult rv;
 
     // only files can be executables
-    PRBool isFile;
+    bool isFile;
     rv = IsFile(&isFile);
     if (NS_FAILED(rv))
         return rv;
@@ -2342,7 +2345,7 @@ nsLocalFile::IsExecutable(PRBool *_retval)
         return NS_OK;
 
     //TODO: shouldn't we be checking mFollowSymlinks here?
-    PRBool symLink;
+    bool symLink;
     rv = IsSymlink(&symLink);
     if (NS_FAILED(rv))
         return rv;
@@ -2445,10 +2448,10 @@ nsLocalFile::IsExecutable(PRBool *_retval)
             "wsf",
             "wsh"};
         nsDependentSubstring ext = Substring(path, dotIdx + 1);
-        for ( int i = 0; i < NS_ARRAY_LENGTH(executableExts); i++ ) {
+        for ( int i = 0; i < ArrayLength(executableExts); i++ ) {
             if ( ext.EqualsASCII(executableExts[i])) {
                 // Found a match.  Set result and quit.
-                *_retval = PR_TRUE;
+                *_retval = true;
                 break;
             }
         }
@@ -2459,7 +2462,7 @@ nsLocalFile::IsExecutable(PRBool *_retval)
 
 
 NS_IMETHODIMP
-nsLocalFile::IsDirectory(PRBool *_retval)
+nsLocalFile::IsDirectory(bool *_retval)
 {
     NS_ENSURE_ARG(_retval);
 
@@ -2472,7 +2475,7 @@ nsLocalFile::IsDirectory(PRBool *_retval)
 }
 
 NS_IMETHODIMP
-nsLocalFile::IsFile(PRBool *_retval)
+nsLocalFile::IsFile(bool *_retval)
 {
     NS_ENSURE_ARG(_retval);
 
@@ -2485,13 +2488,13 @@ nsLocalFile::IsFile(PRBool *_retval)
 }
 
 NS_IMETHODIMP
-nsLocalFile::IsHidden(PRBool *_retval)
+nsLocalFile::IsHidden(bool *_retval)
 {
     return HasFileAttribute(FILE_ATTRIBUTE_HIDDEN, _retval);
 }
 
 nsresult
-nsLocalFile::HasFileAttribute(DWORD fileAttrib, PRBool *_retval)
+nsLocalFile::HasFileAttribute(DWORD fileAttrib, bool *_retval)
 {
     NS_ENSURE_ARG(_retval);
 
@@ -2509,7 +2512,7 @@ nsLocalFile::HasFileAttribute(DWORD fileAttrib, PRBool *_retval)
 }
 
 NS_IMETHODIMP
-nsLocalFile::IsSymlink(PRBool *_retval)
+nsLocalFile::IsSymlink(bool *_retval)
 {
     // Check we are correctly initialized.
     CHECK_mWorkingPath();
@@ -2519,7 +2522,7 @@ nsLocalFile::IsSymlink(PRBool *_retval)
     // unless it is a valid shortcut path it's not a symlink
     if (!IsShortcutPath(mWorkingPath))
     {
-        *_retval = PR_FALSE;
+        *_retval = false;
         return NS_OK;
     }
 
@@ -2534,13 +2537,13 @@ nsLocalFile::IsSymlink(PRBool *_retval)
 }
 
 NS_IMETHODIMP
-nsLocalFile::IsSpecial(PRBool *_retval)
+nsLocalFile::IsSpecial(bool *_retval)
 {
     return HasFileAttribute(FILE_ATTRIBUTE_SYSTEM, _retval);
 }
 
 NS_IMETHODIMP
-nsLocalFile::Equals(nsIFile *inFile, PRBool *_retval)
+nsLocalFile::Equals(nsIFile *inFile, bool *_retval)
 {
     NS_ENSURE_ARG(inFile);
     NS_ENSURE_ARG(_retval);
@@ -2549,7 +2552,7 @@ nsLocalFile::Equals(nsIFile *inFile, PRBool *_retval)
 
     nsCOMPtr<nsILocalFileWin> lf(do_QueryInterface(inFile));
     if (!lf) {
-        *_retval = PR_FALSE;
+        *_retval = false;
         return NS_OK;
     }
 
@@ -2564,12 +2567,12 @@ nsLocalFile::Equals(nsIFile *inFile, PRBool *_retval)
 
 
 NS_IMETHODIMP
-nsLocalFile::Contains(nsIFile *inFile, PRBool recur, PRBool *_retval)
+nsLocalFile::Contains(nsIFile *inFile, bool recur, bool *_retval)
 {
     // Check we are correctly initialized.
     CHECK_mWorkingPath();
 
-    *_retval = PR_FALSE;
+    *_retval = false;
 
     nsAutoString myFilePath;
     if (NS_FAILED(GetTarget(myFilePath)))
@@ -2586,7 +2589,7 @@ nsLocalFile::Contains(nsIFile *inFile, PRBool recur, PRBool *_retval)
     {
         if (_wcsnicmp(myFilePath.get(), inFilePath.get(), myFilePathLen) == 0)
         {
-            *_retval = PR_TRUE;
+            *_retval = true;
         }
 
     }
@@ -2600,7 +2603,7 @@ nsLocalFile::GetTarget(nsAString &_retval)
 {
     _retval.Truncate();
 #if STRICT_FAKE_SYMLINKS
-    PRBool symLink;
+    bool symLink;
 
     nsresult rv = IsSymlink(&symLink);
     if (NS_FAILED(rv))
@@ -2618,15 +2621,15 @@ nsLocalFile::GetTarget(nsAString &_retval)
 }
 
 
-/* attribute PRBool followLinks; */
+/* attribute bool followLinks; */
 NS_IMETHODIMP
-nsLocalFile::GetFollowLinks(PRBool *aFollowLinks)
+nsLocalFile::GetFollowLinks(bool *aFollowLinks)
 {
     *aFollowLinks = mFollowSymlinks;
     return NS_OK;
 }
 NS_IMETHODIMP
-nsLocalFile::SetFollowLinks(PRBool aFollowLinks)
+nsLocalFile::SetFollowLinks(bool aFollowLinks)
 {
     MakeDirty();
     mFollowSymlinks = aFollowLinks;
@@ -2654,7 +2657,7 @@ nsLocalFile::GetDirectoryEntries(nsISimpleEnumerator * *entries)
         return NS_OK;
     }
 
-    PRBool isDir;
+    bool isDir;
     rv = IsDirectory(&isDir);
     if (NS_FAILED(rv))
         return rv;
@@ -2694,7 +2697,7 @@ nsLocalFile::SetPersistentDescriptor(const nsACString &aPersistentDescriptor)
 }   
 
 /* attrib unsigned long fileAttributesWin; */
-static PRBool IsXPOrGreater()
+static bool IsXPOrGreater()
 {
     OSVERSIONINFO osvi;
 
@@ -2799,7 +2802,7 @@ nsLocalFile::RevealUsingShell()
     return NS_ERROR_FAILURE;
   }
 
-  PRBool isDirectory;
+  bool isDirectory;
   nsresult rv = IsDirectory(&isDirectory);
   NS_ENSURE_SUCCESS(rv, rv);
 
@@ -2812,7 +2815,7 @@ nsLocalFile::RevealUsingShell()
     }
 
     const ITEMIDLIST* selection[] = { dir };
-    UINT count = PR_ARRAY_SIZE(selection);
+    UINT count = ArrayLength(selection);
 
     //Perform the open of the directory.
     hr = sSHOpenFolderAndSelectItems(dir, count, selection, 0);
@@ -2841,7 +2844,7 @@ nsLocalFile::RevealUsingShell()
     }
     
     const ITEMIDLIST* selection[] = { item };
-    UINT count = PR_ARRAY_SIZE(selection);
+    UINT count = ArrayLength(selection);
 
     //Perform the selection of the file.
     hr = sSHOpenFolderAndSelectItems(dir, count, selection, 0);
@@ -2921,7 +2924,7 @@ nsLocalFile::Launch()
 
 
 nsresult
-NS_NewLocalFile(const nsAString &path, PRBool followLinks, nsILocalFile* *result)
+NS_NewLocalFile(const nsAString &path, bool followLinks, nsILocalFile* *result)
 {
     nsLocalFile* file = new nsLocalFile();
     if (file == nsnull)
@@ -3090,7 +3093,7 @@ nsLocalFile::GetNativeTarget(nsACString &_retval)
 }
 
 nsresult
-NS_NewNativeLocalFile(const nsACString &path, PRBool followLinks, nsILocalFile* *result)
+NS_NewNativeLocalFile(const nsACString &path, bool followLinks, nsILocalFile* *result)
 {
     nsAutoString buf;
     nsresult rv = NS_CopyNativeToUnicode(path, buf);
@@ -3107,12 +3110,14 @@ nsLocalFile::EnsureShortPath()
     if (!mShortWorkingPath.IsEmpty())
         return;
 
-    WCHAR thisshort[MAX_PATH];
-    DWORD thisr = ::GetShortPathNameW(mWorkingPath.get(), thisshort,
-                                      sizeof(thisshort));
-    // If an error occurred (thisr == 0) thisshort is uninitialized memory!
-    if (thisr != 0 && thisr < sizeof(thisshort))
-        mShortWorkingPath.Assign(thisshort);
+    WCHAR shortPath[MAX_PATH + 1];
+    DWORD lengthNeeded = ::GetShortPathNameW(mWorkingPath.get(), shortPath,
+                                             ArrayLength(shortPath));
+    // If an error occurred then lengthNeeded is set to 0 or the length of the
+    // needed buffer including NULL termination.  If it succeeds the number of
+    // wide characters not including NULL termination is returned.
+    if (lengthNeeded != 0 && lengthNeeded < ArrayLength(shortPath))
+        mShortWorkingPath.Assign(shortPath);
     else
         mShortWorkingPath.Assign(mWorkingPath);
 }
@@ -3120,11 +3125,11 @@ nsLocalFile::EnsureShortPath()
 // nsIHashable
 
 NS_IMETHODIMP
-nsLocalFile::Equals(nsIHashable* aOther, PRBool *aResult)
+nsLocalFile::Equals(nsIHashable* aOther, bool *aResult)
 {
     nsCOMPtr<nsIFile> otherfile(do_QueryInterface(aOther));
     if (!otherfile) {
-        *aResult = PR_FALSE;
+        *aResult = false;
         return NS_OK;
     }
 
@@ -3203,7 +3208,7 @@ nsresult nsDriveEnumerator::Init()
     return NS_OK;
 }
 
-NS_IMETHODIMP nsDriveEnumerator::HasMoreElements(PRBool *aHasMore)
+NS_IMETHODIMP nsDriveEnumerator::HasMoreElements(bool *aHasMore)
 {
     *aHasMore = *mStartOfCurrentDrive != L'\0';
     return NS_OK;
@@ -3226,7 +3231,7 @@ NS_IMETHODIMP nsDriveEnumerator::GetNext(nsISupports **aNext)
     mStartOfCurrentDrive = ++driveEnd;
 
     nsILocalFile *file;
-    nsresult rv = NS_NewLocalFile(drive, PR_FALSE, &file);
+    nsresult rv = NS_NewLocalFile(drive, false, &file);
 
     *aNext = file;
     return rv;
