@@ -84,17 +84,17 @@ using namespace mozilla;
 class nsIAppShell;
 
 nsAppShellService::nsAppShellService() : 
-  mXPCOMWillShutDown(PR_FALSE),
-  mXPCOMShuttingDown(PR_FALSE),
+  mXPCOMWillShutDown(false),
+  mXPCOMShuttingDown(false),
   mModalWindowCount(0),
-  mApplicationProvidedHiddenWindow(PR_FALSE)
+  mApplicationProvidedHiddenWindow(false)
 {
   nsCOMPtr<nsIObserverService> obs
     (do_GetService("@mozilla.org/observer-service;1"));
 
   if (obs) {
-    obs->AddObserver(this, "xpcom-will-shutdown", PR_FALSE);
-    obs->AddObserver(this, "xpcom-shutdown", PR_FALSE);
+    obs->AddObserver(this, "xpcom-will-shutdown", false);
+    obs->AddObserver(this, "xpcom-shutdown", false);
   }
 }
 
@@ -111,7 +111,7 @@ NS_IMPL_ISUPPORTS2(nsAppShellService,
                    nsIObserver)
 
 NS_IMETHODIMP
-nsAppShellService::CreateHiddenWindow(nsIAppShell* aAppShell)
+nsAppShellService::CreateHiddenWindow()
 {
   nsresult rv;
   PRInt32 initialHeight = 100, initialWidth = 100;
@@ -121,7 +121,7 @@ nsAppShellService::CreateHiddenWindow(nsIAppShell* aAppShell)
   nsAdoptingCString prefVal =
       Preferences::GetCString("browser.hiddenWindowChromeURL");
   const char* hiddenWindowURL = prefVal.get() ? prefVal.get() : DEFAULT_HIDDENWINDOW_URL;
-  mApplicationProvidedHiddenWindow = prefVal.get() ? PR_TRUE : PR_FALSE;
+  mApplicationProvidedHiddenWindow = prefVal.get() ? true : false;
 #else
   static const char hiddenWindowURL[] = DEFAULT_HIDDENWINDOW_URL;
   PRUint32    chromeMask =  nsIWebBrowserChrome::CHROME_ALL;
@@ -134,7 +134,7 @@ nsAppShellService::CreateHiddenWindow(nsIAppShell* aAppShell)
   nsRefPtr<nsWebShellWindow> newWindow;
   rv = JustCreateTopWindow(nsnull, url,
                            chromeMask, initialWidth, initialHeight,
-                           PR_TRUE, aAppShell, getter_AddRefs(newWindow));
+                           true, getter_AddRefs(newWindow));
   NS_ENSURE_SUCCESS(rv, rv);
 
   mHiddenWindow.swap(newWindow);
@@ -167,7 +167,6 @@ nsAppShellService::CreateTopLevelWindow(nsIXULWindow *aParent,
                                         PRUint32 aChromeMask,
                                         PRInt32 aInitialWidth,
                                         PRInt32 aInitialHeight,
-                                        nsIAppShell* aAppShell,
                                         nsIXULWindow **aResult)
 
 {
@@ -179,7 +178,7 @@ nsAppShellService::CreateTopLevelWindow(nsIXULWindow *aParent,
   nsWebShellWindow *newWindow = nsnull;
   rv = JustCreateTopWindow(aParent, aUrl,
                            aChromeMask, aInitialWidth, aInitialHeight,
-                           PR_FALSE, aAppShell, &newWindow);  // addrefs
+                           false, &newWindow);  // addrefs
 
   *aResult = newWindow; // transfer ref
 
@@ -235,23 +234,23 @@ nsAppShellService::CalculateWindowZLevel(nsIXULWindow *aParent,
 /*
  * Checks to see if any existing window is currently in fullscreen mode.
  */
-static PRBool
+static bool
 CheckForFullscreenWindow()
 {
   nsCOMPtr<nsIWindowMediator> wm(do_GetService(NS_WINDOWMEDIATOR_CONTRACTID));
   if (!wm)
-    return PR_FALSE;
+    return false;
 
   nsCOMPtr<nsISimpleEnumerator> windowList;
   wm->GetXULWindowEnumerator(nsnull, getter_AddRefs(windowList));
   if (!windowList)
-    return PR_FALSE;
+    return false;
 
   for (;;) {
-    PRBool more = PR_FALSE;
+    bool more = false;
     windowList->HasMoreElements(&more);
     if (!more)
-      return PR_FALSE;
+      return false;
 
     nsCOMPtr<nsISupports> supportsWindow;
     windowList->GetNext(getter_AddRefs(supportsWindow));
@@ -262,11 +261,11 @@ CheckForFullscreenWindow()
       baseWin->GetMainWidget(getter_AddRefs(widget));
       if (widget && NS_SUCCEEDED(widget->GetSizeMode(&sizeMode)) && 
           sizeMode == nsSizeMode_Fullscreen) {
-        return PR_TRUE;
+        return true;
       }
     }
   }
-  return PR_FALSE;
+  return false;
 }
 #endif
 
@@ -279,8 +278,7 @@ nsAppShellService::JustCreateTopWindow(nsIXULWindow *aParent,
                                        PRUint32 aChromeMask,
                                        PRInt32 aInitialWidth,
                                        PRInt32 aInitialHeight,
-                                       PRBool aIsHiddenWindow,
-                                       nsIAppShell* aAppShell,
+                                       bool aIsHiddenWindow,
                                        nsWebShellWindow **aResult)
 {
   *aResult = nsnull;
@@ -298,7 +296,7 @@ nsAppShellService::JustCreateTopWindow(nsIXULWindow *aParent,
   // full screen states. This way new browser windows open on top of fullscreen
   // windows normally.
   if (window && CheckForFullscreenWindow())
-    window->IgnoreXULSizeMode(PR_TRUE);
+    window->IgnoreXULSizeMode(true);
 #endif
 
   nsWidgetInitData widgetInitData;
@@ -329,7 +327,7 @@ nsAppShellService::JustCreateTopWindow(nsIXULWindow *aParent,
 #if defined(XP_WIN)
   if (widgetInitData.mWindowType == eWindowType_toplevel ||
       widgetInitData.mWindowType == eWindowType_dialog)
-    widgetInitData.clipChildren = PR_TRUE;
+    widgetInitData.clipChildren = true;
 #endif
 
   // note default chrome overrides other OS chrome settings, but
@@ -365,24 +363,23 @@ nsAppShellService::JustCreateTopWindow(nsIXULWindow *aParent,
       aInitialHeight == nsIAppShellService::SIZE_TO_CONTENT) {
     aInitialWidth = 1;
     aInitialHeight = 1;
-    window->SetIntrinsicallySized(PR_TRUE);
+    window->SetIntrinsicallySized(true);
   }
 
-  PRBool center = aChromeMask & nsIWebBrowserChrome::CHROME_CENTER_SCREEN;
+  bool center = aChromeMask & nsIWebBrowserChrome::CHROME_CENTER_SCREEN;
 
   nsCOMPtr<nsIXULChromeRegistry> reg =
     mozilla::services::GetXULChromeRegistryService();
   if (reg) {
     nsCAutoString package;
     package.AssignLiteral("global");
-    PRBool isRTL = PR_FALSE;
+    bool isRTL = false;
     reg->IsLocaleRTL(package, &isRTL);
     widgetInitData.mRTL = isRTL;
   }
 
   nsresult rv = window->Initialize(parent, center ? aParent : nsnull,
-                                   aAppShell, aUrl,
-                                   aInitialWidth, aInitialHeight,
+                                   aUrl, aInitialWidth, aInitialHeight,
                                    aIsHiddenWindow, widgetInitData);
       
   NS_ENSURE_SUCCESS(rv, rv);
@@ -392,7 +389,7 @@ nsAppShellService::JustCreateTopWindow(nsIXULWindow *aParent,
     parent->AddChildWindow(*aResult);
 
   if (center)
-    rv = (*aResult)->Center(parent, parent ? PR_FALSE : PR_TRUE, PR_FALSE);
+    rv = (*aResult)->Center(parent, parent ? false : true, false);
 
   return rv;
 }
@@ -474,7 +471,7 @@ nsAppShellService::GetHiddenWindowAndJSContext(nsIDOMWindow **aWindow,
 }
 
 NS_IMETHODIMP
-nsAppShellService::GetApplicationProvidedHiddenWindow(PRBool* aAPHW)
+nsAppShellService::GetApplicationProvidedHiddenWindow(bool* aAPHW)
 {
     *aAPHW = mApplicationProvidedHiddenWindow;
     return NS_OK;
@@ -573,9 +570,9 @@ nsAppShellService::Observe(nsISupports* aSubject, const char *aTopic,
                            const PRUnichar *aData)
 {
   if (!strcmp(aTopic, "xpcom-will-shutdown")) {
-    mXPCOMWillShutDown = PR_TRUE;
+    mXPCOMWillShutDown = true;
   } else if (!strcmp(aTopic, "xpcom-shutdown")) {
-    mXPCOMShuttingDown = PR_TRUE;
+    mXPCOMShuttingDown = true;
     if (mHiddenWindow) {
       mHiddenWindow->Destroy();
     }
